from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_ST_STM32C0 = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'STM32C011D6Yx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32C011D6Yx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-12_1.70x1.42mm_P0.35mm_Stagger'], 'footprint':'Package_CSP:ST_WLCSP-12_1.70x1.42mm_P0.35mm_Stagger', 'keywords':'Arm Cortex-M0+ STM32C0 STM32C0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32c011d6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32C0.kicad_sym\nSTM32C011D6Yx\n\nArm Cortex-M0+ STM32C0 STM32C0x1', 'pins':[
            Pin(num='A2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PA8/PA9/PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA7/PA10/PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PA3/PA4/PA5/PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF2/PA0/PA1/PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32C011F_4-6_Px', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32C011F_4-6_Px'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'Arm Cortex-M0+ STM32C0 STM32C0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32c011f4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32C0.kicad_sym\nSTM32C011F_4-6_Px\n\nArm Cortex-M0+ STM32C0 STM32C0x1', 'pins':[
            Pin(num='1',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA9/PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA10/PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32C011F_4-6_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32C011F_4-6_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:ST_UFQFPN-20_3x3mm_P0.5mm'], 'footprint':'Package_DFN_QFN:ST_UFQFPN-20_3x3mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32C0 STM32C0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32c011f4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32C0.kicad_sym\nSTM32C011F_4-6_Ux\n\nArm Cortex-M0+ STM32C0 STM32C0x1', 'pins':[
            Pin(num='1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA9/PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA10/PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32C011J_4-6_Mx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32C011J_4-6_Mx'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Arm Cortex-M0+ STM32C0 STM32C0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32c011j4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32C0.kicad_sym\nSTM32C011J_4-6_Mx\n\nArm Cortex-M0+ STM32C0 STM32C0x1', 'pins':[
            Pin(num='1',name='PC14/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PF2/PA0/PA1/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA8/PA9/PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA10/PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC15/PA14/PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32C031C_4-6_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32C031C_4-6_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32C0 STM32C0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32c031c4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32C0.kicad_sym\nSTM32C031C_4-6_Tx\n\nArm Cortex-M0+ STM32C0 STM32C0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32C031C_4-6_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32C031C_4-6_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32C0 STM32C0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32c031c4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32C0.kicad_sym\nSTM32C031C_4-6_Ux\n\nArm Cortex-M0+ STM32C0 STM32C0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32C031F_4-6_Px', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32C031F_4-6_Px'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'Arm Cortex-M0+ STM32C0 STM32C0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32c031f4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32C0.kicad_sym\nSTM32C031F_4-6_Px\n\nArm Cortex-M0+ STM32C0 STM32C0x1', 'pins':[
            Pin(num='1',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA9/PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA10/PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32C031G_4-6_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32C031G_4-6_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28_4x4mm_P0.5mm'], 'footprint':'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32C0 STM32C0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32c031g4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32C0.kicad_sym\nSTM32C031G_4-6_Ux\n\nArm Cortex-M0+ STM32C0 STM32C0x1', 'pins':[
            Pin(num='1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32C031K_4-6_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32C031K_4-6_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32C0 STM32C0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32c031k4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32C0.kicad_sym\nSTM32C031K_4-6_Tx\n\nArm Cortex-M0+ STM32C0 STM32C0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32C031K_4-6_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32C031K_4-6_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32C0 STM32C0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32c031k4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32C0.kicad_sym\nSTM32C031K_4-6_Ux\n\nArm Cortex-M0+ STM32C0 STM32C0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32C011F4Px', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32C011F4Px'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'Arm Cortex-M0+ STM32C0 STM32C0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32c011f4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32C0.kicad_sym\nSTM32C011F4Px\n\nArm Cortex-M0+ STM32C0 STM32C0x1', 'pins':[
            Pin(num='1',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA9/PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA10/PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32C011F4Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32C011F4Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:ST_UFQFPN-20_3x3mm_P0.5mm', 'Package_DFN_QFN:ST_UFQFPN-20_3x3mm_P0.5mm'], 'footprint':'Package_DFN_QFN:ST_UFQFPN-20_3x3mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32C0 STM32C0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32c011f4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32C0.kicad_sym\nSTM32C011F4Ux\n\nArm Cortex-M0+ STM32C0 STM32C0x1', 'pins':[
            Pin(num='1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA9/PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA10/PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32C011F6Px', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32C011F6Px'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'Arm Cortex-M0+ STM32C0 STM32C0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32c011f6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32C0.kicad_sym\nSTM32C011F6Px\n\nArm Cortex-M0+ STM32C0 STM32C0x1', 'pins':[
            Pin(num='1',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA9/PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA10/PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32C011F6Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32C011F6Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:ST_UFQFPN-20_3x3mm_P0.5mm', 'Package_DFN_QFN:ST_UFQFPN-20_3x3mm_P0.5mm', 'Package_DFN_QFN:ST_UFQFPN-20_3x3mm_P0.5mm'], 'footprint':'Package_DFN_QFN:ST_UFQFPN-20_3x3mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32C0 STM32C0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32c011f6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32C0.kicad_sym\nSTM32C011F6Ux\n\nArm Cortex-M0+ STM32C0 STM32C0x1', 'pins':[
            Pin(num='1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA9/PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA10/PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32C011J4Mx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32C011J4Mx'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Arm Cortex-M0+ STM32C0 STM32C0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32c011j4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32C0.kicad_sym\nSTM32C011J4Mx\n\nArm Cortex-M0+ STM32C0 STM32C0x1', 'pins':[
            Pin(num='1',name='PC14/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PF2/PA0/PA1/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA8/PA9/PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA10/PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC15/PA14/PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32C011J6Mx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32C011J6Mx'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Arm Cortex-M0+ STM32C0 STM32C0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32c011j6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32C0.kicad_sym\nSTM32C011J6Mx\n\nArm Cortex-M0+ STM32C0 STM32C0x1', 'pins':[
            Pin(num='1',name='PC14/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PF2/PA0/PA1/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA8/PA9/PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA10/PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC15/PA14/PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32C031C4Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32C031C4Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32C0 STM32C0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32c031c4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32C0.kicad_sym\nSTM32C031C4Tx\n\nArm Cortex-M0+ STM32C0 STM32C0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32C031C4Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32C031C4Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32C0 STM32C0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32c031c4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32C0.kicad_sym\nSTM32C031C4Ux\n\nArm Cortex-M0+ STM32C0 STM32C0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32C031C6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32C031C6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32C0 STM32C0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32c031c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32C0.kicad_sym\nSTM32C031C6Tx\n\nArm Cortex-M0+ STM32C0 STM32C0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32C031C6Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32C031C6Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32C0 STM32C0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32c031c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32C0.kicad_sym\nSTM32C031C6Ux\n\nArm Cortex-M0+ STM32C0 STM32C0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32C031F4Px', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32C031F4Px'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'Arm Cortex-M0+ STM32C0 STM32C0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32c031f4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32C0.kicad_sym\nSTM32C031F4Px\n\nArm Cortex-M0+ STM32C0 STM32C0x1', 'pins':[
            Pin(num='1',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA9/PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA10/PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32C031F6Px', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32C031F6Px'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'Arm Cortex-M0+ STM32C0 STM32C0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32c031f6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32C0.kicad_sym\nSTM32C031F6Px\n\nArm Cortex-M0+ STM32C0 STM32C0x1', 'pins':[
            Pin(num='1',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA9/PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA10/PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32C031G4Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32C031G4Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm'], 'footprint':'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32C0 STM32C0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32c031g4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32C0.kicad_sym\nSTM32C031G4Ux\n\nArm Cortex-M0+ STM32C0 STM32C0x1', 'pins':[
            Pin(num='1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32C031G6Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32C031G6Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm'], 'footprint':'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32C0 STM32C0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32c031g6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32C0.kicad_sym\nSTM32C031G6Ux\n\nArm Cortex-M0+ STM32C0 STM32C0x1', 'pins':[
            Pin(num='1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32C031K4Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32C031K4Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32C0 STM32C0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32c031k4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32C0.kicad_sym\nSTM32C031K4Tx\n\nArm Cortex-M0+ STM32C0 STM32C0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32C031K4Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32C031K4Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32C0 STM32C0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32c031k4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32C0.kicad_sym\nSTM32C031K4Ux\n\nArm Cortex-M0+ STM32C0 STM32C0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32C031K6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32C031K6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32C0 STM32C0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32c031k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32C0.kicad_sym\nSTM32C031K6Tx\n\nArm Cortex-M0+ STM32C0 STM32C0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32C031K6Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32C031K6Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32C0 STM32C0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32c031k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32C0.kicad_sym\nSTM32C031K6Ux\n\nArm Cortex-M0+ STM32C0 STM32C0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])