from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Relay_SolidState = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'34.81-8240', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'34.81-8240'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Finder_34.81'], 'footprint':'OptoDevice:Finder_34.81', 'keywords':'Photo-Triac Opto Triac', 'description':'', 'datasheet':'https://gfinder.findernet.com/public/attachments/34/EN/S34USAEN.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\n34.81-8240\n\nPhoto-Triac Opto Triac', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'34.81-9024', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'34.81-9024'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Finder_34.81'], 'footprint':'OptoDevice:Finder_34.81', 'keywords':'NPN DC Optocoupler', 'description':'', 'datasheet':'http://www.us.liteon.com/downloads/LTV-817-827-847.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\n34.81-9024\n\nNPN DC Optocoupler', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH0213', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH0213'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8-N7_W7.62mm'], 'footprint':'Package_DIP:DIP-8-N7_W7.62mm', 'keywords':'Opto-Triac Opto Triac Zero Cross Solid State Relays', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH0213\n\nOpto-Triac Opto Triac Zero Cross Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH0213A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH0213A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm'], 'footprint':'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'keywords':'Opto-Triac Opto Triac Zero Cross Solid State Relays', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH0213A\n\nOpto-Triac Opto Triac Zero Cross Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH0223', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH0223'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8-N7_W7.62mm'], 'footprint':'Package_DIP:DIP-8-N7_W7.62mm', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH0223\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH0223A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH0223A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm'], 'footprint':'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH0223A\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ASSR-1218', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ASSR-1218'}), 'ref_prefix':'U', 'fplist':['Package_SO:SO-4_4.4x4.3mm_P2.54mm'], 'footprint':'Package_SO:SO-4_4.4x4.3mm_P2.54mm', 'keywords':'MOSFET Output Photorelay 1-Form-A', 'description':'', 'datasheet':'https://docs.broadcom.com/docs/AV02-0173EN', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nASSR-1218\n\nMOSFET Output Photorelay 1-Form-A', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CPC1002N', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CPC1002N'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOP-4_3.8x4.1mm_P2.54mm'], 'footprint':'Package_SO:SOP-4_3.8x4.1mm_P2.54mm', 'keywords':'MOSFET Output Photorelay 1-Form-A', 'description':'', 'datasheet':'http://www.ixysic.com/home/pdfs.nsf/www/CPC1002N.pdf/$file/CPC1002N.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nCPC1002N\n\nMOSFET Output Photorelay 1-Form-A', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CPC1017N', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CPC1017N'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOP-4_3.8x4.1mm_P2.54mm'], 'footprint':'Package_SO:SOP-4_3.8x4.1mm_P2.54mm', 'keywords':'MOSFET Output Photorelay 1-Form-A', 'description':'', 'datasheet':'http://www.ixysic.com/home/pdfs.nsf/www/CPC1017N.pdf/$file/CPC1017N.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nCPC1017N\n\nMOSFET Output Photorelay 1-Form-A', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FOD420', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FOD420'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-6_W7.62mm'], 'footprint':'Package_DIP:DIP-6_W7.62mm', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/FOD4218-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nFOD420\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FODM3011', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FODM3011'}), 'ref_prefix':'U', 'fplist':['Package_DIP:SMDIP-4_W7.62mm'], 'footprint':'Package_DIP:SMDIP-4_W7.62mm', 'keywords':'Opto-Triac Opto Triac Random Phase Mini-Flat', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/FODM3053_NF098-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nFODM3011\n\nOpto-Triac Opto Triac Random Phase Mini-Flat', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LCC110', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LCC110'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'MOSFET Output Photorelay 1-Form-C', 'description':'', 'datasheet':'http://www.ixysic.com/home/pdfs.nsf/www/LCC110.pdf/$file/LCC110.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nLCC110\n\nMOSFET Output Photorelay 1-Form-C', 'pins':[
            Pin(num='1',name='nc',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='nc',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3010M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3010M'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3023M-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3010M\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3031M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3031M'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3043M-D.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3031M\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'S102S01', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'S102S01'}), 'ref_prefix':'U', 'fplist':['Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight'], 'footprint':'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'keywords':'Opto-Triac Opto Triac Random Phase Solid State Relays', 'description':'', 'datasheet':'http://www.sharp-world.com/products/device/lineup/data/pdf/datasheet/s102s01_e.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nS102S01\n\nOpto-Triac Opto Triac Random Phase Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'S102S02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'S102S02'}), 'ref_prefix':'U', 'fplist':['Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight'], 'footprint':'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'keywords':'Opto-Triac Opto Triac Zero Cross Solid State Relays', 'description':'', 'datasheet':'http://www.sharp-world.com/products/device/lineup/data/pdf/datasheet/s102s02_e.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nS102S02\n\nOpto-Triac Opto Triac Zero Cross Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLP141G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP141G'}), 'ref_prefix':'U', 'fplist':['Package_SO:MFSOP6-5_4.4x3.6mm_P1.27mm'], 'footprint':'Package_SO:MFSOP6-5_4.4x3.6mm_P1.27mm', 'keywords':'OptoThyristor DC Optocoupler', 'description':'', 'datasheet':'http://datasheet.octopart.com/TLP141G(U,F)-Toshiba-datasheet-134958.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP141G\n\nOptoThyristor DC Optocoupler', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLP160G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP160G'}), 'ref_prefix':'U', 'fplist':['Package_SO:MFSOP6-4_4.4x3.6mm_P1.27mm'], 'footprint':'Package_SO:MFSOP6-4_4.4x3.6mm_P1.27mm', 'keywords':'Opto-Triac Opto Triac Random', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=16916&prodName=TLP160G', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP160G\n\nOpto-Triac Opto Triac Random', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLP161G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP161G'}), 'ref_prefix':'U', 'fplist':['Package_SO:MFSOP6-4_4.4x3.6mm_P1.27mm'], 'footprint':'Package_SO:MFSOP6-4_4.4x3.6mm_P1.27mm', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=16921&prodName=TLP161G', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP161G\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLP175A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP175A'}), 'ref_prefix':'U', 'fplist':['Package_SO:MFSOP6-4_4.4x3.6mm_P1.27mm'], 'footprint':'Package_SO:MFSOP6-4_4.4x3.6mm_P1.27mm', 'keywords':'MOSFET Output Photorelay 1-Form-A', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=13665&prodName=TLP175A', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP175A\n\nMOSFET Output Photorelay 1-Form-A', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLP222A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP222A'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-4_W7.62mm'], 'footprint':'Package_DIP:DIP-4_W7.62mm', 'keywords':'MOSFET Output Photorelay 1-Form-A', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=17036&prodName=TLP222A', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP222A\n\nMOSFET Output Photorelay 1-Form-A', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLP222A-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP222A-2'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Dual MOSFET Output Photorelay 1-Form-A', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=17036&prodName=TLP222A', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP222A-2\n\nDual MOSFET Output Photorelay 1-Form-A', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['8', '1', '2', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '3', '6', '5']}] }),
        Part(**{ 'name':'TLP3123', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP3123'}), 'ref_prefix':'U', 'fplist':['Package_SO:SO-4_4.4x3.9mm_P2.54mm'], 'footprint':'Package_SO:SO-4_4.4x3.9mm_P2.54mm', 'keywords':'MOSFET Output Photorelay 1-Form-A', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=10047&prodName=TLP3123', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP3123\n\nMOSFET Output Photorelay 1-Form-A', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLP3542', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP3542'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-5-6_W7.62mm'], 'footprint':'Package_DIP:DIP-5-6_W7.62mm', 'keywords':'photocouplers photorelay solidstate relay normally opened (1-Form-A)', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=1284&prodName=TLP3542', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP3542\n\nphotocouplers photorelay solidstate relay normally opened (1-Form-A)', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLP3543', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP3543'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-6_W7.62mm'], 'footprint':'Package_DIP:DIP-6_W7.62mm', 'keywords':'photocouplers photorelay solidstate relay normally opened (1-Form-A)', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=12660&prodName=TLP3543', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP3543\n\nphotocouplers photorelay solidstate relay normally opened (1-Form-A)', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'34.81-7048', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'34.81-7048'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Finder_34.81', 'OptoDevice:Finder_34.81'], 'footprint':'OptoDevice:Finder_34.81', 'keywords':'NPN DC Optocoupler', 'description':'', 'datasheet':'http://www.us.liteon.com/downloads/LTV-817-827-847.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\n34.81-7048\n\nNPN DC Optocoupler', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH1213', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH1213'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8-N7_W7.62mm', 'Package_DIP:DIP-8-N7_W7.62mm'], 'footprint':'Package_DIP:DIP-8-N7_W7.62mm', 'keywords':'Opto-Triac Opto Triac Zero Cross Solid State Relays', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH1213\n\nOpto-Triac Opto Triac Zero Cross Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH1213A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH1213A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm'], 'footprint':'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'keywords':'Opto-Triac Opto Triac Zero Cross Solid State Relays', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH1213A\n\nOpto-Triac Opto Triac Zero Cross Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH1223', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH1223'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8-N7_W7.62mm', 'Package_DIP:DIP-8-N7_W7.62mm'], 'footprint':'Package_DIP:DIP-8-N7_W7.62mm', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH1223\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH1223A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH1223A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm'], 'footprint':'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH1223A\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH2213', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH2213'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8-N7_W7.62mm', 'Package_DIP:DIP-8-N7_W7.62mm', 'Package_DIP:DIP-8-N7_W7.62mm'], 'footprint':'Package_DIP:DIP-8-N7_W7.62mm', 'keywords':'Opto-Triac Opto Triac Zero Cross Solid State Relays', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH2213\n\nOpto-Triac Opto Triac Zero Cross Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH2213A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH2213A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm'], 'footprint':'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'keywords':'Opto-Triac Opto Triac Zero Cross Solid State Relays', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH2213A\n\nOpto-Triac Opto Triac Zero Cross Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH2223', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH2223'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8-N7_W7.62mm', 'Package_DIP:DIP-8-N7_W7.62mm', 'Package_DIP:DIP-8-N7_W7.62mm'], 'footprint':'Package_DIP:DIP-8-N7_W7.62mm', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH2223\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH2223A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH2223A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm'], 'footprint':'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH2223A\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH3213', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH3213'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8-N7_W7.62mm', 'Package_DIP:DIP-8-N7_W7.62mm', 'Package_DIP:DIP-8-N7_W7.62mm', 'Package_DIP:DIP-8-N7_W7.62mm'], 'footprint':'Package_DIP:DIP-8-N7_W7.62mm', 'keywords':'Opto-Triac Opto Triac Zero Cross Solid State Relays', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH3213\n\nOpto-Triac Opto Triac Zero Cross Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH3213A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH3213A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm'], 'footprint':'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'keywords':'Opto-Triac Opto Triac Zero Cross Solid State Relays', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH3213A\n\nOpto-Triac Opto Triac Zero Cross Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH3223', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH3223'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8-N7_W7.62mm', 'Package_DIP:DIP-8-N7_W7.62mm', 'Package_DIP:DIP-8-N7_W7.62mm', 'Package_DIP:DIP-8-N7_W7.62mm'], 'footprint':'Package_DIP:DIP-8-N7_W7.62mm', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH3223\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AQH3223A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AQH3223A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm'], 'footprint':'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://mediap.industry.panasonic.eu/assets/imported/industrial.panasonic.com/ac/cdn/e/control/relay/solid-state/catalog/semi_eng_aqh.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nAQH3223A\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BC2213A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BC2213A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'Package_SO:SSO-8-7_6.4x9.7mm_P2.54mm'], 'footprint':'Package_SO:SSO-7-8_6.4x9.78mm_P2.54mm', 'keywords':'Opto-Triac Opto Triac Zero Cross Solid State Relays', 'description':'', 'datasheet':'https://wmsc.lcsc.com/wmsc/upload/file/pdf/v2/lcsc/2312161855_BC-BC2213A_C596512.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nBC2213A\n\nOpto-Triac Opto Triac Zero Cross Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CPC1117N', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CPC1117N'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOP-4_3.8x4.1mm_P2.54mm', 'Package_SO:SOP-4_3.8x4.1mm_P2.54mm'], 'footprint':'Package_SO:SOP-4_3.8x4.1mm_P2.54mm', 'keywords':'MOSFET Output Photorelay 1-Form-B NC', 'description':'', 'datasheet':'http://www.ixysic.com/home/pdfs.nsf/www/CPC1117N.pdf/$file/CPC1117N.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nCPC1117N\n\nMOSFET Output Photorelay 1-Form-B NC', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FOD4208', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FOD4208'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-6_W7.62mm', 'Package_DIP:DIP-6_W7.62mm'], 'footprint':'Package_DIP:DIP-6_W7.62mm', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/FOD4218-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nFOD4208\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FOD4216', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FOD4216'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-6_W7.62mm', 'Package_DIP:DIP-6_W7.62mm', 'Package_DIP:DIP-6_W7.62mm'], 'footprint':'Package_DIP:DIP-6_W7.62mm', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/FOD4218-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nFOD4216\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FOD4218', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FOD4218'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-6_W7.62mm', 'Package_DIP:DIP-6_W7.62mm', 'Package_DIP:DIP-6_W7.62mm', 'Package_DIP:DIP-6_W7.62mm'], 'footprint':'Package_DIP:DIP-6_W7.62mm', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/FOD4218-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nFOD4218\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FODM3012', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FODM3012'}), 'ref_prefix':'U', 'fplist':['Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm'], 'footprint':'Package_DIP:SMDIP-4_W7.62mm', 'keywords':'Opto-Triac Opto Triac Random Phase Mini-Flat', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/FODM3053_NF098-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nFODM3012\n\nOpto-Triac Opto Triac Random Phase Mini-Flat', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FODM3022', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FODM3022'}), 'ref_prefix':'U', 'fplist':['Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm'], 'footprint':'Package_DIP:SMDIP-4_W7.62mm', 'keywords':'Opto-Triac Opto Triac Random Phase Mini-Flat', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/FODM3053_NF098-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nFODM3022\n\nOpto-Triac Opto Triac Random Phase Mini-Flat', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FODM3023', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FODM3023'}), 'ref_prefix':'U', 'fplist':['Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm'], 'footprint':'Package_DIP:SMDIP-4_W7.62mm', 'keywords':'Opto-Triac Opto Triac Random Phase Mini-Flat', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/FODM3053_NF098-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nFODM3023\n\nOpto-Triac Opto Triac Random Phase Mini-Flat', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FODM3052', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FODM3052'}), 'ref_prefix':'U', 'fplist':['Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm'], 'footprint':'Package_DIP:SMDIP-4_W7.62mm', 'keywords':'Opto-Triac Opto Triac Random Phase Mini-Flat', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/FODM3053_NF098-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nFODM3052\n\nOpto-Triac Opto Triac Random Phase Mini-Flat', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FODM3053', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FODM3053'}), 'ref_prefix':'U', 'fplist':['Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm', 'Package_DIP:SMDIP-4_W7.62mm'], 'footprint':'Package_DIP:SMDIP-4_W7.62mm', 'keywords':'Opto-Triac Opto Triac Random Phase Mini-Flat', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/FODM3053_NF098-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nFODM3053\n\nOpto-Triac Opto Triac Random Phase Mini-Flat', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HHG1D-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HHG1D-1'}), 'ref_prefix':'U', 'fplist':['Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Relay_THT:Relay_NCR_HHG1D-1'], 'footprint':'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'keywords':'ssr', 'description':'', 'datasheet':'https://ncr.hk/uploads/Relays/Solid_State_Relays/HHG1D-1.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nHHG1D-1\n\nssr', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LAA110', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LAA110'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Dual MOSFET Output Photorelay 1-Form-A', 'description':'', 'datasheet':'http://www.clare.com/home/pdfs.nsf/www/LAA110.pdf/$file/LAA110.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nLAA110\n\nDual MOSFET Output Photorelay 1-Form-A', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '8', '1', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '6', '4', '5']}] }),
        Part(**{ 'name':'LBB110', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LBB110'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Dual MOSFET Output Photorelay 1-Form-B', 'description':'', 'datasheet':'http://www.ixysic.com/home/pdfs.nsf/www/LBB110.pdf/$file/LBB110.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nLBB110\n\nDual MOSFET Output Photorelay 1-Form-B', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '7', '2', '8']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '3', '5', '6']}] }),
        Part(**{ 'name':'MOC3011M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3011M'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3023M-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3011M\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3012M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3012M'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3023M-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3012M\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3020M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3020M'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3023M-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3020M\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3021M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3021M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3023M-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3021M\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3022M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3022M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3023M-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3022M\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3023M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3023M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3023M-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3023M\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3032M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3032M'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3043M-D.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3032M\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3033M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3033M'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3043M-D.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3033M\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3041M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3041M'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3043M-D.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3041M\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3042M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3042M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3043M-D.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3042M\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3043M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3043M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3043M-D.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3043M\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3051M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3051M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3052M-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3051M\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3052M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3052M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Random Phase', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3052M-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3052M\n\nOpto-Triac Opto Triac Random Phase', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3061M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3061M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3163M-D.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3061M\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3062M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3062M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3163M-D.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3062M\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3063M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3063M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3163M-D.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3063M\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3081M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3081M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3083M-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3081M\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3082M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3082M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3083M-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3082M\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3083M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3083M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3083M-D.PDF', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3083M\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3162M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3162M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3163M-D.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3162M\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MOC3163M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MOC3163M'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', '', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MOC3163M-D.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nMOC3163M\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'S112S01', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'S112S01'}), 'ref_prefix':'U', 'fplist':['Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight'], 'footprint':'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'keywords':'Opto-Triac Opto Triac Random Phase Solid State Relays', 'description':'', 'datasheet':'http://www.sharp-world.com/products/device/lineup/data/pdf/datasheet/s112s01_e.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nS112S01\n\nOpto-Triac Opto Triac Random Phase Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'S116S01', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'S116S01'}), 'ref_prefix':'U', 'fplist':['Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight'], 'footprint':'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'keywords':'Opto-Triac Opto Triac Random Phase Solid State Relays', 'description':'', 'datasheet':'http://www.sharp-world.com/products/device/lineup/data/pdf/datasheet/s116s01_e.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nS116S01\n\nOpto-Triac Opto Triac Random Phase Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'S116S02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'S116S02'}), 'ref_prefix':'U', 'fplist':['Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Relay_THT:Relay_NCR_HHG1D-1', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight'], 'footprint':'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'keywords':'Opto-Triac Opto Triac Zero Cross Solid State Relays', 'description':'', 'datasheet':'http://www.sharp-world.com/products/device/lineup/data/pdf/datasheet/s116s02_e.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nS116S02\n\nOpto-Triac Opto Triac Zero Cross Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'S202S01', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'S202S01'}), 'ref_prefix':'U', 'fplist':['Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight'], 'footprint':'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'keywords':'Opto-Triac Opto Triac Random Phase Solid State Relays', 'description':'', 'datasheet':'http://www.sharp-world.com/products/device/lineup/data/pdf/datasheet/s102s01_e.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nS202S01\n\nOpto-Triac Opto Triac Random Phase Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'S202S02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'S202S02'}), 'ref_prefix':'U', 'fplist':['Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Relay_THT:Relay_NCR_HHG1D-1', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight'], 'footprint':'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'keywords':'Opto-Triac Opto Triac Zero Cross Solid State Relays', 'description':'', 'datasheet':'http://www.sharp-world.com/products/device/lineup/data/pdf/datasheet/s102s02_e.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nS202S02\n\nOpto-Triac Opto Triac Zero Cross Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'S212S01', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'S212S01'}), 'ref_prefix':'U', 'fplist':['Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight'], 'footprint':'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'keywords':'Opto-Triac Opto Triac Random Phase Solid State Relays', 'description':'', 'datasheet':'http://www.sharp-world.com/products/device/lineup/data/pdf/datasheet/s112s01_e.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nS212S01\n\nOpto-Triac Opto Triac Random Phase Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'S216S01', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'S216S01'}), 'ref_prefix':'U', 'fplist':['Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight'], 'footprint':'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'keywords':'Opto-Triac Opto Triac Random Phase Solid State Relays', 'description':'', 'datasheet':'http://www.sharp-world.com/products/device/lineup/data/pdf/datasheet/s116s01_e.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nS216S01\n\nOpto-Triac Opto Triac Random Phase Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'S216S02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'S216S02'}), 'ref_prefix':'U', 'fplist':['Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Relay_THT:Relay_NCR_HHG1D-1', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight'], 'footprint':'Package_SIP:SIP4_Sharp-SSR_P7.62mm_Straight', 'keywords':'Opto-Triac Opto Triac Zero Cross Solid State Relays', 'description':'', 'datasheet':'http://www.sharp-world.com/products/device/lineup/data/pdf/datasheet/s116s02_e.pdf', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nS216S02\n\nOpto-Triac Opto Triac Zero Cross Solid State Relays', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLP148G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP148G'}), 'ref_prefix':'U', 'fplist':['Package_SO:MFSOP6-5_4.4x3.6mm_P1.27mm', 'Package_SO:MFSOP6-5_4.4x3.6mm_P1.27mm'], 'footprint':'Package_SO:MFSOP6-5_4.4x3.6mm_P1.27mm', 'keywords':'OptoThyristor DC Optocoupler', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=1019&prodName=TLP148G', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP148G\n\nOptoThyristor DC Optocoupler', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLP160J', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP160J'}), 'ref_prefix':'U', 'fplist':['Package_SO:MFSOP6-4_4.4x3.6mm_P1.27mm', 'Package_SO:MFSOP6-4_4.4x3.6mm_P1.27mm'], 'footprint':'Package_SO:MFSOP6-4_4.4x3.6mm_P1.27mm', 'keywords':'Opto-Triac Opto Triac Random', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=16919&prodName=TLP160J', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP160J\n\nOpto-Triac Opto Triac Random', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLP161J', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP161J'}), 'ref_prefix':'U', 'fplist':['Package_SO:MFSOP6-4_4.4x3.6mm_P1.27mm', 'Package_SO:MFSOP6-4_4.4x3.6mm_P1.27mm'], 'footprint':'Package_SO:MFSOP6-4_4.4x3.6mm_P1.27mm', 'keywords':'Opto-Triac Opto Triac Zero Cross', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=4207&prodName=TLP161J', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP161J\n\nOpto-Triac Opto Triac Zero Cross', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLP3544', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP3544'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-6_W7.62mm', 'Package_DIP:DIP-6_W7.62mm'], 'footprint':'Package_DIP:DIP-6_W7.62mm', 'keywords':'photocouplers photorelay solidstate relay normally opened (1-Form-A)', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=12661&prodName=TLP3544', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP3544\n\nphotocouplers photorelay solidstate relay normally opened (1-Form-A)', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLP3545', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP3545'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-6_W7.62mm', 'Package_DIP:DIP-6_W7.62mm', 'Package_DIP:DIP-6_W7.62mm'], 'footprint':'Package_DIP:DIP-6_W7.62mm', 'keywords':'photocouplers photorelay solidstate relay normally opened (1-Form-A)', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=12663&prodName=TLP3545', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP3545\n\nphotocouplers photorelay solidstate relay normally opened (1-Form-A)', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLP3546', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLP3546'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-6_W7.62mm', 'Package_DIP:DIP-6_W7.62mm', 'Package_DIP:DIP-6_W7.62mm', 'Package_DIP:DIP-6_W7.62mm'], 'footprint':'Package_DIP:DIP-6_W7.62mm', 'keywords':'photocouplers photorelay solidstate relay normally opened (1-Form-A)', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=12671&prodName=TLP3546', 'search_text':'/usr/share/kicad/symbols/Relay_SolidState.kicad_sym\nTLP3546\n\nphotocouplers photorelay solidstate relay normally opened (1-Form-A)', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] })])