# -*- coding: utf-8 -*-

# The MIT License (MIT) - Copyright (c) Dave Vandenbout.

"""
Constants used when generating schematics.
"""

# Constants for KiCad.
GRID = 50
PIN_LABEL_FONT_SIZE = 50
BOX_LABEL_FONT_SIZE = 50
BLK_INT_PAD = 2 * GRID
BLK_EXT_PAD = 2 * GRID
DRAWING_BOX_RESIZE = 100
HIER_TERM_SIZE = 50
