from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

RF_GSM = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'BC66', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BC66'}), 'ref_prefix':'U', 'fplist':['RF_GSM:Quectel_BC66'], 'footprint':'RF_GSM:Quectel_BC66', 'keywords':'NB-IoT Data SMS', 'description':'', 'datasheet':'https://www.quectel.com/UploadImage/Downlad/Quectel_BC66_Hardware_Design_V1.1.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GSM.kicad_sym\nBC66\n\nNB-IoT Data SMS', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SIM_GND',func=pin_types.PWROUT,unit=1),
            Pin(num='11',name='SIM_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SIM_RST',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='SIM_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='SIM_VDD',func=pin_types.PWROUT,unit=1),
            Pin(num='15',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='NETLIGHT',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='PSM_EINT',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='20',name='RI',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='24',name='VDD_EXT',func=pin_types.PWROUT,unit=1),
            Pin(num='25',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='26',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='27',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='RXD_AUX',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='TXD_AUX',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='SPI_MISO',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='31',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='32',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='33',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='RF_ANT',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='RXD_DBG',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='TXD_DBG',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='SPI_MOSI',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VBAT_BB',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VBAT_RF',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='45',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='46',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='47',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='48',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='49',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='SPI_SCLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='50',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='51',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='52',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='53',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='54',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='55',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='56',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='57',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='58',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='SPI_CS',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='PWRKEY',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='ADC0',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BC95', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BC95'}), 'ref_prefix':'U', 'fplist':['RF_GSM:Quectel_BC95'], 'footprint':'RF_GSM:Quectel_BC95', 'keywords':'NB-IoT GSM GPRS Quad-Band SMS', 'description':'', 'datasheet':'https://www.quectel.com/UploadImage/Downlad/Quectel_BC95_Hardware_Design_V1.3.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GSM.kicad_sym\nBC95\n\nNB-IoT GSM GPRS Quad-Band SMS', 'pins':[
            Pin(num='15',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='NETLIGHT',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='DBG_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='DBG_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='ADC',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='VDD_EXT',func=pin_types.PWROUT,unit=1),
            Pin(num='29',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='RI',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='USIM_VDD',func=pin_types.PWROUT,unit=1),
            Pin(num='39',name='USIM_RST',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='USIM_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='USIM_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='USIM_GND',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='VBAT',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='RF_ANT',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='92',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='93',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'M95', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'M95'}), 'ref_prefix':'U', 'fplist':['RF_GSM:Quectel_M95'], 'footprint':'RF_GSM:Quectel_M95', 'keywords':'GSM GPRS AT SMS voice TCP/IP', 'description':'', 'datasheet':'https://www.quectel.com/UploadImage/Downlad/M95_Hardware_Design_V1.3.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GSM.kicad_sym\nM95\n\nGSM GPRS AT SMS voice TCP/IP', 'pins':[
            Pin(num='1',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{PWRKEY}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{EMERG_OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='STATUS',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='NETLIGHT',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DBG_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='DBG_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='VDD_EXT',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='MIC2P',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='DTR',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='CTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='RTS',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='DCD',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='RI',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='SIM_VDD',func=pin_types.PWROUT,unit=1),
            Pin(num='28',name='SIM_RST',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='SIM_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='MIC2N',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='SIM_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='SIM_GND',func=pin_types.PWROUT,unit=1),
            Pin(num='32',name='VRTC',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='VBAT',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='RF_ANT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='MIC1P',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='42',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='MIC1N',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SPK1N',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='SPK1P',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='LOUDSPKN',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='LOUDSPKP',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SARA-U201', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SARA-U201'}), 'ref_prefix':'U', 'fplist':['RF_GSM:ublox_SARA_LGA-96'], 'footprint':'RF_GSM:ublox_SARA_LGA-96', 'keywords':'GSM HSPA 2G 3G', 'description':'', 'datasheet':'https://www.u-blox.com/sites/default/files/SARA-U2_DataSheet_(UBX-13005287).pdf', 'search_text':'/usr/share/kicad/symbols/RF_GSM.kicad_sym\nSARA-U201\n\nGSM HSPA 2G 3G', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RTS',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='TXD',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='RXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='PWR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VUSB_DET',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='CODEC_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='V_BCKP',func=pin_types.PWROUT,unit=1),
            Pin(num='20',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='GPIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GPIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GPIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='SCL',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='USB_D-',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='USB_D+',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='34',name='I2S_WA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='I2S_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='I2S_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='I2S_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='SIM_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='SIM_IO',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='V_INT',func=pin_types.PWROUT,unit=1),
            Pin(num='40',name='SIM_RST',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='VSIM',func=pin_types.PWROUT,unit=1),
            Pin(num='42',name='SIM_DET',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='45',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='46',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='47',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='48',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='49',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='ANT',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='DSR',func=pin_types.OUTPUT,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='ANT_DET',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='RI',func=pin_types.OUTPUT,unit=1),
            Pin(num='70',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='78',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='DCD',func=pin_types.OUTPUT,unit=1),
            Pin(num='80',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='85',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='87',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='88',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='89',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='DTR',func=pin_types.INPUT,unit=1),
            Pin(num='90',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='92',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='93',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='96',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SIM7020E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SIM7020E'}), 'ref_prefix':'U', 'fplist':['RF_GSM:SIMCom_SIM800C'], 'footprint':'RF_GSM:SIMCom_SIM800C', 'keywords':'NB-IoT Data SMS', 'description':'', 'datasheet':'https://simcom.ee/documents/SIM7020/SIM7020%20Hardware%20Design_V1.02.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GSM.kicad_sym\nSIM7020E\n\nNB-IoT Data SMS', 'pins':[
            Pin(num='1',name='UART1_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='GPIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RTC_GPIO0',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='RTC_EINT',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='SIM_DET',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SIM_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SIM_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='SIM_RST',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='SIM_VDD',func=pin_types.PWROUT,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='UART1_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='UART2_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='UART2_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='USB_VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='UART1_RTS',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='ANT',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VBAT',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='ADC',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='~{PWRKEY}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='UART1_CTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='VDD_EXT',func=pin_types.PWROUT,unit=1),
            Pin(num='41',name='NETLIGHT',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='STATUS',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='UART1_DCD',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='UART1_DTR',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='UART1_RI',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDD_3V3',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SIM800C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SIM800C'}), 'ref_prefix':'U', 'fplist':['RF_GSM:SIMCom_SIM800C'], 'footprint':'RF_GSM:SIMCom_SIM800C', 'keywords':'GSM GPRS Quad-Band SMS', 'description':'', 'datasheet':'http://simcom.ee/documents/SIM800C/SIM800C_Hardware_Design_V1.05.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GSM.kicad_sym\nSIM800C\n\nGSM GPRS Quad-Band SMS', 'pins':[
            Pin(num='1',name='UART1_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='MICN',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SPKP',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='SPKN',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='SIM_DET',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SIM_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SIM_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='SIM_RST',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='SIM_VDD',func=pin_types.PWROUT,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='UART1_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='BT_ANT',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='UART2_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='UART2_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='USB_VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VRTC',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='RF_SYNC',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='UART1_RTS',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GSM_ANT',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VBAT',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='ADC',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='~{PWRKEY}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='UART1_CTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='VDD_EXT',func=pin_types.PWROUT,unit=1),
            Pin(num='41',name='NETLIGHT',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='STATUS',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='UART1_DCD',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='UART1_DTR',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='UART1_RI',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='MICP',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SIM900', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SIM900'}), 'ref_prefix':'U', 'fplist':['RF_GSM:SIMCom_SIM900'], 'footprint':'RF_GSM:SIMCom_SIM900', 'keywords':'GSM GPRS Quad-Band SMS FAX', 'description':'', 'datasheet':'http://simcom.ee/documents/SIM900/SIM900_Hardware%20Design_V2.05.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GSM.kicad_sym\nSIM900\n\nGSM GPRS Quad-Band SMS FAX', 'pins':[
            Pin(num='1',name='PWRKEY',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='DISP_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='DISP_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='DISP_D/C',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DISP_CS',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='VDD_EXT',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='MIC_P',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='20',name='MIC_N',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='SPK_P',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='SPK_N',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='ADC',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='VRTC',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='DBG_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='DBG_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='DTR',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='SIM_VDD',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='SIM_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='SIM_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='SIM_RST',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='SIM_PRESENCE',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PWM1',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='PWM2',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='SCL',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RI',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='GPIO1/KBR4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='GPIO2/KBR3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='GPIO3/KBR2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='GPIO4/KBR1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GPIO5/KBR0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='GPIO6/KBC4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='GPIO7/KBC3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='GPIO8/KBC2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='DCD',func=pin_types.OUTPUT,unit=1),
            Pin(num='50',name='GPIO9/KBC1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='GPIO10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='NETLIGHT',func=pin_types.OUTPUT,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VBAT',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='VBAT',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='60',name='RF_ANT',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='STATUS',func=pin_types.OUTPUT,unit=1),
            Pin(num='67',name='GPIO11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='GPIO12',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='RTS',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='TXD',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'UL865', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'UL865'}), 'ref_prefix':'U', 'fplist':['RF_GSM:Telit_xL865'], 'footprint':'RF_GSM:Telit_xL865', 'keywords':'gsm 3g gprs umts hspa', 'description':'', 'datasheet':'http://www.telit.com/fileadmin/user_upload/products/Downloads/3G/Telit_UL865_Hardware_User_Guide_r8.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GSM.kicad_sym\nUL865\n\ngsm 3g gprs umts hspa', 'pins':[
            Pin(num='1',name='C109/DCD/GPO',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='SIMRST',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='SIMCLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='SIMIO',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='ADC_IN1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='ADC_IN2',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='DAC_OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VUSB',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='USB_D-',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='USB_D+',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='C125/RING/GPO',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='SPI_CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='GPIO8/STAT_LED',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='GPIO7/SPI_MRDY',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='GPIO6/SPI_SRDY',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='GPIO5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='C107/DSR/GPO',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='VRTC',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='32',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='ANTENNA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VBATT_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VBATT',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='GPIO4/DVI_CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='C108/DTR/GPI',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='GPIO3/DVI_TX',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='GPIO2/JDR/DVI_RX',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='GPIO1/DVI_WA0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='V_AUX/PWRMON',func=pin_types.PWROUT,unit=1),
            Pin(num='44',name='RXD_AUX/SPI_MISO',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='TXD_AUX/SPI_MOSI',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='C105/RTS/GPI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='C106/CTS/GPO',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='C103/TXD',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='C104/RXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='SIMVCC',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SARA-U260', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SARA-U260'}), 'ref_prefix':'U', 'fplist':['RF_GSM:ublox_SARA_LGA-96', 'RF_GSM:ublox_SARA_LGA-96'], 'footprint':'RF_GSM:ublox_SARA_LGA-96', 'keywords':'GSM HSPA 2G 3G', 'description':'', 'datasheet':'https://www.u-blox.com/sites/default/files/SARA-U2_DataSheet_(UBX-13005287).pdf', 'search_text':'/usr/share/kicad/symbols/RF_GSM.kicad_sym\nSARA-U260\n\nGSM HSPA 2G 3G', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RTS',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='TXD',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='RXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='PWR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VUSB_DET',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='CODEC_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='V_BCKP',func=pin_types.PWROUT,unit=1),
            Pin(num='20',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='GPIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GPIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GPIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='SCL',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='USB_D-',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='USB_D+',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='34',name='I2S_WA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='I2S_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='I2S_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='I2S_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='SIM_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='SIM_IO',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='V_INT',func=pin_types.PWROUT,unit=1),
            Pin(num='40',name='SIM_RST',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='VSIM',func=pin_types.PWROUT,unit=1),
            Pin(num='42',name='SIM_DET',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='45',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='46',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='47',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='48',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='49',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='ANT',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='DSR',func=pin_types.OUTPUT,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='ANT_DET',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='RI',func=pin_types.OUTPUT,unit=1),
            Pin(num='70',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='78',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='DCD',func=pin_types.OUTPUT,unit=1),
            Pin(num='80',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='85',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='87',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='88',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='89',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='DTR',func=pin_types.INPUT,unit=1),
            Pin(num='90',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='92',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='93',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='96',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SARA-U270', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SARA-U270'}), 'ref_prefix':'U', 'fplist':['RF_GSM:ublox_SARA_LGA-96', 'RF_GSM:ublox_SARA_LGA-96', 'RF_GSM:ublox_SARA_LGA-96'], 'footprint':'RF_GSM:ublox_SARA_LGA-96', 'keywords':'GSM HSPA 2G 3G', 'description':'', 'datasheet':'https://www.u-blox.com/sites/default/files/SARA-U2_DataSheet_(UBX-13005287).pdf', 'search_text':'/usr/share/kicad/symbols/RF_GSM.kicad_sym\nSARA-U270\n\nGSM HSPA 2G 3G', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RTS',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='TXD',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='RXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='PWR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VUSB_DET',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='CODEC_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='V_BCKP',func=pin_types.PWROUT,unit=1),
            Pin(num='20',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='GPIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GPIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GPIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='SCL',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='USB_D-',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='USB_D+',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='34',name='I2S_WA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='I2S_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='I2S_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='I2S_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='SIM_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='SIM_IO',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='V_INT',func=pin_types.PWROUT,unit=1),
            Pin(num='40',name='SIM_RST',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='VSIM',func=pin_types.PWROUT,unit=1),
            Pin(num='42',name='SIM_DET',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='45',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='46',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='47',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='48',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='49',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='ANT',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='DSR',func=pin_types.OUTPUT,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='ANT_DET',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='RI',func=pin_types.OUTPUT,unit=1),
            Pin(num='70',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='78',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='DCD',func=pin_types.OUTPUT,unit=1),
            Pin(num='80',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='85',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='87',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='88',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='89',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='DTR',func=pin_types.INPUT,unit=1),
            Pin(num='90',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='92',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='93',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='96',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SARA-U280', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SARA-U280'}), 'ref_prefix':'U', 'fplist':['RF_GSM:ublox_SARA_LGA-96', 'RF_GSM:ublox_SARA_LGA-96', 'RF_GSM:ublox_SARA_LGA-96', 'RF_GSM:ublox_SARA_LGA-96'], 'footprint':'RF_GSM:ublox_SARA_LGA-96', 'keywords':'GSM HSPA 2G 3G', 'description':'', 'datasheet':'https://www.u-blox.com/sites/default/files/SARA-U2_DataSheet_(UBX-13005287).pdf', 'search_text':'/usr/share/kicad/symbols/RF_GSM.kicad_sym\nSARA-U280\n\nGSM HSPA 2G 3G', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RTS',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='TXD',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='RXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='PWR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VUSB_DET',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='CODEC_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='V_BCKP',func=pin_types.PWROUT,unit=1),
            Pin(num='20',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='GPIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GPIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GPIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='SCL',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='USB_D-',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='USB_D+',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='34',name='I2S_WA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='I2S_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='I2S_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='I2S_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='SIM_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='SIM_IO',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='V_INT',func=pin_types.PWROUT,unit=1),
            Pin(num='40',name='SIM_RST',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='VSIM',func=pin_types.PWROUT,unit=1),
            Pin(num='42',name='SIM_DET',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='45',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='46',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='47',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='48',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='49',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='ANT',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='DSR',func=pin_types.OUTPUT,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='ANT_DET',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='RI',func=pin_types.OUTPUT,unit=1),
            Pin(num='70',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='78',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='DCD',func=pin_types.OUTPUT,unit=1),
            Pin(num='80',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='85',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='87',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='88',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='89',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='DTR',func=pin_types.INPUT,unit=1),
            Pin(num='90',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='92',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='93',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='96',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SIM7020C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SIM7020C'}), 'ref_prefix':'U', 'fplist':['RF_GSM:SIMCom_SIM800C', 'RF_GSM:SIMCom_SIM800C'], 'footprint':'RF_GSM:SIMCom_SIM800C', 'keywords':'NB-IoT Data SMS', 'description':'', 'datasheet':'https://simcom.ee/documents/SIM7020/SIM7020%20Hardware%20Design_V1.02.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GSM.kicad_sym\nSIM7020C\n\nNB-IoT Data SMS', 'pins':[
            Pin(num='1',name='UART1_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='GPIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RTC_GPIO0',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='RTC_EINT',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='SIM_DET',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SIM_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SIM_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='SIM_RST',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='SIM_VDD',func=pin_types.PWROUT,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='UART1_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='UART2_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='UART2_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='USB_VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='UART1_RTS',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='ANT',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VBAT',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='ADC',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='~{PWRKEY}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='UART1_CTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='VDD_EXT',func=pin_types.PWROUT,unit=1),
            Pin(num='41',name='NETLIGHT',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='STATUS',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='UART1_DCD',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='UART1_DTR',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='UART1_RI',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDD_3V3',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] })])