from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_STC = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'STC15W201S-35x-SOP16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STC15W201S-35x-SOP16'}), 'ref_prefix':'U', 'fplist':['Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'keywords':'STC 8051 microcontroller', 'description':'', 'datasheet':'www.stcmicro.com/datasheet/STC15F2K60S2-en.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_STC.kicad_sym\nSTC15W201S-35x-SOP16\n\nSTC 8051 microcontroller', 'pins':[
            Pin(num='1',name='P1.2/CMPO/T0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TxD/T2/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='INT0/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='INT1/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{INT2}/RxD_2/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='~{INT3}/TxD_2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P1.0/RSTOUT_LOW',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P1.4/T0CLKO',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CMP-/MCLKO/RST/P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='CMP+/P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RxD/~{INT4}/T2CLKO/P3.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STC8G1K08-38I-TSSOP20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STC8G1K08-38I-TSSOP20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'STC 8051 microcontroller', 'description':'', 'datasheet':'www.stcmicro.com/datasheet/STC8G-en.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_STC.kicad_sym\nSTC8G1K08-38I-TSSOP20\n\nSTC 8051 microcontroller', 'pins':[
            Pin(num='1',name='P1.2/ADC2/SS/T2/ECI',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='INT4/RxD/ADC8/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TxD/ADC9/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='INT0/SCLK_4/SCL_4/ADC10/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='INT1/MISO_4/SDA_4/ADC11/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='CMPO/ECI_2/T1CLKO/MOSI_4/T0/ADC12/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SS_4/CCP0_2/T0CLKO/T1/ADC13/P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='INT2/CMP-/CCP1_2/RxD_2/ADC14/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='INT3/CMP+/CCP2/CCP2_2/TxD_2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P1.0/ADC0/RxD2/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P1.3/ADC3/MOSI/T2CLKO',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P1.1/ADC1/TxD2/CCP0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P1.4/ADC4/MISO/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.5/ADC5/SCLK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.6/ADC6/RxD_3/MCLKO_2/XTALO',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P1.7/ADC7/TxD_3/XTALI',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='MCLKO/RST/P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='P5.5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IAP15W205S-35x-SOP16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IAP15W205S-35x-SOP16'}), 'ref_prefix':'U', 'fplist':['Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'keywords':'STC 8051 microcontroller', 'description':'', 'datasheet':'www.stcmicro.com/datasheet/STC15F2K60S2-en.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_STC.kicad_sym\nIAP15W205S-35x-SOP16\n\nSTC 8051 microcontroller', 'pins':[
            Pin(num='1',name='P1.2/CMPO/T0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TxD/T2/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='INT0/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='INT1/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{INT2}/RxD_2/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='~{INT3}/TxD_2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P1.0/RSTOUT_LOW',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P1.4/T0CLKO',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CMP-/MCLKO/RST/P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='CMP+/P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RxD/~{INT4}/T2CLKO/P3.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IRC15W207S-35x-SOP16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IRC15W207S-35x-SOP16'}), 'ref_prefix':'U', 'fplist':['Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'keywords':'STC 8051 microcontroller', 'description':'', 'datasheet':'www.stcmicro.com/datasheet/STC15F2K60S2-en.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_STC.kicad_sym\nIRC15W207S-35x-SOP16\n\nSTC 8051 microcontroller', 'pins':[
            Pin(num='1',name='P1.2/CMPO/T0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TxD/T2/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='INT0/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='INT1/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{INT2}/RxD_2/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='~{INT3}/TxD_2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P1.0/RSTOUT_LOW',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P1.4/T0CLKO',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CMP-/MCLKO/RST/P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='CMP+/P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RxD/~{INT4}/T2CLKO/P3.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STC15W202S-35x-SOP16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STC15W202S-35x-SOP16'}), 'ref_prefix':'U', 'fplist':['Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'keywords':'STC 8051 microcontroller', 'description':'', 'datasheet':'www.stcmicro.com/datasheet/STC15F2K60S2-en.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_STC.kicad_sym\nSTC15W202S-35x-SOP16\n\nSTC 8051 microcontroller', 'pins':[
            Pin(num='1',name='P1.2/CMPO/T0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TxD/T2/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='INT0/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='INT1/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{INT2}/RxD_2/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='~{INT3}/TxD_2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P1.0/RSTOUT_LOW',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P1.4/T0CLKO',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CMP-/MCLKO/RST/P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='CMP+/P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RxD/~{INT4}/T2CLKO/P3.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STC15W203S-35x-SOP16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STC15W203S-35x-SOP16'}), 'ref_prefix':'U', 'fplist':['Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'keywords':'STC 8051 microcontroller', 'description':'', 'datasheet':'www.stcmicro.com/datasheet/STC15F2K60S2-en.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_STC.kicad_sym\nSTC15W203S-35x-SOP16\n\nSTC 8051 microcontroller', 'pins':[
            Pin(num='1',name='P1.2/CMPO/T0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TxD/T2/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='INT0/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='INT1/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{INT2}/RxD_2/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='~{INT3}/TxD_2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P1.0/RSTOUT_LOW',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P1.4/T0CLKO',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CMP-/MCLKO/RST/P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='CMP+/P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RxD/~{INT4}/T2CLKO/P3.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STC15W204S-35x-SOP16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STC15W204S-35x-SOP16'}), 'ref_prefix':'U', 'fplist':['Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:STC_SOP-16_3.9x9.9mm_P1.27mm', 'keywords':'STC 8051 microcontroller', 'description':'', 'datasheet':'www.stcmicro.com/datasheet/STC15F2K60S2-en.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_STC.kicad_sym\nSTC15W204S-35x-SOP16\n\nSTC 8051 microcontroller', 'pins':[
            Pin(num='1',name='P1.2/CMPO/T0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TxD/T2/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='INT0/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='INT1/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{INT2}/RxD_2/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='~{INT3}/TxD_2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P1.0/RSTOUT_LOW',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P1.4/T0CLKO',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CMP-/MCLKO/RST/P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='CMP+/P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='RxD/~{INT4}/T2CLKO/P3.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STC8G1K04-38I-TSSOP20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STC8G1K04-38I-TSSOP20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'STC 8051 microcontroller', 'description':'', 'datasheet':'www.stcmicro.com/datasheet/STC8G-en.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_STC.kicad_sym\nSTC8G1K04-38I-TSSOP20\n\nSTC 8051 microcontroller', 'pins':[
            Pin(num='1',name='P1.2/ADC2/SS/T2/ECI',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='INT4/RxD/ADC8/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TxD/ADC9/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='INT0/SCLK_4/SCL_4/ADC10/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='INT1/MISO_4/SDA_4/ADC11/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='CMPO/ECI_2/T1CLKO/MOSI_4/T0/ADC12/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SS_4/CCP0_2/T0CLKO/T1/ADC13/P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='INT2/CMP-/CCP1_2/RxD_2/ADC14/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='INT3/CMP+/CCP2/CCP2_2/TxD_2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P1.0/ADC0/RxD2/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P1.3/ADC3/MOSI/T2CLKO',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P1.1/ADC1/TxD2/CCP0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P1.4/ADC4/MISO/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.5/ADC5/SCLK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.6/ADC6/RxD_3/MCLKO_2/XTALO',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P1.7/ADC7/TxD_3/XTALI',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='MCLKO/RST/P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='P5.5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STC8G1K17-38I-TSSOP20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STC8G1K17-38I-TSSOP20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'STC 8051 microcontroller', 'description':'', 'datasheet':'www.stcmicro.com/datasheet/STC8G-en.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_STC.kicad_sym\nSTC8G1K17-38I-TSSOP20\n\nSTC 8051 microcontroller', 'pins':[
            Pin(num='1',name='P1.2/ADC2/SS/T2/ECI',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='INT4/RxD/ADC8/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TxD/ADC9/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='INT0/SCLK_4/SCL_4/ADC10/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='INT1/MISO_4/SDA_4/ADC11/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='CMPO/ECI_2/T1CLKO/MOSI_4/T0/ADC12/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SS_4/CCP0_2/T0CLKO/T1/ADC13/P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='INT2/CMP-/CCP1_2/RxD_2/ADC14/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='INT3/CMP+/CCP2/CCP2_2/TxD_2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P1.0/ADC0/RxD2/CCP1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P1.3/ADC3/MOSI/T2CLKO',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P1.1/ADC1/TxD2/CCP0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P1.4/ADC4/MISO/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.5/ADC5/SCLK/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.6/ADC6/RxD_3/MCLKO_2/XTALO',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P1.7/ADC7/TxD_3/XTALI',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='MCLKO/RST/P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='P5.5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])