from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_NXP_MAC7100 = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'MAC7101', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAC7101'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'ARM7TDMI-S MCU', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MAC7100EC.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_MAC7100.kicad_sym\nMAC7101\n\nARM7TDMI-S MCU', 'pins':[
            Pin(num='1',name='PG4/CANTXD_A',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH6/AN6_B',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name="RDY'/PE6/AN6_A",func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH7/AN7_B',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PE7/AN7_A',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PH8/AN8_B',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PE8/AN8_A',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PH9/AN9_B',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PE9/AN9_A',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PH10/AN10_B',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='VddA',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='VRL',func=pin_types.PASSIVE,unit=1),
            Pin(num='111',name='VRH',func=pin_types.PASSIVE,unit=1),
            Pin(num='112',name='VssA',func=pin_types.PWRIN,unit=1),
            Pin(num='113',name='PE10/AN10_A',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PH11/AN11_B',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PE11/AN11_A',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PH12/AN12_B',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PE12/AN12_A',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PH13/AN13_B',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PE13/AN13_A',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PH14/AN14_B',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PE14/AN14_A',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PH15/AN15_B',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PE15/AN15_A',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='VddX',func=pin_types.PWRIN,unit=1),
            Pin(num='125',name='VssX',func=pin_types.PWRIN,unit=1),
            Pin(num='126',name='Vss2.5',func=pin_types.PWRIN,unit=1),
            Pin(num='127',name='Vdd2.5',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='129',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='VssX',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='131',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='132',name='PA6/RDY',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PA5/MSEO',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PA4/MDO1',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PA3/MDO0',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PA2/EVTI',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PA1/EVTO',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA0/MCKO',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PG14/RXD_C',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VddX',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PG15/TXD_C',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PG0/RXD_B',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PG1/TXD_B',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PG2/RXD_A',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PG3/TXD_A',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2/SIN_A',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB3/SOUT_A',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB4/SCK_A',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PG5/CANRXD_A',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB5/PCS0_A/SS_A',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB6/PCS1_A',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB8/PCS5_A/PCSS_A',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF15/eMIOS15',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF14/eMIOS14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF13/eMIOS13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF12/eMIOS12',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PG8/CANTXD_C',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PF11/eMIOS11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PF10/eMIOS10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PF9/eMIOS9',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PF8/eMIOS8',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PF7/eMIOS7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PF6/eMIOS6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF5/eMIOS5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF4/eMIOS4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PG9/CANRXD_C',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PF3/eMIOS3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PF2/eMIOS2',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PF1/NEXPR/eMIOS1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PF0/NEXPS/eMIOS0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RESET',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VssX',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PG10/CANTXD_D',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VddX',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PG12/RXD_D',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG13/TXD_D',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='Vdd2.5',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Vss2.5',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='VssR',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VddR',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VddPLL',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='XFC',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VssPLL',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='PG11/CANRXD_D',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='EXTAL',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='XTAL',func=pin_types.OUTPUT,unit=1),
            Pin(num='63',name='VssX',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='VddX',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG6/CANTXD_B',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD0/MODB',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD1/MODA',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB9/PCS0_B/SS_B',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB10/PCS5_B/PCSS_B',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB11/PCS2_B',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB12/PCS1_B',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB13/PCSSCK_B',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PB14/SOUT_B',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB15/SIN_B',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VssX',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PG7/CANRXD_B',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD2/CLKOUT/XCLKS',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD3/XIRQ',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD4/IRQ',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='VssX',func=pin_types.PWRIN,unit=1),
            Pin(num='87',name='VddX',func=pin_types.PWRIN,unit=1),
            Pin(num='88',name='PH0/AN0_B',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name="MCKO'/PE0/AN0_A",func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PH1/AN1_B',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name="EVTO'/PE1/AN1_A",func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PH2/AN2_B',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name="EVTI'/PE2/AN2_A",func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PH3/AN3_B',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name="MDO0'/PE3/AN3_A",func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH4/AN4_B',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name="MDO1'/PE4/AN4_A",func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH5/AN5_B',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name="MSEO'/PE5/AN5_A",func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAC7111', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAC7111'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'ARM7TDMI-S MCU', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MAC7100EC.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_MAC7100.kicad_sym\nMAC7111\n\nARM7TDMI-S MCU', 'pins':[
            Pin(num='1',name='PG4/CANTXD_A',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC1/ADDR1',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name="PE1/EVTO'/AN1_A",func=pin_types.BIDIR,unit=1),
            Pin(num='101',name="PE2/EVTI'/AN2_A",func=pin_types.BIDIR,unit=1),
            Pin(num='102',name="PE3/MDO0'/AN3_A",func=pin_types.BIDIR,unit=1),
            Pin(num='103',name="PE4/MDO1'/AN4_A",func=pin_types.BIDIR,unit=1),
            Pin(num='104',name="PE5/MSEO'/AN5_A",func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PE6/RDY/AN6_A',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PE7/AN7_A',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PE8/AN8_A',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PE9/AN9_A',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='VddA',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PC2/ADDR2',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='VRL',func=pin_types.PASSIVE,unit=1),
            Pin(num='111',name='VRH',func=pin_types.PASSIVE,unit=1),
            Pin(num='112',name='VssA',func=pin_types.PWRIN,unit=1),
            Pin(num='113',name='PE10/AN10_A',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PE11/AN11_A',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PE12/AN12_A',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PE13/AN13_A',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PE14/AN14_A',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PE15/AN15_A',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD6/ADDR17',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC3/ADDR3',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PD7/ADDR18',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PD8/ADDR19',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PD9/ADDR20',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD10/ADDR21',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='VddX',func=pin_types.PWRIN,unit=1),
            Pin(num='125',name='VssX',func=pin_types.PWRIN,unit=1),
            Pin(num='126',name='Vss2.5',func=pin_types.PWRIN,unit=1),
            Pin(num='127',name='Vdd2.5',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='129',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='VssX',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='131',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='132',name='PA6/DATA6/RDY',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PA5/DATA5/MSEO',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PA4/DATA4/MDO1',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PA3/DATA3/MDO0',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PA2/DATA2/EVTI',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PA1/DATA1/EVTO',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA0/DATA0/MCKO',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PG14/RXD_C',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VddX',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PG15/TXD_C',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PG0/RXD_B',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PG1/TXD_B',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PG2/RXD_A',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PG3/TXD_A',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1/SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2/SIN_A',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB3/SOUT_A',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB4/SCK_A',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PG5/CANRXD_A',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB5/PCS0_A/SS_A',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB6/PCS1_A',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB8/PCS5_A/PCSS_A',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF15/eMIOS15',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF14/eMIOS14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF13/eMIOS13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF12/eMIOS12',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC4/ADDR4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC5/ADDR5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PG8/CANTXD_C',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6/ADDR6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7/ADDR7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PF11/eMIOS11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PF10/eMIOS10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PF9/eMIOS9',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PF8/eMIOS8',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PF7/eMIOS7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PF6/eMIOS6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF5/eMIOS5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF4/eMIOS4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PG9/CANRXD_C',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PF3/eMIOS3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PF2/eMIOS2',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PF1/NEXPR/eMIOS1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PF0/NEXPS/eMIOS0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC8/ADDR8',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC9/ADDR9',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PC10/ADDR10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PC11/ADDR11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RESET',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VssX',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PG10/CANTXD_D',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VddX',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PG12/RXD_D',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG13/TXD_D',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='Vdd2.5',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Vss2.5',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='VssR',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VddR',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VddPLL',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='XFC',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VssPLL',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='PG11/CANRXD_D',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='EXTAL',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='XTAL',func=pin_types.OUTPUT,unit=1),
            Pin(num='63',name='VssX',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='VddX',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PA15/DATA15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PA14/DATA14',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA13/DATA13',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PD11/OE',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD12/CS2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PG6/CANTXD_B',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD0/BS0/MODB',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD1/BS1/MODA',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB9/PCS0_B/SS_B',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB10/PCS5_B/PCSS_B',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB11/PCS2_B',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB12/PCS1_B',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB13/PCSSCK_B',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PB14/SOUT_B',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB15/SIN_B',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='TA/AS',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PG7/CANRXD_B',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD2/CLKOUT/XCLKS',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD3/XIRQ',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD4/IRQ',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD13/CS1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD14/CS0',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD15/R/W',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='VssX',func=pin_types.PWRIN,unit=1),
            Pin(num='87',name='VddX',func=pin_types.PWRIN,unit=1),
            Pin(num='88',name='PC12/ADDR12',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PC13/ADDR13',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC0/ADDR0',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PC14/ADDR14',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PC15/ADDR15',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PD5/ADDR16',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PA12/DATA12',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PA11/DATA11',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PA10/DATA10',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PA9/DATA9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PA8/DATA8',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PA7/DATA7',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name="PE0/MCKO'/AN0_A",func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])