from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_ST_STM32WL = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'STM32WL54CCUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WL54CCUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WL5x', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wl54cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WL54CCUx\n\nArm Cortex-M4 STM32WL STM32WL5x', 'pins':[
            Pin(num='1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RFO_HP',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WL54JCIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WL54JCIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm'], 'footprint':'Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WL5x', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wl54jc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WL54JCIx\n\nArm Cortex-M4 STM32WL STM32WL5x', 'pins':[
            Pin(num='A1',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='B3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='H1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='RFO_HP',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WL55CCUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WL55CCUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WL5x', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wl55cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WL55CCUx\n\nArm Cortex-M4 STM32WL STM32WL5x', 'pins':[
            Pin(num='1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RFO_HP',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WL55JCIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WL55JCIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm'], 'footprint':'Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WL5x', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wl55jc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WL55JCIx\n\nArm Cortex-M4 STM32WL STM32WL5x', 'pins':[
            Pin(num='A1',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='B3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='H1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='RFO_HP',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WLE4C8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WLE4C8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WLEx', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wle4c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WLE4C8Ux\n\nArm Cortex-M4 STM32WL STM32WLEx', 'pins':[
            Pin(num='1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RFO_HP',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WLE4CBUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WLE4CBUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WLEx', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wle4cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WLE4CBUx\n\nArm Cortex-M4 STM32WL STM32WLEx', 'pins':[
            Pin(num='1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RFO_HP',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WLE4CCUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WLE4CCUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WLEx', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wle4cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WLE4CCUx\n\nArm Cortex-M4 STM32WL STM32WLEx', 'pins':[
            Pin(num='1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RFO_HP',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WLE4J8Ix', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WLE4J8Ix'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm'], 'footprint':'Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WLEx', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wle4j8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WLE4J8Ix\n\nArm Cortex-M4 STM32WL STM32WLEx', 'pins':[
            Pin(num='A1',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='B3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='H1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='RFO_HP',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WLE4JBIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WLE4JBIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm'], 'footprint':'Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WLEx', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wle4jb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WLE4JBIx\n\nArm Cortex-M4 STM32WL STM32WLEx', 'pins':[
            Pin(num='A1',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='B3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='H1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='RFO_HP',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WLE4JCIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WLE4JCIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm'], 'footprint':'Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WLEx', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wle4jc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WLE4JCIx\n\nArm Cortex-M4 STM32WL STM32WLEx', 'pins':[
            Pin(num='A1',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='B3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='H1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='RFO_HP',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WLE5C8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WLE5C8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WLEx', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wle5c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WLE5C8Ux\n\nArm Cortex-M4 STM32WL STM32WLEx', 'pins':[
            Pin(num='1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RFO_HP',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WLE5CBUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WLE5CBUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WLEx', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wle5cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WLE5CBUx\n\nArm Cortex-M4 STM32WL STM32WLEx', 'pins':[
            Pin(num='1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RFO_HP',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WLE5CCUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WLE5CCUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WLEx', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wle5cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WLE5CCUx\n\nArm Cortex-M4 STM32WL STM32WLEx', 'pins':[
            Pin(num='1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RFO_HP',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WLE5J8Ix', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WLE5J8Ix'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm'], 'footprint':'Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WLEx', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wle5j8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WLE5J8Ix\n\nArm Cortex-M4 STM32WL STM32WLEx', 'pins':[
            Pin(num='A1',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='B3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='H1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='RFO_HP',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WLE5JBIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WLE5JBIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm'], 'footprint':'Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WLEx', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wle5jb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WLE5JBIx\n\nArm Cortex-M4 STM32WL STM32WLEx', 'pins':[
            Pin(num='A1',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='B3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='H1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='RFO_HP',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32WLE5JCIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32WLE5JCIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm'], 'footprint':'Package_BGA:ST_UFBGA-73_5x5mm_Layout9x9_P0.5mm', 'keywords':'Arm Cortex-M4 STM32WL STM32WLEx', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32wle5jc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32WL.kicad_sym\nSTM32WLE5JCIx\n\nArm Cortex-M4 STM32WL STM32WLEx', 'pins':[
            Pin(num='A1',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='B3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VDDRF',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VDDRF1V55',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='VSSRF',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='H1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSSRF',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='RFI_N',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='VDDPA',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='VR_PA',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='RFI_P',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='RFO_LP',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='RFO_HP',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])