from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Graphic = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'Logo_Open_Hardware_Large', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Logo_Open_Hardware_Large'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'Logo', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nLogo_Open_Hardware_Large\n\nLogo', 'unit_defs':[] }),
        Part(**{ 'name':'Logo_Open_Hardware_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Logo_Open_Hardware_Small'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'Logo', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nLogo_Open_Hardware_Small\n\nLogo' }),
        Part(**{ 'name':'SYM_Arrow45_Large', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Arrow45_Large'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol arrow angled 45Â°', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Arrow45_Large\n\nsymbol arrow angled 45Â°' }),
        Part(**{ 'name':'SYM_Arrow45_Normal', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Arrow45_Normal'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol arrow angled 45Â°', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Arrow45_Normal\n\nsymbol arrow angled 45Â°' }),
        Part(**{ 'name':'SYM_Arrow45_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Arrow45_Small'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol arrow angled 45Â°', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Arrow45_Small\n\nsymbol arrow angled 45Â°' }),
        Part(**{ 'name':'SYM_Arrow45_Tiny', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Arrow45_Tiny'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol arrow angled 45Â°', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Arrow45_Tiny\n\nsymbol arrow angled 45Â°' }),
        Part(**{ 'name':'SYM_Arrow45_XLarge', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Arrow45_XLarge'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol arrow 45Â° angled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Arrow45_XLarge\n\nsymbol arrow 45Â° angled' }),
        Part(**{ 'name':'SYM_Arrow_Large', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Arrow_Large'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol arrow', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Arrow_Large\n\nsymbol arrow' }),
        Part(**{ 'name':'SYM_Arrow_Normal', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Arrow_Normal'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol arrow', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Arrow_Normal\n\nsymbol arrow' }),
        Part(**{ 'name':'SYM_Arrow_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Arrow_Small'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol arrow', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Arrow_Small\n\nsymbol arrow' }),
        Part(**{ 'name':'SYM_Arrow_Tiny', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Arrow_Tiny'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol arrow', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Arrow_Tiny\n\nsymbol arrow' }),
        Part(**{ 'name':'SYM_Arrow_XLarge', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Arrow_XLarge'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol arrow', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Arrow_XLarge\n\nsymbol arrow' }),
        Part(**{ 'name':'SYM_ESD_Large', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_ESD_Large'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol ESD', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_ESD_Large\n\nsymbol ESD' }),
        Part(**{ 'name':'SYM_ESD_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_ESD_Small'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol ESD', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_ESD_Small\n\nsymbol ESD' }),
        Part(**{ 'name':'SYM_Earth_Protective_Large', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Earth_Protective_Large'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'graphical symbol earth protective', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Earth_Protective_Large\n\ngraphical symbol earth protective' }),
        Part(**{ 'name':'SYM_Earth_Protective_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Earth_Protective_Small'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'graphical symbol earth protective', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Earth_Protective_Small\n\ngraphical symbol earth protective' }),
        Part(**{ 'name':'SYM_EasterEgg_42x60mm', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_EasterEgg_42x60mm'}), 'ref_prefix':'SYM', 'fplist':['Symbol:EasterEgg_EWG1308-2013_ClassA'], 'footprint':'Symbol:EasterEgg_EWG1308-2013_ClassA', 'keywords':'egg easter oval', 'description':'', 'datasheet':'https://eur-lex.europa.eu/LexUriServ/LexUriServ.do?uri=OJ:L:2013:347:0671:0854:de:PDF', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_EasterEgg_42x60mm\n\negg easter oval' }),
        Part(**{ 'name':'SYM_Flash_Large', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Flash_Large'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'graphic symbol flash VAC 220VAC 110VAC power', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Flash_Large\n\ngraphic symbol flash VAC 220VAC 110VAC power' }),
        Part(**{ 'name':'SYM_Flash_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Flash_Small'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'graphic symbol flash VAC 220VAC 110VAC power', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Flash_Small\n\ngraphic symbol flash VAC 220VAC 110VAC power' }),
        Part(**{ 'name':'SYM_Flash_XLarge', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Flash_XLarge'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'graphic symbol flash VAC 220VAC 110VAC power', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Flash_XLarge\n\ngraphic symbol flash VAC 220VAC 110VAC power' }),
        Part(**{ 'name':'SYM_Hot_Large', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Hot_Large'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol logo hot surface warning heat', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Hot_Large\n\nsymbol logo hot surface warning heat' }),
        Part(**{ 'name':'SYM_Hot_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Hot_Small'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol logo hot surface warning heat', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Hot_Small\n\nsymbol logo hot surface warning heat' }),
        Part(**{ 'name':'SYM_LASER_Large', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_LASER_Large'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol logo laser warning', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_LASER_Large\n\nsymbol logo laser warning' }),
        Part(**{ 'name':'SYM_LASER_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_LASER_Small'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol logo laser warning', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_LASER_Small\n\nsymbol logo laser warning' }),
        Part(**{ 'name':'SYM_Magnet_Large', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Magnet_Large'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol logo magnetic field warning', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Magnet_Large\n\nsymbol logo magnetic field warning' }),
        Part(**{ 'name':'SYM_Magnet_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Magnet_Small'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol logo magnetic field warning', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Magnet_Small\n\nsymbol logo magnetic field warning' }),
        Part(**{ 'name':'SYM_Radio_Waves_Large', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Radio_Waves_Large'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol logo radio waves warning radiation', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Radio_Waves_Large\n\nsymbol logo radio waves warning radiation' }),
        Part(**{ 'name':'SYM_Radio_Waves_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Radio_Waves_Small'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol logo radio waves warning radiation', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Radio_Waves_Small\n\nsymbol logo radio waves warning radiation' }),
        Part(**{ 'name':'SYM_Radioactive_Large', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Radioactive_Large'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol logo radioactive radiation warning heat', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Radioactive_Large\n\nsymbol logo radioactive radiation warning heat' }),
        Part(**{ 'name':'SYM_Radioactive_Radiation_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SYM_Radioactive_Radiation_Small'}), 'ref_prefix':'#SYM', 'fplist':[''], 'footprint':'', 'keywords':'symbol logo radioactive radiation warning', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Graphic.kicad_sym\nSYM_Radioactive_Radiation_Small\n\nsymbol logo radioactive radiation warning' })])