from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Comparator = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'AD8561', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD8561'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmp complementary push-pull', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ad8561.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nAD8561\n\ncmp complementary push-pull', 'pins':[
            Pin(num='1',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='LATCH',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='~{Q}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADCMP350', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADCMP350'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:Analog_KS-4'], 'footprint':'Package_TO_SOT_SMD:Analog_KS-4', 'keywords':'cmp collector', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADCMP350_354_356.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nADCMP350\n\ncmp collector', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADCMP356', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADCMP356'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:Analog_KS-4'], 'footprint':'Package_TO_SOT_SMD:Analog_KS-4', 'keywords':'cmp', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADCMP350_354_356.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nADCMP356\n\ncmp', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM2901', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM2901'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmp open collector', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/lm2901.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLM2901\n\ncmp open collector', 'pins':[
            Pin(num='2',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='-',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='+',func=pin_types.INPUT,unit=3),
            Pin(num='13',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='14',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='8',name='-',func=pin_types.INPUT,unit=4),
            Pin(num='9',name='+',func=pin_types.INPUT,unit=4),
            Pin(num='12',name='V-',func=pin_types.PWRIN,unit=5),
            Pin(num='3',name='V+',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '5', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['1', '7', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '13', '11']},{'label': 'uD', 'num': 4, 'pin_nums': ['8', '9', '14']},{'label': 'uE', 'num': 5, 'pin_nums': ['12', '3']}] }),
        Part(**{ 'name':'LM2903', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM2903'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmp open collector', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm393.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLM2903\n\ncmp open collector', 'pins':[
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='V+',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '6', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'LM311', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM311'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmp open collector', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/lm311.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLM311\n\ncmp open collector', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='BAL',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='STRB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM319', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM319'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmp open collector', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm319-n.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLM319\n\ncmp open collector', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=2),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT,unit=2),
            Pin(num='7',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=2),
            Pin(num='9',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='V+',func=pin_types.PWRIN,unit=3),
            Pin(num='6',name='V-',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['5', '3', '2', '12', '1', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '10', '8', '14', '9', '13']},{'label': 'uC', 'num': 3, 'pin_nums': ['6', '11']}] }),
        Part(**{ 'name':'LM319H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM319H'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-100-10'], 'footprint':'Package_TO_SOT_THT:TO-100-10', 'keywords':'cmp open collector', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm319-n.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLM319H\n\ncmp open collector', 'pins':[
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=2),
            Pin(num='8',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='9',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='V+',func=pin_types.PWRIN,unit=3),
            Pin(num='5',name='V-',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '3', '2', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['9', '8', '6', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '5']}] }),
        Part(**{ 'name':'LM339', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM339'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmp open collector', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/lm139.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLM339\n\ncmp open collector', 'pins':[
            Pin(num='2',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='-',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='+',func=pin_types.INPUT,unit=3),
            Pin(num='13',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='14',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='8',name='-',func=pin_types.INPUT,unit=4),
            Pin(num='9',name='+',func=pin_types.INPUT,unit=4),
            Pin(num='12',name='V-',func=pin_types.PWRIN,unit=5),
            Pin(num='3',name='V+',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '4', '5']},{'label': 'uB', 'num': 2, 'pin_nums': ['1', '6', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['13', '11', '10']},{'label': 'uD', 'num': 4, 'pin_nums': ['14', '9', '8']},{'label': 'uE', 'num': 5, 'pin_nums': ['3', '12']}] }),
        Part(**{ 'name':'LM397', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM397'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'single comparator', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm397.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLM397\n\nsingle comparator', 'pins':[
            Pin(num='1',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LMH7324', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LMH7324'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:WQFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:WQFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'cmp push-pull complementary', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lmh7324.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLMH7324\n\ncmp push-pull complementary', 'pins':[
            Pin(num='1',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='VEE',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VCCI',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='VEE',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='VEE',func=pin_types.PWRIN,unit=2),
            Pin(num='6',name='Q',func=pin_types.OUTPUT,unit=2),
            Pin(num='7',name='~{Q}',func=pin_types.OUTPUT,unit=2),
            Pin(num='8',name='VCCO',func=pin_types.PWRIN,unit=2),
            Pin(num='9',name='VCCI',func=pin_types.PWRIN,unit=2),
            Pin(num='13',name='VEE',func=pin_types.PWRIN,unit=3),
            Pin(num='14',name='+',func=pin_types.INPUT,unit=3),
            Pin(num='15',name='-',func=pin_types.INPUT,unit=3),
            Pin(num='16',name='VCCI',func=pin_types.PWRIN,unit=3),
            Pin(num='17',name='VCCO',func=pin_types.PWRIN,unit=3),
            Pin(num='18',name='~{Q}',func=pin_types.OUTPUT,unit=3),
            Pin(num='19',name='Q',func=pin_types.OUTPUT,unit=3),
            Pin(num='20',name='VEE',func=pin_types.PASSIVE,unit=3),
            Pin(num='21',name='VEE',func=pin_types.PWRIN,unit=4),
            Pin(num='22',name='Q',func=pin_types.OUTPUT,unit=4),
            Pin(num='23',name='~{Q}',func=pin_types.OUTPUT,unit=4),
            Pin(num='24',name='VCCO',func=pin_types.PWRIN,unit=4),
            Pin(num='25',name='VCCI',func=pin_types.PWRIN,unit=4),
            Pin(num='26',name='-',func=pin_types.INPUT,unit=4),
            Pin(num='27',name='+',func=pin_types.INPUT,unit=4),
            Pin(num='28',name='VEE',func=pin_types.PASSIVE,unit=4),
            Pin(num='33',name='VEE/EP',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['31', '1', '2', '3', '29', '32', '30', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['12', '9', '7', '10', '5', '8', '11', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['16', '18', '14', '20', '15', '13', '17', '19']},{'label': 'uD', 'num': 4, 'pin_nums': ['22', '26', '24', '28', '21', '23', '25', '27']},{'label': 'uE', 'num': 5, 'pin_nums': ['33']}] }),
        Part(**{ 'name':'LMV331', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LMV331'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'single comparator', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lmv331.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLMV331\n\nsingle comparator', 'pins':[
            Pin(num='1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LMV393', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LMV393'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmp open collector', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lmv331.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLMV393\n\ncmp open collector', 'pins':[
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='V+',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '6', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '4']}] }),
        Part(**{ 'name':'LMV7271', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LMV7271'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmp', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lmv7271.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLMV7271\n\ncmp', 'pins':[
            Pin(num='1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LMV7272', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LMV7272'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_DSBGA-8_1.5195x1.5195mm_Layout3x3_P0.5mm'], 'footprint':'Package_BGA:Texas_DSBGA-8_1.5195x1.5195mm_Layout3x3_P0.5mm', 'keywords':'cmp', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lmv7272.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLMV7272\n\ncmp', 'pins':[
            Pin(num='A1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='B1',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='C1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='A3',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='B3',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='C3',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='A2',name='V+',func=pin_types.PWRIN,unit=3),
            Pin(num='C2',name='V-',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['C1', 'B1', 'A1']},{'label': 'uB', 'num': 2, 'pin_nums': ['C3', 'A3', 'B3']},{'label': 'uC', 'num': 3, 'pin_nums': ['A2', 'C2']}] }),
        Part(**{ 'name':'LT1016', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1016'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmp push-pull complementary latch', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/lt1016.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLT1016\n\ncmp push-pull complementary latch', 'pins':[
            Pin(num='1',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='LATCH',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='~{Q}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1711xMS8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1711xMS8'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'cmp latch push-pull complementary', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/171112f.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLT1711xMS8\n\ncmp latch push-pull complementary', 'pins':[
            Pin(num='1',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='LATCH',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='~{Q}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC6752xMS8-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC6752xMS8-2'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'single comparator high speed cmos', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6752fc.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLTC6752xMS8-2\n\nsingle comparator high speed cmos', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{LE}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC6752xS5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC6752xS5'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:TSOT-23-5'], 'footprint':'Package_TO_SOT_SMD:TSOT-23-5', 'keywords':'single comparator high speed cmos', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6752fc.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLTC6752xS5\n\nsingle comparator high speed cmos', 'pins':[
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC6752xSC6-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC6752xSC6-1'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'single comparator high speed cmos', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6752fc.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLTC6752xSC6-1\n\nsingle comparator high speed cmos', 'pins':[
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{LE}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC6752xSC6-4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC6752xSC6-4'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'single comparator high speed cmos', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6752fc.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLTC6752xSC6-4\n\nsingle comparator high speed cmos', 'pins':[
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC6752xUD-3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC6752xUD-3'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-12-1EP_3x3mm_P0.5mm_EP1.65x1.65mm'], 'footprint':'Package_DFN_QFN:QFN-12-1EP_3x3mm_P0.5mm_EP1.65x1.65mm', 'keywords':'single comparator high speed cmos', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6752fc.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLTC6752xUD-3\n\nsingle comparator high speed cmos', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='VEE',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{LE}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VEE',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC6754xSC6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC6754xSC6'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'cmp r2r rtr push-pull complementary', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6754f.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLTC6754xSC6\n\ncmp r2r rtr push-pull complementary', 'pins':[
            Pin(num='1',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~{Q}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC6754xUD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC6754xUD'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-12-1EP_3x3mm_P0.5mm_EP1.65x1.65mm'], 'footprint':'Package_DFN_QFN:QFN-12-1EP_3x3mm_P0.5mm_EP1.65x1.65mm', 'keywords':'cmp r2r rtr push-pull complementary', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6754f.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLTC6754xUD\n\ncmp r2r rtr push-pull complementary', 'pins':[
            Pin(num='1',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='VEE',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VCCI',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{LE}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VEE',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX941xPA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX941xPA'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'single comparator', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX941-MAX944.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMAX941xPA\n\nsingle comparator', 'pins':[
            Pin(num='1',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{LATCH}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX941xSA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX941xSA'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'single comparator', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX941-MAX944.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMAX941xSA\n\nsingle comparator', 'pins':[
            Pin(num='1',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{LATCH}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX941xUA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX941xUA'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'single comparator', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX941-MAX944.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMAX941xUA\n\nsingle comparator', 'pins':[
            Pin(num='1',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{LATCH}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP6561-OT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP6561-OT'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'cmp', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/MCP6561-1R-1U-2-4-1.8V-Low-Power-Push-Pull-Output-Comparator-DS20002139E.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMCP6561-OT\n\ncmp', 'pins':[
            Pin(num='2',name='V-',func=pin_types.PWRIN),
            Pin(num='5',name='V+',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP6561R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP6561R'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'cmp', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/MCP6561-1R-1U-2-4-1.8V-Low-Power-Push-Pull-Output-Comparator-DS20002139E.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMCP6561R\n\ncmp', 'pins':[
            Pin(num='2',name='V+',func=pin_types.PWRIN),
            Pin(num='5',name='V-',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP6561U', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP6561U'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'cmp', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/MCP6561-1R-1U-2-4-1.8V-Low-Power-Push-Pull-Output-Comparator-DS20002139E.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMCP6561U\n\ncmp', 'pins':[
            Pin(num='2',name='V-',func=pin_types.PWRIN),
            Pin(num='5',name='V+',func=pin_types.PWRIN),
            Pin(num='1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP6561x-LT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP6561x-LT'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'keywords':'cmp', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/MCP6561-1R-1U-2-4-1.8V-Low-Power-Push-Pull-Output-Comparator-DS20002139E.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMCP6561x-LT\n\ncmp', 'pins':[
            Pin(num='2',name='V-',func=pin_types.PWRIN),
            Pin(num='5',name='V+',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP6562', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP6562'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmp', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/MCP6561-1R-1U-2-4-1.8V-Low-Power-Push-Pull-Output-Comparator-DS20002139E.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMCP6562\n\ncmp', 'pins':[
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='V+',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '6', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'MCP6566', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP6566'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmp collector', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/MCP6566-6R-6U-7-9-1.8V-Low-Power-Open-Drain-Output-Comparator-DS20002143G.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMCP6566\n\ncmp collector', 'pins':[
            Pin(num='2',name='V-',func=pin_types.PWRIN),
            Pin(num='5',name='V+',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP6566R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP6566R'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'cmp collector', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/MCP6566-6R-6U-7-9-1.8V-Low-Power-Open-Drain-Output-Comparator-DS20002143G.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMCP6566R\n\ncmp collector', 'pins':[
            Pin(num='2',name='V+',func=pin_types.PWRIN),
            Pin(num='5',name='V-',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP6566U', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP6566U'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'cmp collector', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/MCP6566-6R-6U-7-9-1.8V-Low-Power-Open-Drain-Output-Comparator-DS20002143G.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMCP6566U\n\ncmp collector', 'pins':[
            Pin(num='2',name='V-',func=pin_types.PWRIN),
            Pin(num='5',name='V+',func=pin_types.PWRIN),
            Pin(num='1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP6567', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP6567'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmp collector', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/MCP6566-6R-6U-7-9-1.8V-Low-Power-Open-Drain-Output-Comparator-DS20002143G.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMCP6567\n\ncmp collector', 'pins':[
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='V+',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '3', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '5', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'MCP6569', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP6569'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmp collector', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/MCP6566-6R-6U-7-9-1.8V-Low-Power-Open-Drain-Output-Comparator-DS20002143G.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMCP6569\n\ncmp collector', 'pins':[
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='10',name='+',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='9',name='-',func=pin_types.INPUT,unit=3),
            Pin(num='12',name='+',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='-',func=pin_types.INPUT,unit=4),
            Pin(num='14',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='11',name='V-',func=pin_types.PWRIN,unit=5),
            Pin(num='4',name='V+',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '5', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '8', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['12', '14', '13']},{'label': 'uE', 'num': 5, 'pin_nums': ['11', '4']}] }),
        Part(**{ 'name':'MCP65R41', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP65R41'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'cmp reference', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/22269B.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMCP65R41\n\ncmp reference', 'pins':[
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Vref',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP65R46', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP65R46'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'cmp reference open collector drain', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/22269B.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMCP65R46\n\ncmp reference open collector drain', 'pins':[
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Vref',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MIC845H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MIC845H'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'keywords':'single cmp', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/mic845.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMIC845H\n\nsingle cmp', 'pins':[
            Pin(num='1',name='NIC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MIC845N', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MIC845N'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'keywords':'single cmp collector', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/mic845.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMIC845N\n\nsingle cmp collector', 'pins':[
            Pin(num='1',name='NIC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TL3116', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TL3116'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmp push-pull complementary', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tl3116.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nTL3116\n\ncmp push-pull complementary', 'pins':[
            Pin(num='1',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='LATCH',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='~{Q}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLV3501AID', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLV3501AID'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'single comparator high speed cmos', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tlv3501.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nTLV3501AID\n\nsingle comparator high speed cmos', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='SHDN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLV3501AIDBV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLV3501AIDBV'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'single comparator high speed cmos', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tlv3501.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nTLV3501AIDBV\n\nsingle comparator high speed cmos', 'pins':[
            Pin(num='1',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='SHDN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADCMP354', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADCMP354'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:Analog_KS-4', 'Package_TO_SOT_SMD:Analog_KS-4'], 'footprint':'Package_TO_SOT_SMD:Analog_KS-4', 'keywords':'cmp collector', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADCMP350_354_356.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nADCMP354\n\ncmp collector', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM393', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM393'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'cmp open collector', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm393.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLM393\n\ncmp open collector', 'pins':[
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='V+',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '3', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '7', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'LMV339', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LMV339'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'cmp open collector', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/lmv331.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLMV339\n\ncmp open collector', 'pins':[
            Pin(num='2',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='-',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='+',func=pin_types.INPUT,unit=3),
            Pin(num='13',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='14',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='8',name='-',func=pin_types.INPUT,unit=4),
            Pin(num='9',name='+',func=pin_types.INPUT,unit=4),
            Pin(num='12',name='V-',func=pin_types.PWRIN,unit=5),
            Pin(num='3',name='V+',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['5', '2', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['1', '6', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['11', '13', '10']},{'label': 'uD', 'num': 4, 'pin_nums': ['8', '14', '9']},{'label': 'uE', 'num': 5, 'pin_nums': ['3', '12']}] }),
        Part(**{ 'name':'LMV7219M5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LMV7219M5'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'cmp', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/lmv7219.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLMV7219M5\n\ncmp', 'pins':[
            Pin(num='2',name='V-',func=pin_types.PWRIN),
            Pin(num='5',name='V+',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LMV7219M7', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LMV7219M7'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'keywords':'cmp', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/lmv7219.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLMV7219M7\n\ncmp', 'pins':[
            Pin(num='2',name='V-',func=pin_types.PWRIN),
            Pin(num='5',name='V+',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LMV7275', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LMV7275'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'cmp', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lmv7275.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLMV7275\n\ncmp', 'pins':[
            Pin(num='1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LP2901D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LP2901D'}), 'ref_prefix':'U', 'fplist':['', '', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'', 'keywords':'cmp open collector', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/lp2901.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLP2901D\n\ncmp open collector', 'pins':[
            Pin(num='2',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='-',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='+',func=pin_types.INPUT,unit=3),
            Pin(num='13',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='14',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='8',name='-',func=pin_types.INPUT,unit=4),
            Pin(num='9',name='+',func=pin_types.INPUT,unit=4),
            Pin(num='12',name='V-',func=pin_types.PWRIN,unit=5),
            Pin(num='3',name='V+',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['5', '2', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '7', '1']},{'label': 'uC', 'num': 3, 'pin_nums': ['13', '10', '11']},{'label': 'uD', 'num': 4, 'pin_nums': ['14', '9', '8']},{'label': 'uE', 'num': 5, 'pin_nums': ['12', '3']}] }),
        Part(**{ 'name':'LT1011', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1011'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'cmp open collector', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/lt1011.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLT1011\n\ncmp open collector', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='BAL',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='STRB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1116', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1116'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'cmp push-pull complementary latch', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/1116fc.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLT1116\n\ncmp push-pull complementary latch', 'pins':[
            Pin(num='1',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='LATCH',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='~{Q}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX9031AU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX9031AU'}), 'ref_prefix':'U', 'fplist':['', 'Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'', 'keywords':'rail-rail', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX9030-MAX9034.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMAX9031AU\n\nrail-rail', 'pins':[
            Pin(num='1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX9031AX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX9031AX'}), 'ref_prefix':'U', 'fplist':['', 'Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'', 'keywords':'rail-rail', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX9030-MAX9034.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMAX9031AX\n\nrail-rail', 'pins':[
            Pin(num='1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MIC845L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MIC845L'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'keywords':'single cmp', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/mic845.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMIC845L\n\nsingle cmp', 'pins':[
            Pin(num='1',name='NIC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TL331', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TL331'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'single comparator', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tl331.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nTL331\n\nsingle comparator', 'pins':[
            Pin(num='1',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLV7031DBV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLV7031DBV'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'cmp', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tlv7031.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nTLV7031DBV\n\ncmp', 'pins':[
            Pin(num='2',name='V-',func=pin_types.PWRIN),
            Pin(num='5',name='V+',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLV7041DBV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLV7041DBV'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'cmp collector', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tlv7041.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nTLV7041DBV\n\ncmp collector', 'pins':[
            Pin(num='2',name='V-',func=pin_types.PWRIN),
            Pin(num='5',name='V+',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] })])