from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_Microchip_AVR = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'AT90CAN32-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90CAN32-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7679.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90CAN32-16A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90CAN32-16M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90CAN32-16M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7679.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90CAN32-16M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90PWM1-16M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90PWM1-16M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.65x4.65mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.65x4.65mm', 'keywords':'AVR 8bit Microcontroller LightingAVR PWM', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc4378.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90PWM1-16M\n\nAVR 8bit Microcontroller LightingAVR PWM', 'pins':[
            Pin(num='1',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL1/PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='XTAL2/PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='26',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='30',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='31',name='~{RESET}/PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90PWM1-16S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90PWM1-16S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-24W_7.5x15.4mm_P1.27mm'], 'footprint':'Package_SO:SOIC-24W_7.5x15.4mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller LightingAVR PWM', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc4378.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90PWM1-16S\n\nAVR 8bit Microcontroller LightingAVR PWM', 'pins':[
            Pin(num='1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL1/PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='XTAL2/PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~{RESET}/PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90USB162-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90USB162-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7707.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90USB162-16A\n\nAVR 8bit Microcontroller USB', 'pins':[
            Pin(num='1',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{HWB}/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='UGND',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90USB646-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90USB646-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7593.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90USB646-A\n\nAVR 8bit Microcontroller USB', 'pins':[
            Pin(num='1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE2/~{HWB}',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='UGND',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PE3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90USB646-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90USB646-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'keywords':'AVR 8bit Microcontroller USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7593.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90USB646-M\n\nAVR 8bit Microcontroller USB', 'pins':[
            Pin(num='1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE2/~{HWB}',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='UGND',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PE3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90USB82-16M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90USB82-16M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.6x3.6mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.6x3.6mm', 'keywords':'AVR 8bit Microcontroller USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7707.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90USB82-16M\n\nAVR 8bit Microcontroller USB', 'pins':[
            Pin(num='1',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{HWB}/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='UGND',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90CAN128-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90CAN128-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7679.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90CAN128-16A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90CAN128-16M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90CAN128-16M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7679.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90CAN128-16M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90CAN64-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90CAN64-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7679.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90CAN64-16A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90CAN64-16M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90CAN64-16M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7679.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90CAN64-16M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90USB1286-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90USB1286-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7593.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90USB1286-A\n\nAVR 8bit Microcontroller USB', 'pins':[
            Pin(num='1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE2/~{HWB}',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='UGND',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PE3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90USB1286-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90USB1286-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'keywords':'AVR 8bit Microcontroller USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7593.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90USB1286-M\n\nAVR 8bit Microcontroller USB', 'pins':[
            Pin(num='1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE2/~{HWB}',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='UGND',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PE3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90USB1287-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90USB1287-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7593.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90USB1287-A\n\nAVR 8bit Microcontroller USB', 'pins':[
            Pin(num='1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE2/~{HWB}',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='UGND',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PE3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90USB1287-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90USB1287-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'keywords':'AVR 8bit Microcontroller USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7593.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90USB1287-M\n\nAVR 8bit Microcontroller USB', 'pins':[
            Pin(num='1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE2/~{HWB}',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='UGND',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PE3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90USB162-16M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90USB162-16M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.6x3.6mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.6x3.6mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.6x3.6mm', 'keywords':'AVR 8bit Microcontroller USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7707.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90USB162-16M\n\nAVR 8bit Microcontroller USB', 'pins':[
            Pin(num='1',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{HWB}/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='UGND',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90USB647-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90USB647-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7593.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90USB647-A\n\nAVR 8bit Microcontroller USB', 'pins':[
            Pin(num='1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE2/~{HWB}',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='UGND',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PE3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90USB647-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90USB647-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'keywords':'AVR 8bit Microcontroller USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7593.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90USB647-M\n\nAVR 8bit Microcontroller USB', 'pins':[
            Pin(num='1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE2/~{HWB}',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='UGND',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PE3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])