from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Transistor_Power_Module = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'A2C25S12M3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A2C25S12M3'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:ST_ACEPACK-2-CIB'], 'footprint':'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'keywords':'IGBT Power Module Trench Field Stop Technology M series', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/a2c25s12m3.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nA2C25S12M3\n\nIGBT Power Module Trench Field Stop Technology M series', 'pins':[
            Pin(num='B',name='B',func=pin_types.PASSIVE,unit=1),
            Pin(num='EU',name='EU',func=pin_types.PASSIVE,unit=1),
            Pin(num='EV',name='EV',func=pin_types.PASSIVE,unit=1),
            Pin(num='EW',name='EW',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='G1',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='G2',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='G3',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='G4',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='G5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='G6',func=pin_types.PASSIVE,unit=1),
            Pin(num='GB',name='GB',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='L1',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='L2',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='L3',func=pin_types.PASSIVE,unit=1),
            Pin(num='N',name='N',func=pin_types.PASSIVE,unit=1),
            Pin(num='NB',name='NB',func=pin_types.PASSIVE,unit=1),
            Pin(num='P',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='T1',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='T2',func=pin_types.PASSIVE,unit=1),
            Pin(num='U',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='V',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='W',name='W',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FS75R07N2E4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FS75R07N2E4'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:Infineon_AG-ECONO2'], 'footprint':'Transistor_Power_Module:Infineon_AG-ECONO2', 'keywords':'IGBT Power Module Trench Field Stop Technology', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-FS75R07N2E4-DS-v02_00-en_de.pdf?fileId=db3a30432f5008fe012f52f916333979', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nFS75R07N2E4\n\nIGBT Power Module Trench Field Stop Technology', 'pins':[
            Pin(num='13',name='N1',func=pin_types.PASSIVE),
            Pin(num='14',name='N1',func=pin_types.PASSIVE),
            Pin(num='15',name='P1',func=pin_types.PASSIVE),
            Pin(num='16',name='P1',func=pin_types.PASSIVE),
            Pin(num='17',name='T1',func=pin_types.PASSIVE),
            Pin(num='18',name='T2',func=pin_types.PASSIVE),
            Pin(num='19',name='W',func=pin_types.PASSIVE),
            Pin(num='20',name='W',func=pin_types.PASSIVE),
            Pin(num='21',name='V',func=pin_types.PASSIVE),
            Pin(num='22',name='V',func=pin_types.PASSIVE),
            Pin(num='23',name='U',func=pin_types.PASSIVE),
            Pin(num='24',name='U',func=pin_types.PASSIVE),
            Pin(num='25',name='P1',func=pin_types.PASSIVE),
            Pin(num='26',name='P1',func=pin_types.PASSIVE),
            Pin(num='27',name='N1',func=pin_types.PASSIVE),
            Pin(num='28',name='N1',func=pin_types.PASSIVE),
            Pin(num='1',name='G1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='W',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='G6',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='N1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='G2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='N1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='G3',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='G4',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='N1',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='G5',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MG1215H-XBN2MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MG1215H-XBN2MM'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:Littelfuse_Package_H_XBN2MM'], 'footprint':'Transistor_Power_Module:Littelfuse_Package_H_XBN2MM', 'keywords':'IGBT Power Module Trench Field Stop Technology', 'description':'', 'datasheet':'https://www.littelfuse.com/~/media/electronics/datasheets/power_semiconductors/littelfuse_power_semiconductor_igbt_module_mg1215h_xbn2mm_datasheet.pdf.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nMG1215H-XBN2MM\n\nIGBT Power Module Trench Field Stop Technology', 'pins':[
            Pin(num='1',name='L1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='N1',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='G6',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='G4',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='G2',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='GB',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='W',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='G5',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='G3',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='L2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='G1',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='N',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='N1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='L3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='W',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='B',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='T1',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='T2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MG1275W-XN2MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MG1275W-XN2MM'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:Littelfuse_Package_W_XN2MM'], 'footprint':'Transistor_Power_Module:Littelfuse_Package_W_XN2MM', 'keywords':'IGBT Power Module Trench Field Stop Technology', 'description':'', 'datasheet':'https://www.littelfuse.com/~/media/electronics/datasheets/power_semiconductors/littelfuse_power_semiconductor_igbt_module_mg1275w_xn2mm_datasheet.pdf.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nMG1275W-XN2MM\n\nIGBT Power Module Trench Field Stop Technology', 'pins':[
            Pin(num='13',name='N1',func=pin_types.PASSIVE),
            Pin(num='14',name='N1',func=pin_types.PASSIVE),
            Pin(num='15',name='N1',func=pin_types.PASSIVE),
            Pin(num='16',name='P1',func=pin_types.PASSIVE),
            Pin(num='17',name='P1',func=pin_types.PASSIVE),
            Pin(num='18',name='P1',func=pin_types.PASSIVE),
            Pin(num='19',name='T1',func=pin_types.PASSIVE),
            Pin(num='20',name='T2',func=pin_types.PASSIVE),
            Pin(num='30',name='P1',func=pin_types.PASSIVE),
            Pin(num='31',name='P1',func=pin_types.PASSIVE),
            Pin(num='32',name='P1',func=pin_types.PASSIVE),
            Pin(num='33',name='N1',func=pin_types.PASSIVE),
            Pin(num='34',name='N1',func=pin_types.PASSIVE),
            Pin(num='35',name='N1',func=pin_types.PASSIVE),
            Pin(num='1',name='G1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='W',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='G6',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='N1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='W',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='W',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='W',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='G2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='N1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='G3',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='G4',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='N1',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='G5',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STGIPS10C60-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STGIPS10C60-H'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:ST_SDIP-25L'], 'footprint':'Transistor_Power_Module:ST_SDIP-25L', 'keywords':'SLLIMM IPM inverter short-circuit rugged IGBT', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stgips10c60-h.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nSTGIPS10C60-H\n\nSLLIMM IPM inverter short-circuit rugged IGBT', 'pins':[
            Pin(num='1',name='OUTU',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='HINV',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='OUTW',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='VBOOTW',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='LINW',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='HINW',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{SD}/OD',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='CIN',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='NW',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='W',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VBOOTU',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='NV',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='NU',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='LINU',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='HINU',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='OUTV',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='VBOOTV',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='LINV',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STGIPS10K60A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STGIPS10K60A'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:ST_SDIP-25L'], 'footprint':'Transistor_Power_Module:ST_SDIP-25L', 'keywords':'SLLIMM IPM inverter short-circuit rugged IGBT', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stgips10k60a.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nSTGIPS10K60A\n\nSLLIMM IPM inverter short-circuit rugged IGBT', 'pins':[
            Pin(num='1',name='OUTU',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='HINV',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='OUTW',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='VBOOTW',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='LINW',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='HINW',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='T1',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='T2',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='NW',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='W',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VBOOTU',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='NV',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='NU',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='LINU',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='HINU',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='OUTV',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='VBOOTV',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='LINV',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STGIPS14K60T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STGIPS14K60T'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:ST_SDIP-25L'], 'footprint':'Transistor_Power_Module:ST_SDIP-25L', 'keywords':'SLLIMM IPM inverter short-circuit rugged IGBT', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stgips14k60t.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nSTGIPS14K60T\n\nSLLIMM IPM inverter short-circuit rugged IGBT', 'pins':[
            Pin(num='1',name='OUTU',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='HINV',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='OUTW',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='VBOOTW',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='~{LINW}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='HINW',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{SD}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='T1',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='NW',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='W',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VBOOTU',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='NV',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='NU',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~{LINU}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='HINU',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='OUTV',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='VBOOTV',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{LINV}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STGIPS20K60', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STGIPS20K60'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:ST_SDIP-25L'], 'footprint':'Transistor_Power_Module:ST_SDIP-25L', 'keywords':'SLLIMM IPM inverter short-circuit rugged IGBT', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stgips20k60.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nSTGIPS20K60\n\nSLLIMM IPM inverter short-circuit rugged IGBT', 'pins':[
            Pin(num='1',name='OUTU',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='HINV',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='OUTW',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='VBOOTW',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='~{LINW}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='HINW',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{SD}/OD',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='CIN',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='NW',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='W',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VBOOTU',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='NV',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='NU',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~{LINU}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='HINU',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='OUTV',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='VBOOTV',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{LINV}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'A2C25S12M3-F', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A2C25S12M3-F'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT'], 'footprint':'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'keywords':'IGBT Power Module Trench Field Stop Technology M series', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/a2c25s12m3-f.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nA2C25S12M3-F\n\nIGBT Power Module Trench Field Stop Technology M series', 'pins':[
            Pin(num='B',name='B',func=pin_types.PASSIVE,unit=1),
            Pin(num='EU',name='EU',func=pin_types.PASSIVE,unit=1),
            Pin(num='EV',name='EV',func=pin_types.PASSIVE,unit=1),
            Pin(num='EW',name='EW',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='G1',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='G2',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='G3',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='G4',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='G5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='G6',func=pin_types.PASSIVE,unit=1),
            Pin(num='GB',name='GB',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='L1',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='L2',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='L3',func=pin_types.PASSIVE,unit=1),
            Pin(num='N',name='N',func=pin_types.PASSIVE,unit=1),
            Pin(num='NB',name='NB',func=pin_types.PASSIVE,unit=1),
            Pin(num='P',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='T1',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='T2',func=pin_types.PASSIVE,unit=1),
            Pin(num='U',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='V',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='W',name='W',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'A2C35S12M3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A2C35S12M3'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:ST_ACEPACK-2-CIB'], 'footprint':'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'keywords':'IGBT Power Module Trench Field Stop Technology M series', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/a2c35s12m3.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nA2C35S12M3\n\nIGBT Power Module Trench Field Stop Technology M series', 'pins':[
            Pin(num='B',name='B',func=pin_types.PASSIVE,unit=1),
            Pin(num='EU',name='EU',func=pin_types.PASSIVE,unit=1),
            Pin(num='EV',name='EV',func=pin_types.PASSIVE,unit=1),
            Pin(num='EW',name='EW',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='G1',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='G2',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='G3',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='G4',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='G5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='G6',func=pin_types.PASSIVE,unit=1),
            Pin(num='GB',name='GB',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='L1',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='L2',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='L3',func=pin_types.PASSIVE,unit=1),
            Pin(num='N',name='N',func=pin_types.PASSIVE,unit=1),
            Pin(num='NB',name='NB',func=pin_types.PASSIVE,unit=1),
            Pin(num='P',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='T1',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='T2',func=pin_types.PASSIVE,unit=1),
            Pin(num='U',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='V',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='W',name='W',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'A2C35S12M3-F', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A2C35S12M3-F'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT'], 'footprint':'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'keywords':'IGBT Power Module Trench Field Stop Technology M series', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/a2c35s12m3-f.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nA2C35S12M3-F\n\nIGBT Power Module Trench Field Stop Technology M series', 'pins':[
            Pin(num='B',name='B',func=pin_types.PASSIVE,unit=1),
            Pin(num='EU',name='EU',func=pin_types.PASSIVE,unit=1),
            Pin(num='EV',name='EV',func=pin_types.PASSIVE,unit=1),
            Pin(num='EW',name='EW',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='G1',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='G2',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='G3',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='G4',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='G5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='G6',func=pin_types.PASSIVE,unit=1),
            Pin(num='GB',name='GB',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='L1',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='L2',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='L3',func=pin_types.PASSIVE,unit=1),
            Pin(num='N',name='N',func=pin_types.PASSIVE,unit=1),
            Pin(num='NB',name='NB',func=pin_types.PASSIVE,unit=1),
            Pin(num='P',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='T1',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='T2',func=pin_types.PASSIVE,unit=1),
            Pin(num='U',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='V',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='W',name='W',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'A2C50S65M2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A2C50S65M2'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:ST_ACEPACK-2-CIB'], 'footprint':'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'keywords':'IGBT Power Module Trench Field Stop Technology M series', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/a2c50s65m2.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nA2C50S65M2\n\nIGBT Power Module Trench Field Stop Technology M series', 'pins':[
            Pin(num='B',name='B',func=pin_types.PASSIVE,unit=1),
            Pin(num='EU',name='EU',func=pin_types.PASSIVE,unit=1),
            Pin(num='EV',name='EV',func=pin_types.PASSIVE,unit=1),
            Pin(num='EW',name='EW',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='G1',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='G2',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='G3',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='G4',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='G5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='G6',func=pin_types.PASSIVE,unit=1),
            Pin(num='GB',name='GB',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='L1',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='L2',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='L3',func=pin_types.PASSIVE,unit=1),
            Pin(num='N',name='N',func=pin_types.PASSIVE,unit=1),
            Pin(num='NB',name='NB',func=pin_types.PASSIVE,unit=1),
            Pin(num='P',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='T1',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='T2',func=pin_types.PASSIVE,unit=1),
            Pin(num='U',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='V',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='W',name='W',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'A2C50S65M2-F', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A2C50S65M2-F'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT'], 'footprint':'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'keywords':'IGBT Power Module Trench Field Stop Technology M series', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/a2c50s65m2-f.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nA2C50S65M2-F\n\nIGBT Power Module Trench Field Stop Technology M series', 'pins':[
            Pin(num='B',name='B',func=pin_types.PASSIVE,unit=1),
            Pin(num='EU',name='EU',func=pin_types.PASSIVE,unit=1),
            Pin(num='EV',name='EV',func=pin_types.PASSIVE,unit=1),
            Pin(num='EW',name='EW',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='G1',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='G2',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='G3',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='G4',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='G5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='G6',func=pin_types.PASSIVE,unit=1),
            Pin(num='GB',name='GB',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='L1',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='L2',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='L3',func=pin_types.PASSIVE,unit=1),
            Pin(num='N',name='N',func=pin_types.PASSIVE,unit=1),
            Pin(num='NB',name='NB',func=pin_types.PASSIVE,unit=1),
            Pin(num='P',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='T1',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='T2',func=pin_types.PASSIVE,unit=1),
            Pin(num='U',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='V',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='W',name='W',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FP10R06W1E3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FP10R06W1E3'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:Infineon_EasyPIM-1B'], 'footprint':'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'keywords':'IGBT Power Module Trench Field Stop Technology M series', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-FP10R06W1E3-DS-v02_01-en_de.pdf?fileId=db3a304412b407950112b43312285a63', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nFP10R06W1E3\n\nIGBT Power Module Trench Field Stop Technology M series', 'pins':[
            Pin(num='B',name='B',func=pin_types.PASSIVE,unit=1),
            Pin(num='EU',name='EU',func=pin_types.PASSIVE,unit=1),
            Pin(num='EV',name='EV',func=pin_types.PASSIVE,unit=1),
            Pin(num='EW',name='EW',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='G1',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='G2',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='G3',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='G4',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='G5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='G6',func=pin_types.PASSIVE,unit=1),
            Pin(num='GB',name='GB',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='L1',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='L2',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='L3',func=pin_types.PASSIVE,unit=1),
            Pin(num='N',name='N',func=pin_types.PASSIVE,unit=1),
            Pin(num='NB',name='NB',func=pin_types.PASSIVE,unit=1),
            Pin(num='P',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='T1',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='T2',func=pin_types.PASSIVE,unit=1),
            Pin(num='U',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='V',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='W',name='W',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FP15R06W1E3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FP15R06W1E3'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:Infineon_EasyPIM-1B', 'Transistor_Power_Module:Infineon_EasyPIM-1B'], 'footprint':'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'keywords':'IGBT Power Module Trench Field Stop Technology', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-FP15R06W1E3-DS-v02_01-en_de.pdf?fileId=db3a304412b407950112b43321b15a77', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nFP15R06W1E3\n\nIGBT Power Module Trench Field Stop Technology', 'pins':[
            Pin(num='B',name='B',func=pin_types.PASSIVE,unit=1),
            Pin(num='EU',name='EU',func=pin_types.PASSIVE,unit=1),
            Pin(num='EV',name='EV',func=pin_types.PASSIVE,unit=1),
            Pin(num='EW',name='EW',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='G1',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='G2',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='G3',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='G4',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='G5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='G6',func=pin_types.PASSIVE,unit=1),
            Pin(num='GB',name='GB',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='L1',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='L2',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='L3',func=pin_types.PASSIVE,unit=1),
            Pin(num='N',name='N',func=pin_types.PASSIVE,unit=1),
            Pin(num='NB',name='NB',func=pin_types.PASSIVE,unit=1),
            Pin(num='P',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='T1',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='T2',func=pin_types.PASSIVE,unit=1),
            Pin(num='U',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='V',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='W',name='W',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FP15R12W2T4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FP15R12W2T4'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:Infineon_EasyPIM-1B', 'Transistor_Power_Module:Infineon_EasyPIM-1B', 'Transistor_Power_Module:Infineon_EasyPIM-2B'], 'footprint':'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'keywords':'IGBT Power Module Trench Field Stop Technology', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-FP15R12W2T4-DS-v03_00-en_de.pdf?fileId=db3a30433ba77ced013bae67c3eb3a5e', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nFP15R12W2T4\n\nIGBT Power Module Trench Field Stop Technology', 'pins':[
            Pin(num='B',name='B',func=pin_types.PASSIVE,unit=1),
            Pin(num='EU',name='EU',func=pin_types.PASSIVE,unit=1),
            Pin(num='EV',name='EV',func=pin_types.PASSIVE,unit=1),
            Pin(num='EW',name='EW',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='G1',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='G2',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='G3',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='G4',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='G5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='G6',func=pin_types.PASSIVE,unit=1),
            Pin(num='GB',name='GB',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='L1',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='L2',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='L3',func=pin_types.PASSIVE,unit=1),
            Pin(num='N',name='N',func=pin_types.PASSIVE,unit=1),
            Pin(num='NB',name='NB',func=pin_types.PASSIVE,unit=1),
            Pin(num='P',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='T1',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='T2',func=pin_types.PASSIVE,unit=1),
            Pin(num='U',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='V',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='W',name='W',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FP25R12W2T4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FP25R12W2T4'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:Infineon_EasyPIM-1B', 'Transistor_Power_Module:Infineon_EasyPIM-1B', 'Transistor_Power_Module:Infineon_EasyPIM-2B', 'Transistor_Power_Module:Infineon_EasyPIM-2B'], 'footprint':'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'keywords':'IGBT Power Module Trench Field Stop Technology', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-FP25R12W2T4-DS-v02_02-EN.pdf?fileId=db3a3043163797a60116389cdaeb0183', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nFP25R12W2T4\n\nIGBT Power Module Trench Field Stop Technology', 'pins':[
            Pin(num='B',name='B',func=pin_types.PASSIVE,unit=1),
            Pin(num='EU',name='EU',func=pin_types.PASSIVE,unit=1),
            Pin(num='EV',name='EV',func=pin_types.PASSIVE,unit=1),
            Pin(num='EW',name='EW',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='G1',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='G2',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='G3',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='G4',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='G5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='G6',func=pin_types.PASSIVE,unit=1),
            Pin(num='GB',name='GB',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='L1',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='L2',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='L3',func=pin_types.PASSIVE,unit=1),
            Pin(num='N',name='N',func=pin_types.PASSIVE,unit=1),
            Pin(num='NB',name='NB',func=pin_types.PASSIVE,unit=1),
            Pin(num='P',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='T1',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='T2',func=pin_types.PASSIVE,unit=1),
            Pin(num='U',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='V',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='W',name='W',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FP25R12W2T4P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FP25R12W2T4P'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:Infineon_EasyPIM-1B', 'Transistor_Power_Module:Infineon_EasyPIM-1B', 'Transistor_Power_Module:Infineon_EasyPIM-2B', 'Transistor_Power_Module:Infineon_EasyPIM-2B', 'Transistor_Power_Module:Infineon_EasyPIM-2B'], 'footprint':'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'keywords':'IGBT Power Module Trench Field Stop Technology', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-FP25R12W2T4P-DS-v03_00-EN.pdf?fileId=5546d4625bd71aa0015bfbc806e571fc', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nFP25R12W2T4P\n\nIGBT Power Module Trench Field Stop Technology', 'pins':[
            Pin(num='B',name='B',func=pin_types.PASSIVE,unit=1),
            Pin(num='EU',name='EU',func=pin_types.PASSIVE,unit=1),
            Pin(num='EV',name='EV',func=pin_types.PASSIVE,unit=1),
            Pin(num='EW',name='EW',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='G1',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='G2',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='G3',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='G4',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='G5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='G6',func=pin_types.PASSIVE,unit=1),
            Pin(num='GB',name='GB',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='L1',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='L2',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='L3',func=pin_types.PASSIVE,unit=1),
            Pin(num='N',name='N',func=pin_types.PASSIVE,unit=1),
            Pin(num='NB',name='NB',func=pin_types.PASSIVE,unit=1),
            Pin(num='P',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='T1',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='T2',func=pin_types.PASSIVE,unit=1),
            Pin(num='U',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='V',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='W',name='W',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FP35R12W2T4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FP35R12W2T4'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:Infineon_EasyPIM-1B', 'Transistor_Power_Module:Infineon_EasyPIM-1B', 'Transistor_Power_Module:Infineon_EasyPIM-2B', 'Transistor_Power_Module:Infineon_EasyPIM-2B', 'Transistor_Power_Module:Infineon_EasyPIM-2B', 'Transistor_Power_Module:Infineon_EasyPIM-2B'], 'footprint':'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'keywords':'IGBT Power Module Trench Field Stop Technology', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-FP35R12W2T4-DS-v02_02-EN.pdf?fileId=db3a3043163797a6011638a0541501a0', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nFP35R12W2T4\n\nIGBT Power Module Trench Field Stop Technology', 'pins':[
            Pin(num='B',name='B',func=pin_types.PASSIVE,unit=1),
            Pin(num='EU',name='EU',func=pin_types.PASSIVE,unit=1),
            Pin(num='EV',name='EV',func=pin_types.PASSIVE,unit=1),
            Pin(num='EW',name='EW',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='G1',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='G2',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='G3',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='G4',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='G5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='G6',func=pin_types.PASSIVE,unit=1),
            Pin(num='GB',name='GB',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='L1',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='L2',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='L3',func=pin_types.PASSIVE,unit=1),
            Pin(num='N',name='N',func=pin_types.PASSIVE,unit=1),
            Pin(num='NB',name='NB',func=pin_types.PASSIVE,unit=1),
            Pin(num='P',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='T1',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='T2',func=pin_types.PASSIVE,unit=1),
            Pin(num='U',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='V',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='W',name='W',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FP35R12W2T4P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FP35R12W2T4P'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:Infineon_EasyPIM-1B', 'Transistor_Power_Module:Infineon_EasyPIM-1B', 'Transistor_Power_Module:Infineon_EasyPIM-2B', 'Transistor_Power_Module:Infineon_EasyPIM-2B', 'Transistor_Power_Module:Infineon_EasyPIM-2B', 'Transistor_Power_Module:Infineon_EasyPIM-2B', 'Transistor_Power_Module:Infineon_EasyPIM-2B'], 'footprint':'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'keywords':'IGBT Power Module Trench Field Stop Technology', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-FP35R12W2T4P-DS-v03_00-EN.pdf?fileId=5546d4625bd71aa0015bfbbf0d7a71f8', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nFP35R12W2T4P\n\nIGBT Power Module Trench Field Stop Technology', 'pins':[
            Pin(num='B',name='B',func=pin_types.PASSIVE,unit=1),
            Pin(num='EU',name='EU',func=pin_types.PASSIVE,unit=1),
            Pin(num='EV',name='EV',func=pin_types.PASSIVE,unit=1),
            Pin(num='EW',name='EW',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='G1',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='G2',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='G3',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='G4',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='G5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='G6',func=pin_types.PASSIVE,unit=1),
            Pin(num='GB',name='GB',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='L1',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='L2',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='L3',func=pin_types.PASSIVE,unit=1),
            Pin(num='N',name='N',func=pin_types.PASSIVE,unit=1),
            Pin(num='NB',name='NB',func=pin_types.PASSIVE,unit=1),
            Pin(num='P',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='T1',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='T2',func=pin_types.PASSIVE,unit=1),
            Pin(num='U',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='V',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='W',name='W',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FP50R06W2E3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FP50R06W2E3'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'Transistor_Power_Module:ST_ACEPACK-2-CIB_PressFIT', 'Transistor_Power_Module:Infineon_EasyPIM-1B', 'Transistor_Power_Module:Infineon_EasyPIM-1B', 'Transistor_Power_Module:Infineon_EasyPIM-2B', 'Transistor_Power_Module:Infineon_EasyPIM-2B', 'Transistor_Power_Module:Infineon_EasyPIM-2B', 'Transistor_Power_Module:Infineon_EasyPIM-2B', 'Transistor_Power_Module:Infineon_EasyPIM-2B', 'Transistor_Power_Module:Infineon_EasyPIM-2B'], 'footprint':'Transistor_Power_Module:ST_ACEPACK-2-CIB', 'keywords':'IGBT Power Module Trench Field Stop Technology', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-FP50R06W2E3-DS-v02_02-EN.pdf?fileId=db3a30431b3e89eb011b455c99987d24', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nFP50R06W2E3\n\nIGBT Power Module Trench Field Stop Technology', 'pins':[
            Pin(num='B',name='B',func=pin_types.PASSIVE,unit=1),
            Pin(num='EU',name='EU',func=pin_types.PASSIVE,unit=1),
            Pin(num='EV',name='EV',func=pin_types.PASSIVE,unit=1),
            Pin(num='EW',name='EW',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='G1',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='G2',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='G3',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='G4',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='G5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='G6',func=pin_types.PASSIVE,unit=1),
            Pin(num='GB',name='GB',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='L1',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='L2',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='L3',func=pin_types.PASSIVE,unit=1),
            Pin(num='N',name='N',func=pin_types.PASSIVE,unit=1),
            Pin(num='NB',name='NB',func=pin_types.PASSIVE,unit=1),
            Pin(num='P',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='P1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='T1',func=pin_types.PASSIVE,unit=1),
            Pin(num='T2',name='T2',func=pin_types.PASSIVE,unit=1),
            Pin(num='U',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='V',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='W',name='W',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MG12100W-XN2MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MG12100W-XN2MM'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:Littelfuse_Package_W_XN2MM', 'Transistor_Power_Module:Littelfuse_Package_W_XN2MM'], 'footprint':'Transistor_Power_Module:Littelfuse_Package_W_XN2MM', 'keywords':'IGBT Power Module Trench Field Stop Technology', 'description':'', 'datasheet':'https://www.littelfuse.com/~/media/electronics/datasheets/power_semiconductors/littelfuse_power_semiconductor_igbt_module_mg12100w_xn2mm_datasheet.pdf.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nMG12100W-XN2MM\n\nIGBT Power Module Trench Field Stop Technology', 'pins':[
            Pin(num='13',name='N1',func=pin_types.PASSIVE),
            Pin(num='14',name='N1',func=pin_types.PASSIVE),
            Pin(num='15',name='N1',func=pin_types.PASSIVE),
            Pin(num='16',name='P1',func=pin_types.PASSIVE),
            Pin(num='17',name='P1',func=pin_types.PASSIVE),
            Pin(num='18',name='P1',func=pin_types.PASSIVE),
            Pin(num='19',name='T1',func=pin_types.PASSIVE),
            Pin(num='20',name='T2',func=pin_types.PASSIVE),
            Pin(num='30',name='P1',func=pin_types.PASSIVE),
            Pin(num='31',name='P1',func=pin_types.PASSIVE),
            Pin(num='32',name='P1',func=pin_types.PASSIVE),
            Pin(num='33',name='N1',func=pin_types.PASSIVE),
            Pin(num='34',name='N1',func=pin_types.PASSIVE),
            Pin(num='35',name='N1',func=pin_types.PASSIVE),
            Pin(num='1',name='G1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='W',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='G6',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='N1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='W',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='W',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='W',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='G2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='N1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='G3',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='G4',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='N1',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='G5',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MG1225H-XBN2MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MG1225H-XBN2MM'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:Littelfuse_Package_H_XBN2MM', 'Transistor_Power_Module:Littelfuse_Package_H_XBN2MM'], 'footprint':'Transistor_Power_Module:Littelfuse_Package_H_XBN2MM', 'keywords':'IGBT Power Module Trench Field Stop Technology', 'description':'', 'datasheet':'https://www.littelfuse.com/~/media/electronics/datasheets/power_semiconductors/littelfuse_power_semiconductor_igbt_module_mg1225h_xbn2mm_datasheet.pdf.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nMG1225H-XBN2MM\n\nIGBT Power Module Trench Field Stop Technology', 'pins':[
            Pin(num='1',name='L1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='N1',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='G6',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='G4',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='G2',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='GB',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='W',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='G5',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='G3',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='L2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='G1',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='N',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='N1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='L3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='W',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='B',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='T1',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='T2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MG1225H-XN2MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MG1225H-XN2MM'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:Infineon_AG-ECONO2', 'Transistor_Power_Module:Littelfuse_Package_H_XN2MM'], 'footprint':'Transistor_Power_Module:Infineon_AG-ECONO2', 'keywords':'IGBT Power Module Trench Field Stop Technology', 'description':'', 'datasheet':'https://www.littelfuse.com/~/media/electronics/datasheets/power_semiconductors/littelfuse_power_semiconductor_igbt_module_mg1225h_xn2mm_datasheet.pdf.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nMG1225H-XN2MM\n\nIGBT Power Module Trench Field Stop Technology', 'pins':[
            Pin(num='13',name='N1',func=pin_types.PASSIVE),
            Pin(num='14',name='N1',func=pin_types.PASSIVE),
            Pin(num='15',name='P1',func=pin_types.PASSIVE),
            Pin(num='16',name='P1',func=pin_types.PASSIVE),
            Pin(num='17',name='T1',func=pin_types.PASSIVE),
            Pin(num='18',name='T2',func=pin_types.PASSIVE),
            Pin(num='19',name='W',func=pin_types.PASSIVE),
            Pin(num='20',name='W',func=pin_types.PASSIVE),
            Pin(num='21',name='V',func=pin_types.PASSIVE),
            Pin(num='22',name='V',func=pin_types.PASSIVE),
            Pin(num='23',name='U',func=pin_types.PASSIVE),
            Pin(num='24',name='U',func=pin_types.PASSIVE),
            Pin(num='25',name='P1',func=pin_types.PASSIVE),
            Pin(num='26',name='P1',func=pin_types.PASSIVE),
            Pin(num='27',name='N1',func=pin_types.PASSIVE),
            Pin(num='28',name='N1',func=pin_types.PASSIVE),
            Pin(num='1',name='G1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='W',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='G6',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='N1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='G2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='N1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='G3',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='G4',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='N1',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='G5',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MG1240H-XBN2MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MG1240H-XBN2MM'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:Littelfuse_Package_H_XBN2MM', 'Transistor_Power_Module:Littelfuse_Package_H_XBN2MM', 'Transistor_Power_Module:Littelfuse_Package_H_XBN2MM'], 'footprint':'Transistor_Power_Module:Littelfuse_Package_H_XBN2MM', 'keywords':'IGBT Power Module Trench Field Stop Technology', 'description':'', 'datasheet':'https://www.littelfuse.com/~/media/electronics/datasheets/power_semiconductors/littelfuse_power_semiconductor_igbt_module_mg1240h_xbn2mm_datasheet.pdf.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nMG1240H-XBN2MM\n\nIGBT Power Module Trench Field Stop Technology', 'pins':[
            Pin(num='1',name='L1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='N1',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='G6',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='G4',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='G2',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='GB',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='W',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='G5',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='G3',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='L2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='G1',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='N',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='N1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='L3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='W',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='B',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='T1',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='T2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MG1250H-XN2MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MG1250H-XN2MM'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:Infineon_AG-ECONO2', 'Transistor_Power_Module:Littelfuse_Package_H_XN2MM', 'Transistor_Power_Module:Littelfuse_Package_H_XN2MM'], 'footprint':'Transistor_Power_Module:Infineon_AG-ECONO2', 'keywords':'IGBT Power Module Trench Field Stop Technology', 'description':'', 'datasheet':'https://www.littelfuse.com/~/media/electronics/datasheets/power_semiconductors/littelfuse_power_semiconductor_igbt_module_mg1250h_xn2mm_datasheet.pdf.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nMG1250H-XN2MM\n\nIGBT Power Module Trench Field Stop Technology', 'pins':[
            Pin(num='13',name='N1',func=pin_types.PASSIVE),
            Pin(num='14',name='N1',func=pin_types.PASSIVE),
            Pin(num='15',name='P1',func=pin_types.PASSIVE),
            Pin(num='16',name='P1',func=pin_types.PASSIVE),
            Pin(num='17',name='T1',func=pin_types.PASSIVE),
            Pin(num='18',name='T2',func=pin_types.PASSIVE),
            Pin(num='19',name='W',func=pin_types.PASSIVE),
            Pin(num='20',name='W',func=pin_types.PASSIVE),
            Pin(num='21',name='V',func=pin_types.PASSIVE),
            Pin(num='22',name='V',func=pin_types.PASSIVE),
            Pin(num='23',name='U',func=pin_types.PASSIVE),
            Pin(num='24',name='U',func=pin_types.PASSIVE),
            Pin(num='25',name='P1',func=pin_types.PASSIVE),
            Pin(num='26',name='P1',func=pin_types.PASSIVE),
            Pin(num='27',name='N1',func=pin_types.PASSIVE),
            Pin(num='28',name='N1',func=pin_types.PASSIVE),
            Pin(num='1',name='G1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='W',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='G6',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='N1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='G2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='N1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='G3',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='G4',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='N1',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='G5',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MG1250W-XBN2MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MG1250W-XBN2MM'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:Littelfuse_Package_H_XBN2MM', 'Transistor_Power_Module:Littelfuse_Package_H_XBN2MM', 'Transistor_Power_Module:Littelfuse_Package_H_XBN2MM', 'Transistor_Power_Module:Littelfuse_Package_W_XBN2MM'], 'footprint':'Transistor_Power_Module:Littelfuse_Package_H_XBN2MM', 'keywords':'IGBT Power Module Trench Field Stop Technology', 'description':'', 'datasheet':'https://www.littelfuse.com/~/media/electronics/datasheets/power_semiconductors/littelfuse_power_semiconductor_igbt_module_mg1250w_xbn2mm_datasheet.pdf.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nMG1250W-XBN2MM\n\nIGBT Power Module Trench Field Stop Technology', 'pins':[
            Pin(num='1',name='L1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='N1',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='G6',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='G4',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='G2',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='GB',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='W',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='G5',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='G3',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='L2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='G1',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='N',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='N1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='L3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='W',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='B',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='T1',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='T2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MG1275W-XBN2MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MG1275W-XBN2MM'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:Littelfuse_Package_H_XBN2MM', 'Transistor_Power_Module:Littelfuse_Package_H_XBN2MM', 'Transistor_Power_Module:Littelfuse_Package_H_XBN2MM', 'Transistor_Power_Module:Littelfuse_Package_W_XBN2MM', 'Transistor_Power_Module:Littelfuse_Package_W_XBN2MM'], 'footprint':'Transistor_Power_Module:Littelfuse_Package_H_XBN2MM', 'keywords':'IGBT Power Module Trench Field Stop Technology', 'description':'', 'datasheet':'https://www.littelfuse.com/~/media/electronics/datasheets/power_semiconductors/littelfuse_power_semiconductor_igbt_module_mg1275w_xbn2mm_datasheet.pdf.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nMG1275W-XBN2MM\n\nIGBT Power Module Trench Field Stop Technology', 'pins':[
            Pin(num='1',name='L1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='N1',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='G6',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='G4',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='G2',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='GB',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='W',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='G5',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='G3',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='L2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='G1',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='N',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='N1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='L3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='W',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='B',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='T1',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='T2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STGIPS10K60A2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STGIPS10K60A2'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:ST_SDIP-25L', 'Transistor_Power_Module:ST_SDIP-25L'], 'footprint':'Transistor_Power_Module:ST_SDIP-25L', 'keywords':'SLLIMM IPM inverter short-circuit rugged IGBT', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stgips10k60a2.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nSTGIPS10K60A2\n\nSLLIMM IPM inverter short-circuit rugged IGBT', 'pins':[
            Pin(num='1',name='OUTU',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='HINV',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='OUTW',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='VBOOTW',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='LINW',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='HINW',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='T1',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='T2',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='NW',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='W',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VBOOTU',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='NV',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='NU',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='LINU',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='HINU',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='OUTV',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='VBOOTV',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='LINV',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STGIPS10K60T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STGIPS10K60T'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:ST_SDIP-25L', 'Transistor_Power_Module:ST_SDIP-25L'], 'footprint':'Transistor_Power_Module:ST_SDIP-25L', 'keywords':'SLLIMM IPM inverter short-circuit rugged IGBT', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stgips10k60t.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nSTGIPS10K60T\n\nSLLIMM IPM inverter short-circuit rugged IGBT', 'pins':[
            Pin(num='1',name='OUTU',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='HINV',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='OUTW',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='VBOOTW',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='~{LINW}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='HINW',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{SD}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='T1',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='NW',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='W',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VBOOTU',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='NV',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='NU',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~{LINU}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='HINU',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='OUTV',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='VBOOTV',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{LINV}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STGIPS14K60', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STGIPS14K60'}), 'ref_prefix':'U', 'fplist':['Transistor_Power_Module:ST_SDIP-25L', 'Transistor_Power_Module:ST_SDIP-25L'], 'footprint':'Transistor_Power_Module:ST_SDIP-25L', 'keywords':'SLLIMM IPM inverter short-circuit rugged IGBT', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stgips14k60.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Power_Module.kicad_sym\nSTGIPS14K60\n\nSLLIMM IPM inverter short-circuit rugged IGBT', 'pins':[
            Pin(num='1',name='OUTU',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='HINV',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='OUTW',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='VBOOTW',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='~{LINW}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='HINW',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{SD}/OD',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='CIN',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='NW',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='W',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VBOOTU',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='NV',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='V',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='NU',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='U',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='P',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~{LINU}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='HINU',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='OUTV',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='VBOOTV',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{LINV}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] })])