from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Timer_PLL = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'ADF4002BCPZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADF4002BCPZ'}), 'ref_prefix':'U', 'fplist':['Package_CSP:LFCSP-20-1EP_4x4mm_P0.5mm_EP2.1x2.1mm'], 'footprint':'Package_CSP:LFCSP-20-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'keywords':'Analog Devices PFD', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADF4002.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nADF4002BCPZ\n\nAnalog Devices PFD', 'pins':[
            Pin(num='1',name='CPGND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='CE',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='DATA',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='LE',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='MUXOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='DVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='VP',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='RSET',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='CP',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RFINB',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RFINA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='REFIN',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='DGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADF4002BRUZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADF4002BRUZ'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'Analog Devices PFD', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADF4002.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nADF4002BRUZ\n\nAnalog Devices PFD', 'pins':[
            Pin(num='1',name='RSET',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CE',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='DATA',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='LE',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='MUXOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VP',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CP',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='CPGND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='RFINB',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='RFINA',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='REFIN',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='DGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADF4158', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADF4158'}), 'ref_prefix':'U', 'fplist':['Package_CSP:LFCSP-24-1EP_4x4mm_P0.5mm_EP2.5x2.5mm'], 'footprint':'Package_CSP:LFCSP-24-1EP_4x4mm_P0.5mm_EP2.5x2.5mm', 'keywords':'fractional-N PLL', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADF4158.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nADF4158\n\nfractional-N PLL', 'pins':[
            Pin(num='1',name='CPGND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='SDGND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='TXDATA',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='CE',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='DATA',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='LE',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='MUXOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='SDVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='SW1',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='SW2',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='VP',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='RSET',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='CP',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RFINB',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RFINA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='REFIN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADF4351', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADF4351'}), 'ref_prefix':'U', 'fplist':['Package_CSP:LFCSP-32-1EP_5x5mm_P0.5mm_EP3.25x3.25mm'], 'footprint':'Package_CSP:LFCSP-32-1EP_5x5mm_P0.5mm_EP3.25x3.25mm', 'keywords':'fractional-N PLL', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADF4351.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nADF4351\n\nfractional-N PLL', 'pins':[
            Pin(num='1',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='AGNDVCO',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='RF_OUT_A+',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='RF_OUT_A-',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='RF_OUT_B+',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='RF_OUT_B-',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VVCO',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VVCO',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='AGNDVCO',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='TEMP',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DATA',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VTUNE',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='AGNDVCO',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='RSET',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='VCOM',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='VREF',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='LD',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PDB_RF',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='REFIN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='LE',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='MUXOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='SDGND',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='SDVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='EP',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='CE',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SW',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Vp',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='CPout',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='CPGND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CDCVF2505', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CDCVF2505'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'pll clock driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/cdcvf2505.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nCDCVF2505\n\npll clock driver', 'pins':[
            Pin(num='1',name='CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='1Y1',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='1Y0',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='1Y2',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='1Y3',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='CLKOUT',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CS2000-CP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CS2000-CP'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:MSOP-10_3x3mm_P0.5mm', 'keywords':'Clock Synthesizer Multiplier', 'description':'', 'datasheet':'https://statics.cirrus.com/pubs/proDatasheet/CS2000-CP_F3.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nCS2000-CP\n\nClock Synthesizer Multiplier', 'pins':[
            Pin(num='1',name='VD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SDA/CDIN',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CLK_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='AUX_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='CLK_IN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='XTO',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='XTI/REF_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='AD0/~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='SCL/CCLK',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ICS525-01R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ICS525-01R'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-28_3.9x9.9mm_P0.635mm'], 'footprint':'Package_SO:SSOP-28_3.9x9.9mm_P0.635mm', 'keywords':'Configurable clock', 'description':'', 'datasheet':'https://www.idt.com/document/dst/525-01-02-datasheet', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nICS525-01R\n\nConfigurable clock', 'pins':[
            Pin(num='1',name='R5',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='V0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='V1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='V2',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='V3',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='V4',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='V5',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='V6',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='V7',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='V8',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{PD}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='R6',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='CLK',func=pin_types.TRISTATE,unit=1),
            Pin(num='22',name='REF',func=pin_types.TRISTATE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='R0',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='R1',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='R2',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='R3',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='R4',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='S0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='S1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='S2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='X1/ICLK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='X2',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si5342A-D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si5342A-D'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'Clock Jitter Attenuator Multiplier', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/Si5345-44-42-D-DataSheet.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nSi5342A-D\n\nClock Jitter Attenuator Multiplier', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='IN2b',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SDA/SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A1/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='A0/~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VDDO0',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='OUT0b',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='IN1b',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='VDDO1',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='OUT1b',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='VDDS',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='~{LOL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='~{LOS_XAXB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='VDDS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN_SEL0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='~{LOS0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='~{LOS1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='~{INTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='VDDS',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='~{LOS2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='~{LOS3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='IN_SEL1',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='I2C_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='X1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='IN3/FB_IN',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='IN3b/FB_INb',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='IN0b',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='XB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='X2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si5344A-D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si5344A-D'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'Clock Jitter Attenuator Multiplier', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/Si5345-44-42-D-DataSheet.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nSi5344A-D\n\nClock Jitter Attenuator Multiplier', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='IN2b',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SDA/SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A1/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='A0/~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VDDO0',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='OUT0b',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='IN1b',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='VDDO1',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='OUT1b',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='VDDS',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='~{LOL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='~{LOS_XAXB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='VDDO2',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN_SEL0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='OUT2b',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='~{INTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='VDDO3',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='OUT3b',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='IN_SEL1',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='I2C_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='X1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='IN3/FB_IN',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='IN3b/FB_INb',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='IN0b',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='XB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='X2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si5345A-D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si5345A-D'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.2x5.2mm', 'keywords':'Clock Jitter Attenuator Multiplier', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/Si5345-44-42-D-DataSheet.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nSi5345A-D\n\nClock Jitter Attenuator Multiplier', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='X2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{INTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='IN2b',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='A1/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SDA/SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='A0/~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IN1b',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='VDDO0',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='OUT0b',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='FDEC',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='VDDO1',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='OUT1b',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='VDDO2',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN_SEL0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='OUT2b',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VDDO3',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='OUT3b',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='VDDO4',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='OUT4b',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='OUT4',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='I2C_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN_SEL1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VDDO5',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='OUT5b',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='OUT5',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='VDDO6',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='OUT6b',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='OUT6',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='~{LOL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='FINC',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDDO7',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='50',name='OUT7b',func=pin_types.OUTPUT,unit=1),
            Pin(num='51',name='OUT7',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='VDDO8',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='OUT8b',func=pin_types.OUTPUT,unit=1),
            Pin(num='54',name='OUT8',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='56',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='57',name='VDDO9',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='OUT9b',func=pin_types.OUTPUT,unit=1),
            Pin(num='59',name='OUT9',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='IN3/FB_IN',func=pin_types.INPUT,unit=1),
            Pin(num='62',name='IN3b/FB_INb',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='64',name='IN0b',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='X1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='XA',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='XB',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADF4350', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADF4350'}), 'ref_prefix':'U', 'fplist':['Package_CSP:LFCSP-32-1EP_5x5mm_P0.5mm_EP3.25x3.25mm', 'Package_CSP:LFCSP-32-1EP_5x5mm_P0.5mm_EP3.25x3.25mm'], 'footprint':'Package_CSP:LFCSP-32-1EP_5x5mm_P0.5mm_EP3.25x3.25mm', 'keywords':'fractional-N PLL', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADF4350.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nADF4350\n\nfractional-N PLL', 'pins':[
            Pin(num='1',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='AGNDVCO',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='RF_OUT_A+',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='RF_OUT_A-',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='RF_OUT_B+',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='RF_OUT_B-',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VVCO',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VVCO',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='AGNDVCO',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='TEMP',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DATA',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VTUNE',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='AGNDVCO',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='RSET',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='VCOM',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='VREF',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='LD',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PDB_RF',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='REFIN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='LE',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='MUXOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='SDGND',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='SDVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='EP',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='CE',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SW',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Vp',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='CPout',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='CPGND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ICS525R-02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ICS525R-02'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-28_3.9x9.9mm_P0.635mm', 'Package_SO:SSOP-28_3.9x9.9mm_P0.635mm'], 'footprint':'Package_SO:SSOP-28_3.9x9.9mm_P0.635mm', 'keywords':'Configurable clock', 'description':'', 'datasheet':'https://www.idt.com/document/dst/525-01-02-datasheet', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nICS525R-02\n\nConfigurable clock', 'pins':[
            Pin(num='1',name='R5',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='V0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='V1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='V2',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='V3',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='V4',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='V5',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='V6',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='V7',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='V8',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{PD}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='R6',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='CLK',func=pin_types.TRISTATE,unit=1),
            Pin(num='22',name='REF',func=pin_types.TRISTATE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='R0',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='R1',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='R2',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='R3',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='R4',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='S0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='S1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='S2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='X1/ICLK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='X2',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si5342B-D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si5342B-D'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'Clock Jitter Attenuator Multiplier', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/Si5345-44-42-D-DataSheet.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nSi5342B-D\n\nClock Jitter Attenuator Multiplier', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='IN2b',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SDA/SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A1/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='A0/~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VDDO0',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='OUT0b',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='IN1b',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='VDDO1',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='OUT1b',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='VDDS',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='~{LOL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='~{LOS_XAXB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='VDDS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN_SEL0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='~{LOS0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='~{LOS1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='~{INTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='VDDS',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='~{LOS2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='~{LOS3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='IN_SEL1',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='I2C_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='X1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='IN3/FB_IN',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='IN3b/FB_INb',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='IN0b',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='XB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='X2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si5342C-D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si5342C-D'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'Clock Jitter Attenuator Multiplier', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/Si5345-44-42-D-DataSheet.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nSi5342C-D\n\nClock Jitter Attenuator Multiplier', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='IN2b',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SDA/SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A1/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='A0/~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VDDO0',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='OUT0b',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='IN1b',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='VDDO1',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='OUT1b',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='VDDS',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='~{LOL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='~{LOS_XAXB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='VDDS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN_SEL0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='~{LOS0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='~{LOS1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='~{INTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='VDDS',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='~{LOS2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='~{LOS3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='IN_SEL1',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='I2C_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='X1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='IN3/FB_IN',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='IN3b/FB_INb',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='IN0b',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='XB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='X2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si5342D-D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si5342D-D'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'Clock Jitter Attenuator Multiplier', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/Si5345-44-42-D-DataSheet.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nSi5342D-D\n\nClock Jitter Attenuator Multiplier', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='IN2b',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SDA/SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A1/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='A0/~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VDDO0',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='OUT0b',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='IN1b',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='VDDO1',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='OUT1b',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='VDDS',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='~{LOL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='~{LOS_XAXB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='VDDS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN_SEL0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='~{LOS0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='~{LOS1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='~{INTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='VDDS',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='~{LOS2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='~{LOS3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='IN_SEL1',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='I2C_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='X1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='IN3/FB_IN',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='IN3b/FB_INb',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='IN0b',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='XB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='X2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si5344B-D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si5344B-D'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'Clock Jitter Attenuator Multiplier', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/Si5345-44-42-D-DataSheet.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nSi5344B-D\n\nClock Jitter Attenuator Multiplier', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='IN2b',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SDA/SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A1/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='A0/~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VDDO0',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='OUT0b',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='IN1b',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='VDDO1',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='OUT1b',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='VDDS',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='~{LOL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='~{LOS_XAXB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='VDDO2',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN_SEL0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='OUT2b',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='~{INTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='VDDO3',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='OUT3b',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='IN_SEL1',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='I2C_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='X1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='IN3/FB_IN',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='IN3b/FB_INb',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='IN0b',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='XB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='X2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si5344C-D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si5344C-D'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'Clock Jitter Attenuator Multiplier', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/Si5345-44-42-D-DataSheet.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nSi5344C-D\n\nClock Jitter Attenuator Multiplier', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='IN2b',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SDA/SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A1/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='A0/~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VDDO0',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='OUT0b',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='IN1b',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='VDDO1',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='OUT1b',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='VDDS',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='~{LOL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='~{LOS_XAXB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='VDDO2',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN_SEL0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='OUT2b',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='~{INTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='VDDO3',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='OUT3b',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='IN_SEL1',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='I2C_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='X1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='IN3/FB_IN',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='IN3b/FB_INb',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='IN0b',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='XB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='X2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si5344D-D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si5344D-D'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'Clock Jitter Attenuator Multiplier', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/Si5345-44-42-D-DataSheet.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nSi5344D-D\n\nClock Jitter Attenuator Multiplier', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='IN2b',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SDA/SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A1/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='A0/~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VDDO0',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='OUT0b',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='IN1b',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='VDDO1',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='OUT1b',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='VDDS',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='~{LOL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='~{LOS_XAXB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='VDDO2',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN_SEL0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='OUT2b',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='~{INTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='VDDO3',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='OUT3b',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='IN_SEL1',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='I2C_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='X1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='IN3/FB_IN',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='IN3b/FB_INb',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='IN0b',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='XB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='X2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si5345B-D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si5345B-D'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.2x5.2mm', 'keywords':'Clock Jitter Attenuator Multiplier', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/Si5345-44-42-D-DataSheet.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nSi5345B-D\n\nClock Jitter Attenuator Multiplier', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='X2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{INTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='IN2b',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='A1/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SDA/SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='A0/~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IN1b',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='VDDO0',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='OUT0b',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='FDEC',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='VDDO1',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='OUT1b',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='VDDO2',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN_SEL0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='OUT2b',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VDDO3',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='OUT3b',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='VDDO4',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='OUT4b',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='OUT4',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='I2C_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN_SEL1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VDDO5',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='OUT5b',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='OUT5',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='VDDO6',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='OUT6b',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='OUT6',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='~{LOL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='FINC',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDDO7',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='50',name='OUT7b',func=pin_types.OUTPUT,unit=1),
            Pin(num='51',name='OUT7',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='VDDO8',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='OUT8b',func=pin_types.OUTPUT,unit=1),
            Pin(num='54',name='OUT8',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='56',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='57',name='VDDO9',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='OUT9b',func=pin_types.OUTPUT,unit=1),
            Pin(num='59',name='OUT9',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='IN3/FB_IN',func=pin_types.INPUT,unit=1),
            Pin(num='62',name='IN3b/FB_INb',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='64',name='IN0b',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='X1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='XA',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='XB',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si5345C-D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si5345C-D'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.2x5.2mm', 'keywords':'Clock Jitter Attenuator Multiplier', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/Si5345-44-42-D-DataSheet.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nSi5345C-D\n\nClock Jitter Attenuator Multiplier', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='X2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{INTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='IN2b',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='A1/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SDA/SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='A0/~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IN1b',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='VDDO0',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='OUT0b',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='FDEC',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='VDDO1',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='OUT1b',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='VDDO2',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN_SEL0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='OUT2b',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VDDO3',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='OUT3b',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='VDDO4',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='OUT4b',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='OUT4',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='I2C_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN_SEL1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VDDO5',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='OUT5b',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='OUT5',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='VDDO6',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='OUT6b',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='OUT6',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='~{LOL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='FINC',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDDO7',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='50',name='OUT7b',func=pin_types.OUTPUT,unit=1),
            Pin(num='51',name='OUT7',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='VDDO8',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='OUT8b',func=pin_types.OUTPUT,unit=1),
            Pin(num='54',name='OUT8',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='56',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='57',name='VDDO9',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='OUT9b',func=pin_types.OUTPUT,unit=1),
            Pin(num='59',name='OUT9',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='IN3/FB_IN',func=pin_types.INPUT,unit=1),
            Pin(num='62',name='IN3b/FB_INb',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='64',name='IN0b',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='X1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='XA',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='XB',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si5345D-D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si5345D-D'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.2x5.2mm', 'keywords':'Clock Jitter Attenuator Multiplier', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/Si5345-44-42-D-DataSheet.pdf', 'search_text':'/usr/share/kicad/symbols/Timer_PLL.kicad_sym\nSi5345D-D\n\nClock Jitter Attenuator Multiplier', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='X2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{INTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='IN2b',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='A1/SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SDA/SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='A0/~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IN1b',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='VDDO0',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='OUT0b',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='OUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='FDEC',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='VDDO1',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='OUT1b',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='VDDO2',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN_SEL0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='OUT2b',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VDDO3',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='OUT3b',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='VDDO4',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='OUT4b',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='OUT4',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='I2C_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN_SEL1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VDDO5',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='OUT5b',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='OUT5',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='VDDO6',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='OUT6b',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='OUT6',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='~{LOL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='FINC',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='VDDO7',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='50',name='OUT7b',func=pin_types.OUTPUT,unit=1),
            Pin(num='51',name='OUT7',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='VDDO8',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='OUT8b',func=pin_types.OUTPUT,unit=1),
            Pin(num='54',name='OUT8',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='56',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='57',name='VDDO9',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='OUT9b',func=pin_types.OUTPUT,unit=1),
            Pin(num='59',name='OUT9',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='IN3/FB_IN',func=pin_types.INPUT,unit=1),
            Pin(num='62',name='IN3b/FB_INb',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='64',name='IN0b',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='X1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='XA',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='XB',func=pin_types.INPUT,unit=1)], 'unit_defs':[] })])