from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Driver_Display = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'82720', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'82720'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'Graphics Controller', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Driver_Display.kicad_sym\n82720\n\nGraphics Controller', 'pins':[
            Pin(num='1',name='2xWCLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{WR}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='DB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='DB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='DB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='DB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='DB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='DB6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='DB7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='~{DBIN}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='LPEN',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='AD0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='AD1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='AD2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='AD3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='AD4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AD5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='AD6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='AD7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='HSYNC',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='AD8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='AD9',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='AD10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='AD14',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='AD12',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='AD13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='AD14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='AD15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='A16',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='A17',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='VSYNC',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='BLANK',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='(ALE)~{RAS}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='DREQ',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='~{DACK}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{RD}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS7843E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS7843E'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-16_3.9x4.9mm_P0.635mm'], 'footprint':'Package_SO:SSOP-16_3.9x4.9mm_P0.635mm', 'keywords':'Single-supply, 12bit, 4 ch, touch screen driver, 2.2 - 5.25 VDD, -40 to +85 C, QSPI, SPI, 3-wire serial interface, SSOP-16', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads7843.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Display.kicad_sym\nADS7843E\n\nSingle-supply, 12bit, 4 ch, touch screen driver, 2.2 - 5.25 VDD, -40 to +85 C, QSPI, SPI, 3-wire serial interface, SSOP-16', 'pins':[
            Pin(num='1',name='+VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='+VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{PENIRQ}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='BUSY',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='DCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='X+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Y+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='X-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Y-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VREF',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AY0438X-L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AY0438X-L'}), 'ref_prefix':'U', 'fplist':['Package_LCC:PLCC-44'], 'footprint':'Package_LCC:PLCC-44', 'keywords':'driver display', 'description':'', 'datasheet':'http://www.farnell.com/datasheets/43336.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Display.kicad_sym\nAY0438X-L\n\ndriver display', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SEG_26',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='SEG_25',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='SEG_24',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='SEG_23',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='SEG_22',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SEG_21',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='SEG_20',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='SEG_19',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='SEG_18',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='SEG_17',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='LOAD',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='SEG_16',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='SEG_15',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='SEG_14',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='SEG_13',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='SEG_12',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='SEG_11',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='SEG_10',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='SEG_9',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='29',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='SEG_32',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='SEG_8',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='SEG_7',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='SEG_6',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='BP',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='LCD0',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='SEG_5',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='SEG_4',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='DATA_IN',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='DATA_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='SEG_31',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='SEG_3',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='SEG_2',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='SEG_1',func=pin_types.OUTPUT,unit=1),
            Pin(num='44',name='CLOCK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SEG_30',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='SEG_29',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='SEG_28',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='SEG_27',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AY0438X-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AY0438X-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'driver display', 'description':'', 'datasheet':'http://www.farnell.com/datasheets/43336.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Display.kicad_sym\nAY0438X-P\n\ndriver display', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SEG_25',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='SEG_24',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='SEG_23',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='SEG_22',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='SEG_21',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SEG_20',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='SEG_19',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='SEG_18',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='SEG_17',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='SEG_16',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='LOAD',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='SEG_15',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='SEG_14',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='SEG_13',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='SEG_12',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='SEG_11',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='SEG_10',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='SEG_9',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='SEG_8',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='SEG_7',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='SEG_6',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='SEG_32',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='BP',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='LCD0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='SEG_5',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='SEG_4',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='DATA_IN',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='DATA_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='SEG_3',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='SEG_2',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='SEG_1',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='SEG_31',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='CLOCK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SEG_30',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='SEG_29',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='SEG_28',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='SEG_27',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='SEG_26',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CR2013-MI2120', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CR2013-MI2120'}), 'ref_prefix':'U', 'fplist':['Display:CR2013-MI2120'], 'footprint':'Display:CR2013-MI2120', 'keywords':'driver display', 'description':'', 'datasheet':'http://pan.baidu.com/s/11Y990', 'search_text':'/usr/share/kicad/symbols/Driver_Display.kicad_sym\nCR2013-MI2120\n\ndriver display', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SD_CS',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SD_MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SD_MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='SD_SCK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='FLASH_CD',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D/~{C}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='LED',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='MISO',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XPT2046QF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XPT2046QF'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-16-1EP_4x4mm_P0.65mm_EP2.1x2.1mm'], 'footprint':'Package_DFN_QFN:QFN-16-1EP_4x4mm_P0.65mm_EP2.1x2.1mm', 'keywords':'', 'description':'', 'datasheet':'http://www.xptek.cn/uploadfile/download/201707171401161883.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Display.kicad_sym\nXPT2046QF\n\n', 'pins':[
            Pin(num='1',name='BUSY',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='AUX',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='VREF',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='IOVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='~{PENIRQ}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='DCLK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XP',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='YP',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='XN',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='YN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XPT2046TS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XPT2046TS'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'Single-supply, 12bit, 4 ch, touch screen driver, 2.2 - 5.25 VDD, -40 to +85 C, QSPI, SPI, 3-wire serial interface, TSSOP-16', 'description':'', 'datasheet':'http://www.xptek.cn/uploadfile/download/201707171401161883.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Display.kicad_sym\nXPT2046TS\n\nSingle-supply, 12bit, 4 ch, touch screen driver, 2.2 - 5.25 VDD, -40 to +85 C, QSPI, SPI, 3-wire serial interface, TSSOP-16', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IOVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{PENIRQ}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='BUSY',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='DCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='XP',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='YP',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='XN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='YN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VREF',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS7843E-2K5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS7843E-2K5'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-16_3.9x4.9mm_P0.635mm', 'Package_SO:SSOP-16_3.9x4.9mm_P0.635mm'], 'footprint':'Package_SO:SSOP-16_3.9x4.9mm_P0.635mm', 'keywords':'Single-supply, 12bit, 4 ch, touch screen driver, 2.2 - 5.25 VDD, -40 to +85 C, QSPI, SPI, 3-wire serial interface, SSOP-16', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads7843.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Display.kicad_sym\nADS7843E-2K5\n\nSingle-supply, 12bit, 4 ch, touch screen driver, 2.2 - 5.25 VDD, -40 to +85 C, QSPI, SPI, 3-wire serial interface, SSOP-16', 'pins':[
            Pin(num='1',name='+VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='+VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{PENIRQ}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='BUSY',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='DCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='X+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Y+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='X-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Y-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VREF',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS7843EG4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS7843EG4'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-16_3.9x4.9mm_P0.635mm', 'Package_SO:SSOP-16_3.9x4.9mm_P0.635mm', 'Package_SO:SSOP-16_3.9x4.9mm_P0.635mm'], 'footprint':'Package_SO:SSOP-16_3.9x4.9mm_P0.635mm', 'keywords':'Single-supply, 12bit, 4 ch, touch screen driver, 2.2 - 5.25 VDD, -40 to +85 C, QSPI, SPI, 3-wire serial interface, SSOP-16', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads7843.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Display.kicad_sym\nADS7843EG4\n\nSingle-supply, 12bit, 4 ch, touch screen driver, 2.2 - 5.25 VDD, -40 to +85 C, QSPI, SPI, 3-wire serial interface, SSOP-16', 'pins':[
            Pin(num='1',name='+VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='+VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{PENIRQ}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='BUSY',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='DCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='X+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Y+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='X-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Y-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VREF',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADS7843IDBQRQ1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADS7843IDBQRQ1'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-16_3.9x4.9mm_P0.635mm', 'Package_SO:SSOP-16_3.9x4.9mm_P0.635mm', 'Package_SO:SSOP-16_3.9x4.9mm_P0.635mm', 'Package_SO:SSOP-16_3.9x4.9mm_P0.635mm'], 'footprint':'Package_SO:SSOP-16_3.9x4.9mm_P0.635mm', 'keywords':'Single-supply, 12bit, 4 ch, touch screen driver, 2.2 - 5.25 VDD, -40 to +125 C, QSPI, SPI, 3-wire serial interface, SSOP-16', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ads7843-q1.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Display.kicad_sym\nADS7843IDBQRQ1\n\nSingle-supply, 12bit, 4 ch, touch screen driver, 2.2 - 5.25 VDD, -40 to +125 C, QSPI, SPI, 3-wire serial interface, SSOP-16', 'pins':[
            Pin(num='1',name='+VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='+VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{PENIRQ}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='BUSY',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='DCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='X+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Y+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='X-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Y-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VREF',func=pin_types.INPUT,unit=1)], 'unit_defs':[] })])