from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

RF_AM_FM = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'LA1185', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LA1185'}), 'ref_prefix':'U', 'fplist':['Package_SIP:SIP-9_22.3x3mm_P2.54mm'], 'footprint':'Package_SIP:SIP-9_22.3x3mm_P2.54mm', 'keywords':'FM mixer receiver amplifier', 'description':'', 'datasheet':'https://www.alldatasheet.com/datasheet-pdf/pdf/39974/SANYO/LA1185.html', 'search_text':'/usr/share/kicad/symbols/RF_AM_FM.kicad_sym\nLA1185\n\nFM mixer receiver amplifier', 'pins':[
            Pin(num='1',name='RF_IN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='RF_BYPASS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RF_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='MIX_IN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='MIX_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='OSC_MON',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='OSC',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCS3142', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCS3142'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'KEELOQ classic ultimate keyless entry keyfob ISM', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001747A.pdf', 'search_text':'/usr/share/kicad/symbols/RF_AM_FM.kicad_sym\nMCS3142\n\nKEELOQ classic ultimate keyless entry keyfob ISM', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RF_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='DATA_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='XTAL',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='CTRL_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='DATA_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='~{LED}',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='SW2',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='SW1',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='SW0',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='SOSCI',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='SOSCO',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='SW3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PGC',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='PGD',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='CTRL_IN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SA605D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SA605D'}), 'ref_prefix':'U', 'fplist':['Package_SO:SO-20_12.8x7.5mm_P1.27mm'], 'footprint':'Package_SO:SO-20_12.8x7.5mm_P1.27mm', 'keywords':'High performance monolithic low-power FM IF system', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/SA605.pdf', 'search_text':'/usr/share/kicad/symbols/RF_AM_FM.kicad_sym\nSA605D\n\nHigh performance monolithic low-power FM IF system', 'pins':[
            Pin(num='1',name='RF_IN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='QUADRATURE_IN',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='LIMITER_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='LIMITER_DECOUPL',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='LIMITER_DECOUPL',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='LIMITER_IN',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='IF_AMP_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='IF_AMP_DECOUPL',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='IF_AMP_IN',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='IF_AMP_DECOUPL',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='RF_BYPASS',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='MIXER_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='OSC_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='MUTE_INPUT',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='RSSI_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='MUTED_AUD_OUTP',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='UNMUTED_AUD_OUTP',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SA636DK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SA636DK'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:SSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'Low-voltage, monolithic, FM, IF, RSSI', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/SA636.pdf', 'search_text':'/usr/share/kicad/symbols/RF_AM_FM.kicad_sym\nSA636DK\n\nLow-voltage, monolithic, FM, IF, RSSI', 'pins':[
            Pin(num='1',name='RF_IN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='QUADRATURE_IN',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='LIMITER_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='LIMITER_DECOUPL',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='LIMITER_DECOUPL',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='LIMITER_IN',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='IF_AMP_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='IF_AMP_DECOUPL',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='IF_AMP_IN',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='IF_AMP_DECOUPL',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='RF_IN_DECOUPL',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='MIXER_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='OSC_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RSSI_FEEDBACK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='RSSI_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='POWER_DOWN_CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='DATA_OUT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si4362', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si4362'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.5x2.5mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.5x2.5mm', 'keywords':'radio receiver', 'description':'', 'datasheet':'http://www.silabs.com/Support%20Documents/TechnicalDocs/Si4362.pdf', 'search_text':'/usr/share/kicad/symbols/RF_AM_FM.kicad_sym\nSi4362\n\nradio receiver', 'pins':[
            Pin(num='1',name='SDN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='~{IRQ}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{SEL}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='GPIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RXp',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='GPIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='RXn',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='GPIO0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si4735-D60-GU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si4735-D60-GU'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-24_3.9x8.7mm_P0.635mm'], 'footprint':'Package_SO:SSOP-24_3.9x8.7mm_P0.635mm', 'keywords':'Broadcast AM FM SW LW Radio Receiver RDS RBDS', 'description':'', 'datasheet':'http://www.silabs.com/Support%20Documents/TechnicalDocs/Si4730-31-34-35-D60.pdf', 'search_text':'/usr/share/kicad/symbols/RF_AM_FM.kicad_sym\nSi4735-D60-GU\n\nBroadcast AM FM SW LW Radio Receiver RDS RBDS', 'pins':[
            Pin(num='1',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='AMI',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='~{SEN}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DFS',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='DBYP',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='ROUT/[DOUT]',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='LOUT/[DFS]',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GPO3/[DCLK]',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GPO2/[~{INT}]',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='GPO1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='FMI',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='RFGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ZETA-433-SO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ZETA-433-SO'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'RF TRANSCEIVER MODULE', 'description':'', 'datasheet':'https://www.rfsolutions.co.uk/downloads/1456219226DS-ZETA.pdf', 'search_text':'/usr/share/kicad/symbols/RF_AM_FM.kicad_sym\nZETA-433-SO\n\nRF TRANSCEIVER MODULE', 'pins':[
            Pin(num='1',name='ANT',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='SEL',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='SDN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~{IRQ}',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GPIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SCLK',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SA605DK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SA605DK'}), 'ref_prefix':'U', 'fplist':['Package_SO:SO-20_12.8x7.5mm_P1.27mm', 'Package_SO:SSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:SO-20_12.8x7.5mm_P1.27mm', 'keywords':'High performance monolithic low-power FM IF system', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/SA605.pdf', 'search_text':'/usr/share/kicad/symbols/RF_AM_FM.kicad_sym\nSA605DK\n\nHigh performance monolithic low-power FM IF system', 'pins':[
            Pin(num='1',name='RF_IN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='QUADRATURE_IN',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='LIMITER_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='LIMITER_DECOUPL',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='LIMITER_DECOUPL',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='LIMITER_IN',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='IF_AMP_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='IF_AMP_DECOUPL',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='IF_AMP_IN',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='IF_AMP_DECOUPL',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='RF_BYPASS',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='MIXER_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='OSC_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='MUTE_INPUT',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='RSSI_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='MUTED_AUD_OUTP',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='UNMUTED_AUD_OUTP',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si4730-D60-GU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si4730-D60-GU'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-24_3.9x8.7mm_P0.635mm', 'Package_SO:SSOP-24_3.9x8.7mm_P0.635mm'], 'footprint':'Package_SO:SSOP-24_3.9x8.7mm_P0.635mm', 'keywords':'Broadcast AM FM Radio Receiver', 'description':'', 'datasheet':'http://www.silabs.com/Support%20Documents/TechnicalDocs/Si4730-31-34-35-D60.pdf', 'search_text':'/usr/share/kicad/symbols/RF_AM_FM.kicad_sym\nSi4730-D60-GU\n\nBroadcast AM FM Radio Receiver', 'pins':[
            Pin(num='1',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='AMI',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='~{SEN}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DFS',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='DBYP',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='ROUT/[DOUT]',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='LOUT/[DFS]',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GPO3/[DCLK]',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GPO2/[~{INT}]',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='GPO1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='FMI',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='RFGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si4731-D60-GU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si4731-D60-GU'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-24_3.9x8.7mm_P0.635mm', 'Package_SO:SSOP-24_3.9x8.7mm_P0.635mm', 'Package_SO:SSOP-24_3.9x8.7mm_P0.635mm'], 'footprint':'Package_SO:SSOP-24_3.9x8.7mm_P0.635mm', 'keywords':'Broadcast AM FM Radio Receiver RDS RBDS', 'description':'', 'datasheet':'http://www.silabs.com/Support%20Documents/TechnicalDocs/Si4730-31-34-35-D60.pdf', 'search_text':'/usr/share/kicad/symbols/RF_AM_FM.kicad_sym\nSi4731-D60-GU\n\nBroadcast AM FM Radio Receiver RDS RBDS', 'pins':[
            Pin(num='1',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='AMI',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='~{SEN}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DFS',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='DBYP',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='ROUT/[DOUT]',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='LOUT/[DFS]',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GPO3/[DCLK]',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GPO2/[~{INT}]',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='GPO1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='FMI',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='RFGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si4734-D60-GU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si4734-D60-GU'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-24_3.9x8.7mm_P0.635mm', 'Package_SO:SSOP-24_3.9x8.7mm_P0.635mm', 'Package_SO:SSOP-24_3.9x8.7mm_P0.635mm', 'Package_SO:SSOP-24_3.9x8.7mm_P0.635mm'], 'footprint':'Package_SO:SSOP-24_3.9x8.7mm_P0.635mm', 'keywords':'Broadcast AM FM SW LW Radio Receiver', 'description':'', 'datasheet':'http://www.silabs.com/Support%20Documents/TechnicalDocs/Si4730-31-34-35-D60.pdf', 'search_text':'/usr/share/kicad/symbols/RF_AM_FM.kicad_sym\nSi4734-D60-GU\n\nBroadcast AM FM SW LW Radio Receiver', 'pins':[
            Pin(num='1',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='AMI',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='~{SEN}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RCLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DFS',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='DBYP',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='ROUT/[DOUT]',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='LOUT/[DFS]',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GPO3/[DCLK]',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GPO2/[~{INT}]',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='GPO1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='FMI',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='RFGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ZETA-868-SO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ZETA-868-SO'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'RF TRANSCEIVER MODULE', 'description':'', 'datasheet':'https://www.rfsolutions.co.uk/downloads/1456219226DS-ZETA.pdf', 'search_text':'/usr/share/kicad/symbols/RF_AM_FM.kicad_sym\nZETA-868-SO\n\nRF TRANSCEIVER MODULE', 'pins':[
            Pin(num='1',name='ANT',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='SEL',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='SDN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~{IRQ}',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GPIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SCLK',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ZETA-915-SO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ZETA-915-SO'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'RF TRANSCEIVER MODULE', 'description':'', 'datasheet':'https://www.rfsolutions.co.uk/downloads/1456219226DS-ZETA.pdf', 'search_text':'/usr/share/kicad/symbols/RF_AM_FM.kicad_sym\nZETA-915-SO\n\nRF TRANSCEIVER MODULE', 'pins':[
            Pin(num='1',name='ANT',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='SEL',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='SDN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~{IRQ}',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GPIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SCLK',func=pin_types.INPUT,unit=1)], 'unit_defs':[] })])