from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Connector = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'4P2C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4P2C'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'4P2C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\n4P2C\n\n4P2C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4P2C_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4P2C_Shielded'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'4P2C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\n4P2C_Shielded\n\n4P2C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4P4C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4P4C'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'4P4C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\n4P4C\n\n4P4C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'4P4C_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'4P4C_Shielded'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'4P4C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\n4P4C_Shielded\n\n4P4C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'6P2C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'6P2C'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'6P2C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\n6P2C\n\n6P2C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'6P2C_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'6P2C_Shielded'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'6P2C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\n6P2C_Shielded\n\n6P2C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'6P4C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'6P4C'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'6P4C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\n6P4C\n\n6P4C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'6P4C_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'6P4C_Shielded'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'6P4C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\n6P4C_Shielded\n\n6P4C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'6P6C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'6P6C'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'6P6C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\n6P6C\n\n6P6C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'6P6C_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'6P6C_Shielded'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'6P6C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\n6P6C_Shielded\n\n6P6C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'8P4C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'8P4C'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'8P4C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\n8P4C\n\n8P4C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'8P4C_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'8P4C_Shielded'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'8P4C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\n8P4C_Shielded\n\n8P4C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'8P8C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'8P8C'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'8P8C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\n8P8C\n\n8P8C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'8P8C_LED', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'8P8C_LED'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'8P8C RJ socket connector led', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\n8P8C_LED\n\n8P8C RJ socket connector led', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'8P8C_LED_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'8P8C_LED_Shielded'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'8P8C RJ socket connector led', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\n8P8C_LED_Shielded\n\n8P8C RJ socket connector led', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'8P8C_LED_Shielded_x2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'8P8C_LED_Shielded_x2'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'8P8C RJ socket connector led dual', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\n8P8C_LED_Shielded_x2\n\n8P8C RJ socket connector led dual', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='15',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='16',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='17',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='18',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='19',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='20',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='21',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='22',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='23',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['5', '7', '2', 'SH', '11', '12', '3', '6', '1', '4', '8', '10', '9']},{'label': 'uB', 'num': 2, 'pin_nums': ['13', '16', '21', '18', '17', '15', '20', '24', 'SH', '19', '14', '22', '23']}] }),
        Part(**{ 'name':'8P8C_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'8P8C_Shielded'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'8P8C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\n8P8C_Shielded\n\n8P8C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATX-20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATX-20'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'ATX PSU', 'description':'', 'datasheet':'https://web.aub.edu.lb/pub/docs/atx_201.pdf#page=20', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nATX-20\n\nATX PSU', 'pins':[
            Pin(num='1',name='+3.3V',func=pin_types.PWROUT,unit=1),
            Pin(num='10',name='+12V',func=pin_types.PWROUT,unit=1),
            Pin(num='11',name='+3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='-12V',func=pin_types.PWROUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='PS_ON#',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='-5V/NC',func=pin_types.PWROUT,unit=1),
            Pin(num='19',name='+5V',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='+3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='+5V',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='+5V',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='+5V',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='PWR_OK',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='+5VSB',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATX-24', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATX-24'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'ATX PSU', 'description':'', 'datasheet':'https://www.intel.com/content/dam/www/public/us/en/documents/guides/power-supply-design-guide-june.pdf#page=33', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nATX-24\n\nATX PSU', 'pins':[
            Pin(num='1',name='+3.3V',func=pin_types.PWROUT,unit=1),
            Pin(num='10',name='+12V',func=pin_types.PWROUT,unit=1),
            Pin(num='11',name='+12V',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='+3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='+3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='-12V',func=pin_types.PWROUT,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='PS_ON#',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='+3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='+5V',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='+5V',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='+5V',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='+5V',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='+5V',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='PWR_OK',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='+5VSB',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR-ISP-10', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR-ISP-10'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'AVR ISP Connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nAVR-ISP-10\n\nAVR ISP Connector', 'pins':[
            Pin(num='1',name='MOSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~{RST}',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='SCK',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='MISO',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR-ISP-6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR-ISP-6'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'AVR ISP Connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nAVR-ISP-6\n\nAVR ISP Connector', 'pins':[
            Pin(num='1',name='MISO',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='SCK',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='MOSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~{RST}',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR-JTAG-10', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR-JTAG-10'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'AVR JTAG Connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nAVR-JTAG-10\n\nAVR JTAG Connector', 'pins':[
            Pin(num='1',name='TCK',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='TDO',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='TMS',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~{SRST}',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~{TRST}',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='TDI',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR-PDI-6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR-PDI-6'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'AVR PDI Connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nAVR-PDI-6\n\nAVR PDI Connector', 'pins':[
            Pin(num='1',name='DATA',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='CLOCK',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR-TPI-6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR-TPI-6'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'AVR TPI Connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nAVR-TPI-6\n\nAVR TPI Connector', 'pins':[
            Pin(num='1',name='DATA',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='CLOCK',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='~{RST}',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AVR-UPDI-6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AVR-UPDI-6'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'AVR UPDI Connector', 'description':'', 'datasheet':'https://www.microchip.com/webdoc/GUID-9D10622A-5C16-4405-B092-1BDD437B4976/index.html?GUID-9B349315-2842-4189-B88C-49F4E1055D7F', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nAVR-UPDI-6\n\nAVR UPDI Connector', 'pins':[
            Pin(num='1',name='DATA',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Barrel_Jack', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Barrel_Jack'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'DC power barrel jack connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nBarrel_Jack\n\nDC power barrel jack connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Barrel_Jack_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Barrel_Jack_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'DC power barrel jack connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nBarrel_Jack_MountingPin\n\nDC power barrel jack connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Barrel_Jack_Switch', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Barrel_Jack_Switch'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'DC power barrel jack connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nBarrel_Jack_Switch\n\nDC power barrel jack connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Barrel_Jack_Switch_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Barrel_Jack_Switch_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'DC power barrel jack connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nBarrel_Jack_Switch_MountingPin\n\nDC power barrel jack connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Barrel_Jack_Switch_Pin3Ring', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Barrel_Jack_Switch_Pin3Ring'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'DC power barrel jack connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nBarrel_Jack_Switch_Pin3Ring\n\nDC power barrel jack connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Bus_ISA_16bit', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Bus_ISA_16bit'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'ISA', 'description':'', 'datasheet':'https://en.wikipedia.org/wiki/Industry_Standard_Architecture', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nBus_ISA_16bit\n\nISA', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{SMEMW}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='~{SMEMR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{IOW}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='~{IOR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~{DACK3}',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='DRQ3',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='~{DACK1}',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='DRQ1',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='~{REFRESH}',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='RESET',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='IRQ7',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='IRQ6',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='IRQ5',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='IRQ4',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='IRQ3',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='~{DACK2}',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='TC',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='ALE',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='OSC',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='IO',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='DB7',func=pin_types.TRISTATE,unit=1),
            Pin(num='34',name='DB6',func=pin_types.TRISTATE,unit=1),
            Pin(num='35',name='DB5',func=pin_types.TRISTATE,unit=1),
            Pin(num='36',name='DB4',func=pin_types.TRISTATE,unit=1),
            Pin(num='37',name='DB3',func=pin_types.TRISTATE,unit=1),
            Pin(num='38',name='DB2',func=pin_types.TRISTATE,unit=1),
            Pin(num='39',name='DB1',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='IRQ2',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='DB0',func=pin_types.TRISTATE,unit=1),
            Pin(num='41',name='IO_READY',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='AEN',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='BA19',func=pin_types.TRISTATE,unit=1),
            Pin(num='44',name='BA18',func=pin_types.TRISTATE,unit=1),
            Pin(num='45',name='BA17',func=pin_types.TRISTATE,unit=1),
            Pin(num='46',name='BA16',func=pin_types.TRISTATE,unit=1),
            Pin(num='47',name='BA15',func=pin_types.TRISTATE,unit=1),
            Pin(num='48',name='BA14',func=pin_types.TRISTATE,unit=1),
            Pin(num='49',name='BA13',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='-5V',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='BA12',func=pin_types.TRISTATE,unit=1),
            Pin(num='51',name='BA11',func=pin_types.TRISTATE,unit=1),
            Pin(num='52',name='BA10',func=pin_types.TRISTATE,unit=1),
            Pin(num='53',name='BA09',func=pin_types.TRISTATE,unit=1),
            Pin(num='54',name='BA08',func=pin_types.TRISTATE,unit=1),
            Pin(num='55',name='BA07',func=pin_types.TRISTATE,unit=1),
            Pin(num='56',name='BA06',func=pin_types.TRISTATE,unit=1),
            Pin(num='57',name='BA05',func=pin_types.TRISTATE,unit=1),
            Pin(num='58',name='BA04',func=pin_types.TRISTATE,unit=1),
            Pin(num='59',name='BA03',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='DRQ2',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='BA02',func=pin_types.TRISTATE,unit=1),
            Pin(num='61',name='BA01',func=pin_types.TRISTATE,unit=1),
            Pin(num='62',name='BA00',func=pin_types.TRISTATE,unit=1),
            Pin(num='63',name='~{MEMCS16}',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='~{IOCS16}',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='IRQ10',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='IRQ11',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='IRQ12',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='IRQ15',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='IRQ14',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='-12V',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='~{DACK0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='71',name='DRQ0',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='~{DACK5}',func=pin_types.OUTPUT,unit=1),
            Pin(num='73',name='DRQ5',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='~{DACK6}',func=pin_types.OUTPUT,unit=1),
            Pin(num='75',name='DRQ6',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='~{DACK7}',func=pin_types.OUTPUT,unit=1),
            Pin(num='77',name='DRQ7',func=pin_types.PASSIVE,unit=1),
            Pin(num='78',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='79',name='MASTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='UNUSED',func=pin_types.PASSIVE,unit=1),
            Pin(num='80',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='81',name='SBHE',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='LA23',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='LA22',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='LA21',func=pin_types.PASSIVE,unit=1),
            Pin(num='85',name='LA20',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='LA19',func=pin_types.PASSIVE,unit=1),
            Pin(num='87',name='LA18',func=pin_types.PASSIVE,unit=1),
            Pin(num='88',name='LA17',func=pin_types.PASSIVE,unit=1),
            Pin(num='89',name='~{MEMR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='+12V',func=pin_types.PWRIN,unit=1),
            Pin(num='90',name='~{MEMW}',func=pin_types.OUTPUT,unit=1),
            Pin(num='91',name='D8',func=pin_types.TRISTATE,unit=1),
            Pin(num='92',name='D9',func=pin_types.TRISTATE,unit=1),
            Pin(num='93',name='D10',func=pin_types.TRISTATE,unit=1),
            Pin(num='94',name='D11',func=pin_types.TRISTATE,unit=1),
            Pin(num='95',name='D12',func=pin_types.TRISTATE,unit=1),
            Pin(num='96',name='D13',func=pin_types.TRISTATE,unit=1),
            Pin(num='97',name='D14',func=pin_types.TRISTATE,unit=1),
            Pin(num='98',name='D15',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Bus_ISA_8bit', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Bus_ISA_8bit'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'ISA', 'description':'', 'datasheet':'https://en.wikipedia.org/wiki/Industry_Standard_Architecture', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nBus_ISA_8bit\n\nISA', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{SMEMW}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='~{SMEMR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{IOW}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='~{IOR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~{DACK3}',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='DRQ3',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='~{DACK1}',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='DRQ1',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='~{DACK0}',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='RESET',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='IRQ7',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='IRQ6',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='IRQ5',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='IRQ4',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='IRQ3',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='~{DACK2}',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='TC',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='ALE',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='OSC',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='IO',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='DB7',func=pin_types.TRISTATE,unit=1),
            Pin(num='34',name='DB6',func=pin_types.TRISTATE,unit=1),
            Pin(num='35',name='DB5',func=pin_types.TRISTATE,unit=1),
            Pin(num='36',name='DB4',func=pin_types.TRISTATE,unit=1),
            Pin(num='37',name='DB3',func=pin_types.TRISTATE,unit=1),
            Pin(num='38',name='DB2',func=pin_types.TRISTATE,unit=1),
            Pin(num='39',name='DB1',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='IRQ2',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='DB0',func=pin_types.TRISTATE,unit=1),
            Pin(num='41',name='IO_READY',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='AEN',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='BA19',func=pin_types.TRISTATE,unit=1),
            Pin(num='44',name='BA18',func=pin_types.TRISTATE,unit=1),
            Pin(num='45',name='BA17',func=pin_types.TRISTATE,unit=1),
            Pin(num='46',name='BA16',func=pin_types.TRISTATE,unit=1),
            Pin(num='47',name='BA15',func=pin_types.TRISTATE,unit=1),
            Pin(num='48',name='BA14',func=pin_types.TRISTATE,unit=1),
            Pin(num='49',name='BA13',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='-5V',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='BA12',func=pin_types.TRISTATE,unit=1),
            Pin(num='51',name='BA11',func=pin_types.TRISTATE,unit=1),
            Pin(num='52',name='BA10',func=pin_types.TRISTATE,unit=1),
            Pin(num='53',name='BA09',func=pin_types.TRISTATE,unit=1),
            Pin(num='54',name='BA08',func=pin_types.TRISTATE,unit=1),
            Pin(num='55',name='BA07',func=pin_types.TRISTATE,unit=1),
            Pin(num='56',name='BA06',func=pin_types.TRISTATE,unit=1),
            Pin(num='57',name='BA05',func=pin_types.TRISTATE,unit=1),
            Pin(num='58',name='BA04',func=pin_types.TRISTATE,unit=1),
            Pin(num='59',name='BA03',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='DRQ2',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='BA02',func=pin_types.TRISTATE,unit=1),
            Pin(num='61',name='BA01',func=pin_types.TRISTATE,unit=1),
            Pin(num='62',name='BA00',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='-12V',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='UNUSED',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='+12V',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Bus_M.2_Socket_A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Bus_M.2_Socket_A'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'M2 NGNF PCI-E', 'description':'', 'datasheet':'https://web.archive.org/web/20200613074028/http://read.pudn.com/downloads794/doc/project/3133918/PCIe_M.2_Electromechanical_Spec_Rev1.0_Final_11012013_RS_Clean.pdf#page=148', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nBus_M.2_Socket_A\n\nM2 NGNF PCI-E', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='~{LED_2}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='MLDIR_Sense',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='DP_ML3n',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='DP_AUXn',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='DP_ML3p',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='DP_AUXp',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='DP_ML2n',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='DP_ML1n',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='DP_ML2p',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='DP_ML1p',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='USB_D+',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='DP_HPD',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='DP_ML0n',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='DP_ML0p',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PETp0',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='PETn0',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='VENDOR_DEFINED',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='VENDOR_DEFINED',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='PERp0',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VENDOR_DEFINED',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='PERn0',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='COEX3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='COEX2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='REFCLKp0',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='COEX1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='REFCLKn0',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='USB_D-',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='SUSCLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='51',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='~{PERST0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='53',name='~{CLKREQ0}',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='~{W_DISABLE2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='~{PEWAKE0}',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='~{W_DISABLE1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='57',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='I2C_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PETp1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{LED_1}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='60',name='I2C_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='61',name='PETn1',func=pin_types.OUTPUT,unit=1),
            Pin(num='62',name='~{ALERT}',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='RESERVED',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='PERp1',func=pin_types.INPUT,unit=1),
            Pin(num='66',name='~{PERST1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='67',name='PERn1',func=pin_types.INPUT,unit=1),
            Pin(num='68',name='~{CLKREQ1}',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='~{PEWAKE1}',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='REFCLKp1',func=pin_types.OUTPUT,unit=1),
            Pin(num='72',name='3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='REFCLKn1',func=pin_types.OUTPUT,unit=1),
            Pin(num='74',name='3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Bus_M.2_Socket_B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Bus_M.2_Socket_B'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'M2 NGNF PCI-E', 'description':'', 'datasheet':'https://web.archive.org/web/20200613074028/http://read.pudn.com/downloads794/doc/project/3133918/PCIe_M.2_Electromechanical_Spec_Rev1.0_Final_11012013_RS_Clean.pdf#page=154', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nBus_M.2_Socket_B\n\nM2 NGNF PCI-E', 'pins':[
            Pin(num='1',name='CONFIG_3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GPIO_9/DAS/~{DSS}/~{LED1}',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='GPIO_5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='CONFIG_0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='GPIO_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='GPIO_11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GPIO_7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='DPR',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='GPIO_10',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='GPIO_8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PERn1/USB3.0-Rx-/SSIC-RxN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='UIM-RESET',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='PERp1/USB3.0-Rx+/SSIC-RxP',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='UIM-CLK',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='UIM-DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PETn1/USB3.0-Tx-/SSIC-TxN',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='UIM-PWR',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='PETp1/USB3.0-Tx+/SSIC-TxP',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='DEVSLP',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='GPIO_0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PERn0/SATA-B+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='GPIO_1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PERp0/SATA-B-',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='GPIO_2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='GPIO_3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PETn0/SATA-A-',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='GPIO_4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PETp0/SATA-A+',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='~{PERST}',func=pin_types.OUTPUT,unit=1),
            Pin(num='51',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='~{CLKREQ}',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='REFCLKn',func=pin_types.OUTPUT,unit=1),
            Pin(num='54',name='~{PEWAKE}',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='REFCLKp',func=pin_types.OUTPUT,unit=1),
            Pin(num='56',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='57',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='59',name='ANTCTL0',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{FULL_CARD_POWER_OFF}',func=pin_types.OUTPUT,unit=1),
            Pin(num='60',name='COEX3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='ANTCTL1',func=pin_types.INPUT,unit=1),
            Pin(num='62',name='COEX2',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='ANTCTL2',func=pin_types.INPUT,unit=1),
            Pin(num='64',name='COEX1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='ANTCTL3',func=pin_types.INPUT,unit=1),
            Pin(num='66',name='SIM_DETECT',func=pin_types.OUTPUT,unit=1),
            Pin(num='67',name='~{RESET}',func=pin_types.OUTPUT,unit=1),
            Pin(num='68',name='SUSCLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='69',name='CONFIG_1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='USB_D+',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='CONFIG_2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{W_DISABLE1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='USB_D-',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Bus_M.2_Socket_E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Bus_M.2_Socket_E'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'M2 NGNF PCI-E', 'description':'', 'datasheet':'https://web.archive.org/web/20200613074028/http://read.pudn.com/downloads794/doc/project/3133918/PCIe_M.2_Electromechanical_Spec_Rev1.0_Final_11012013_RS_Clean.pdf#page=150', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nBus_M.2_Socket_E\n\nM2 NGNF PCI-E', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PCM_SYNC/I2S_WS',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SDIO_CMD',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PCM_IN/I2S_SD_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SDIO_DATA0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PCM_OUT/I2S_SD_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SDIO_DATA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{LED_2}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='SDIO_DATA2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='SDIO_DATA3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='~{UART_WAKE}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='~{SDIO_WAKE}',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='UART_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{SDIO_RESET}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='USB_D+',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='UART_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='UART_CTS',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PETp0',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='UART_RTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='PETn0',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='VENDOR_DEFINED',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='VENDOR_DEFINED',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='PERp0',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VENDOR_DEFINED',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='PERn0',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='COEX3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='COEX2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='REFCLKp0',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='COEX1',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='REFCLKn0',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='USB_D-',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='SUSCLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='51',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='~{PERST0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='53',name='~{CLKREQ0}',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='~{W_DISABLE2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='~{PEWAKE0}',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='~{W_DISABLE1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='57',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='I2C_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='RESERVED/PETp1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{LED_1}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='60',name='I2C_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='61',name='RESERVED/PETn1',func=pin_types.OUTPUT,unit=1),
            Pin(num='62',name='~{ALERT}',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='RESERVED',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='RESERVED/PERp1',func=pin_types.INPUT,unit=1),
            Pin(num='66',name='UIM_SWP/~{PERST1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='67',name='RESERVED/PERn1',func=pin_types.INPUT,unit=1),
            Pin(num='68',name='UIM_POWER_SNK/~{CLKREQ1}',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='UIM_POWER_SRC/GPIO1/~{PEWAKE1}',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='RESERVED/REFCLKp1',func=pin_types.OUTPUT,unit=1),
            Pin(num='72',name='3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='RESERVED/REFCLKn1',func=pin_types.OUTPUT,unit=1),
            Pin(num='74',name='3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='PCM_CLK/I2S_SCK',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SDIO_CLK',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Bus_M.2_Socket_M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Bus_M.2_Socket_M'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'M2 NGNF PCI-E', 'description':'', 'datasheet':'https://web.archive.org/web/20200613074028/http://read.pudn.com/downloads794/doc/project/3133918/PCIe_M.2_Electromechanical_Spec_Rev1.0_Final_11012013_RS_Clean.pdf#page=155', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nBus_M.2_Socket_M\n\nM2 NGNF PCI-E', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='DAS/~{DSS}/~{LED1}',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PETn3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='PETp3',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='PERn2',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PERp2',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='PETn2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='PETp2',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='27',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='29',name='PERn1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='31',name='PERp1',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='35',name='PETn1',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='PETp1',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='DEVSLP',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='41',name='PERn0/SATA-B+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='PERp0/SATA-B-',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='47',name='PETn0/SATA-A-',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='49',name='PETp0/SATA-A+',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='PERn3',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='~{PERST}',func=pin_types.OUTPUT,unit=1),
            Pin(num='51',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='~{CLKREQ}',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='REFCLKn',func=pin_types.OUTPUT,unit=1),
            Pin(num='54',name='~{PEWAKE}',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='REFCLKp',func=pin_types.OUTPUT,unit=1),
            Pin(num='56',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='57',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='67',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='68',name='SUSCLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='69',name='PEDET',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PERp3',func=pin_types.INPUT,unit=1),
            Pin(num='70',name='3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Bus_PCI_32bit_5V', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Bus_PCI_32bit_5V'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'PCI 5V', 'description':'', 'datasheet':'http://pinouts.ru/Slots/PCI_pinout.shtml', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nBus_PCI_32bit_5V\n\nPCI 5V', 'pins':[
            Pin(num='A1',name='TRST#',func=pin_types.OUTPUT,unit=1),
            Pin(num='A10',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='A11',name='RESERVED',func=pin_types.PASSIVE,unit=1),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A14',name='RESERVED',func=pin_types.PASSIVE,unit=1),
            Pin(num='A15',name='RST#',func=pin_types.OUTPUT,unit=1),
            Pin(num='A16',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='A17',name='GNT#',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A19',name='RESERVED',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='+12V',func=pin_types.PWRIN,unit=1),
            Pin(num='A20',name='AD[30]',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='+3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='A22',name='AD[28]',func=pin_types.BIDIR,unit=1),
            Pin(num='A23',name='AD[26]',func=pin_types.BIDIR,unit=1),
            Pin(num='A24',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A25',name='AD[24]',func=pin_types.BIDIR,unit=1),
            Pin(num='A26',name='IDSEL',func=pin_types.OUTPUT,unit=1),
            Pin(num='A27',name='+3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='A28',name='AD[22]',func=pin_types.BIDIR,unit=1),
            Pin(num='A29',name='AD[20]',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='TMS',func=pin_types.OUTPUT,unit=1),
            Pin(num='A30',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A31',name='AD[18]',func=pin_types.BIDIR,unit=1),
            Pin(num='A32',name='AD[16]',func=pin_types.BIDIR,unit=1),
            Pin(num='A33',name='+3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='A34',name='FRAME#',func=pin_types.BIDIR,unit=1),
            Pin(num='A35',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A36',name='TRDY#',func=pin_types.BIDIR,unit=1),
            Pin(num='A37',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A38',name='STOP#',func=pin_types.BIDIR,unit=1),
            Pin(num='A39',name='+3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='TDI',func=pin_types.OUTPUT,unit=1),
            Pin(num='A40',name='SDONE',func=pin_types.BIDIR,unit=1),
            Pin(num='A41',name='SBO#',func=pin_types.BIDIR,unit=1),
            Pin(num='A42',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A43',name='PAR',func=pin_types.BIDIR,unit=1),
            Pin(num='A44',name='AD[15]',func=pin_types.BIDIR,unit=1),
            Pin(num='A45',name='+3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='A46',name='AD[13]',func=pin_types.BIDIR,unit=1),
            Pin(num='A47',name='AD[11]',func=pin_types.BIDIR,unit=1),
            Pin(num='A48',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A49',name='AD[09]',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='A52',name='C/BE#[0]',func=pin_types.BIDIR,unit=1),
            Pin(num='A53',name='+3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='A54',name='AD[06]',func=pin_types.BIDIR,unit=1),
            Pin(num='A55',name='AD[04]',func=pin_types.BIDIR,unit=1),
            Pin(num='A56',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A57',name='AD[02]',func=pin_types.BIDIR,unit=1),
            Pin(num='A58',name='AD[00]',func=pin_types.BIDIR,unit=1),
            Pin(num='A59',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='INTA#',func=pin_types.INPUT,unit=1),
            Pin(num='A60',name='REQ64#',func=pin_types.BIDIR,unit=1),
            Pin(num='A61',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='A62',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='INTC#',func=pin_types.INPUT,unit=1),
            Pin(num='A8',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='RESERVED',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='-12V',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='RESERVED',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='PRSNT2#',func=pin_types.INPUT,unit=1),
            Pin(num='B12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B14',name='RESERVED',func=pin_types.PASSIVE,unit=1),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B16',name='CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B18',name='REQ#',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='TCK',func=pin_types.OUTPUT,unit=1),
            Pin(num='B20',name='AD[31]',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='AD[29]',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B23',name='AD[27]',func=pin_types.BIDIR,unit=1),
            Pin(num='B24',name='AD[25]',func=pin_types.BIDIR,unit=1),
            Pin(num='B25',name='+3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='B26',name='C/BE#[3]',func=pin_types.BIDIR,unit=1),
            Pin(num='B27',name='AD[23]',func=pin_types.BIDIR,unit=1),
            Pin(num='B28',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B29',name='AD[21]',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B30',name='AD[19]',func=pin_types.BIDIR,unit=1),
            Pin(num='B31',name='+3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='B32',name='AD[17]',func=pin_types.BIDIR,unit=1),
            Pin(num='B33',name='C/BE#[2]',func=pin_types.BIDIR,unit=1),
            Pin(num='B34',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B35',name='IRDY#',func=pin_types.BIDIR,unit=1),
            Pin(num='B36',name='+3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='B37',name='DEVSEL#',func=pin_types.BIDIR,unit=1),
            Pin(num='B38',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B39',name='LOCK#',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='TDO',func=pin_types.INPUT,unit=1),
            Pin(num='B40',name='PERR#',func=pin_types.BIDIR,unit=1),
            Pin(num='B41',name='+3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='B42',name='SERR#',func=pin_types.INPUT,unit=1),
            Pin(num='B43',name='+3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='B44',name='C/BE#[1]',func=pin_types.BIDIR,unit=1),
            Pin(num='B45',name='AD[14]',func=pin_types.BIDIR,unit=1),
            Pin(num='B46',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B47',name='AD[12]',func=pin_types.BIDIR,unit=1),
            Pin(num='B48',name='AD[10]',func=pin_types.BIDIR,unit=1),
            Pin(num='B49',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='B52',name='AD[08]',func=pin_types.BIDIR,unit=1),
            Pin(num='B53',name='AD[07]',func=pin_types.BIDIR,unit=1),
            Pin(num='B54',name='+3.3V',func=pin_types.INPUT,unit=1),
            Pin(num='B55',name='AD[05]',func=pin_types.BIDIR,unit=1),
            Pin(num='B56',name='AD[03]',func=pin_types.BIDIR,unit=1),
            Pin(num='B57',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B58',name='AD[01]',func=pin_types.BIDIR,unit=1),
            Pin(num='B59',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='B60',name='ACK64#',func=pin_types.BIDIR,unit=1),
            Pin(num='B61',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='B62',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='B7',name='INTB#',func=pin_types.INPUT,unit=1),
            Pin(num='B8',name='INTD#',func=pin_types.INPUT,unit=1),
            Pin(num='B9',name='PRSNT1#',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Bus_PCI_32bit_Universal', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Bus_PCI_32bit_Universal'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'PCI 5V 3.3V 3V3', 'description':'', 'datasheet':'http://pinouts.ru/Slots/PCI_pinout.shtml', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nBus_PCI_32bit_Universal\n\nPCI 5V 3.3V 3V3', 'pins':[
            Pin(num='A1',name='~{TRST#}',func=pin_types.OUTPUT,unit=1),
            Pin(num='A10',name='VIO',func=pin_types.PWRIN,unit=1),
            Pin(num='A11',name='RESERVED',func=pin_types.PASSIVE,unit=1),
            Pin(num='A14',name='3.3VAUX',func=pin_types.PASSIVE,unit=1),
            Pin(num='A15',name='~{RST#}',func=pin_types.OUTPUT,unit=1),
            Pin(num='A16',name='VIO',func=pin_types.PWRIN,unit=1),
            Pin(num='A17',name='~{GNT#}',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A19',name='PME#',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='+12V',func=pin_types.PWRIN,unit=1),
            Pin(num='A20',name='AD[30]',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='+3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='A22',name='AD[28]',func=pin_types.BIDIR,unit=1),
            Pin(num='A23',name='AD[26]',func=pin_types.BIDIR,unit=1),
            Pin(num='A24',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A25',name='AD[24]',func=pin_types.BIDIR,unit=1),
            Pin(num='A26',name='IDSEL',func=pin_types.OUTPUT,unit=1),
            Pin(num='A27',name='+3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='A28',name='AD[22]',func=pin_types.BIDIR,unit=1),
            Pin(num='A29',name='AD[20]',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='TMS',func=pin_types.OUTPUT,unit=1),
            Pin(num='A30',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A31',name='AD[18]',func=pin_types.BIDIR,unit=1),
            Pin(num='A32',name='AD[16]',func=pin_types.BIDIR,unit=1),
            Pin(num='A33',name='+3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='A34',name='~{FRAME#}',func=pin_types.BIDIR,unit=1),
            Pin(num='A35',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A36',name='~{TRDY#}',func=pin_types.BIDIR,unit=1),
            Pin(num='A37',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A38',name='~{STOP#}',func=pin_types.BIDIR,unit=1),
            Pin(num='A39',name='+3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='TDI',func=pin_types.OUTPUT,unit=1),
            Pin(num='A40',name='RESERVED',func=pin_types.BIDIR,unit=1),
            Pin(num='A41',name='RESERVED',func=pin_types.BIDIR,unit=1),
            Pin(num='A42',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A43',name='PAR',func=pin_types.BIDIR,unit=1),
            Pin(num='A44',name='AD[15]',func=pin_types.BIDIR,unit=1),
            Pin(num='A45',name='+3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='A46',name='AD[13]',func=pin_types.BIDIR,unit=1),
            Pin(num='A47',name='AD[11]',func=pin_types.BIDIR,unit=1),
            Pin(num='A48',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A49',name='AD[09]',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='A52',name='~{C/BE#[0]}',func=pin_types.BIDIR,unit=1),
            Pin(num='A53',name='+3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='A54',name='AD[06]',func=pin_types.BIDIR,unit=1),
            Pin(num='A55',name='AD[04]',func=pin_types.BIDIR,unit=1),
            Pin(num='A56',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A57',name='AD[02]',func=pin_types.BIDIR,unit=1),
            Pin(num='A58',name='AD[00]',func=pin_types.BIDIR,unit=1),
            Pin(num='A59',name='VIO',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='~{INTA#}',func=pin_types.INPUT,unit=1),
            Pin(num='A60',name='~{REQ64#}',func=pin_types.BIDIR,unit=1),
            Pin(num='A61',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='A62',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='~{INTC#}',func=pin_types.INPUT,unit=1),
            Pin(num='A8',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='RESERVED',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='-12V',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='RESERVED',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='~{PRSNT2#}',func=pin_types.INPUT,unit=1),
            Pin(num='B14',name='RESERVED',func=pin_types.PASSIVE,unit=1),
            Pin(num='B15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B16',name='CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='B17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B18',name='~{REQ#}',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='VIO',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='TCK',func=pin_types.OUTPUT,unit=1),
            Pin(num='B20',name='AD[31]',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='AD[29]',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B23',name='AD[27]',func=pin_types.BIDIR,unit=1),
            Pin(num='B24',name='AD[25]',func=pin_types.BIDIR,unit=1),
            Pin(num='B25',name='+3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='B26',name='C/BE#[3]',func=pin_types.BIDIR,unit=1),
            Pin(num='B27',name='AD[23]',func=pin_types.BIDIR,unit=1),
            Pin(num='B28',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B29',name='AD[21]',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B30',name='AD[19]',func=pin_types.BIDIR,unit=1),
            Pin(num='B31',name='+3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='B32',name='AD[17]',func=pin_types.BIDIR,unit=1),
            Pin(num='B33',name='~{C/BE#[2]}',func=pin_types.BIDIR,unit=1),
            Pin(num='B34',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B35',name='~{IRDY#}',func=pin_types.BIDIR,unit=1),
            Pin(num='B36',name='+3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='B37',name='~{DEVSEL#}',func=pin_types.BIDIR,unit=1),
            Pin(num='B38',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B39',name='~{LOCK#}',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='TDO',func=pin_types.INPUT,unit=1),
            Pin(num='B40',name='~{PERR#}',func=pin_types.BIDIR,unit=1),
            Pin(num='B41',name='+3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='B42',name='~{SERR#}',func=pin_types.INPUT,unit=1),
            Pin(num='B43',name='+3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='B44',name='~{C/BE#[1]}',func=pin_types.BIDIR,unit=1),
            Pin(num='B45',name='AD[14]',func=pin_types.BIDIR,unit=1),
            Pin(num='B46',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B47',name='AD[12]',func=pin_types.BIDIR,unit=1),
            Pin(num='B48',name='AD[10]',func=pin_types.BIDIR,unit=1),
            Pin(num='B49',name='M66EN',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='B52',name='AD[08]',func=pin_types.BIDIR,unit=1),
            Pin(num='B53',name='AD[07]',func=pin_types.BIDIR,unit=1),
            Pin(num='B54',name='+3.3V',func=pin_types.INPUT,unit=1),
            Pin(num='B55',name='AD[05]',func=pin_types.BIDIR,unit=1),
            Pin(num='B56',name='AD[03]',func=pin_types.BIDIR,unit=1),
            Pin(num='B57',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B58',name='AD[01]',func=pin_types.BIDIR,unit=1),
            Pin(num='B59',name='VIO',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='B60',name='~{ACK64#}',func=pin_types.BIDIR,unit=1),
            Pin(num='B61',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='B62',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='B7',name='~{INTB#}',func=pin_types.INPUT,unit=1),
            Pin(num='B8',name='~{INTD#}',func=pin_types.INPUT,unit=1),
            Pin(num='B9',name='~{PRSNT1#}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Bus_PCI_Express_Mini', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Bus_PCI_Express_Mini'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'mini pcie', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nBus_PCI_Express_Mini\n\nmini pcie', 'pins':[
            Pin(num='1',name='~{WAKE}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='UIM_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='REFCLK-',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='UIM_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='REFCLK+',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{UIM_RESET}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='UIM_VPP',func=pin_types.PWROUT,unit=1),
            Pin(num='17',name='UIM_C8',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='UIM_C4',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='+3V3AUX',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='~{W_DISABLE}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='~{PERST}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PERn0',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='+3V3AUX',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PERp0',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='+1V5',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='COEX1',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='SMB_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='PETn0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='SMB_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PETp0',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='USB_D-',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='USB_D+',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='+3V3AUX',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='+3V3AUX',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='~{LED_WWAN}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='~{LED_WLAN}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='45',name='Reserved',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='~{LED_WPAN}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='47',name='Reserved',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='+1V5',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='Reserved',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='COEX2',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Reserved',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='+3V3AUX',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='+1V5',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='~{CLKREQ}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='UIM_PWR',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MP',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Bus_PCI_Express_x1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Bus_PCI_Express_x1'}), 'ref_prefix':'J', 'fplist':['Connector_PCBEdge:BUS_PCIexpress_x1'], 'footprint':'Connector_PCBEdge:BUS_PCIexpress_x1', 'keywords':'pcie', 'description':'', 'datasheet':'http://www.ritrontek.com/uploadfile/2016/1026/20161026105231124.pdf#page=63', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nBus_PCI_Express_x1\n\npcie', 'pins':[
            Pin(num='A1',name='~{PRSNT1}',func=pin_types.PASSIVE,unit=1),
            Pin(num='A10',name='+3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='A11',name='~{PERST}',func=pin_types.INPUT,unit=1),
            Pin(num='A12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A13',name='REFCLK+',func=pin_types.INPUT,unit=1),
            Pin(num='A14',name='REFCLK-',func=pin_types.INPUT,unit=1),
            Pin(num='A15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A16',name='PERp0',func=pin_types.OUTPUT,unit=1),
            Pin(num='A17',name='PERn0',func=pin_types.OUTPUT,unit=1),
            Pin(num='A18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='+12V',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='+12V',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='JTAG2',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='JTAG3',func=pin_types.INPUT,unit=1),
            Pin(num='A7',name='JTAG4',func=pin_types.OUTPUT,unit=1),
            Pin(num='A8',name='JTAG5',func=pin_types.INPUT,unit=1),
            Pin(num='A9',name='+3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='+12V',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='3.3Vaux',func=pin_types.PWRIN,unit=1),
            Pin(num='B11',name='~{WAKE}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='B12',name='RSVD',func=pin_types.PASSIVE,unit=1),
            Pin(num='B13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B14',name='PETp0',func=pin_types.INPUT,unit=1),
            Pin(num='B15',name='PETn0',func=pin_types.INPUT,unit=1),
            Pin(num='B16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B17',name='~{PRSNT2}',func=pin_types.PASSIVE,unit=1),
            Pin(num='B18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='+12V',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='+12V',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='SMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='SMDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='+3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='JTAG1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Bus_PCI_Express_x16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Bus_PCI_Express_x16'}), 'ref_prefix':'J', 'fplist':['Connector_PCBEdge:BUS_PCIexpress_x16'], 'footprint':'Connector_PCBEdge:BUS_PCIexpress_x16', 'keywords':'pcie', 'description':'', 'datasheet':'http://www.ritrontek.com/uploadfile/2016/1026/20161026105231124.pdf#page=63', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nBus_PCI_Express_x16\n\npcie', 'pins':[
            Pin(num='A1',name='~{PRSNT1}',func=pin_types.PASSIVE,unit=1),
            Pin(num='A10',name='+3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='A11',name='~{PERST}',func=pin_types.INPUT,unit=1),
            Pin(num='A12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A13',name='REFCLK+',func=pin_types.INPUT,unit=1),
            Pin(num='A14',name='REFCLK-',func=pin_types.INPUT,unit=1),
            Pin(num='A15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A16',name='PERp0',func=pin_types.OUTPUT,unit=1),
            Pin(num='A17',name='PERn0',func=pin_types.OUTPUT,unit=1),
            Pin(num='A18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A19',name='RSVD',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='+12V',func=pin_types.PASSIVE,unit=1),
            Pin(num='A20',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A21',name='PERp1',func=pin_types.OUTPUT,unit=1),
            Pin(num='A22',name='PERn1',func=pin_types.OUTPUT,unit=1),
            Pin(num='A23',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A25',name='PERp2',func=pin_types.OUTPUT,unit=1),
            Pin(num='A26',name='PERn2',func=pin_types.OUTPUT,unit=1),
            Pin(num='A27',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A29',name='PERp3',func=pin_types.OUTPUT,unit=1),
            Pin(num='A3',name='+12V',func=pin_types.PASSIVE,unit=1),
            Pin(num='A30',name='PERn3',func=pin_types.OUTPUT,unit=1),
            Pin(num='A31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A32',name='RSVD',func=pin_types.PASSIVE,unit=1),
            Pin(num='A33',name='RSVD',func=pin_types.PASSIVE,unit=1),
            Pin(num='A34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A35',name='PERp4',func=pin_types.OUTPUT,unit=1),
            Pin(num='A36',name='PERn4',func=pin_types.OUTPUT,unit=1),
            Pin(num='A37',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A39',name='PERp5',func=pin_types.OUTPUT,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A40',name='PERn5',func=pin_types.OUTPUT,unit=1),
            Pin(num='A41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A42',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A43',name='PERp6',func=pin_types.OUTPUT,unit=1),
            Pin(num='A44',name='PERn6',func=pin_types.OUTPUT,unit=1),
            Pin(num='A45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A46',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A47',name='PERp7',func=pin_types.OUTPUT,unit=1),
            Pin(num='A48',name='PERn7',func=pin_types.OUTPUT,unit=1),
            Pin(num='A49',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='JTAG2',func=pin_types.INPUT,unit=1),
            Pin(num='A50',name='RSVD',func=pin_types.PASSIVE,unit=1),
            Pin(num='A51',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A52',name='PERp8',func=pin_types.OUTPUT,unit=1),
            Pin(num='A53',name='PERn8',func=pin_types.OUTPUT,unit=1),
            Pin(num='A54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A55',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A56',name='PERp9',func=pin_types.OUTPUT,unit=1),
            Pin(num='A57',name='PERn9',func=pin_types.OUTPUT,unit=1),
            Pin(num='A58',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A59',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A6',name='JTAG3',func=pin_types.INPUT,unit=1),
            Pin(num='A60',name='PERp10',func=pin_types.OUTPUT,unit=1),
            Pin(num='A61',name='PERn10',func=pin_types.OUTPUT,unit=1),
            Pin(num='A62',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A64',name='PERp11',func=pin_types.OUTPUT,unit=1),
            Pin(num='A65',name='PERn11',func=pin_types.OUTPUT,unit=1),
            Pin(num='A66',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A67',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A68',name='PERp12',func=pin_types.OUTPUT,unit=1),
            Pin(num='A69',name='PERn12',func=pin_types.OUTPUT,unit=1),
            Pin(num='A7',name='JTAG4',func=pin_types.OUTPUT,unit=1),
            Pin(num='A70',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A71',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A72',name='PERp13',func=pin_types.OUTPUT,unit=1),
            Pin(num='A73',name='PERn13',func=pin_types.OUTPUT,unit=1),
            Pin(num='A74',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A75',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A76',name='PERp14',func=pin_types.OUTPUT,unit=1),
            Pin(num='A77',name='PERn14',func=pin_types.OUTPUT,unit=1),
            Pin(num='A78',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A79',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='JTAG5',func=pin_types.INPUT,unit=1),
            Pin(num='A80',name='PERp15',func=pin_types.OUTPUT,unit=1),
            Pin(num='A81',name='PERn15',func=pin_types.OUTPUT,unit=1),
            Pin(num='A82',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A9',name='+3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='+12V',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='3.3Vaux',func=pin_types.PWRIN,unit=1),
            Pin(num='B11',name='~{WAKE}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='B12',name='RSVD',func=pin_types.PASSIVE,unit=1),
            Pin(num='B13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B14',name='PETp0',func=pin_types.INPUT,unit=1),
            Pin(num='B15',name='PETn0',func=pin_types.INPUT,unit=1),
            Pin(num='B16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B17',name='~{PRSNT2}',func=pin_types.PASSIVE,unit=1),
            Pin(num='B18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B19',name='PETp1',func=pin_types.INPUT,unit=1),
            Pin(num='B2',name='+12V',func=pin_types.PASSIVE,unit=1),
            Pin(num='B20',name='PETn1',func=pin_types.INPUT,unit=1),
            Pin(num='B21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B23',name='PETp2',func=pin_types.INPUT,unit=1),
            Pin(num='B24',name='PETn2',func=pin_types.INPUT,unit=1),
            Pin(num='B25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B26',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B27',name='PETp3',func=pin_types.INPUT,unit=1),
            Pin(num='B28',name='PETn3',func=pin_types.INPUT,unit=1),
            Pin(num='B29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='+12V',func=pin_types.PASSIVE,unit=1),
            Pin(num='B30',name='RSVD',func=pin_types.PASSIVE,unit=1),
            Pin(num='B31',name='~{PRSNT2}',func=pin_types.PASSIVE,unit=1),
            Pin(num='B32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B33',name='PETp4',func=pin_types.INPUT,unit=1),
            Pin(num='B34',name='PETn4',func=pin_types.INPUT,unit=1),
            Pin(num='B35',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B36',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B37',name='PETp5',func=pin_types.INPUT,unit=1),
            Pin(num='B38',name='PETn5',func=pin_types.INPUT,unit=1),
            Pin(num='B39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B40',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B41',name='PETp6',func=pin_types.INPUT,unit=1),
            Pin(num='B42',name='PETn6',func=pin_types.INPUT,unit=1),
            Pin(num='B43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B45',name='PETp7',func=pin_types.INPUT,unit=1),
            Pin(num='B46',name='PETn7',func=pin_types.INPUT,unit=1),
            Pin(num='B47',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B48',name='~{PRSNT2}',func=pin_types.PASSIVE,unit=1),
            Pin(num='B49',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='SMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='B50',name='PETp8',func=pin_types.INPUT,unit=1),
            Pin(num='B51',name='PETn8',func=pin_types.INPUT,unit=1),
            Pin(num='B52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B54',name='PETp9',func=pin_types.INPUT,unit=1),
            Pin(num='B55',name='PETn9',func=pin_types.INPUT,unit=1),
            Pin(num='B56',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B57',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B58',name='PETp10',func=pin_types.INPUT,unit=1),
            Pin(num='B59',name='PETn10',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='SMDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='B60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B61',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B62',name='PETp11',func=pin_types.INPUT,unit=1),
            Pin(num='B63',name='PETn11',func=pin_types.INPUT,unit=1),
            Pin(num='B64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B66',name='PETp12',func=pin_types.INPUT,unit=1),
            Pin(num='B67',name='PETn12',func=pin_types.INPUT,unit=1),
            Pin(num='B68',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B69',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B70',name='PETp13',func=pin_types.INPUT,unit=1),
            Pin(num='B71',name='PETn13',func=pin_types.INPUT,unit=1),
            Pin(num='B72',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B73',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B74',name='PETp14',func=pin_types.INPUT,unit=1),
            Pin(num='B75',name='PETn14',func=pin_types.INPUT,unit=1),
            Pin(num='B76',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B77',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B78',name='PETp15',func=pin_types.INPUT,unit=1),
            Pin(num='B79',name='PETn15',func=pin_types.INPUT,unit=1),
            Pin(num='B8',name='+3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='B80',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B81',name='~{PRSNT2}',func=pin_types.PASSIVE,unit=1),
            Pin(num='B82',name='RSVD',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='JTAG1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Bus_PCI_Express_x4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Bus_PCI_Express_x4'}), 'ref_prefix':'J', 'fplist':['Connector_PCBEdge:BUS_PCIexpress_x4'], 'footprint':'Connector_PCBEdge:BUS_PCIexpress_x4', 'keywords':'pcie', 'description':'', 'datasheet':'http://www.ritrontek.com/uploadfile/2016/1026/20161026105231124.pdf#page=63', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nBus_PCI_Express_x4\n\npcie', 'pins':[
            Pin(num='A1',name='~{PRSNT1}',func=pin_types.PASSIVE,unit=1),
            Pin(num='A10',name='+3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='A11',name='~{PERST}',func=pin_types.INPUT,unit=1),
            Pin(num='A12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A13',name='REFCLK+',func=pin_types.INPUT,unit=1),
            Pin(num='A14',name='REFCLK-',func=pin_types.INPUT,unit=1),
            Pin(num='A15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A16',name='PERp0',func=pin_types.OUTPUT,unit=1),
            Pin(num='A17',name='PERn0',func=pin_types.OUTPUT,unit=1),
            Pin(num='A18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A19',name='RSVD',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='+12V',func=pin_types.PASSIVE,unit=1),
            Pin(num='A20',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A21',name='PERp1',func=pin_types.OUTPUT,unit=1),
            Pin(num='A22',name='PERn1',func=pin_types.OUTPUT,unit=1),
            Pin(num='A23',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A25',name='PERp2',func=pin_types.OUTPUT,unit=1),
            Pin(num='A26',name='PERn2',func=pin_types.OUTPUT,unit=1),
            Pin(num='A27',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A29',name='PERp3',func=pin_types.OUTPUT,unit=1),
            Pin(num='A3',name='+12V',func=pin_types.PASSIVE,unit=1),
            Pin(num='A30',name='PERn3',func=pin_types.OUTPUT,unit=1),
            Pin(num='A31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A32',name='RSVD',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='JTAG2',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='JTAG3',func=pin_types.INPUT,unit=1),
            Pin(num='A7',name='JTAG4',func=pin_types.OUTPUT,unit=1),
            Pin(num='A8',name='JTAG5',func=pin_types.INPUT,unit=1),
            Pin(num='A9',name='+3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='+12V',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='3.3Vaux',func=pin_types.PWRIN,unit=1),
            Pin(num='B11',name='~{WAKE}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='B12',name='RSVD',func=pin_types.PASSIVE,unit=1),
            Pin(num='B13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B14',name='PETp0',func=pin_types.INPUT,unit=1),
            Pin(num='B15',name='PETn0',func=pin_types.INPUT,unit=1),
            Pin(num='B16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B17',name='~{PRSNT2}',func=pin_types.PASSIVE,unit=1),
            Pin(num='B18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B19',name='PETp1',func=pin_types.INPUT,unit=1),
            Pin(num='B2',name='+12V',func=pin_types.PASSIVE,unit=1),
            Pin(num='B20',name='PETn1',func=pin_types.INPUT,unit=1),
            Pin(num='B21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B23',name='PETp2',func=pin_types.INPUT,unit=1),
            Pin(num='B24',name='PETn2',func=pin_types.INPUT,unit=1),
            Pin(num='B25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B26',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B27',name='PETp3',func=pin_types.INPUT,unit=1),
            Pin(num='B28',name='PETn3',func=pin_types.INPUT,unit=1),
            Pin(num='B29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='+12V',func=pin_types.PASSIVE,unit=1),
            Pin(num='B30',name='RSVD',func=pin_types.PASSIVE,unit=1),
            Pin(num='B31',name='~{PRSNT2}',func=pin_types.PASSIVE,unit=1),
            Pin(num='B32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='SMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='SMDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='+3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='JTAG1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Bus_PCI_Express_x8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Bus_PCI_Express_x8'}), 'ref_prefix':'J', 'fplist':['Connector_PCBEdge:BUS_PCIexpress_x8'], 'footprint':'Connector_PCBEdge:BUS_PCIexpress_x8', 'keywords':'pcie', 'description':'', 'datasheet':'http://www.ritrontek.com/uploadfile/2016/1026/20161026105231124.pdf#page=63', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nBus_PCI_Express_x8\n\npcie', 'pins':[
            Pin(num='A1',name='~{PRSNT1}',func=pin_types.PASSIVE,unit=1),
            Pin(num='A10',name='+3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='A11',name='~{PERST}',func=pin_types.INPUT,unit=1),
            Pin(num='A12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A13',name='REFCLK+',func=pin_types.INPUT,unit=1),
            Pin(num='A14',name='REFCLK-',func=pin_types.INPUT,unit=1),
            Pin(num='A15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A16',name='PERp0',func=pin_types.OUTPUT,unit=1),
            Pin(num='A17',name='PERn0',func=pin_types.OUTPUT,unit=1),
            Pin(num='A18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A19',name='RSVD',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='+12V',func=pin_types.PASSIVE,unit=1),
            Pin(num='A20',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A21',name='PERp1',func=pin_types.OUTPUT,unit=1),
            Pin(num='A22',name='PERn1',func=pin_types.OUTPUT,unit=1),
            Pin(num='A23',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A25',name='PERp2',func=pin_types.OUTPUT,unit=1),
            Pin(num='A26',name='PERn2',func=pin_types.OUTPUT,unit=1),
            Pin(num='A27',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A29',name='PERp3',func=pin_types.OUTPUT,unit=1),
            Pin(num='A3',name='+12V',func=pin_types.PASSIVE,unit=1),
            Pin(num='A30',name='PERn3',func=pin_types.OUTPUT,unit=1),
            Pin(num='A31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A32',name='RSVD',func=pin_types.PASSIVE,unit=1),
            Pin(num='A33',name='RSVD',func=pin_types.PASSIVE,unit=1),
            Pin(num='A34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A35',name='PERp4',func=pin_types.OUTPUT,unit=1),
            Pin(num='A36',name='PERn4',func=pin_types.OUTPUT,unit=1),
            Pin(num='A37',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A39',name='PERp5',func=pin_types.OUTPUT,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A40',name='PERn5',func=pin_types.OUTPUT,unit=1),
            Pin(num='A41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A42',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A43',name='PERp6',func=pin_types.OUTPUT,unit=1),
            Pin(num='A44',name='PERn6',func=pin_types.OUTPUT,unit=1),
            Pin(num='A45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A46',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A47',name='PERp7',func=pin_types.OUTPUT,unit=1),
            Pin(num='A48',name='PERn7',func=pin_types.OUTPUT,unit=1),
            Pin(num='A49',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='JTAG2',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='JTAG3',func=pin_types.INPUT,unit=1),
            Pin(num='A7',name='JTAG4',func=pin_types.OUTPUT,unit=1),
            Pin(num='A8',name='JTAG5',func=pin_types.INPUT,unit=1),
            Pin(num='A9',name='+3.3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='+12V',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='3.3Vaux',func=pin_types.PWRIN,unit=1),
            Pin(num='B11',name='~{WAKE}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='B12',name='RSVD',func=pin_types.PASSIVE,unit=1),
            Pin(num='B13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B14',name='PETp0',func=pin_types.INPUT,unit=1),
            Pin(num='B15',name='PETn0',func=pin_types.INPUT,unit=1),
            Pin(num='B16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B17',name='~{PRSNT2}',func=pin_types.PASSIVE,unit=1),
            Pin(num='B18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B19',name='PETp1',func=pin_types.INPUT,unit=1),
            Pin(num='B2',name='+12V',func=pin_types.PASSIVE,unit=1),
            Pin(num='B20',name='PETn1',func=pin_types.INPUT,unit=1),
            Pin(num='B21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B23',name='PETp2',func=pin_types.INPUT,unit=1),
            Pin(num='B24',name='PETn2',func=pin_types.INPUT,unit=1),
            Pin(num='B25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B26',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B27',name='PETp3',func=pin_types.INPUT,unit=1),
            Pin(num='B28',name='PETn3',func=pin_types.INPUT,unit=1),
            Pin(num='B29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='+12V',func=pin_types.PASSIVE,unit=1),
            Pin(num='B30',name='RSVD',func=pin_types.PASSIVE,unit=1),
            Pin(num='B31',name='~{PRSNT2}',func=pin_types.PASSIVE,unit=1),
            Pin(num='B32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B33',name='PETp4',func=pin_types.INPUT,unit=1),
            Pin(num='B34',name='PETn4',func=pin_types.INPUT,unit=1),
            Pin(num='B35',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B36',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B37',name='PETp5',func=pin_types.INPUT,unit=1),
            Pin(num='B38',name='PETn5',func=pin_types.INPUT,unit=1),
            Pin(num='B39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B40',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B41',name='PETp6',func=pin_types.INPUT,unit=1),
            Pin(num='B42',name='PETn6',func=pin_types.INPUT,unit=1),
            Pin(num='B43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B45',name='PETp7',func=pin_types.INPUT,unit=1),
            Pin(num='B46',name='PETn7',func=pin_types.INPUT,unit=1),
            Pin(num='B47',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B48',name='~{PRSNT2}',func=pin_types.PASSIVE,unit=1),
            Pin(num='B49',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='SMCLK',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='SMDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='+3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='JTAG1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CUI_PD-30', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CUI_PD-30'}), 'ref_prefix':'J', 'fplist':['Connector:CUI_PD-30'], 'footprint':'Connector:CUI_PD-30', 'keywords':'connector 3-pin PD-30 power DIN', 'description':'', 'datasheet':'http://www.cui.com/product/resource/pd-30.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nCUI_PD-30\n\nconnector 3-pin PD-30 power DIN', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Shield',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CUI_PD-30S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CUI_PD-30S'}), 'ref_prefix':'J', 'fplist':['Connector:CUI_PD-30S'], 'footprint':'Connector:CUI_PD-30S', 'keywords':'connector 3-pin PD-30S power DIN', 'description':'', 'datasheet':'http://www.cui.com/product/resource/pd-30.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nCUI_PD-30S\n\nconnector 3-pin PD-30S power DIN', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Shield',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='Shield',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CoaxialSwitch_Testpoint', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CoaxialSwitch_Testpoint'}), 'ref_prefix':'TP', 'fplist':[''], 'footprint':'', 'keywords':'Coaxial Switch RF testpoint', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nCoaxialSwitch_Testpoint\n\nCoaxial Switch RF testpoint', 'pins':[
            Pin(num='A',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='C',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='G',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x01_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x01_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x01_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x01_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x01_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x01_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x02_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x02_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x02_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x02_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x02_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x02_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x03_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x03_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x03_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x03_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x03_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x03_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x04_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x04_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x04_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x04_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x04_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x04_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x05_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x05_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x05_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x05_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x05_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x05_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x06_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x06_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x06_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x06_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x06_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x06_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x07_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x07_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x07_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x07_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x07_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x07_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x08_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x08_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x08_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x08_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x08_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x08_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x09_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x09_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x09_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x09_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x09_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x09_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x10_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x10_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x10_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x10_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x10_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x10_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x11_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x11_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x11_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x11_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x11_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x11_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x12_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x12_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x12_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x12_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x12_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x12_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x13_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x13_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x13_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x13_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x13_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x13_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x14_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x14_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x14_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x14_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x14_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x14_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x15_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x15_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x15_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x15_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x15_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x15_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x16_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x16_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x16_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x16_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x16_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x16_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x17_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x17_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x17_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x17_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x17_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x17_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x18_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x18_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x18_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x18_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x18_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x18_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x19_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x19_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x19_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x19_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x19_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x19_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x20_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x20_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x20_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x20_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x20_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x20_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x21_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x21_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x21_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x21_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x21_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x21_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x22_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x22_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x22_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x22_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x22_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x22_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x23_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x23_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x23_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x23_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x23_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x23_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x24_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x24_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x24_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x24_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x24_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x24_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x25_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x25_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x25_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x25_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x25_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x25_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x26_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x26_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x26_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x26_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x26_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x26_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x27_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x27_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x27_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x27_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x27_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x27_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x28_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x28_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x28_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x28_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x28_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x28_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x29_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x29_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x29_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x29_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x29_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x29_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x30_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x30_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x30_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x30_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x30_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x30_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x31_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x31_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x31_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x31_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x31_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x31_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x32_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x32_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x32_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x32_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x32_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x32_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x33_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x33_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x33_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x33_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x33_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x33_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x34_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x34_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x34_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x34_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x34_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x34_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x35_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x35_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x35_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x35_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x35_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x35_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x36_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x36_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x36_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x36_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x36_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x36_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x37_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x37_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x37_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x37_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x37_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x37_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x38_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x38_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x38_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x38_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x38_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x38_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x39_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x39_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x39_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x39_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x39_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x39_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x40_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x40_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x40_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x40_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x40_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x40_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x41_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x41_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x41_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x41_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x41_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x41_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x42_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x42_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x42_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x42_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x42_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x42_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x43_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x43_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x43_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x43_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x43_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x43_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x44_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x44_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x44_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x44_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x44_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x44_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x45_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x45_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x45_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x45_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x45_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x45_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x46_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x46_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x46_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x46_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x46_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x46_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x47_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x47_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x47_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x47_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x47_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x47_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x48_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x48_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x48_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x48_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x48_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x48_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x49_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x49_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x49_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x49_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x49_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x49_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x50_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x50_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x50_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x50_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x50_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x50_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x51_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x51_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x51_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x51_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x51_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x51_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x52_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x52_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x52_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x52_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x52_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x52_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x53_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x53_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x53_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x53_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x53_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x53_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x54_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x54_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x54_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x54_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x54_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x54_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x55_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x55_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x55_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x55_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x55_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x55_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x56_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x56_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x56_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x56_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x56_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x56_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x57_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x57_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x57_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x57_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x57_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x57_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x58_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x58_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x58_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x58_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x58_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x58_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x59_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x59_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x59_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x59_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x59_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x59_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x60_Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x60_Pin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x60_Pin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x60_Socket', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x60_Socket'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_01x60_Socket\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_15X4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_15X4'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_15X4\n\nconnector', 'pins':[
            Pin(num='A1',name='1A',func=pin_types.PASSIVE,unit=1),
            Pin(num='A10',name='10A',func=pin_types.PASSIVE,unit=1),
            Pin(num='A11',name='11A',func=pin_types.PASSIVE,unit=1),
            Pin(num='A12',name='12A',func=pin_types.PASSIVE,unit=1),
            Pin(num='A13',name='13A',func=pin_types.PASSIVE,unit=1),
            Pin(num='A14',name='14A',func=pin_types.PASSIVE,unit=1),
            Pin(num='A15',name='15A',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='2A',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='3A',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='4A',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='5A',func=pin_types.PASSIVE,unit=1),
            Pin(num='A6',name='6A',func=pin_types.PASSIVE,unit=1),
            Pin(num='A7',name='7A',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='8A',func=pin_types.PASSIVE,unit=1),
            Pin(num='A9',name='9A',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='1B',func=pin_types.PASSIVE,unit=1),
            Pin(num='B10',name='10B',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='11B',func=pin_types.PASSIVE,unit=1),
            Pin(num='B12',name='12B',func=pin_types.PASSIVE,unit=1),
            Pin(num='B13',name='13B',func=pin_types.PASSIVE,unit=1),
            Pin(num='B14',name='14B',func=pin_types.PASSIVE,unit=1),
            Pin(num='B15',name='15B',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='2B',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='3B',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='4B',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='5B',func=pin_types.PASSIVE,unit=1),
            Pin(num='B6',name='6B',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='7B',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='8B',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='9B',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='1C',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='10C',func=pin_types.PASSIVE,unit=1),
            Pin(num='C11',name='11C',func=pin_types.PASSIVE,unit=1),
            Pin(num='C12',name='12C',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='13C',func=pin_types.PASSIVE,unit=1),
            Pin(num='C14',name='14C',func=pin_types.PASSIVE,unit=1),
            Pin(num='C15',name='15C',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='2C',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='3C',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='4C',func=pin_types.PASSIVE,unit=1),
            Pin(num='C5',name='5C',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='6C',func=pin_types.PASSIVE,unit=1),
            Pin(num='C7',name='7C',func=pin_types.PASSIVE,unit=1),
            Pin(num='C8',name='8C',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='9C',func=pin_types.PASSIVE,unit=1),
            Pin(num='D1',name='1D',func=pin_types.PASSIVE,unit=1),
            Pin(num='D10',name='10D',func=pin_types.PASSIVE,unit=1),
            Pin(num='D11',name='11D',func=pin_types.PASSIVE,unit=1),
            Pin(num='D12',name='12D',func=pin_types.PASSIVE,unit=1),
            Pin(num='D13',name='13D',func=pin_types.PASSIVE,unit=1),
            Pin(num='D14',name='14D',func=pin_types.PASSIVE,unit=1),
            Pin(num='D15',name='15D',func=pin_types.PASSIVE,unit=1),
            Pin(num='D2',name='2D',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='3D',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='4D',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='5D',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='6D',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='7D',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='8D',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='9D',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_ARM_JTAG_SWD_10', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_ARM_JTAG_SWD_10'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'Cortex Debug Connector ARM SWD JTAG', 'description':'', 'datasheet':'http://infocenter.arm.com/help/topic/com.arm.doc.ddi0314h/DDI0314H_coresight_components_trm.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_ARM_JTAG_SWD_10\n\nCortex Debug Connector ARM SWD JTAG', 'pins':[
            Pin(num='1',name='VTref',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RESET}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='SWDIO/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='SWCLK/TCK',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='SWO/TDO',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='KEY',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC/TDI',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='GNDDetect',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_ARM_JTAG_SWD_20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_ARM_JTAG_SWD_20'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'IDC20 Pinheader Pins Connector ARM JTAG SWD', 'description':'', 'datasheet':'http://infocenter.arm.com/help/topic/com.arm.doc.dui0499b/DUI0499B_system_design_reference.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_ARM_JTAG_SWD_20\n\nIDC20 Pinheader Pins Connector ARM JTAG SWD', 'pins':[
            Pin(num='1',name='VTREF',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='RTCK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='TDO/SWO',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='~{SRST}',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='DBGRQ/NC',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='DBGACK/NC',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='VCC/NC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~{TRST}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TDI',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='TMS/SWDIO',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='TCK/SWCLK',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_ARM_SWD_TagConnect_TC2030', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_ARM_SWD_TagConnect_TC2030'}), 'ref_prefix':'J', 'fplist':['Connector:Tag-Connect_TC2030-IDC-FP_2x03_P1.27mm_Vertical'], 'footprint':'Connector:Tag-Connect_TC2030-IDC-FP_2x03_P1.27mm_Vertical', 'keywords':'Cortex Debug Connector ARM SWD JTAG', 'description':'', 'datasheet':'https://www.tag-connect.com/wp-content/uploads/bsk-pdf-manager/TC2030-CTX_1.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_ARM_SWD_TagConnect_TC2030\n\nCortex Debug Connector ARM SWD JTAG', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN),
            Pin(num='2',name='SWDIO',func=pin_types.BIDIR),
            Pin(num='3',name='~{RESET}',func=pin_types.OPENCOLL),
            Pin(num='4',name='SWCLK',func=pin_types.OUTPUT),
            Pin(num='5',name='GND',func=pin_types.PWRIN),
            Pin(num='6',name='SWO',func=pin_types.INPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_Coaxial', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_Coaxial'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'BNC SMA SMB SMC LEMO coaxial connector CINCH RCA MCX MMCX U.FL UMRF', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_Coaxial\n\nBNC SMA SMB SMC LEMO coaxial connector CINCH RCA MCX MMCX U.FL UMRF', 'pins':[
            Pin(num='1',name='In',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Ext',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_Coaxial_Power', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_Coaxial_Power'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'BNC SMA SMB SMC LEMO coaxial connector CINCH RCA', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_Coaxial_Power\n\nBNC SMA SMB SMC LEMO coaxial connector CINCH RCA', 'pins':[
            Pin(num='1',name='In',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Ext',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_Coaxial_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_Coaxial_Small'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'BNC SMA SMB SMC LEMO coaxial connector CINCH RCA MCX MMCX U.FL UMRF', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_Coaxial_Small\n\nBNC SMA SMB SMC LEMO coaxial connector CINCH RCA MCX MMCX U.FL UMRF', 'pins':[
            Pin(num='1',name='In',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Ext',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_Coaxial_x2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_Coaxial_x2'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'BNC SMA SMB SMC LEMO coaxial connector CINCH RCA', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_Coaxial_x2\n\nBNC SMA SMB SMC LEMO coaxial connector CINCH RCA', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IN2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='EXT',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_Coaxial_x2_Isolated', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_Coaxial_x2_Isolated'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'BNC SMA SMB SMC LEMO coaxial connector CINCH RCA', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_Coaxial_x2_Isolated\n\nBNC SMA SMB SMC LEMO coaxial connector CINCH RCA', 'pins':[
            Pin(num='1',name='In1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Ext1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='In2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='Ext2',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '3']}] }),
        Part(**{ 'name':'Conn_PIC_ICSP_ICD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_PIC_ICSP_ICD'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'icsp icd pic microchip', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/devicedoc/30277d.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_PIC_ICSP_ICD\n\nicsp icd pic microchip', 'pins':[
            Pin(num='1',name='~{MCLR}/VPP',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PGD/ICSPDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PGC/ICSPCLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='PGM/LVP',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_Plug_2P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_Plug_2P'}), 'ref_prefix':'P', 'fplist':[''], 'footprint':'', 'keywords':'2P mains plug wall', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_Plug_2P\n\n2P mains plug wall', 'pins':[
            Pin(num='1',name='L',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='N',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_Plug_3P_Protected', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_Plug_3P_Protected'}), 'ref_prefix':'P', 'fplist':[''], 'footprint':'', 'keywords':'3P mains plug protected wall', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_Plug_3P_Protected\n\n3P mains plug protected wall', 'pins':[
            Pin(num='1',name='L',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='N',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='PE',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_Receptacle_2P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_Receptacle_2P'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'2P mains receptacle wall', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_Receptacle_2P\n\n2P mains receptacle wall', 'pins':[
            Pin(num='1',name='L',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='N',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_Receptacle_3P_Protected', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_Receptacle_3P_Protected'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'3P mains receptacle protected wall', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_Receptacle_3P_Protected\n\n3P mains receptacle protected wall', 'pins':[
            Pin(num='1',name='N',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='L',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PE',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_ST_STDC14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_ST_STDC14'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'ST STM32 Cortex Debug Connector ARM SWD JTAG', 'description':'', 'datasheet':'https://www.st.com/content/ccc/resource/technical/document/user_manual/group1/99/49/91/b6/b2/3a/46/e5/DM00526767/files/DM00526767.pdf/jcr:content/translations/en.DM00526767.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_ST_STDC14\n\nST STM32 Cortex Debug Connector ARM SWD JTAG', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='JTDI/NC',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='GNDDetect',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~{RST}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='VCP_RX',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VCP_TX',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='JTMS/SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='JCLK/SWCLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='JTDO/SWO',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='JRCLK/NC',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_Triaxial', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_Triaxial'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'LEMO triaxial connector differential LVDS', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_Triaxial\n\nLEMO triaxial connector differential LVDS', 'pins':[
            Pin(num='1',name='In1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='In2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Ext',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DA15_Plug', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DA15_Plug'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'male plug D-SUB connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDA15_Plug\n\nmale plug D-SUB connector', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='P10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='P111',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='P12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='P13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='P14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='P15',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='P9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DA15_Plug_MountingHoles', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DA15_Plug_MountingHoles'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'male plug D-SUB connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDA15_Plug_MountingHoles\n\nmale plug D-SUB connector', 'pins':[
            Pin(num='0',name='PAD',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='P10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='P111',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='P12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='P13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='P14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='P15',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='P9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DA15_Receptacle', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DA15_Receptacle'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'female receptacle D-SUB connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDA15_Receptacle\n\nfemale receptacle D-SUB connector', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='P10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='P111',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='P12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='P13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='P14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='P15',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='P9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DA15_Receptacle_MountingHoles', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DA15_Receptacle_MountingHoles'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'female receptacle D-SUB connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDA15_Receptacle_MountingHoles\n\nfemale receptacle D-SUB connector', 'pins':[
            Pin(num='0',name='PAD',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='P10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='P111',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='P12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='P13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='P14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='P15',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='P9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DB25_Plug', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DB25_Plug'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'male plug D-SUB connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDB25_Plug\n\nmale plug D-SUB connector', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='P14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='P15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='P16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='P17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='P18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='P19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='P20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='P21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='P22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='P23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='P24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='P25',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DB25_Plug_MountingHoles', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DB25_Plug_MountingHoles'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'male plug D-SUB connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDB25_Plug_MountingHoles\n\nmale plug D-SUB connector', 'pins':[
            Pin(num='0',name='PAD',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='P14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='P15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='P16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='P17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='P18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='P19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='P20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='P21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='P22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='P23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='P24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='P25',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DB25_Receptacle', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DB25_Receptacle'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'female receptacle D-SUB connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDB25_Receptacle\n\nfemale receptacle D-SUB connector', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='P14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='P15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='P16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='P17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='P18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='P19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='P20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='P21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='P22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='P23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='P24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='P25',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DB25_Receptacle_MountingHoles', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DB25_Receptacle_MountingHoles'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'female receptacle D-SUB connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDB25_Receptacle_MountingHoles\n\nfemale receptacle D-SUB connector', 'pins':[
            Pin(num='0',name='PAD',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='P14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='P15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='P16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='P17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='P18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='P19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='P20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='P21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='P22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='P23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='P24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='P25',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DC37_Plug', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DC37_Plug'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'male plug D-SUB connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDC37_Plug\n\nmale plug D-SUB connector', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='37',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DC37_Plug_MountingHoles', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DC37_Plug_MountingHoles'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'male plug D-SUB connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDC37_Plug_MountingHoles\n\nmale plug D-SUB connector', 'pins':[
            Pin(num='0',name='PAD',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='37',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DC37_Receptacle', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DC37_Receptacle'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'female receptacle D-SUB connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDC37_Receptacle\n\nfemale receptacle D-SUB connector', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='37',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DC37_Receptacle_MountingHoles', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DC37_Receptacle_MountingHoles'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'female receptacle D-SUB connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDC37_Receptacle_MountingHoles\n\nfemale receptacle D-SUB connector', 'pins':[
            Pin(num='0',name='PAD',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='37',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DE15_Plug_HighDensity', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DE15_Plug_HighDensity'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector plug male VGA D-SUB', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDE15_Plug_HighDensity\n\nconnector plug male VGA D-SUB', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DE15_Plug_HighDensity_MountingHoles', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DE15_Plug_HighDensity_MountingHoles'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector plug male D-SUB VGA', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDE15_Plug_HighDensity_MountingHoles\n\nconnector plug male D-SUB VGA', 'pins':[
            Pin(num='0',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DE15_Receptacle_HighDensity', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DE15_Receptacle_HighDensity'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector  receptacle de15 VGA female D-SUB', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDE15_Receptacle_HighDensity\n\nconnector  receptacle de15 VGA female D-SUB', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DE15_Receptacle_HighDensity_MountingHoles', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DE15_Receptacle_HighDensity_MountingHoles'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector receptacle de15 female D-SUB VGA', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDE15_Receptacle_HighDensity_MountingHoles\n\nconnector receptacle de15 female D-SUB VGA', 'pins':[
            Pin(num='0',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DE9_Plug', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DE9_Plug'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector male plug D-SUB DB9', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDE9_Plug\n\nconnector male plug D-SUB DB9', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DE9_Plug_MountingHoles', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DE9_Plug_MountingHoles'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector plug male D-SUB DB9', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDE9_Plug_MountingHoles\n\nconnector plug male D-SUB DB9', 'pins':[
            Pin(num='0',name='PAD',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DE9_Receptacle', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DE9_Receptacle'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector receptacle female D-SUB DB9', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDE9_Receptacle\n\nconnector receptacle female D-SUB DB9', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DE9_Receptacle_MountingHoles', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DE9_Receptacle_MountingHoles'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector receptacle female D-SUB DB9', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDE9_Receptacle_MountingHoles\n\nconnector receptacle female D-SUB DB9', 'pins':[
            Pin(num='0',name='PAD',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN-3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN-3'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'circular DIN connector', 'description':'', 'datasheet':'http://www.mouser.com/ds/2/18/40_c091_abd_e-75918.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN-3\n\ncircular DIN connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN-4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN-4'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'circular DIN connector', 'description':'', 'datasheet':'http://www.mouser.com/ds/2/18/40_c091_abd_e-75918.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN-4\n\ncircular DIN connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN-5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN-5'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'circular DIN connector', 'description':'', 'datasheet':'http://www.mouser.com/ds/2/18/40_c091_abd_e-75918.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN-5\n\ncircular DIN connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN-5_180degree', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN-5_180degree'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'circular DIN connector stereo audio', 'description':'', 'datasheet':'http://www.mouser.com/ds/2/18/40_c091_abd_e-75918.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN-5_180degree\n\ncircular DIN connector stereo audio', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN-6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN-6'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'circular DIN connector', 'description':'', 'datasheet':'http://www.mouser.com/ds/2/18/40_c091_abd_e-75918.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN-6\n\ncircular DIN connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN-7', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN-7'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'circular DIN connector', 'description':'', 'datasheet':'http://www.mouser.com/ds/2/18/40_c091_abd_e-75918.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN-7\n\ncircular DIN connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN-7_CenterPin7', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN-7_CenterPin7'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'circular DIN connector', 'description':'', 'datasheet':'http://www.mouser.com/ds/2/18/40_c091_abd_e-75918.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN-7_CenterPin7\n\ncircular DIN connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN-8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN-8'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'circular DIN connector', 'description':'', 'datasheet':'http://www.mouser.com/ds/2/18/40_c091_abd_e-75918.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN-8\n\ncircular DIN connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN41612_01x32_A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN41612_01x32_A'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN41612_01x32_A\n\nconnector', 'pins':[
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN41612_02x05_AB_EvenPins', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN41612_02x05_AB_EvenPins'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN41612_02x05_AB_EvenPins\n\nconnector', 'pins':[
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN41612_02x05_AC_EvenPins', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN41612_02x05_AC_EvenPins'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN41612_02x05_AC_EvenPins\n\nconnector', 'pins':[
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='c10',name='Pin_c10',func=pin_types.PASSIVE,unit=1),
            Pin(num='c2',name='Pin_c2',func=pin_types.PASSIVE,unit=1),
            Pin(num='c4',name='Pin_c4',func=pin_types.PASSIVE,unit=1),
            Pin(num='c6',name='Pin_c6',func=pin_types.PASSIVE,unit=1),
            Pin(num='c8',name='Pin_c8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN41612_02x05_AE_EvenPins', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN41612_02x05_AE_EvenPins'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN41612_02x05_AE_EvenPins\n\nconnector', 'pins':[
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='e10',name='Pin_e10',func=pin_types.PASSIVE,unit=1),
            Pin(num='e2',name='Pin_e2',func=pin_types.PASSIVE,unit=1),
            Pin(num='e4',name='Pin_e4',func=pin_types.PASSIVE,unit=1),
            Pin(num='e6',name='Pin_e6',func=pin_types.PASSIVE,unit=1),
            Pin(num='e8',name='Pin_e8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN41612_02x05_ZB_EvenPins', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN41612_02x05_ZB_EvenPins'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN41612_02x05_ZB_EvenPins\n\nconnector', 'pins':[
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='z10',name='Pin_z10',func=pin_types.PASSIVE,unit=1),
            Pin(num='z2',name='Pin_z2',func=pin_types.PASSIVE,unit=1),
            Pin(num='z4',name='Pin_z4',func=pin_types.PASSIVE,unit=1),
            Pin(num='z6',name='Pin_z6',func=pin_types.PASSIVE,unit=1),
            Pin(num='z8',name='Pin_z8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN41612_02x08_AB_EvenPins', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN41612_02x08_AB_EvenPins'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN41612_02x08_AB_EvenPins\n\nconnector', 'pins':[
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN41612_02x08_AC_EvenPins', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN41612_02x08_AC_EvenPins'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN41612_02x08_AC_EvenPins\n\nconnector', 'pins':[
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='c10',name='Pin_c10',func=pin_types.PASSIVE,unit=1),
            Pin(num='c12',name='Pin_c12',func=pin_types.PASSIVE,unit=1),
            Pin(num='c14',name='Pin_c14',func=pin_types.PASSIVE,unit=1),
            Pin(num='c16',name='Pin_c16',func=pin_types.PASSIVE,unit=1),
            Pin(num='c2',name='Pin_c2',func=pin_types.PASSIVE,unit=1),
            Pin(num='c4',name='Pin_c4',func=pin_types.PASSIVE,unit=1),
            Pin(num='c6',name='Pin_c6',func=pin_types.PASSIVE,unit=1),
            Pin(num='c8',name='Pin_c8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN41612_02x08_AE_EvenPins', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN41612_02x08_AE_EvenPins'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN41612_02x08_AE_EvenPins\n\nconnector', 'pins':[
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='e10',name='Pin_e10',func=pin_types.PASSIVE,unit=1),
            Pin(num='e12',name='Pin_e12',func=pin_types.PASSIVE,unit=1),
            Pin(num='e14',name='Pin_e14',func=pin_types.PASSIVE,unit=1),
            Pin(num='e16',name='Pin_e16',func=pin_types.PASSIVE,unit=1),
            Pin(num='e2',name='Pin_e2',func=pin_types.PASSIVE,unit=1),
            Pin(num='e4',name='Pin_e4',func=pin_types.PASSIVE,unit=1),
            Pin(num='e6',name='Pin_e6',func=pin_types.PASSIVE,unit=1),
            Pin(num='e8',name='Pin_e8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN41612_02x08_ZB_EvenPins', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN41612_02x08_ZB_EvenPins'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN41612_02x08_ZB_EvenPins\n\nconnector', 'pins':[
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='z10',name='Pin_z10',func=pin_types.PASSIVE,unit=1),
            Pin(num='z12',name='Pin_z12',func=pin_types.PASSIVE,unit=1),
            Pin(num='z14',name='Pin_z14',func=pin_types.PASSIVE,unit=1),
            Pin(num='z16',name='Pin_z16',func=pin_types.PASSIVE,unit=1),
            Pin(num='z2',name='Pin_z2',func=pin_types.PASSIVE,unit=1),
            Pin(num='z4',name='Pin_z4',func=pin_types.PASSIVE,unit=1),
            Pin(num='z6',name='Pin_z6',func=pin_types.PASSIVE,unit=1),
            Pin(num='z8',name='Pin_z8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN41612_02x10_AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN41612_02x10_AB'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN41612_02x10_AB\n\nconnector', 'pins':[
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN41612_02x10_AC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN41612_02x10_AC'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN41612_02x10_AC\n\nconnector', 'pins':[
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='c1',name='Pin_c1',func=pin_types.PASSIVE,unit=1),
            Pin(num='c10',name='Pin_c10',func=pin_types.PASSIVE,unit=1),
            Pin(num='c2',name='Pin_c2',func=pin_types.PASSIVE,unit=1),
            Pin(num='c3',name='Pin_c3',func=pin_types.PASSIVE,unit=1),
            Pin(num='c4',name='Pin_c4',func=pin_types.PASSIVE,unit=1),
            Pin(num='c5',name='Pin_c5',func=pin_types.PASSIVE,unit=1),
            Pin(num='c6',name='Pin_c6',func=pin_types.PASSIVE,unit=1),
            Pin(num='c7',name='Pin_c7',func=pin_types.PASSIVE,unit=1),
            Pin(num='c8',name='Pin_c8',func=pin_types.PASSIVE,unit=1),
            Pin(num='c9',name='Pin_c9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN41612_02x10_AE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN41612_02x10_AE'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN41612_02x10_AE\n\nconnector', 'pins':[
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='e1',name='Pin_e1',func=pin_types.PASSIVE,unit=1),
            Pin(num='e10',name='Pin_e10',func=pin_types.PASSIVE,unit=1),
            Pin(num='e2',name='Pin_e2',func=pin_types.PASSIVE,unit=1),
            Pin(num='e3',name='Pin_e3',func=pin_types.PASSIVE,unit=1),
            Pin(num='e4',name='Pin_e4',func=pin_types.PASSIVE,unit=1),
            Pin(num='e5',name='Pin_e5',func=pin_types.PASSIVE,unit=1),
            Pin(num='e6',name='Pin_e6',func=pin_types.PASSIVE,unit=1),
            Pin(num='e7',name='Pin_e7',func=pin_types.PASSIVE,unit=1),
            Pin(num='e8',name='Pin_e8',func=pin_types.PASSIVE,unit=1),
            Pin(num='e9',name='Pin_e9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN41612_02x10_ZB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN41612_02x10_ZB'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN41612_02x10_ZB\n\nconnector', 'pins':[
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1),
            Pin(num='z1',name='Pin_z1',func=pin_types.PASSIVE,unit=1),
            Pin(num='z10',name='Pin_z10',func=pin_types.PASSIVE,unit=1),
            Pin(num='z2',name='Pin_z2',func=pin_types.PASSIVE,unit=1),
            Pin(num='z3',name='Pin_z3',func=pin_types.PASSIVE,unit=1),
            Pin(num='z4',name='Pin_z4',func=pin_types.PASSIVE,unit=1),
            Pin(num='z5',name='Pin_z5',func=pin_types.PASSIVE,unit=1),
            Pin(num='z6',name='Pin_z6',func=pin_types.PASSIVE,unit=1),
            Pin(num='z7',name='Pin_z7',func=pin_types.PASSIVE,unit=1),
            Pin(num='z8',name='Pin_z8',func=pin_types.PASSIVE,unit=1),
            Pin(num='z9',name='Pin_z9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN41612_02x16_AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN41612_02x16_AB'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN41612_02x16_AB\n\nconnector', 'pins':[
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN41612_02x16_AB_EvenPins', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN41612_02x16_AB_EvenPins'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN41612_02x16_AB_EvenPins\n\nconnector', 'pins':[
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN41612_02x16_AC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN41612_02x16_AC'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN41612_02x16_AC\n\nconnector', 'pins':[
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='c1',name='Pin_c1',func=pin_types.PASSIVE,unit=1),
            Pin(num='c10',name='Pin_c10',func=pin_types.PASSIVE,unit=1),
            Pin(num='c11',name='Pin_c11',func=pin_types.PASSIVE,unit=1),
            Pin(num='c12',name='Pin_c12',func=pin_types.PASSIVE,unit=1),
            Pin(num='c13',name='Pin_c13',func=pin_types.PASSIVE,unit=1),
            Pin(num='c14',name='Pin_c14',func=pin_types.PASSIVE,unit=1),
            Pin(num='c15',name='Pin_c15',func=pin_types.PASSIVE,unit=1),
            Pin(num='c16',name='Pin_c16',func=pin_types.PASSIVE,unit=1),
            Pin(num='c2',name='Pin_c2',func=pin_types.PASSIVE,unit=1),
            Pin(num='c3',name='Pin_c3',func=pin_types.PASSIVE,unit=1),
            Pin(num='c4',name='Pin_c4',func=pin_types.PASSIVE,unit=1),
            Pin(num='c5',name='Pin_c5',func=pin_types.PASSIVE,unit=1),
            Pin(num='c6',name='Pin_c6',func=pin_types.PASSIVE,unit=1),
            Pin(num='c7',name='Pin_c7',func=pin_types.PASSIVE,unit=1),
            Pin(num='c8',name='Pin_c8',func=pin_types.PASSIVE,unit=1),
            Pin(num='c9',name='Pin_c9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN41612_02x16_AC_EvenPins', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN41612_02x16_AC_EvenPins'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN41612_02x16_AC_EvenPins\n\nconnector', 'pins':[
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='c10',name='Pin_c10',func=pin_types.PASSIVE,unit=1),
            Pin(num='c12',name='Pin_c12',func=pin_types.PASSIVE,unit=1),
            Pin(num='c14',name='Pin_c14',func=pin_types.PASSIVE,unit=1),
            Pin(num='c16',name='Pin_c16',func=pin_types.PASSIVE,unit=1),
            Pin(num='c18',name='Pin_c18',func=pin_types.PASSIVE,unit=1),
            Pin(num='c2',name='Pin_c2',func=pin_types.PASSIVE,unit=1),
            Pin(num='c20',name='Pin_c20',func=pin_types.PASSIVE,unit=1),
            Pin(num='c22',name='Pin_c22',func=pin_types.PASSIVE,unit=1),
            Pin(num='c24',name='Pin_c24',func=pin_types.PASSIVE,unit=1),
            Pin(num='c26',name='Pin_c26',func=pin_types.PASSIVE,unit=1),
            Pin(num='c28',name='Pin_c28',func=pin_types.PASSIVE,unit=1),
            Pin(num='c30',name='Pin_c30',func=pin_types.PASSIVE,unit=1),
            Pin(num='c32',name='Pin_c32',func=pin_types.PASSIVE,unit=1),
            Pin(num='c4',name='Pin_c4',func=pin_types.PASSIVE,unit=1),
            Pin(num='c6',name='Pin_c6',func=pin_types.PASSIVE,unit=1),
            Pin(num='c8',name='Pin_c8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN41612_02x16_AE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN41612_02x16_AE'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN41612_02x16_AE\n\nconnector', 'pins':[
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='e1',name='Pin_e1',func=pin_types.PASSIVE,unit=1),
            Pin(num='e10',name='Pin_e10',func=pin_types.PASSIVE,unit=1),
            Pin(num='e11',name='Pin_e11',func=pin_types.PASSIVE,unit=1),
            Pin(num='e12',name='Pin_e12',func=pin_types.PASSIVE,unit=1),
            Pin(num='e13',name='Pin_e13',func=pin_types.PASSIVE,unit=1),
            Pin(num='e14',name='Pin_e14',func=pin_types.PASSIVE,unit=1),
            Pin(num='e15',name='Pin_e15',func=pin_types.PASSIVE,unit=1),
            Pin(num='e16',name='Pin_e16',func=pin_types.PASSIVE,unit=1),
            Pin(num='e2',name='Pin_e2',func=pin_types.PASSIVE,unit=1),
            Pin(num='e3',name='Pin_e3',func=pin_types.PASSIVE,unit=1),
            Pin(num='e4',name='Pin_e4',func=pin_types.PASSIVE,unit=1),
            Pin(num='e5',name='Pin_e5',func=pin_types.PASSIVE,unit=1),
            Pin(num='e6',name='Pin_e6',func=pin_types.PASSIVE,unit=1),
            Pin(num='e7',name='Pin_e7',func=pin_types.PASSIVE,unit=1),
            Pin(num='e8',name='Pin_e8',func=pin_types.PASSIVE,unit=1),
            Pin(num='e9',name='Pin_e9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN41612_02x16_AE_EvenPins', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN41612_02x16_AE_EvenPins'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN41612_02x16_AE_EvenPins\n\nconnector', 'pins':[
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='e10',name='Pin_e10',func=pin_types.PASSIVE,unit=1),
            Pin(num='e12',name='Pin_e12',func=pin_types.PASSIVE,unit=1),
            Pin(num='e14',name='Pin_e14',func=pin_types.PASSIVE,unit=1),
            Pin(num='e16',name='Pin_e16',func=pin_types.PASSIVE,unit=1),
            Pin(num='e18',name='Pin_e18',func=pin_types.PASSIVE,unit=1),
            Pin(num='e2',name='Pin_e2',func=pin_types.PASSIVE,unit=1),
            Pin(num='e20',name='Pin_e20',func=pin_types.PASSIVE,unit=1),
            Pin(num='e22',name='Pin_e22',func=pin_types.PASSIVE,unit=1),
            Pin(num='e24',name='Pin_e24',func=pin_types.PASSIVE,unit=1),
            Pin(num='e26',name='Pin_e26',func=pin_types.PASSIVE,unit=1),
            Pin(num='e28',name='Pin_e28',func=pin_types.PASSIVE,unit=1),
            Pin(num='e30',name='Pin_e30',func=pin_types.PASSIVE,unit=1),
            Pin(num='e32',name='Pin_e32',func=pin_types.PASSIVE,unit=1),
            Pin(num='e4',name='Pin_e4',func=pin_types.PASSIVE,unit=1),
            Pin(num='e6',name='Pin_e6',func=pin_types.PASSIVE,unit=1),
            Pin(num='e8',name='Pin_e8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN41612_02x16_ZB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN41612_02x16_ZB'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN41612_02x16_ZB\n\nconnector', 'pins':[
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1),
            Pin(num='z1',name='Pin_z1',func=pin_types.PASSIVE,unit=1),
            Pin(num='z10',name='Pin_z10',func=pin_types.PASSIVE,unit=1),
            Pin(num='z11',name='Pin_z11',func=pin_types.PASSIVE,unit=1),
            Pin(num='z12',name='Pin_z12',func=pin_types.PASSIVE,unit=1),
            Pin(num='z13',name='Pin_z13',func=pin_types.PASSIVE,unit=1),
            Pin(num='z14',name='Pin_z14',func=pin_types.PASSIVE,unit=1),
            Pin(num='z15',name='Pin_z15',func=pin_types.PASSIVE,unit=1),
            Pin(num='z16',name='Pin_z16',func=pin_types.PASSIVE,unit=1),
            Pin(num='z2',name='Pin_z2',func=pin_types.PASSIVE,unit=1),
            Pin(num='z3',name='Pin_z3',func=pin_types.PASSIVE,unit=1),
            Pin(num='z4',name='Pin_z4',func=pin_types.PASSIVE,unit=1),
            Pin(num='z5',name='Pin_z5',func=pin_types.PASSIVE,unit=1),
            Pin(num='z6',name='Pin_z6',func=pin_types.PASSIVE,unit=1),
            Pin(num='z7',name='Pin_z7',func=pin_types.PASSIVE,unit=1),
            Pin(num='z8',name='Pin_z8',func=pin_types.PASSIVE,unit=1),
            Pin(num='z9',name='Pin_z9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN41612_02x16_ZB_EvenPins', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN41612_02x16_ZB_EvenPins'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN41612_02x16_ZB_EvenPins\n\nconnector', 'pins':[
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='z10',name='Pin_z10',func=pin_types.PASSIVE,unit=1),
            Pin(num='z12',name='Pin_z12',func=pin_types.PASSIVE,unit=1),
            Pin(num='z14',name='Pin_z14',func=pin_types.PASSIVE,unit=1),
            Pin(num='z16',name='Pin_z16',func=pin_types.PASSIVE,unit=1),
            Pin(num='z18',name='Pin_z18',func=pin_types.PASSIVE,unit=1),
            Pin(num='z2',name='Pin_z2',func=pin_types.PASSIVE,unit=1),
            Pin(num='z20',name='Pin_z20',func=pin_types.PASSIVE,unit=1),
            Pin(num='z22',name='Pin_z22',func=pin_types.PASSIVE,unit=1),
            Pin(num='z24',name='Pin_z24',func=pin_types.PASSIVE,unit=1),
            Pin(num='z26',name='Pin_z26',func=pin_types.PASSIVE,unit=1),
            Pin(num='z28',name='Pin_z28',func=pin_types.PASSIVE,unit=1),
            Pin(num='z30',name='Pin_z30',func=pin_types.PASSIVE,unit=1),
            Pin(num='z32',name='Pin_z32',func=pin_types.PASSIVE,unit=1),
            Pin(num='z4',name='Pin_z4',func=pin_types.PASSIVE,unit=1),
            Pin(num='z6',name='Pin_z6',func=pin_types.PASSIVE,unit=1),
            Pin(num='z8',name='Pin_z8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN41612_02x32_AB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN41612_02x32_AB'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN41612_02x32_AB\n\nconnector', 'pins':[
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN41612_02x32_AC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN41612_02x32_AC'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN41612_02x32_AC\n\nconnector', 'pins':[
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='c1',name='Pin_c1',func=pin_types.PASSIVE,unit=1),
            Pin(num='c10',name='Pin_c10',func=pin_types.PASSIVE,unit=1),
            Pin(num='c11',name='Pin_c11',func=pin_types.PASSIVE,unit=1),
            Pin(num='c12',name='Pin_c12',func=pin_types.PASSIVE,unit=1),
            Pin(num='c13',name='Pin_c13',func=pin_types.PASSIVE,unit=1),
            Pin(num='c14',name='Pin_c14',func=pin_types.PASSIVE,unit=1),
            Pin(num='c15',name='Pin_c15',func=pin_types.PASSIVE,unit=1),
            Pin(num='c16',name='Pin_c16',func=pin_types.PASSIVE,unit=1),
            Pin(num='c17',name='Pin_c17',func=pin_types.PASSIVE,unit=1),
            Pin(num='c18',name='Pin_c18',func=pin_types.PASSIVE,unit=1),
            Pin(num='c19',name='Pin_c19',func=pin_types.PASSIVE,unit=1),
            Pin(num='c2',name='Pin_c2',func=pin_types.PASSIVE,unit=1),
            Pin(num='c20',name='Pin_c20',func=pin_types.PASSIVE,unit=1),
            Pin(num='c21',name='Pin_c21',func=pin_types.PASSIVE,unit=1),
            Pin(num='c22',name='Pin_c22',func=pin_types.PASSIVE,unit=1),
            Pin(num='c23',name='Pin_c23',func=pin_types.PASSIVE,unit=1),
            Pin(num='c24',name='Pin_c24',func=pin_types.PASSIVE,unit=1),
            Pin(num='c25',name='Pin_c25',func=pin_types.PASSIVE,unit=1),
            Pin(num='c26',name='Pin_c26',func=pin_types.PASSIVE,unit=1),
            Pin(num='c27',name='Pin_c27',func=pin_types.PASSIVE,unit=1),
            Pin(num='c28',name='Pin_c28',func=pin_types.PASSIVE,unit=1),
            Pin(num='c29',name='Pin_c29',func=pin_types.PASSIVE,unit=1),
            Pin(num='c3',name='Pin_c3',func=pin_types.PASSIVE,unit=1),
            Pin(num='c30',name='Pin_c30',func=pin_types.PASSIVE,unit=1),
            Pin(num='c31',name='Pin_c31',func=pin_types.PASSIVE,unit=1),
            Pin(num='c32',name='Pin_c32',func=pin_types.PASSIVE,unit=1),
            Pin(num='c4',name='Pin_c4',func=pin_types.PASSIVE,unit=1),
            Pin(num='c5',name='Pin_c5',func=pin_types.PASSIVE,unit=1),
            Pin(num='c6',name='Pin_c6',func=pin_types.PASSIVE,unit=1),
            Pin(num='c7',name='Pin_c7',func=pin_types.PASSIVE,unit=1),
            Pin(num='c8',name='Pin_c8',func=pin_types.PASSIVE,unit=1),
            Pin(num='c9',name='Pin_c9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN41612_02x32_AE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN41612_02x32_AE'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN41612_02x32_AE\n\nconnector', 'pins':[
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='e1',name='Pin_e1',func=pin_types.PASSIVE,unit=1),
            Pin(num='e10',name='Pin_e10',func=pin_types.PASSIVE,unit=1),
            Pin(num='e11',name='Pin_e11',func=pin_types.PASSIVE,unit=1),
            Pin(num='e12',name='Pin_e12',func=pin_types.PASSIVE,unit=1),
            Pin(num='e13',name='Pin_e13',func=pin_types.PASSIVE,unit=1),
            Pin(num='e14',name='Pin_e14',func=pin_types.PASSIVE,unit=1),
            Pin(num='e15',name='Pin_e15',func=pin_types.PASSIVE,unit=1),
            Pin(num='e16',name='Pin_e16',func=pin_types.PASSIVE,unit=1),
            Pin(num='e17',name='Pin_e17',func=pin_types.PASSIVE,unit=1),
            Pin(num='e18',name='Pin_e18',func=pin_types.PASSIVE,unit=1),
            Pin(num='e19',name='Pin_e19',func=pin_types.PASSIVE,unit=1),
            Pin(num='e2',name='Pin_e2',func=pin_types.PASSIVE,unit=1),
            Pin(num='e20',name='Pin_e20',func=pin_types.PASSIVE,unit=1),
            Pin(num='e21',name='Pin_e21',func=pin_types.PASSIVE,unit=1),
            Pin(num='e22',name='Pin_e22',func=pin_types.PASSIVE,unit=1),
            Pin(num='e23',name='Pin_e23',func=pin_types.PASSIVE,unit=1),
            Pin(num='e24',name='Pin_e24',func=pin_types.PASSIVE,unit=1),
            Pin(num='e25',name='Pin_e25',func=pin_types.PASSIVE,unit=1),
            Pin(num='e26',name='Pin_e26',func=pin_types.PASSIVE,unit=1),
            Pin(num='e27',name='Pin_e27',func=pin_types.PASSIVE,unit=1),
            Pin(num='e28',name='Pin_e28',func=pin_types.PASSIVE,unit=1),
            Pin(num='e29',name='Pin_e29',func=pin_types.PASSIVE,unit=1),
            Pin(num='e3',name='Pin_e3',func=pin_types.PASSIVE,unit=1),
            Pin(num='e30',name='Pin_e30',func=pin_types.PASSIVE,unit=1),
            Pin(num='e31',name='Pin_e31',func=pin_types.PASSIVE,unit=1),
            Pin(num='e32',name='Pin_e32',func=pin_types.PASSIVE,unit=1),
            Pin(num='e4',name='Pin_e4',func=pin_types.PASSIVE,unit=1),
            Pin(num='e5',name='Pin_e5',func=pin_types.PASSIVE,unit=1),
            Pin(num='e6',name='Pin_e6',func=pin_types.PASSIVE,unit=1),
            Pin(num='e7',name='Pin_e7',func=pin_types.PASSIVE,unit=1),
            Pin(num='e8',name='Pin_e8',func=pin_types.PASSIVE,unit=1),
            Pin(num='e9',name='Pin_e9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIN41612_02x32_ZB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIN41612_02x32_ZB'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDIN41612_02x32_ZB\n\nconnector', 'pins':[
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1),
            Pin(num='z1',name='Pin_z1',func=pin_types.PASSIVE,unit=1),
            Pin(num='z10',name='Pin_z10',func=pin_types.PASSIVE,unit=1),
            Pin(num='z11',name='Pin_z11',func=pin_types.PASSIVE,unit=1),
            Pin(num='z12',name='Pin_z12',func=pin_types.PASSIVE,unit=1),
            Pin(num='z13',name='Pin_z13',func=pin_types.PASSIVE,unit=1),
            Pin(num='z14',name='Pin_z14',func=pin_types.PASSIVE,unit=1),
            Pin(num='z15',name='Pin_z15',func=pin_types.PASSIVE,unit=1),
            Pin(num='z16',name='Pin_z16',func=pin_types.PASSIVE,unit=1),
            Pin(num='z17',name='Pin_z17',func=pin_types.PASSIVE,unit=1),
            Pin(num='z18',name='Pin_z18',func=pin_types.PASSIVE,unit=1),
            Pin(num='z19',name='Pin_z19',func=pin_types.PASSIVE,unit=1),
            Pin(num='z2',name='Pin_z2',func=pin_types.PASSIVE,unit=1),
            Pin(num='z20',name='Pin_z20',func=pin_types.PASSIVE,unit=1),
            Pin(num='z21',name='Pin_z21',func=pin_types.PASSIVE,unit=1),
            Pin(num='z22',name='Pin_z22',func=pin_types.PASSIVE,unit=1),
            Pin(num='z23',name='Pin_z23',func=pin_types.PASSIVE,unit=1),
            Pin(num='z24',name='Pin_z24',func=pin_types.PASSIVE,unit=1),
            Pin(num='z25',name='Pin_z25',func=pin_types.PASSIVE,unit=1),
            Pin(num='z26',name='Pin_z26',func=pin_types.PASSIVE,unit=1),
            Pin(num='z27',name='Pin_z27',func=pin_types.PASSIVE,unit=1),
            Pin(num='z28',name='Pin_z28',func=pin_types.PASSIVE,unit=1),
            Pin(num='z29',name='Pin_z29',func=pin_types.PASSIVE,unit=1),
            Pin(num='z3',name='Pin_z3',func=pin_types.PASSIVE,unit=1),
            Pin(num='z30',name='Pin_z30',func=pin_types.PASSIVE,unit=1),
            Pin(num='z31',name='Pin_z31',func=pin_types.PASSIVE,unit=1),
            Pin(num='z32',name='Pin_z32',func=pin_types.PASSIVE,unit=1),
            Pin(num='z4',name='Pin_z4',func=pin_types.PASSIVE,unit=1),
            Pin(num='z5',name='Pin_z5',func=pin_types.PASSIVE,unit=1),
            Pin(num='z6',name='Pin_z6',func=pin_types.PASSIVE,unit=1),
            Pin(num='z7',name='Pin_z7',func=pin_types.PASSIVE,unit=1),
            Pin(num='z8',name='Pin_z8',func=pin_types.PASSIVE,unit=1),
            Pin(num='z9',name='Pin_z9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DVI-D_Dual_Link', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DVI-D_Dual_Link'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'dvi digital visual interface', 'description':'', 'datasheet':'https://www.molex.com/content/dam/molex/molex-dot-com/products/automated/en-us/salesdrawingpdf/743/74320/743204004_sd.pdf?inline', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDVI-D_Dual_Link\n\ndvi digital visual interface', 'pins':[
            Pin(num='1',name='D2-',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='D1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='D1/3S',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='D3-',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='D3+',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='HPD',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='D0-',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='D0+',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='D0/5S',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='D2+',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='D5-',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='D5+',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='CKS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='CK+',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='CK-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='D2/4S',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='D4-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='D4+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='DDCCL',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='DDCIO',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='D1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='SH',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DVI-I_Dual_Link', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DVI-I_Dual_Link'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'dvi digital visual interface', 'description':'', 'datasheet':'https://www.molex.com/content/dam/molex/molex-dot-com/products/automated/en-us/salesdrawingpdf/743/74320/743201004_sd.pdf?inline', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nDVI-I_Dual_Link\n\ndvi digital visual interface', 'pins':[
            Pin(num='1',name='D2-',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='D1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='D1/3S',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='D3-',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='D3+',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='HPD',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='D0-',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='D0+',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='D0/5S',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='D2+',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='D5-',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='D5+',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='CKS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='CK+',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='CK-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='D2/4S',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='D4-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='D4+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='DDCCL',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='DDCIO',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSYNC',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='D1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='Red',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='Green',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='Blue',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='HSYNC',func=pin_types.PASSIVE,unit=1),
            Pin(num='C5',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='SH',name='SH',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ExpressCard', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ExpressCard'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'expresscard pci express', 'description':'', 'datasheet':'https://web.archive.org/web/20180809060653/http://www.usb.org/developers/expresscard/EC_specifications/ExpressCard_2_0_FINAL.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nExpressCard\n\nexpresscard pci express', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWROUT,unit=1),
            Pin(num='10',name='1V5',func=pin_types.PWROUT,unit=1),
            Pin(num='11',name='~{WAKE}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='3V3_AUX',func=pin_types.PWROUT,unit=1),
            Pin(num='13',name='~{PERST}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='3V3',func=pin_types.PWROUT,unit=1),
            Pin(num='15',name='3V3',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='~{CLKREQ}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{CPPE}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='REFCLK-',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='REFCLK+',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='USBD-',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='PERn0/SSRX-',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='PERp0/SSRX+',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='PETn0/SSTX-',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='PETp0/SSTX+',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='USBD+',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{CPUSB}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{USB3}',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RESERVED',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='SMBCLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='SMDDATA',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='1V5',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HDMI_A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HDMI_A'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'hdmi conn', 'description':'', 'datasheet':'https://en.wikipedia.org/wiki/HDMI', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nHDMI_A\n\nhdmi conn', 'pins':[
            Pin(num='1',name='D2+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='CK+',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='CKS',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='CK-',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='CEC',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='UTILITY',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='SCL',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='HPD',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='D2S',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D2-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='D1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='D1S',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='D1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='D0+',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='D0S',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='D0-',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='SH',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HDMI_A_1.4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HDMI_A_1.4'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'hdmi conn', 'description':'', 'datasheet':'https://en.wikipedia.org/wiki/HDMI', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nHDMI_A_1.4\n\nhdmi conn', 'pins':[
            Pin(num='1',name='D2+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='CK+',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='CKS',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='CK-',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='CEC',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='UTILITY/HEAC+',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='SCL',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='HPD/HEAC-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='D2S',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D2-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='D1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='D1S',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='D1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='D0+',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='D0S',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='D0-',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='SH',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HDMI_B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HDMI_B'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'hdmi conn', 'description':'', 'datasheet':'http://pinouts.ru/Video/hdmi_pinout.shtml', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nHDMI_B\n\nhdmi conn', 'pins':[
            Pin(num='1',name='D2+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='CK+',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='CKS',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='CK-',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='D5+',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='D5S',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='D5-',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='D4+',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='D4S',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='D4-',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='D3+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='D2S',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='D3S',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='D3-',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='CEC',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='SCL',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='HPD',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='D2-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='D1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='D1S',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='D1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='D0+',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='D0S',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='D0-',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='SH',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HDMI_C_1.3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HDMI_C_1.3'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'hdmi conn', 'description':'', 'datasheet':'http://pinoutguide.com/PortableDevices/mini_hdmi_pinout.shtml', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nHDMI_C_1.3\n\nhdmi conn', 'pins':[
            Pin(num='1',name='D2S',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='CKS',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='CK+',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='CK-',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='CEC',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SCL',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='UTILITY',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='HPD',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='D2+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='D2-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='D1S',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='D1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='D1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='D0S',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='D0+',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='D0-',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='SH',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HDMI_C_1.4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HDMI_C_1.4'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'hdmi conn', 'description':'', 'datasheet':'http://pinoutguide.com/PortableDevices/mini_hdmi_pinout.shtml', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nHDMI_C_1.4\n\nhdmi conn', 'pins':[
            Pin(num='1',name='D2S',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='CKS',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='CK+',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='CK-',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='CEC',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SCL',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='UTILITY/HEAC+',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='HPD/HEAC-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='D2+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='D2-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='D1S',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='D1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='D1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='D0S',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='D0+',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='D0-',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='SH',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HDMI_D_1.4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HDMI_D_1.4'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'hdmi conn', 'description':'', 'datasheet':'http://pinoutguide.com/PortableDevices/micro_hdmi_type_d_pinout.shtml', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nHDMI_D_1.4\n\nhdmi conn', 'pins':[
            Pin(num='1',name='HPD/HEAC-',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='D0S',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='D0-',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='CK+',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='CKS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='CK-',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='CEC',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='SCL',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='UTILITY/HEAC+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='D2+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='D2S',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='D2-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='D1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='D1S',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='D1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='D0+',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='SH',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HDMI_E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HDMI_E'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'hdmi conn', 'description':'', 'datasheet':'https://www.hdmi.org/manufacturer/specification.aspx', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nHDMI_E\n\nhdmi conn', 'pins':[
            Pin(num='1',name='D2+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='CK+',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='CKS',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='CK-',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='CEC',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='UTILITY',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='SCL',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='+5V',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='HPD',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='D2S',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D2-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='D1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='D1S',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='D1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='D0+',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='D0S',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='D0-',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='SH',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IEC61076-2_M8_A-coding_01x03_Plug_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IEC61076-2_M8_A-coding_01x03_Plug_Shielded'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'M8', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nIEC61076-2_M8_A-coding_01x03_Plug_Shielded\n\nM8', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IEC61076-2_M8_A-coding_01x03_Receptacle_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IEC61076-2_M8_A-coding_01x03_Receptacle_Shielded'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'M8', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nIEC61076-2_M8_A-coding_01x03_Receptacle_Shielded\n\nM8', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IEC61076-2_M8_A-coding_01x04_Plug_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IEC61076-2_M8_A-coding_01x04_Plug_Shielded'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'M8 connector', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nIEC61076-2_M8_A-coding_01x04_Plug_Shielded\n\nM8 connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IEC61076-2_M8_A-coding_01x04_Receptacle_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IEC61076-2_M8_A-coding_01x04_Receptacle_Shielded'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'M8 connector', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nIEC61076-2_M8_A-coding_01x04_Receptacle_Shielded\n\nM8 connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IEC_60320_C13_Plug', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IEC_60320_C13_Plug'}), 'ref_prefix':'P', 'fplist':[''], 'footprint':'', 'keywords':'Receptacle C13 IEC320', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nIEC_60320_C13_Plug\n\nReceptacle C13 IEC320', 'pins':[
            Pin(num='1',name='N',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='L',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PE',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IEC_60320_C14_Receptacle', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IEC_60320_C14_Receptacle'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'Plug C14 IEC320', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nIEC_60320_C14_Receptacle\n\nPlug C14 IEC320', 'pins':[
            Pin(num='1',name='L',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='N',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PE',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IEC_60320_C5_Plug', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IEC_60320_C5_Plug'}), 'ref_prefix':'P', 'fplist':[''], 'footprint':'', 'keywords':'C5 IEC 60320', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nIEC_60320_C5_Plug\n\nC5 IEC 60320', 'pins':[
            Pin(num='1',name='N',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='L',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PE',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IEC_60320_C6_Receptacle', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IEC_60320_C6_Receptacle'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'IEC 60320 C6', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nIEC_60320_C6_Receptacle\n\nIEC 60320 C6', 'pins':[
            Pin(num='1',name='L',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='N',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PE',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IEC_60320_C7_Plug', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IEC_60320_C7_Plug'}), 'ref_prefix':'P', 'fplist':[''], 'footprint':'', 'keywords':'C7 Plug  IEC 60320', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nIEC_60320_C7_Plug\n\nC7 Plug  IEC 60320', 'pins':[
            Pin(num='1',name='N',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='L',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IEC_60320_C8_Receptacle', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IEC_60320_C8_Receptacle'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'C8 Receptacle  IEC 60320', 'description':'', 'datasheet':'~ ', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nIEC_60320_C8_Receptacle\n\nC8 Receptacle  IEC 60320', 'pins':[
            Pin(num='1',name='L',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='N',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IEEE1394a', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IEEE1394a'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector IEEE1394a FireWire', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nIEEE1394a\n\nconnector IEEE1394a FireWire', 'pins':[
            Pin(num='1',name='PWR',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TPB-',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TPB+',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TPA-',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TPA+',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SH',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='SH',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JAE_SIM_Card_SF72S006', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JAE_SIM_Card_SF72S006'}), 'ref_prefix':'J', 'fplist':['Connector_JAE:JAE_SIM_Card_SF72S006'], 'footprint':'Connector_JAE:JAE_SIM_Card_SF72S006', 'keywords':'SIM card UICC 4FF', 'description':'', 'datasheet':'https://www.jae.com/direct/topics/topics_file_download/topics_id=68892&ext_no=06&index=0&_lang=en&v=202003111511468456809', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nJAE_SIM_Card_SF72S006\n\nSIM card UICC 4FF', 'pins':[
            Pin(num='C1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='RST',func=pin_types.INPUT,unit=1),
            Pin(num='C3',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='C5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='VPP/SWP',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='I/O',func=pin_types.BIDIR,unit=1),
            Pin(num='CSW',name='CSW',func=pin_types.PASSIVE,unit=1),
            Pin(num='DSW',name='DSW',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='SH',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LEMO2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LEMO2'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'LEMO connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nLEMO2\n\nLEMO connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LEMO4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LEMO4'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'LEMO connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nLEMO4\n\nLEMO connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LEMO5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LEMO5'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'LEMO connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nLEMO5\n\nLEMO connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LEMO6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LEMO6'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'LEMO connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nLEMO6\n\nLEMO connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MXM3.0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MXM3.0'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'MXM connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nMXM3.0\n\nMXM connector', 'pins':[
            Pin(num='1',name='5V',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RSVD',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='101',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='102',name='PEX_TX6#',func=pin_types.INPUT,unit=1),
            Pin(num='103',name='PEX_RX6#',func=pin_types.OUTPUT,unit=1),
            Pin(num='104',name='PEX_TX6',func=pin_types.INPUT,unit=1),
            Pin(num='105',name='PEX_RX6',func=pin_types.OUTPUT,unit=1),
            Pin(num='106',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='107',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='PEX_TX5#',func=pin_types.INPUT,unit=1),
            Pin(num='109',name='PEX_RX5#',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='110',name='PEX_TX5',func=pin_types.INPUT,unit=1),
            Pin(num='111',name='PEX_RX5',func=pin_types.OUTPUT,unit=1),
            Pin(num='112',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='113',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='PEX_TX4#',func=pin_types.INPUT,unit=1),
            Pin(num='115',name='PEX_RX4#',func=pin_types.OUTPUT,unit=1),
            Pin(num='116',name='PEX_TX4',func=pin_types.INPUT,unit=1),
            Pin(num='117',name='PEX_RX4',func=pin_types.OUTPUT,unit=1),
            Pin(num='118',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='119',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='RSVD',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PEX_TX3#',func=pin_types.INPUT,unit=1),
            Pin(num='121',name='PEX_RX3#',func=pin_types.OUTPUT,unit=1),
            Pin(num='122',name='PEX_TX3',func=pin_types.INPUT,unit=1),
            Pin(num='123',name='PEX_RX3',func=pin_types.OUTPUT,unit=1),
            Pin(num='124',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='125',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='133',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='134',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='135',name='PEX_RX2#',func=pin_types.OUTPUT,unit=1),
            Pin(num='136',name='PEX_TX2#',func=pin_types.INPUT,unit=1),
            Pin(num='137',name='PEX_RX2',func=pin_types.OUTPUT,unit=1),
            Pin(num='138',name='PEX_TX2',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='RSVD',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='141',name='PEX_RX1#',func=pin_types.OUTPUT,unit=1),
            Pin(num='142',name='PEX_TX1#',func=pin_types.INPUT,unit=1),
            Pin(num='143',name='PEX_RX1',func=pin_types.OUTPUT,unit=1),
            Pin(num='144',name='PEX_TX1',func=pin_types.INPUT,unit=1),
            Pin(num='145',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='146',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='147',name='PEX_RX0#',func=pin_types.OUTPUT,unit=1),
            Pin(num='148',name='PEX_TX0#',func=pin_types.INPUT,unit=1),
            Pin(num='149',name='PEX_RX0',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='150',name='PEX_TX0',func=pin_types.INPUT,unit=1),
            Pin(num='151',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='152',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='153',name='PEX_REFCLK#',func=pin_types.INPUT,unit=1),
            Pin(num='154',name='PEX_CLK_REQ#',func=pin_types.OUTPUT,unit=1),
            Pin(num='155',name='PEX_REFCLK',func=pin_types.INPUT,unit=1),
            Pin(num='156',name='PEX_RST#',func=pin_types.INPUT,unit=1),
            Pin(num='157',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='158',name='VGA_DDC_DAT',func=pin_types.BIDIR,unit=1),
            Pin(num='159',name='RSVD',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RSVD',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='VGA_DDC_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='161',name='RSVD',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='VGA_VSYNC',func=pin_types.OUTPUT,unit=1),
            Pin(num='163',name='RSVD',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='VGA_HSYNC',func=pin_types.OUTPUT,unit=1),
            Pin(num='165',name='RSVD',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='167',name='RSVD',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='VGA_RED',func=pin_types.OUTPUT,unit=1),
            Pin(num='169',name='LVDS_UCLK#',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='170',name='VGA_GREEN',func=pin_types.OUTPUT,unit=1),
            Pin(num='171',name='LVDS_UCLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='172',name='VGA_BLUE',func=pin_types.OUTPUT,unit=1),
            Pin(num='173',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='174',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='175',name='LVDS_UTX3#',func=pin_types.OUTPUT,unit=1),
            Pin(num='176',name='LVDS_LCLK#',func=pin_types.OUTPUT,unit=1),
            Pin(num='177',name='LVDS_UTX3',func=pin_types.OUTPUT,unit=1),
            Pin(num='178',name='LVDS_LCLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='179',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='PWR_LEVEL',func=pin_types.INPUT,unit=1),
            Pin(num='180',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='181',name='LVDS_UTX2#',func=pin_types.OUTPUT,unit=1),
            Pin(num='182',name='LVDS_LTX3#',func=pin_types.OUTPUT,unit=1),
            Pin(num='183',name='LVDS_UTX2',func=pin_types.OUTPUT,unit=1),
            Pin(num='184',name='LVDS_LTX3',func=pin_types.OUTPUT,unit=1),
            Pin(num='185',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='186',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='187',name='LVDS_UTX1#',func=pin_types.OUTPUT,unit=1),
            Pin(num='188',name='LVDS_LTX2#',func=pin_types.OUTPUT,unit=1),
            Pin(num='189',name='LVDS_UTX1',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='PEX_STD_SW#',func=pin_types.INPUT,unit=1),
            Pin(num='190',name='LVDS_LTX2',func=pin_types.OUTPUT,unit=1),
            Pin(num='191',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='192',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='193',name='LVDS_UTX0#',func=pin_types.OUTPUT,unit=1),
            Pin(num='194',name='LVDS_LTX1#',func=pin_types.OUTPUT,unit=1),
            Pin(num='195',name='LVDS_UTX0',func=pin_types.OUTPUT,unit=1),
            Pin(num='196',name='LVDS_LTX1',func=pin_types.OUTPUT,unit=1),
            Pin(num='197',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='198',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='199',name='DP_C_L0#',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='PRSNT_R#',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='TH_OVERT#',func=pin_types.OUTPUT,unit=1),
            Pin(num='200',name='LVDS_LTX0#',func=pin_types.OUTPUT,unit=1),
            Pin(num='201',name='DP_C_L0',func=pin_types.OUTPUT,unit=1),
            Pin(num='202',name='LVDS_LTX0',func=pin_types.OUTPUT,unit=1),
            Pin(num='203',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='204',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='205',name='DP_C_L1#',func=pin_types.OUTPUT,unit=1),
            Pin(num='206',name='DP_D_L0#',func=pin_types.OUTPUT,unit=1),
            Pin(num='207',name='DP_C_L1',func=pin_types.OUTPUT,unit=1),
            Pin(num='208',name='DP_D_L0',func=pin_types.OUTPUT,unit=1),
            Pin(num='209',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='VGA_DISABLE#',func=pin_types.INPUT,unit=1),
            Pin(num='210',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='211',name='DP_C_L2#',func=pin_types.OUTPUT,unit=1),
            Pin(num='212',name='DP_D_L1#',func=pin_types.OUTPUT,unit=1),
            Pin(num='213',name='DP_C_L2',func=pin_types.OUTPUT,unit=1),
            Pin(num='214',name='DP_D_L1',func=pin_types.OUTPUT,unit=1),
            Pin(num='215',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='216',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='217',name='DP_C_L3#',func=pin_types.OUTPUT,unit=1),
            Pin(num='218',name='DP_D_L2#',func=pin_types.OUTPUT,unit=1),
            Pin(num='219',name='DP_C_L3',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='TH_ALERT#',func=pin_types.BIDIR,unit=1),
            Pin(num='220',name='DP_D_L2',func=pin_types.OUTPUT,unit=1),
            Pin(num='221',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='222',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='223',name='DP_C_AUX#',func=pin_types.BIDIR,unit=1),
            Pin(num='224',name='DP_D_L3#',func=pin_types.OUTPUT,unit=1),
            Pin(num='225',name='DP_C_AUX',func=pin_types.BIDIR,unit=1),
            Pin(num='226',name='DP_D_L3',func=pin_types.OUTPUT,unit=1),
            Pin(num='227',name='RSVD',func=pin_types.BIDIR,unit=1),
            Pin(num='228',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='229',name='RSVD',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PNL_PWR_EN',func=pin_types.OUTPUT,unit=1),
            Pin(num='230',name='DP_D_AUX#',func=pin_types.BIDIR,unit=1),
            Pin(num='231',name='RSVD',func=pin_types.BIDIR,unit=1),
            Pin(num='232',name='DP_D_AUX',func=pin_types.BIDIR,unit=1),
            Pin(num='233',name='RSVD',func=pin_types.BIDIR,unit=1),
            Pin(num='234',name='DP_C_HPD',func=pin_types.INPUT,unit=1),
            Pin(num='235',name='RSVD',func=pin_types.BIDIR,unit=1),
            Pin(num='236',name='DP_D_HPD',func=pin_types.INPUT,unit=1),
            Pin(num='237',name='RSVD',func=pin_types.BIDIR,unit=1),
            Pin(num='238',name='RSVD',func=pin_types.BIDIR,unit=1),
            Pin(num='239',name='RSVD',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TH_PWM',func=pin_types.OUTPUT,unit=1),
            Pin(num='240',name='RSVD',func=pin_types.BIDIR,unit=1),
            Pin(num='241',name='RSVD',func=pin_types.BIDIR,unit=1),
            Pin(num='242',name='RSVD',func=pin_types.BIDIR,unit=1),
            Pin(num='243',name='RSVD',func=pin_types.BIDIR,unit=1),
            Pin(num='244',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='245',name='RSVD',func=pin_types.BIDIR,unit=1),
            Pin(num='246',name='DP_B_L0#',func=pin_types.OUTPUT,unit=1),
            Pin(num='247',name='RSVD',func=pin_types.BIDIR,unit=1),
            Pin(num='248',name='DP_B_L0',func=pin_types.OUTPUT,unit=1),
            Pin(num='249',name='RSVD',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PNL_BL_EN',func=pin_types.OUTPUT,unit=1),
            Pin(num='250',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='251',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='252',name='DP_B_L1#',func=pin_types.OUTPUT,unit=1),
            Pin(num='253',name='DP_A_L0#',func=pin_types.OUTPUT,unit=1),
            Pin(num='254',name='DP_B_L1',func=pin_types.OUTPUT,unit=1),
            Pin(num='255',name='DP_A_L0',func=pin_types.OUTPUT,unit=1),
            Pin(num='256',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='257',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='258',name='DP_B_L2#',func=pin_types.OUTPUT,unit=1),
            Pin(num='259',name='DP_A_L1#',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='GPIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='260',name='DP_B_L2',func=pin_types.OUTPUT,unit=1),
            Pin(num='261',name='DP_A_L1',func=pin_types.OUTPUT,unit=1),
            Pin(num='262',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='263',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='264',name='DP_B_L3#',func=pin_types.OUTPUT,unit=1),
            Pin(num='265',name='DP_A_L2#',func=pin_types.OUTPUT,unit=1),
            Pin(num='266',name='DP_B_L3',func=pin_types.OUTPUT,unit=1),
            Pin(num='267',name='DP_A_L2',func=pin_types.OUTPUT,unit=1),
            Pin(num='268',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='269',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='PNL_BL_PWM',func=pin_types.OUTPUT,unit=1),
            Pin(num='270',name='DP_B_AUX#',func=pin_types.BIDIR,unit=1),
            Pin(num='271',name='DP_A_L3#',func=pin_types.OUTPUT,unit=1),
            Pin(num='272',name='DP_B_AUX',func=pin_types.BIDIR,unit=1),
            Pin(num='273',name='DP_A_L3',func=pin_types.OUTPUT,unit=1),
            Pin(num='274',name='DP_B_HPD',func=pin_types.INPUT,unit=1),
            Pin(num='275',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='276',name='DP_A_HPD',func=pin_types.INPUT,unit=1),
            Pin(num='277',name='DP_A_AUX#',func=pin_types.BIDIR,unit=1),
            Pin(num='278',name='3V3',func=pin_types.PWRIN,unit=1),
            Pin(num='279',name='DP_A_AUX',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='280',name='3V3',func=pin_types.PASSIVE,unit=1),
            Pin(num='281',name='PRSNT_L#',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='HDMI_CEC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='5V',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='GPIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='DVI_HPD',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='SMB_DAT',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='LVDS_DDC_DAT',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='SMB_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='LVDS_DDC_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='OEM',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='OEM',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='WAKE#',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='OEM',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='OEM',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='OEM',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='OEM',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='OEM',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='OEM',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='PEX_TX15#',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='PEX_RX15#',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='5V',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='PEX_TX15',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='PEX_RX15',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PEX_TX14#',func=pin_types.INPUT,unit=1),
            Pin(num='55',name='PEX_RX14#',func=pin_types.OUTPUT,unit=1),
            Pin(num='56',name='PEX_TX14',func=pin_types.INPUT,unit=1),
            Pin(num='57',name='PEX_RX14',func=pin_types.OUTPUT,unit=1),
            Pin(num='58',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='PWR_GOOD',func=pin_types.OUTPUT,unit=1),
            Pin(num='60',name='PEX_TX13#',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PEX_RX13#',func=pin_types.OUTPUT,unit=1),
            Pin(num='62',name='PEX_TX13',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='PEX_RX13',func=pin_types.OUTPUT,unit=1),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='PEX_TX12#',func=pin_types.INPUT,unit=1),
            Pin(num='67',name='PEX_RX12#',func=pin_types.OUTPUT,unit=1),
            Pin(num='68',name='PEX_TX12',func=pin_types.INPUT,unit=1),
            Pin(num='69',name='PEX_RX12',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='5V',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='PEX_TX11#',func=pin_types.INPUT,unit=1),
            Pin(num='73',name='PEX_RX11#',func=pin_types.OUTPUT,unit=1),
            Pin(num='74',name='PEX_TX11',func=pin_types.INPUT,unit=1),
            Pin(num='75',name='PEX_RX11',func=pin_types.OUTPUT,unit=1),
            Pin(num='76',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='78',name='PEX_TX10#',func=pin_types.INPUT,unit=1),
            Pin(num='79',name='PEX_RX10#',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='PWR_EN',func=pin_types.INPUT,unit=1),
            Pin(num='80',name='PEX_TX10',func=pin_types.INPUT,unit=1),
            Pin(num='81',name='PEX_RX10',func=pin_types.OUTPUT,unit=1),
            Pin(num='82',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='PEX_TX9#',func=pin_types.INPUT,unit=1),
            Pin(num='85',name='PEX_RX9#',func=pin_types.OUTPUT,unit=1),
            Pin(num='86',name='PEX_TX9',func=pin_types.INPUT,unit=1),
            Pin(num='87',name='PEX_RX9',func=pin_types.OUTPUT,unit=1),
            Pin(num='88',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='89',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='5V',func=pin_types.PASSIVE,unit=1),
            Pin(num='90',name='PEX_TX8#',func=pin_types.INPUT,unit=1),
            Pin(num='91',name='PEX_RX8#',func=pin_types.OUTPUT,unit=1),
            Pin(num='92',name='PEX_TX8',func=pin_types.INPUT,unit=1),
            Pin(num='93',name='PEX_RX8',func=pin_types.OUTPUT,unit=1),
            Pin(num='94',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='96',name='PEX_TX7#',func=pin_types.INPUT,unit=1),
            Pin(num='97',name='PEX_RX7#',func=pin_types.OUTPUT,unit=1),
            Pin(num='98',name='PEX_TX7',func=pin_types.INPUT,unit=1),
            Pin(num='99',name='PEX_RX7',func=pin_types.OUTPUT,unit=1),
            Pin(num='E1',name='PWR_SRC',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='PWR_SRC',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Micro_SD_Card', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Micro_SD_Card'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector SD microsd', 'description':'', 'datasheet':'https://www.we-online.com/components/products/datasheet/693072010801.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nMicro_SD_Card\n\nconnector SD microsd', 'pins':[
            Pin(num='1',name='DAT2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='DAT3/CD',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CMD',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='DAT0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DAT1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SHIELD',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Micro_SD_Card_Det1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Micro_SD_Card_Det1'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector SD microsd', 'description':'', 'datasheet':'https://datasheet.lcsc.com/lcsc/2110151630_XKB-Connectivity-XKTF-015-N_C381082.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nMicro_SD_Card_Det1\n\nconnector SD microsd', 'pins':[
            Pin(num='1',name='DAT2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SHIELD',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='DAT3/CD',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CMD',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='DAT0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DAT1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='DET',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Micro_SD_Card_Det2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Micro_SD_Card_Det2'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector SD microsd', 'description':'', 'datasheet':'https://www.hirose.com/en/product/document?clcode=&productname=&series=DM3&documenttype=Catalog&lang=en&documentid=D49662_en', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nMicro_SD_Card_Det2\n\nconnector SD microsd', 'pins':[
            Pin(num='1',name='DAT2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='DET_A',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='SHIELD',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='DAT3/CD',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CMD',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='DAT0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DAT1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='DET_B',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Microsemi_FlashPro-JTAG-10', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Microsemi_FlashPro-JTAG-10'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'JTAG IDC10 Pinheader Pins Connector', 'description':'', 'datasheet':'https://www.microsemi.com/document-portal/doc_view/129973-lpf-ac386-an', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nMicrosemi_FlashPro-JTAG-10\n\nJTAG IDC10 Pinheader Pins Connector', 'pins':[
            Pin(num='1',name='TCK',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='TDO',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PGM/NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='TMS',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VJTAG',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VPUMP',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='~{TRST}',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='TDI',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Mini-DIN-3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Mini-DIN-3'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'Mini-DIN', 'description':'', 'datasheet':'http://www.assmann-wsw.com/fileadmin/catalogue/10_MiniDIN_rev4-0.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nMini-DIN-3\n\nMini-DIN', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Mini-DIN-4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Mini-DIN-4'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'Mini-DIN', 'description':'', 'datasheet':'http://service.powerdynamics.com/ec/Catalog17/Section%2011.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nMini-DIN-4\n\nMini-DIN', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Mini-DIN-5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Mini-DIN-5'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'Mini-DIN', 'description':'', 'datasheet':'http://service.powerdynamics.com/ec/Catalog17/Section%2011.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nMini-DIN-5\n\nMini-DIN', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Mini-DIN-6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Mini-DIN-6'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'Mini-DIN', 'description':'', 'datasheet':'http://service.powerdynamics.com/ec/Catalog17/Section%2011.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nMini-DIN-6\n\nMini-DIN', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Mini-DIN-7', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Mini-DIN-7'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'Mini-DIN', 'description':'', 'datasheet':'http://service.powerdynamics.com/ec/Catalog17/Section%2011.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nMini-DIN-7\n\nMini-DIN', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Mini-DIN-8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Mini-DIN-8'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'Mini-DIN', 'description':'', 'datasheet':'http://service.powerdynamics.com/ec/Catalog17/Section%2011.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nMini-DIN-8\n\nMini-DIN', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ45_Abracon_ARJP11A-MASA-B-A-EMU2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ45_Abracon_ARJP11A-MASA-B-A-EMU2'}), 'ref_prefix':'J', 'fplist':['Connector_RJ:RJ45_Abracon_ARJP11A-MA_Horizontal'], 'footprint':'Connector_RJ:RJ45_Abracon_ARJP11A-MA_Horizontal', 'keywords':'single port ethernet transformer socket poe center-tap', 'description':'', 'datasheet':'https://abracon.com/Magnetics/lan/ARJP11A.PDF', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ45_Abracon_ARJP11A-MASA-B-A-EMU2\n\nsingle port ethernet transformer socket poe center-tap', 'pins':[
            Pin(num='1',name='TD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='V-',func=pin_types.PWROUT,unit=1),
            Pin(num='11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='TCT',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='RCT',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='RD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='V+',func=pin_types.PWROUT,unit=1),
            Pin(num='SH',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ45_Amphenol_RJMG1BD3B8K1ANR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ45_Amphenol_RJMG1BD3B8K1ANR'}), 'ref_prefix':'J', 'fplist':['Connector_RJ:RJ45_Amphenol_RJMG1BD3B8K1ANR'], 'footprint':'Connector_RJ:RJ45_Amphenol_RJMG1BD3B8K1ANR', 'keywords':'RJ45 Magjack Socket', 'description':'', 'datasheet':'https://www.amphenol-cs.com/media/wysiwyg/files/drawing/rjmg1bd3b8k1anr.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ45_Amphenol_RJMG1BD3B8K1ANR\n\nRJ45 Magjack Socket', 'pins':[
            Pin(num='L1',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',func=pin_types.PASSIVE,unit=1),
            Pin(num='L4',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='TD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='TD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='R3',name='RD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='R4',name='TCT',func=pin_types.PASSIVE,unit=1),
            Pin(num='R5',name='RCT',func=pin_types.PASSIVE,unit=1),
            Pin(num='R6',name='RD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='R7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='R8',func=pin_types.PWRIN,unit=1),
            Pin(num='SH',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ45_Bel_SI-60062-F', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ45_Bel_SI-60062-F'}), 'ref_prefix':'J', 'fplist':['Connector_RJ:RJ45_Bel_SI-60062-F'], 'footprint':'Connector_RJ:RJ45_Bel_SI-60062-F', 'keywords':'RJ45 Magjack Socket', 'description':'', 'datasheet':'https://belfuse.com/resources/drawings/magneticsolutions/dr-mag-si-60062-f.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ45_Bel_SI-60062-F\n\nRJ45 Magjack Socket', 'pins':[
            Pin(num='1',name='TD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TCT',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='TD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='RCT',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='RD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',func=pin_types.PASSIVE,unit=1),
            Pin(num='L4',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ45_Bel_V895-1001-AW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ45_Bel_V895-1001-AW'}), 'ref_prefix':'J', 'fplist':['Connector_RJ:RJ45_Bel_V895-1001-AW_Vertical'], 'footprint':'Connector_RJ:RJ45_Bel_V895-1001-AW_Vertical', 'keywords':'single port ethernet transformer socket poe center-tap', 'description':'', 'datasheet':'https://www.belfuse.com/resources/drawings/magneticsolutions/dr-mag-v895-1001-aw.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ45_Bel_V895-1001-AW\n\nsingle port ethernet transformer socket poe center-tap', 'pins':[
            Pin(num='1',name='TD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Vc4',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='CT',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Vc1',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Vc2',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Vc3',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ45_Halo_HFJ11-x2450E-LxxRL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ45_Halo_HFJ11-x2450E-LxxRL'}), 'ref_prefix':'J', 'fplist':['Connector_RJ:RJ45_HALO_HFJ11-x2450E-LxxRL_Horizontal'], 'footprint':'Connector_RJ:RJ45_HALO_HFJ11-x2450E-LxxRL_Horizontal', 'keywords':'FastJack socket', 'description':'', 'datasheet':'https://www.haloelectronics.com/pdf/fastjack-100baset.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ45_Halo_HFJ11-x2450E-LxxRL\n\nFastJack socket', 'pins':[
            Pin(num='1',name='TD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='TCT',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='RCT',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='RD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',func=pin_types.PWRIN,unit=1),
            Pin(num='9',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ45_Halo_HFJ11-x2450ERL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ45_Halo_HFJ11-x2450ERL'}), 'ref_prefix':'J', 'fplist':['Connector_RJ:RJ45_HALO_HFJ11-x2450ERL_Horizontal'], 'footprint':'Connector_RJ:RJ45_HALO_HFJ11-x2450ERL_Horizontal', 'keywords':'FastJack socket', 'description':'', 'datasheet':'https://www.haloelectronics.com/pdf/fastjack-100baset.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ45_Halo_HFJ11-x2450ERL\n\nFastJack socket', 'pins':[
            Pin(num='1',name='TD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='TCT',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='RCT',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='RD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',func=pin_types.PWRIN,unit=1),
            Pin(num='SH',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ45_Halo_HFJ11-x2450HRL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ45_Halo_HFJ11-x2450HRL'}), 'ref_prefix':'J', 'fplist':['Connector_RJ:RJ45_HALO_HFJ11-x2450HRL_Horizontal'], 'footprint':'Connector_RJ:RJ45_HALO_HFJ11-x2450HRL_Horizontal', 'keywords':'FastJack socket', 'description':'', 'datasheet':'https://www.haloelectronics.com/pdf/fastjack-100baset.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ45_Halo_HFJ11-x2450HRL\n\nFastJack socket', 'pins':[
            Pin(num='1',name='TD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='TCT',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='RCT',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='RD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',func=pin_types.PWRIN,unit=1),
            Pin(num='SH',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ45_Hanrun_HR911105A_Horizontal', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ45_Hanrun_HR911105A_Horizontal'}), 'ref_prefix':'J', 'fplist':['Connector_RJ:RJ45_Hanrun_HR911105A_Horizontal'], 'footprint':'Connector_RJ:RJ45_Hanrun_HR911105A_Horizontal', 'keywords':'RJ45 Magjack Socket', 'description':'', 'datasheet':'https://datasheet.lcsc.com/lcsc/1811141815_HANRUN-Zhongshan-HanRun-Elec-HR911105A_C12074.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ45_Hanrun_HR911105A_Horizontal\n\nRJ45 Magjack Socket', 'pins':[
            Pin(num='1',name='TD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='TCT',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='RCT',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='RD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',func=pin_types.PWRIN,unit=1),
            Pin(num='9',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ45_JK00177', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ45_JK00177'}), 'ref_prefix':'J', 'fplist':['Connector_RJ:RJ45_Pulse_JK00177NL_Horizontal'], 'footprint':'Connector_RJ:RJ45_Pulse_JK00177NL_Horizontal', 'keywords':'8P8C RJ socket jack connector POE', 'description':'', 'datasheet':'https://productfinder.pulseeng.com/doc_type/WEB301/doc_num/J432/doc_part/J432.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ45_JK00177\n\n8P8C RJ socket jack connector POE', 'pins':[
            Pin(num='1',name='MXCT3',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='MX1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='MX1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='MXCT1',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='LED2+',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='LED2-',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='LED1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='LED1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='VDC1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='VDC1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VDC2+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='MX3-',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='VDC2-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='MX3+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='MX2+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='MX2-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='MXCT2',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='MXCT4',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='MX4+',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='MX4-',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ45_JK0654219', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ45_JK0654219'}), 'ref_prefix':'J', 'fplist':['Connector_RJ:RJ45_Pulse_JK0654219NL_Horizontal'], 'footprint':'Connector_RJ:RJ45_Pulse_JK0654219NL_Horizontal', 'keywords':'8P8C RJ socket jack connector', 'description':'', 'datasheet':'https://media.digikey.com/pdf/Data%20Sheets/Pulse%20PDFs/JK%20Series.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ45_JK0654219\n\n8P8C RJ socket jack connector', 'pins':[
            Pin(num='1',name='MXCT3',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='MX1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='MX1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='MXCT1',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='LED2-',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='LED2+',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='LED1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='LED1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='MX3-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='MX3+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='MX2+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='MX2-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='MXCT2',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='MXCT4',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='MX4+',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='MX4-',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ45_Kycon_G7LX-A88S7-BP-GY', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ45_Kycon_G7LX-A88S7-BP-GY'}), 'ref_prefix':'J', 'fplist':['Connector_RJ:RJ45_Kycon_G7LX-A88S7-BP-xx_Horizontal'], 'footprint':'Connector_RJ:RJ45_Kycon_G7LX-A88S7-BP-xx_Horizontal', 'keywords':'RJ45 Magjack', 'description':'', 'datasheet':'http://www.kycon.com/Pub_Eng_Draw/G7LX-A88S7-BP-GY.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ45_Kycon_G7LX-A88S7-BP-GY\n\nRJ45 Magjack', 'pins':[
            Pin(num='1',name='TD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='LEDY_K',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='LEDY_A',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='LEDG_K',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='LEDG_A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='TCT',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='RD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='RCT',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='R4',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='SHIELD',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ45_Pulse_JXD6-0001NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ45_Pulse_JXD6-0001NL'}), 'ref_prefix':'J', 'fplist':['Connector_RJ:RJ45_Pulse_JXD6-0001NL_Horizontal'], 'footprint':'Connector_RJ:RJ45_Pulse_JXD6-0001NL_Horizontal', 'keywords':'lan jack socket transformer', 'description':'', 'datasheet':'https://productfinder.pulseeng.com/doc_type/WEB301/doc_num/JXD6-0001NL/doc_part/JXD6-0001NL.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ45_Pulse_JXD6-0001NL\n\nlan jack socket transformer', 'pins':[
            Pin(num='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='TCT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='TD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='TD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='RD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='RD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='RCT',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ45_RB1-125B8G1A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ45_RB1-125B8G1A'}), 'ref_prefix':'J', 'fplist':['Connector_RJ:RJ45_UDE_RB1-125B8G1A'], 'footprint':'Connector_RJ:RJ45_UDE_RB1-125B8G1A', 'keywords':'lan jack socket transformer ethernet gigabit 10 100 1000 baset', 'description':'', 'datasheet':'https://datasheet.lcsc.com/szlcsc/1901091107_UDE-Corp-RB1-125B8G1A_C363353.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ45_RB1-125B8G1A\n\nlan jack socket transformer ethernet gigabit 10 100 1000 baset', 'pins':[
            Pin(num='R10',name='GND',func=pin_types.PWRIN),
            Pin(num='L1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='L4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='CT',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='TD1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='R3',name='TD1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='R4',name='TD2+',func=pin_types.PASSIVE,unit=1),
            Pin(num='R5',name='TD2-',func=pin_types.PASSIVE,unit=1),
            Pin(num='R6',name='TD3+',func=pin_types.PASSIVE,unit=1),
            Pin(num='R7',name='TD3-',func=pin_types.PASSIVE,unit=1),
            Pin(num='R8',name='TD4+',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='TD4-',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='SH',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ45_Wuerth_74980111211', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ45_Wuerth_74980111211'}), 'ref_prefix':'J', 'fplist':['Connector_RJ:RJ45_Wuerth_74980111211_Horizontal'], 'footprint':'Connector_RJ:RJ45_Wuerth_74980111211_Horizontal', 'keywords':'lan jack socket transformer smt', 'description':'', 'datasheet':'https://www.we-online.de/katalog/datasheet/74980111211.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ45_Wuerth_74980111211\n\nlan jack socket transformer smt', 'pins':[
            Pin(num='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',func=pin_types.PWRIN,unit=1),
            Pin(num='11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='TD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='TCT',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='TD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='RD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='RCT',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='RD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='SH',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ45_Wuerth_7499010121A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ45_Wuerth_7499010121A'}), 'ref_prefix':'J', 'fplist':['Connector_RJ:RJ45_Wuerth_7499010121A_Horizontal'], 'footprint':'Connector_RJ:RJ45_Wuerth_7499010121A_Horizontal', 'keywords':'lan jack socket transformer', 'description':'', 'datasheet':'http://katalog.we-online.de/pbs/datasheet/7499010121A.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ45_Wuerth_7499010121A\n\nlan jack socket transformer', 'pins':[
            Pin(num='1',name='TD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TCT',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='TD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='RCT',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='RD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',func=pin_types.PWRIN,unit=1),
            Pin(num='9',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ45_Wuerth_7499151120', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ45_Wuerth_7499151120'}), 'ref_prefix':'J', 'fplist':['Connector_RJ:RJ45_Wuerth_7499151120_Horizontal'], 'footprint':'Connector_RJ:RJ45_Wuerth_7499151120_Horizontal', 'keywords':'dual lan jack socket transformer', 'description':'', 'datasheet':'http://katalog.we-online.de/pbs/datasheet/7499151120.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ45_Wuerth_7499151120\n\ndual lan jack socket transformer', 'pins':[
            Pin(num='SH',name='~',func=pin_types.PWRIN),
            Pin(num='10U',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11U',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12U',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='13U',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14U',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='1U',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2U',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3U',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4U',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5U',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6U',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7U',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8U',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9U',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10D',name='~',func=pin_types.NOCONNECT,unit=2),
            Pin(num='11D',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='12D',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='13D',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='14D',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='1D',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='2D',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='3D',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='4D',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='5D',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='6D',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='7D',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='8D',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='9D',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['11U', '5U', '10U', 'SH', '13U', '1U', '3U', '7U', '12U', '4U', '6U', '8U', '9U', '2U', '14U']},{'label': 'uB', 'num': 2, 'pin_nums': ['1D', '8D', '3D', '5D', '13D', '9D', 'SH', '11D', '7D', '14D', '2D', '4D', '12D', '6D', '10D']}] }),
        Part(**{ 'name':'Raspberry_Pi_2_3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Raspberry_Pi_2_3'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'raspberrypi gpio', 'description':'', 'datasheet':'https://www.raspberrypi.org/documentation/hardware/raspberrypi/schematics/rpi_SCH_3bplus_1p0_reduced.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRaspberry_Pi_2_3\n\nraspberrypi gpio', 'pins':[
            Pin(num='1',name='3V3',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GPIO15/RXD',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='GPIO17',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GPIO18/PWM0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GPIO27',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GPIO22',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GPIO23',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='3V3',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GPIO24',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='MOSI0/GPIO10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='5V',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='MISO0/GPIO9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='GPIO25',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='SCLK0/GPIO11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='~{CE0}/GPIO8',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='~{CE1}/GPIO7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='ID_SD/GPIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='ID_SC/GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='GCLK1/GPIO5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='SDA/GPIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='GCLK2/GPIO6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PWM0/GPIO12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PWM1/GPIO13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='GPIO19/MISO1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='GPIO16',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='GPIO26',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GPIO20/MOSI1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='5V',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='GPIO21/SCLK1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SCL/GPIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GCLK0/GPIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GPIO14/TXD',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SCART-F', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SCART-F'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nSCART-F\n\nconnector', 'pins':[
            Pin(num='1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='P10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='P11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='P12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='P13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='P14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='P15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='P16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='P17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='P18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='P19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='P20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='P21',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='P6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='P7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='P8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='P9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SD_Card_Device', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SD_Card_Device'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector SD', 'description':'', 'datasheet':'http://www.convict.lu/pdf/ProdManualSDCardv1.9.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nSD_Card_Device\n\nconnector SD', 'pins':[
            Pin(num='1',name='CD/DAT3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='CMD',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='DAT0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DAT1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='DAT2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SD_Card_Receptacle', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SD_Card_Receptacle'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector SD', 'description':'', 'datasheet':'http://portal.fciconnect.com/Comergent//fci/drawing/10067847.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nSD_Card_Receptacle\n\nconnector SD', 'pins':[
            Pin(num='1',name='CD/DAT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='CARD_DETECT',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='WRITE_PROTECT',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='SHELL1',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='SHELL2',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='CMD',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='DAT0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DAT1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='DAT2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SIM_Card', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SIM_Card'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'SIM card UICC', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nSIM_Card\n\nSIM card UICC', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RST',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VPP',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I/O',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SIM_Card_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SIM_Card_Shielded'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'SIM card UICC', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nSIM_Card_Shielded\n\nSIM card UICC', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RST',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VPP',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I/O',func=pin_types.BIDIR,unit=1),
            Pin(num='SH',name='SH',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SODIMM-200', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SODIMM-200'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'SODIMM SO-DIMM DDR1 DDR2', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nSODIMM-200\n\nSODIMM SO-DIMM DDR1 DDR2', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='40',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='9',func=pin_types.PASSIVE,unit=1),
            Pin(num='100',name='100',func=pin_types.PASSIVE,unit=2),
            Pin(num='101',name='101',func=pin_types.PASSIVE,unit=2),
            Pin(num='102',name='102',func=pin_types.PASSIVE,unit=2),
            Pin(num='103',name='103',func=pin_types.PASSIVE,unit=2),
            Pin(num='104',name='104',func=pin_types.PASSIVE,unit=2),
            Pin(num='105',name='105',func=pin_types.PASSIVE,unit=2),
            Pin(num='106',name='106',func=pin_types.PASSIVE,unit=2),
            Pin(num='107',name='107',func=pin_types.PASSIVE,unit=2),
            Pin(num='108',name='108',func=pin_types.PASSIVE,unit=2),
            Pin(num='109',name='109',func=pin_types.PASSIVE,unit=2),
            Pin(num='110',name='110',func=pin_types.PASSIVE,unit=2),
            Pin(num='111',name='111',func=pin_types.PASSIVE,unit=2),
            Pin(num='112',name='112',func=pin_types.PASSIVE,unit=2),
            Pin(num='113',name='113',func=pin_types.PASSIVE,unit=2),
            Pin(num='114',name='114',func=pin_types.PASSIVE,unit=2),
            Pin(num='115',name='115',func=pin_types.PASSIVE,unit=2),
            Pin(num='116',name='116',func=pin_types.PASSIVE,unit=2),
            Pin(num='117',name='117',func=pin_types.PASSIVE,unit=2),
            Pin(num='118',name='118',func=pin_types.PASSIVE,unit=2),
            Pin(num='119',name='119',func=pin_types.PASSIVE,unit=2),
            Pin(num='120',name='120',func=pin_types.PASSIVE,unit=2),
            Pin(num='121',name='121',func=pin_types.PASSIVE,unit=2),
            Pin(num='122',name='122',func=pin_types.PASSIVE,unit=2),
            Pin(num='123',name='123',func=pin_types.PASSIVE,unit=2),
            Pin(num='124',name='124',func=pin_types.PASSIVE,unit=2),
            Pin(num='125',name='125',func=pin_types.PASSIVE,unit=2),
            Pin(num='126',name='126',func=pin_types.PASSIVE,unit=2),
            Pin(num='127',name='127',func=pin_types.PASSIVE,unit=2),
            Pin(num='128',name='128',func=pin_types.PASSIVE,unit=2),
            Pin(num='129',name='129',func=pin_types.PASSIVE,unit=2),
            Pin(num='130',name='130',func=pin_types.PASSIVE,unit=2),
            Pin(num='131',name='131',func=pin_types.PASSIVE,unit=2),
            Pin(num='132',name='132',func=pin_types.PASSIVE,unit=2),
            Pin(num='133',name='133',func=pin_types.PASSIVE,unit=2),
            Pin(num='134',name='134',func=pin_types.PASSIVE,unit=2),
            Pin(num='135',name='135',func=pin_types.PASSIVE,unit=2),
            Pin(num='136',name='136',func=pin_types.PASSIVE,unit=2),
            Pin(num='137',name='137',func=pin_types.PASSIVE,unit=2),
            Pin(num='138',name='138',func=pin_types.PASSIVE,unit=2),
            Pin(num='139',name='139',func=pin_types.PASSIVE,unit=2),
            Pin(num='140',name='140',func=pin_types.PASSIVE,unit=2),
            Pin(num='141',name='141',func=pin_types.PASSIVE,unit=2),
            Pin(num='142',name='142',func=pin_types.PASSIVE,unit=2),
            Pin(num='143',name='143',func=pin_types.PASSIVE,unit=2),
            Pin(num='144',name='144',func=pin_types.PASSIVE,unit=2),
            Pin(num='145',name='145',func=pin_types.PASSIVE,unit=2),
            Pin(num='146',name='146',func=pin_types.PASSIVE,unit=2),
            Pin(num='147',name='147',func=pin_types.PASSIVE,unit=2),
            Pin(num='148',name='148',func=pin_types.PASSIVE,unit=2),
            Pin(num='149',name='149',func=pin_types.PASSIVE,unit=2),
            Pin(num='150',name='150',func=pin_types.PASSIVE,unit=2),
            Pin(num='151',name='151',func=pin_types.PASSIVE,unit=2),
            Pin(num='152',name='152',func=pin_types.PASSIVE,unit=2),
            Pin(num='153',name='153',func=pin_types.PASSIVE,unit=2),
            Pin(num='154',name='154',func=pin_types.PASSIVE,unit=2),
            Pin(num='155',name='155',func=pin_types.PASSIVE,unit=2),
            Pin(num='156',name='156',func=pin_types.PASSIVE,unit=2),
            Pin(num='157',name='157',func=pin_types.PASSIVE,unit=2),
            Pin(num='158',name='158',func=pin_types.PASSIVE,unit=2),
            Pin(num='159',name='159',func=pin_types.PASSIVE,unit=2),
            Pin(num='160',name='160',func=pin_types.PASSIVE,unit=2),
            Pin(num='161',name='161',func=pin_types.PASSIVE,unit=2),
            Pin(num='162',name='162',func=pin_types.PASSIVE,unit=2),
            Pin(num='163',name='163',func=pin_types.PASSIVE,unit=2),
            Pin(num='164',name='164',func=pin_types.PASSIVE,unit=2),
            Pin(num='165',name='165',func=pin_types.PASSIVE,unit=2),
            Pin(num='166',name='166',func=pin_types.PASSIVE,unit=2),
            Pin(num='167',name='167',func=pin_types.PASSIVE,unit=2),
            Pin(num='168',name='168',func=pin_types.PASSIVE,unit=2),
            Pin(num='169',name='169',func=pin_types.PASSIVE,unit=2),
            Pin(num='170',name='170',func=pin_types.PASSIVE,unit=2),
            Pin(num='171',name='171',func=pin_types.PASSIVE,unit=2),
            Pin(num='172',name='172',func=pin_types.PASSIVE,unit=2),
            Pin(num='173',name='173',func=pin_types.PASSIVE,unit=2),
            Pin(num='174',name='174',func=pin_types.PASSIVE,unit=2),
            Pin(num='175',name='175',func=pin_types.PASSIVE,unit=2),
            Pin(num='176',name='176',func=pin_types.PASSIVE,unit=2),
            Pin(num='177',name='177',func=pin_types.PASSIVE,unit=2),
            Pin(num='178',name='178',func=pin_types.PASSIVE,unit=2),
            Pin(num='179',name='179',func=pin_types.PASSIVE,unit=2),
            Pin(num='180',name='180',func=pin_types.PASSIVE,unit=2),
            Pin(num='181',name='181',func=pin_types.PASSIVE,unit=2),
            Pin(num='182',name='182',func=pin_types.PASSIVE,unit=2),
            Pin(num='183',name='183',func=pin_types.PASSIVE,unit=2),
            Pin(num='184',name='184',func=pin_types.PASSIVE,unit=2),
            Pin(num='185',name='185',func=pin_types.PASSIVE,unit=2),
            Pin(num='186',name='186',func=pin_types.PASSIVE,unit=2),
            Pin(num='187',name='187',func=pin_types.PASSIVE,unit=2),
            Pin(num='188',name='188',func=pin_types.PASSIVE,unit=2),
            Pin(num='189',name='189',func=pin_types.PASSIVE,unit=2),
            Pin(num='190',name='190',func=pin_types.PASSIVE,unit=2),
            Pin(num='191',name='191',func=pin_types.PASSIVE,unit=2),
            Pin(num='192',name='192',func=pin_types.PASSIVE,unit=2),
            Pin(num='193',name='193',func=pin_types.PASSIVE,unit=2),
            Pin(num='194',name='194',func=pin_types.PASSIVE,unit=2),
            Pin(num='195',name='195',func=pin_types.PASSIVE,unit=2),
            Pin(num='196',name='196',func=pin_types.PASSIVE,unit=2),
            Pin(num='197',name='197',func=pin_types.PASSIVE,unit=2),
            Pin(num='198',name='198',func=pin_types.PASSIVE,unit=2),
            Pin(num='199',name='199',func=pin_types.PASSIVE,unit=2),
            Pin(num='200',name='200',func=pin_types.PASSIVE,unit=2),
            Pin(num='41',name='41',func=pin_types.PASSIVE,unit=2),
            Pin(num='42',name='42',func=pin_types.PASSIVE,unit=2),
            Pin(num='43',name='43',func=pin_types.PASSIVE,unit=2),
            Pin(num='44',name='44',func=pin_types.PASSIVE,unit=2),
            Pin(num='45',name='45',func=pin_types.PASSIVE,unit=2),
            Pin(num='46',name='46',func=pin_types.PASSIVE,unit=2),
            Pin(num='47',name='47',func=pin_types.PASSIVE,unit=2),
            Pin(num='48',name='48',func=pin_types.PASSIVE,unit=2),
            Pin(num='49',name='49',func=pin_types.PASSIVE,unit=2),
            Pin(num='50',name='50',func=pin_types.PASSIVE,unit=2),
            Pin(num='51',name='51',func=pin_types.PASSIVE,unit=2),
            Pin(num='52',name='52',func=pin_types.PASSIVE,unit=2),
            Pin(num='53',name='53',func=pin_types.PASSIVE,unit=2),
            Pin(num='54',name='54',func=pin_types.PASSIVE,unit=2),
            Pin(num='55',name='55',func=pin_types.PASSIVE,unit=2),
            Pin(num='56',name='56',func=pin_types.PASSIVE,unit=2),
            Pin(num='57',name='57',func=pin_types.PASSIVE,unit=2),
            Pin(num='58',name='58',func=pin_types.PASSIVE,unit=2),
            Pin(num='59',name='59',func=pin_types.PASSIVE,unit=2),
            Pin(num='60',name='60',func=pin_types.PASSIVE,unit=2),
            Pin(num='61',name='61',func=pin_types.PASSIVE,unit=2),
            Pin(num='62',name='62',func=pin_types.PASSIVE,unit=2),
            Pin(num='63',name='63',func=pin_types.PASSIVE,unit=2),
            Pin(num='64',name='64',func=pin_types.PASSIVE,unit=2),
            Pin(num='65',name='65',func=pin_types.PASSIVE,unit=2),
            Pin(num='66',name='66',func=pin_types.PASSIVE,unit=2),
            Pin(num='67',name='67',func=pin_types.PASSIVE,unit=2),
            Pin(num='68',name='68',func=pin_types.PASSIVE,unit=2),
            Pin(num='69',name='69',func=pin_types.PASSIVE,unit=2),
            Pin(num='70',name='70',func=pin_types.PASSIVE,unit=2),
            Pin(num='71',name='71',func=pin_types.PASSIVE,unit=2),
            Pin(num='72',name='72',func=pin_types.PASSIVE,unit=2),
            Pin(num='73',name='73',func=pin_types.PASSIVE,unit=2),
            Pin(num='74',name='74',func=pin_types.PASSIVE,unit=2),
            Pin(num='75',name='75',func=pin_types.PASSIVE,unit=2),
            Pin(num='76',name='76',func=pin_types.PASSIVE,unit=2),
            Pin(num='77',name='77',func=pin_types.PASSIVE,unit=2),
            Pin(num='78',name='78',func=pin_types.PASSIVE,unit=2),
            Pin(num='79',name='79',func=pin_types.PASSIVE,unit=2),
            Pin(num='80',name='80',func=pin_types.PASSIVE,unit=2),
            Pin(num='81',name='81',func=pin_types.PASSIVE,unit=2),
            Pin(num='82',name='82',func=pin_types.PASSIVE,unit=2),
            Pin(num='83',name='83',func=pin_types.PASSIVE,unit=2),
            Pin(num='84',name='84',func=pin_types.PASSIVE,unit=2),
            Pin(num='85',name='85',func=pin_types.PASSIVE,unit=2),
            Pin(num='86',name='86',func=pin_types.PASSIVE,unit=2),
            Pin(num='87',name='87',func=pin_types.PASSIVE,unit=2),
            Pin(num='88',name='88',func=pin_types.PASSIVE,unit=2),
            Pin(num='89',name='89',func=pin_types.PASSIVE,unit=2),
            Pin(num='90',name='90',func=pin_types.PASSIVE,unit=2),
            Pin(num='91',name='91',func=pin_types.PASSIVE,unit=2),
            Pin(num='92',name='92',func=pin_types.PASSIVE,unit=2),
            Pin(num='93',name='93',func=pin_types.PASSIVE,unit=2),
            Pin(num='94',name='94',func=pin_types.PASSIVE,unit=2),
            Pin(num='95',name='95',func=pin_types.PASSIVE,unit=2),
            Pin(num='96',name='96',func=pin_types.PASSIVE,unit=2),
            Pin(num='97',name='97',func=pin_types.PASSIVE,unit=2),
            Pin(num='98',name='98',func=pin_types.PASSIVE,unit=2),
            Pin(num='99',name='99',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['26', '35', '6', '29', '27', '1', '36', '7', '14', '28', '37', '8', '16', '3', '15', '21', '13', '30', '38', '9', '20', '2', '31', '39', '23', '32', '4', '10', '22', '19', '11', '18', '33', '40', '17', '25', '34', '5', '24', '12']},{'label': 'uB', 'num': 2, 'pin_nums': ['85', '67', '61', '104', '68', '136', '86', '71', '105', '137', '161', '87', '106', '63', '70', '138', '162', '191', '73', '88', '107', '62', '139', '64', '72', '89', '108', '140', '164', '75', '90', '165', '109', '141', '163', '166', '74', '91', '110', '142', '167', '92', '176', '111', '143', '168', '169', '192', '76', '93', '112', '144', '193', '94', '113', '170', '145', '194', '95', '114', '146', '172', '195', '96', '115', '190', '147', '173', '196', '171', '97', '116', '148', '197', '177', '98', '117', '149', '178', '198', '42', '99', '118', '150', '179', '199', '119', '151', '180', '66', '200', '120', '152', '181', '41', '121', '182', '153', '122', '154', '189', '43', '123', '155', '184', '44', '124', '156', '183', '45', '125', '157', '186', '46', '60', '188', '126', '55', '158', '185', '47', '187', '127', '48', '159', '128', '160', '49', '129', '54', '78', '50', '79', '130', '53', '103', '51', '80', '131', '56', '135', '174', '52', '57', '65', '81', '100', '132', '175', '77', '58', '82', '101', '133', '59', '83', '102', '134', '84', '69']}] }),
        Part(**{ 'name':'SODIMM-200_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SODIMM-200_Split'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'SODIMM SO-DIMM DDR1 DDR2', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nSODIMM-200_Split\n\nSODIMM SO-DIMM DDR1 DDR2', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='40',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='9',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='41',func=pin_types.PASSIVE,unit=2),
            Pin(num='42',name='42',func=pin_types.PASSIVE,unit=2),
            Pin(num='43',name='43',func=pin_types.PASSIVE,unit=2),
            Pin(num='44',name='44',func=pin_types.PASSIVE,unit=2),
            Pin(num='45',name='45',func=pin_types.PASSIVE,unit=2),
            Pin(num='46',name='46',func=pin_types.PASSIVE,unit=2),
            Pin(num='47',name='47',func=pin_types.PASSIVE,unit=2),
            Pin(num='48',name='48',func=pin_types.PASSIVE,unit=2),
            Pin(num='49',name='49',func=pin_types.PASSIVE,unit=2),
            Pin(num='50',name='50',func=pin_types.PASSIVE,unit=2),
            Pin(num='51',name='51',func=pin_types.PASSIVE,unit=2),
            Pin(num='52',name='52',func=pin_types.PASSIVE,unit=2),
            Pin(num='53',name='53',func=pin_types.PASSIVE,unit=2),
            Pin(num='54',name='54',func=pin_types.PASSIVE,unit=2),
            Pin(num='55',name='55',func=pin_types.PASSIVE,unit=2),
            Pin(num='56',name='56',func=pin_types.PASSIVE,unit=2),
            Pin(num='57',name='57',func=pin_types.PASSIVE,unit=2),
            Pin(num='58',name='58',func=pin_types.PASSIVE,unit=2),
            Pin(num='59',name='59',func=pin_types.PASSIVE,unit=2),
            Pin(num='60',name='60',func=pin_types.PASSIVE,unit=2),
            Pin(num='61',name='61',func=pin_types.PASSIVE,unit=2),
            Pin(num='62',name='62',func=pin_types.PASSIVE,unit=2),
            Pin(num='63',name='63',func=pin_types.PASSIVE,unit=2),
            Pin(num='64',name='64',func=pin_types.PASSIVE,unit=2),
            Pin(num='65',name='65',func=pin_types.PASSIVE,unit=2),
            Pin(num='66',name='66',func=pin_types.PASSIVE,unit=2),
            Pin(num='67',name='67',func=pin_types.PASSIVE,unit=2),
            Pin(num='68',name='68',func=pin_types.PASSIVE,unit=2),
            Pin(num='69',name='69',func=pin_types.PASSIVE,unit=2),
            Pin(num='70',name='70',func=pin_types.PASSIVE,unit=2),
            Pin(num='71',name='71',func=pin_types.PASSIVE,unit=2),
            Pin(num='72',name='72',func=pin_types.PASSIVE,unit=2),
            Pin(num='73',name='73',func=pin_types.PASSIVE,unit=2),
            Pin(num='74',name='74',func=pin_types.PASSIVE,unit=2),
            Pin(num='75',name='75',func=pin_types.PASSIVE,unit=2),
            Pin(num='76',name='76',func=pin_types.PASSIVE,unit=2),
            Pin(num='77',name='77',func=pin_types.PASSIVE,unit=2),
            Pin(num='78',name='78',func=pin_types.PASSIVE,unit=2),
            Pin(num='79',name='79',func=pin_types.PASSIVE,unit=2),
            Pin(num='80',name='80',func=pin_types.PASSIVE,unit=2),
            Pin(num='100',name='100',func=pin_types.PASSIVE,unit=3),
            Pin(num='101',name='101',func=pin_types.PASSIVE,unit=3),
            Pin(num='102',name='102',func=pin_types.PASSIVE,unit=3),
            Pin(num='103',name='103',func=pin_types.PASSIVE,unit=3),
            Pin(num='104',name='104',func=pin_types.PASSIVE,unit=3),
            Pin(num='105',name='105',func=pin_types.PASSIVE,unit=3),
            Pin(num='106',name='106',func=pin_types.PASSIVE,unit=3),
            Pin(num='107',name='107',func=pin_types.PASSIVE,unit=3),
            Pin(num='108',name='108',func=pin_types.PASSIVE,unit=3),
            Pin(num='109',name='109',func=pin_types.PASSIVE,unit=3),
            Pin(num='110',name='110',func=pin_types.PASSIVE,unit=3),
            Pin(num='111',name='111',func=pin_types.PASSIVE,unit=3),
            Pin(num='112',name='112',func=pin_types.PASSIVE,unit=3),
            Pin(num='113',name='113',func=pin_types.PASSIVE,unit=3),
            Pin(num='114',name='114',func=pin_types.PASSIVE,unit=3),
            Pin(num='115',name='115',func=pin_types.PASSIVE,unit=3),
            Pin(num='116',name='116',func=pin_types.PASSIVE,unit=3),
            Pin(num='117',name='117',func=pin_types.PASSIVE,unit=3),
            Pin(num='118',name='118',func=pin_types.PASSIVE,unit=3),
            Pin(num='119',name='119',func=pin_types.PASSIVE,unit=3),
            Pin(num='120',name='120',func=pin_types.PASSIVE,unit=3),
            Pin(num='81',name='81',func=pin_types.PASSIVE,unit=3),
            Pin(num='82',name='82',func=pin_types.PASSIVE,unit=3),
            Pin(num='83',name='83',func=pin_types.PASSIVE,unit=3),
            Pin(num='84',name='84',func=pin_types.PASSIVE,unit=3),
            Pin(num='85',name='85',func=pin_types.PASSIVE,unit=3),
            Pin(num='86',name='86',func=pin_types.PASSIVE,unit=3),
            Pin(num='87',name='87',func=pin_types.PASSIVE,unit=3),
            Pin(num='88',name='88',func=pin_types.PASSIVE,unit=3),
            Pin(num='89',name='89',func=pin_types.PASSIVE,unit=3),
            Pin(num='90',name='90',func=pin_types.PASSIVE,unit=3),
            Pin(num='91',name='91',func=pin_types.PASSIVE,unit=3),
            Pin(num='92',name='92',func=pin_types.PASSIVE,unit=3),
            Pin(num='93',name='93',func=pin_types.PASSIVE,unit=3),
            Pin(num='94',name='94',func=pin_types.PASSIVE,unit=3),
            Pin(num='95',name='95',func=pin_types.PASSIVE,unit=3),
            Pin(num='96',name='96',func=pin_types.PASSIVE,unit=3),
            Pin(num='97',name='97',func=pin_types.PASSIVE,unit=3),
            Pin(num='98',name='98',func=pin_types.PASSIVE,unit=3),
            Pin(num='99',name='99',func=pin_types.PASSIVE,unit=3),
            Pin(num='121',name='121',func=pin_types.PASSIVE,unit=4),
            Pin(num='122',name='122',func=pin_types.PASSIVE,unit=4),
            Pin(num='123',name='123',func=pin_types.PASSIVE,unit=4),
            Pin(num='124',name='124',func=pin_types.PASSIVE,unit=4),
            Pin(num='125',name='125',func=pin_types.PASSIVE,unit=4),
            Pin(num='126',name='126',func=pin_types.PASSIVE,unit=4),
            Pin(num='127',name='127',func=pin_types.PASSIVE,unit=4),
            Pin(num='128',name='128',func=pin_types.PASSIVE,unit=4),
            Pin(num='129',name='129',func=pin_types.PASSIVE,unit=4),
            Pin(num='130',name='130',func=pin_types.PASSIVE,unit=4),
            Pin(num='131',name='131',func=pin_types.PASSIVE,unit=4),
            Pin(num='132',name='132',func=pin_types.PASSIVE,unit=4),
            Pin(num='133',name='133',func=pin_types.PASSIVE,unit=4),
            Pin(num='134',name='134',func=pin_types.PASSIVE,unit=4),
            Pin(num='135',name='135',func=pin_types.PASSIVE,unit=4),
            Pin(num='136',name='136',func=pin_types.PASSIVE,unit=4),
            Pin(num='137',name='137',func=pin_types.PASSIVE,unit=4),
            Pin(num='138',name='138',func=pin_types.PASSIVE,unit=4),
            Pin(num='139',name='139',func=pin_types.PASSIVE,unit=4),
            Pin(num='140',name='140',func=pin_types.PASSIVE,unit=4),
            Pin(num='141',name='141',func=pin_types.PASSIVE,unit=4),
            Pin(num='142',name='142',func=pin_types.PASSIVE,unit=4),
            Pin(num='143',name='143',func=pin_types.PASSIVE,unit=4),
            Pin(num='144',name='144',func=pin_types.PASSIVE,unit=4),
            Pin(num='145',name='145',func=pin_types.PASSIVE,unit=4),
            Pin(num='146',name='146',func=pin_types.PASSIVE,unit=4),
            Pin(num='147',name='147',func=pin_types.PASSIVE,unit=4),
            Pin(num='148',name='148',func=pin_types.PASSIVE,unit=4),
            Pin(num='149',name='149',func=pin_types.PASSIVE,unit=4),
            Pin(num='150',name='150',func=pin_types.PASSIVE,unit=4),
            Pin(num='151',name='151',func=pin_types.PASSIVE,unit=4),
            Pin(num='152',name='152',func=pin_types.PASSIVE,unit=4),
            Pin(num='153',name='153',func=pin_types.PASSIVE,unit=4),
            Pin(num='154',name='154',func=pin_types.PASSIVE,unit=4),
            Pin(num='155',name='155',func=pin_types.PASSIVE,unit=4),
            Pin(num='156',name='156',func=pin_types.PASSIVE,unit=4),
            Pin(num='157',name='157',func=pin_types.PASSIVE,unit=4),
            Pin(num='158',name='158',func=pin_types.PASSIVE,unit=4),
            Pin(num='159',name='159',func=pin_types.PASSIVE,unit=4),
            Pin(num='160',name='160',func=pin_types.PASSIVE,unit=4),
            Pin(num='161',name='161',func=pin_types.PASSIVE,unit=5),
            Pin(num='162',name='162',func=pin_types.PASSIVE,unit=5),
            Pin(num='163',name='163',func=pin_types.PASSIVE,unit=5),
            Pin(num='164',name='164',func=pin_types.PASSIVE,unit=5),
            Pin(num='165',name='165',func=pin_types.PASSIVE,unit=5),
            Pin(num='166',name='166',func=pin_types.PASSIVE,unit=5),
            Pin(num='167',name='167',func=pin_types.PASSIVE,unit=5),
            Pin(num='168',name='168',func=pin_types.PASSIVE,unit=5),
            Pin(num='169',name='169',func=pin_types.PASSIVE,unit=5),
            Pin(num='170',name='170',func=pin_types.PASSIVE,unit=5),
            Pin(num='171',name='171',func=pin_types.PASSIVE,unit=5),
            Pin(num='172',name='172',func=pin_types.PASSIVE,unit=5),
            Pin(num='173',name='173',func=pin_types.PASSIVE,unit=5),
            Pin(num='174',name='174',func=pin_types.PASSIVE,unit=5),
            Pin(num='175',name='175',func=pin_types.PASSIVE,unit=5),
            Pin(num='176',name='176',func=pin_types.PASSIVE,unit=5),
            Pin(num='177',name='177',func=pin_types.PASSIVE,unit=5),
            Pin(num='178',name='178',func=pin_types.PASSIVE,unit=5),
            Pin(num='179',name='179',func=pin_types.PASSIVE,unit=5),
            Pin(num='180',name='180',func=pin_types.PASSIVE,unit=5),
            Pin(num='181',name='181',func=pin_types.PASSIVE,unit=5),
            Pin(num='182',name='182',func=pin_types.PASSIVE,unit=5),
            Pin(num='183',name='183',func=pin_types.PASSIVE,unit=5),
            Pin(num='184',name='184',func=pin_types.PASSIVE,unit=5),
            Pin(num='185',name='185',func=pin_types.PASSIVE,unit=5),
            Pin(num='186',name='186',func=pin_types.PASSIVE,unit=5),
            Pin(num='187',name='187',func=pin_types.PASSIVE,unit=5),
            Pin(num='188',name='188',func=pin_types.PASSIVE,unit=5),
            Pin(num='189',name='189',func=pin_types.PASSIVE,unit=5),
            Pin(num='190',name='190',func=pin_types.PASSIVE,unit=5),
            Pin(num='191',name='191',func=pin_types.PASSIVE,unit=5),
            Pin(num='192',name='192',func=pin_types.PASSIVE,unit=5),
            Pin(num='193',name='193',func=pin_types.PASSIVE,unit=5),
            Pin(num='194',name='194',func=pin_types.PASSIVE,unit=5),
            Pin(num='195',name='195',func=pin_types.PASSIVE,unit=5),
            Pin(num='196',name='196',func=pin_types.PASSIVE,unit=5),
            Pin(num='197',name='197',func=pin_types.PASSIVE,unit=5),
            Pin(num='198',name='198',func=pin_types.PASSIVE,unit=5),
            Pin(num='199',name='199',func=pin_types.PASSIVE,unit=5),
            Pin(num='200',name='200',func=pin_types.PASSIVE,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['14', '37', '3', '8', '15', '23', '30', '38', '9', '16', '17', '24', '31', '39', '11', '18', '25', '32', '4', '19', '26', '33', '40', '10', '2', '12', '27', '34', '5', '20', '1', '22', '28', '35', '6', '13', '21', '29', '36', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['55', '63', '47', '71', '79', '48', '56', '64', '72', '80', '65', '57', '41', '49', '73', '42', '50', '58', '66', '74', '59', '43', '51', '67', '75', '52', '44', '60', '68', '76', '53', '45', '61', '69', '77', '46', '54', '62', '70', '78']},{'label': 'uC', 'num': 3, 'pin_nums': ['105', '81', '97', '89', '113', '106', '114', '82', '90', '98', '107', '115', '83', '91', '99', '100', '108', '116', '84', '92', '101', '109', '117', '85', '93', '102', '110', '118', '86', '94', '103', '111', '119', '87', '95', '104', '112', '120', '88', '96']},{'label': 'uD', 'num': 4, 'pin_nums': ['149', '126', '134', '142', '150', '158', '127', '135', '151', '159', '143', '128', '136', '144', '152', '160', '121', '129', '137', '145', '153', '122', '130', '138', '146', '154', '123', '131', '139', '147', '155', '124', '132', '140', '148', '156', '125', '133', '141', '157']},{'label': 'uE', 'num': 5, 'pin_nums': ['198', '174', '190', '166', '182', '183', '191', '199', '175', '167', '173', '181', '189', '168', '176', '184', '192', '197', '200', '177', '161', '169', '185', '193', '162', '170', '178', '186', '194', '171', '179', '163', '187', '195', '164', '172', '180', '188', '196', '165']}] }),
        Part(**{ 'name':'Samtec_ASP-134602-01', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Samtec_ASP-134602-01'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'FPGA Mezzanine Card FMC Terminal Connector Header', 'description':'', 'datasheet':'http://suddendocs.samtec.com/prints/asp-134602-01-mkt.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nSamtec_ASP-134602-01\n\nFPGA Mezzanine Card FMC Terminal Connector Header', 'pins':[
            Pin(num='A1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='A10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='A11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='A12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='A13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='A14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='A15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='A16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='A17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='A18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='A19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='A20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='A21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='A22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='A23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='A24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='A25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='A26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='A27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='A28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='A29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='A30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='A31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='A32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='A33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='A34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='A35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='A36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='A37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='A38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='A39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='A40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='A6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='A7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='A9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='Pin_1',func=pin_types.PASSIVE,unit=2),
            Pin(num='B10',name='Pin_10',func=pin_types.PASSIVE,unit=2),
            Pin(num='B11',name='Pin_11',func=pin_types.PASSIVE,unit=2),
            Pin(num='B12',name='Pin_12',func=pin_types.PASSIVE,unit=2),
            Pin(num='B13',name='Pin_13',func=pin_types.PASSIVE,unit=2),
            Pin(num='B14',name='Pin_14',func=pin_types.PASSIVE,unit=2),
            Pin(num='B15',name='Pin_15',func=pin_types.PASSIVE,unit=2),
            Pin(num='B16',name='Pin_16',func=pin_types.PASSIVE,unit=2),
            Pin(num='B17',name='Pin_17',func=pin_types.PASSIVE,unit=2),
            Pin(num='B18',name='Pin_18',func=pin_types.PASSIVE,unit=2),
            Pin(num='B19',name='Pin_19',func=pin_types.PASSIVE,unit=2),
            Pin(num='B2',name='Pin_2',func=pin_types.PASSIVE,unit=2),
            Pin(num='B20',name='Pin_20',func=pin_types.PASSIVE,unit=2),
            Pin(num='B21',name='Pin_21',func=pin_types.PASSIVE,unit=2),
            Pin(num='B22',name='Pin_22',func=pin_types.PASSIVE,unit=2),
            Pin(num='B23',name='Pin_23',func=pin_types.PASSIVE,unit=2),
            Pin(num='B24',name='Pin_24',func=pin_types.PASSIVE,unit=2),
            Pin(num='B25',name='Pin_25',func=pin_types.PASSIVE,unit=2),
            Pin(num='B26',name='Pin_26',func=pin_types.PASSIVE,unit=2),
            Pin(num='B27',name='Pin_27',func=pin_types.PASSIVE,unit=2),
            Pin(num='B28',name='Pin_28',func=pin_types.PASSIVE,unit=2),
            Pin(num='B29',name='Pin_29',func=pin_types.PASSIVE,unit=2),
            Pin(num='B3',name='Pin_3',func=pin_types.PASSIVE,unit=2),
            Pin(num='B30',name='Pin_30',func=pin_types.PASSIVE,unit=2),
            Pin(num='B31',name='Pin_31',func=pin_types.PASSIVE,unit=2),
            Pin(num='B32',name='Pin_32',func=pin_types.PASSIVE,unit=2),
            Pin(num='B33',name='Pin_33',func=pin_types.PASSIVE,unit=2),
            Pin(num='B34',name='Pin_34',func=pin_types.PASSIVE,unit=2),
            Pin(num='B35',name='Pin_35',func=pin_types.PASSIVE,unit=2),
            Pin(num='B36',name='Pin_36',func=pin_types.PASSIVE,unit=2),
            Pin(num='B37',name='Pin_37',func=pin_types.PASSIVE,unit=2),
            Pin(num='B38',name='Pin_38',func=pin_types.PASSIVE,unit=2),
            Pin(num='B39',name='Pin_39',func=pin_types.PASSIVE,unit=2),
            Pin(num='B4',name='Pin_4',func=pin_types.PASSIVE,unit=2),
            Pin(num='B40',name='Pin_40',func=pin_types.PASSIVE,unit=2),
            Pin(num='B5',name='Pin_5',func=pin_types.PASSIVE,unit=2),
            Pin(num='B6',name='Pin_6',func=pin_types.PASSIVE,unit=2),
            Pin(num='B7',name='Pin_7',func=pin_types.PASSIVE,unit=2),
            Pin(num='B8',name='Pin_8',func=pin_types.PASSIVE,unit=2),
            Pin(num='B9',name='Pin_9',func=pin_types.PASSIVE,unit=2),
            Pin(num='C1',name='Pin_1',func=pin_types.PASSIVE,unit=3),
            Pin(num='C10',name='Pin_10',func=pin_types.PASSIVE,unit=3),
            Pin(num='C11',name='Pin_11',func=pin_types.PASSIVE,unit=3),
            Pin(num='C12',name='Pin_12',func=pin_types.PASSIVE,unit=3),
            Pin(num='C13',name='Pin_13',func=pin_types.PASSIVE,unit=3),
            Pin(num='C14',name='Pin_14',func=pin_types.PASSIVE,unit=3),
            Pin(num='C15',name='Pin_15',func=pin_types.PASSIVE,unit=3),
            Pin(num='C16',name='Pin_16',func=pin_types.PASSIVE,unit=3),
            Pin(num='C17',name='Pin_17',func=pin_types.PASSIVE,unit=3),
            Pin(num='C18',name='Pin_18',func=pin_types.PASSIVE,unit=3),
            Pin(num='C19',name='Pin_19',func=pin_types.PASSIVE,unit=3),
            Pin(num='C2',name='Pin_2',func=pin_types.PASSIVE,unit=3),
            Pin(num='C20',name='Pin_20',func=pin_types.PASSIVE,unit=3),
            Pin(num='C21',name='Pin_21',func=pin_types.PASSIVE,unit=3),
            Pin(num='C22',name='Pin_22',func=pin_types.PASSIVE,unit=3),
            Pin(num='C23',name='Pin_23',func=pin_types.PASSIVE,unit=3),
            Pin(num='C24',name='Pin_24',func=pin_types.PASSIVE,unit=3),
            Pin(num='C25',name='Pin_25',func=pin_types.PASSIVE,unit=3),
            Pin(num='C26',name='Pin_26',func=pin_types.PASSIVE,unit=3),
            Pin(num='C27',name='Pin_27',func=pin_types.PASSIVE,unit=3),
            Pin(num='C28',name='Pin_28',func=pin_types.PASSIVE,unit=3),
            Pin(num='C29',name='Pin_29',func=pin_types.PASSIVE,unit=3),
            Pin(num='C3',name='Pin_3',func=pin_types.PASSIVE,unit=3),
            Pin(num='C30',name='Pin_30',func=pin_types.PASSIVE,unit=3),
            Pin(num='C31',name='Pin_31',func=pin_types.PASSIVE,unit=3),
            Pin(num='C32',name='Pin_32',func=pin_types.PASSIVE,unit=3),
            Pin(num='C33',name='Pin_33',func=pin_types.PASSIVE,unit=3),
            Pin(num='C34',name='Pin_34',func=pin_types.PASSIVE,unit=3),
            Pin(num='C35',name='Pin_35',func=pin_types.PASSIVE,unit=3),
            Pin(num='C36',name='Pin_36',func=pin_types.PASSIVE,unit=3),
            Pin(num='C37',name='Pin_37',func=pin_types.PASSIVE,unit=3),
            Pin(num='C38',name='Pin_38',func=pin_types.PASSIVE,unit=3),
            Pin(num='C39',name='Pin_39',func=pin_types.PASSIVE,unit=3),
            Pin(num='C4',name='Pin_4',func=pin_types.PASSIVE,unit=3),
            Pin(num='C40',name='Pin_40',func=pin_types.PASSIVE,unit=3),
            Pin(num='C5',name='Pin_5',func=pin_types.PASSIVE,unit=3),
            Pin(num='C6',name='Pin_6',func=pin_types.PASSIVE,unit=3),
            Pin(num='C7',name='Pin_7',func=pin_types.PASSIVE,unit=3),
            Pin(num='C8',name='Pin_8',func=pin_types.PASSIVE,unit=3),
            Pin(num='C9',name='Pin_9',func=pin_types.PASSIVE,unit=3),
            Pin(num='D1',name='Pin_1',func=pin_types.PASSIVE,unit=4),
            Pin(num='D10',name='Pin_10',func=pin_types.PASSIVE,unit=4),
            Pin(num='D11',name='Pin_11',func=pin_types.PASSIVE,unit=4),
            Pin(num='D12',name='Pin_12',func=pin_types.PASSIVE,unit=4),
            Pin(num='D13',name='Pin_13',func=pin_types.PASSIVE,unit=4),
            Pin(num='D14',name='Pin_14',func=pin_types.PASSIVE,unit=4),
            Pin(num='D15',name='Pin_15',func=pin_types.PASSIVE,unit=4),
            Pin(num='D16',name='Pin_16',func=pin_types.PASSIVE,unit=4),
            Pin(num='D17',name='Pin_17',func=pin_types.PASSIVE,unit=4),
            Pin(num='D18',name='Pin_18',func=pin_types.PASSIVE,unit=4),
            Pin(num='D19',name='Pin_19',func=pin_types.PASSIVE,unit=4),
            Pin(num='D2',name='Pin_2',func=pin_types.PASSIVE,unit=4),
            Pin(num='D20',name='Pin_20',func=pin_types.PASSIVE,unit=4),
            Pin(num='D21',name='Pin_21',func=pin_types.PASSIVE,unit=4),
            Pin(num='D22',name='Pin_22',func=pin_types.PASSIVE,unit=4),
            Pin(num='D23',name='Pin_23',func=pin_types.PASSIVE,unit=4),
            Pin(num='D24',name='Pin_24',func=pin_types.PASSIVE,unit=4),
            Pin(num='D25',name='Pin_25',func=pin_types.PASSIVE,unit=4),
            Pin(num='D26',name='Pin_26',func=pin_types.PASSIVE,unit=4),
            Pin(num='D27',name='Pin_27',func=pin_types.PASSIVE,unit=4),
            Pin(num='D28',name='Pin_28',func=pin_types.PASSIVE,unit=4),
            Pin(num='D29',name='Pin_29',func=pin_types.PASSIVE,unit=4),
            Pin(num='D3',name='Pin_3',func=pin_types.PASSIVE,unit=4),
            Pin(num='D30',name='Pin_30',func=pin_types.PASSIVE,unit=4),
            Pin(num='D31',name='Pin_31',func=pin_types.PASSIVE,unit=4),
            Pin(num='D32',name='Pin_32',func=pin_types.PASSIVE,unit=4),
            Pin(num='D33',name='Pin_33',func=pin_types.PASSIVE,unit=4),
            Pin(num='D34',name='Pin_34',func=pin_types.PASSIVE,unit=4),
            Pin(num='D35',name='Pin_35',func=pin_types.PASSIVE,unit=4),
            Pin(num='D36',name='Pin_36',func=pin_types.PASSIVE,unit=4),
            Pin(num='D37',name='Pin_37',func=pin_types.PASSIVE,unit=4),
            Pin(num='D38',name='Pin_38',func=pin_types.PASSIVE,unit=4),
            Pin(num='D39',name='Pin_39',func=pin_types.PASSIVE,unit=4),
            Pin(num='D4',name='Pin_4',func=pin_types.PASSIVE,unit=4),
            Pin(num='D40',name='Pin_40',func=pin_types.PASSIVE,unit=4),
            Pin(num='D5',name='Pin_5',func=pin_types.PASSIVE,unit=4),
            Pin(num='D6',name='Pin_6',func=pin_types.PASSIVE,unit=4),
            Pin(num='D7',name='Pin_7',func=pin_types.PASSIVE,unit=4),
            Pin(num='D8',name='Pin_8',func=pin_types.PASSIVE,unit=4),
            Pin(num='D9',name='Pin_9',func=pin_types.PASSIVE,unit=4),
            Pin(num='E1',name='Pin_1',func=pin_types.PASSIVE,unit=5),
            Pin(num='E10',name='Pin_10',func=pin_types.PASSIVE,unit=5),
            Pin(num='E11',name='Pin_11',func=pin_types.PASSIVE,unit=5),
            Pin(num='E12',name='Pin_12',func=pin_types.PASSIVE,unit=5),
            Pin(num='E13',name='Pin_13',func=pin_types.PASSIVE,unit=5),
            Pin(num='E14',name='Pin_14',func=pin_types.PASSIVE,unit=5),
            Pin(num='E15',name='Pin_15',func=pin_types.PASSIVE,unit=5),
            Pin(num='E16',name='Pin_16',func=pin_types.PASSIVE,unit=5),
            Pin(num='E17',name='Pin_17',func=pin_types.PASSIVE,unit=5),
            Pin(num='E18',name='Pin_18',func=pin_types.PASSIVE,unit=5),
            Pin(num='E19',name='Pin_19',func=pin_types.PASSIVE,unit=5),
            Pin(num='E2',name='Pin_2',func=pin_types.PASSIVE,unit=5),
            Pin(num='E20',name='Pin_20',func=pin_types.PASSIVE,unit=5),
            Pin(num='E21',name='Pin_21',func=pin_types.PASSIVE,unit=5),
            Pin(num='E22',name='Pin_22',func=pin_types.PASSIVE,unit=5),
            Pin(num='E23',name='Pin_23',func=pin_types.PASSIVE,unit=5),
            Pin(num='E24',name='Pin_24',func=pin_types.PASSIVE,unit=5),
            Pin(num='E25',name='Pin_25',func=pin_types.PASSIVE,unit=5),
            Pin(num='E26',name='Pin_26',func=pin_types.PASSIVE,unit=5),
            Pin(num='E27',name='Pin_27',func=pin_types.PASSIVE,unit=5),
            Pin(num='E28',name='Pin_28',func=pin_types.PASSIVE,unit=5),
            Pin(num='E29',name='Pin_29',func=pin_types.PASSIVE,unit=5),
            Pin(num='E3',name='Pin_3',func=pin_types.PASSIVE,unit=5),
            Pin(num='E30',name='Pin_30',func=pin_types.PASSIVE,unit=5),
            Pin(num='E31',name='Pin_31',func=pin_types.PASSIVE,unit=5),
            Pin(num='E32',name='Pin_32',func=pin_types.PASSIVE,unit=5),
            Pin(num='E33',name='Pin_33',func=pin_types.PASSIVE,unit=5),
            Pin(num='E34',name='Pin_34',func=pin_types.PASSIVE,unit=5),
            Pin(num='E35',name='Pin_35',func=pin_types.PASSIVE,unit=5),
            Pin(num='E36',name='Pin_36',func=pin_types.PASSIVE,unit=5),
            Pin(num='E37',name='Pin_37',func=pin_types.PASSIVE,unit=5),
            Pin(num='E38',name='Pin_38',func=pin_types.PASSIVE,unit=5),
            Pin(num='E39',name='Pin_39',func=pin_types.PASSIVE,unit=5),
            Pin(num='E4',name='Pin_4',func=pin_types.PASSIVE,unit=5),
            Pin(num='E40',name='Pin_40',func=pin_types.PASSIVE,unit=5),
            Pin(num='E5',name='Pin_5',func=pin_types.PASSIVE,unit=5),
            Pin(num='E6',name='Pin_6',func=pin_types.PASSIVE,unit=5),
            Pin(num='E7',name='Pin_7',func=pin_types.PASSIVE,unit=5),
            Pin(num='E8',name='Pin_8',func=pin_types.PASSIVE,unit=5),
            Pin(num='E9',name='Pin_9',func=pin_types.PASSIVE,unit=5),
            Pin(num='F1',name='Pin_1',func=pin_types.PASSIVE,unit=6),
            Pin(num='F10',name='Pin_10',func=pin_types.PASSIVE,unit=6),
            Pin(num='F11',name='Pin_11',func=pin_types.PASSIVE,unit=6),
            Pin(num='F12',name='Pin_12',func=pin_types.PASSIVE,unit=6),
            Pin(num='F13',name='Pin_13',func=pin_types.PASSIVE,unit=6),
            Pin(num='F14',name='Pin_14',func=pin_types.PASSIVE,unit=6),
            Pin(num='F15',name='Pin_15',func=pin_types.PASSIVE,unit=6),
            Pin(num='F16',name='Pin_16',func=pin_types.PASSIVE,unit=6),
            Pin(num='F17',name='Pin_17',func=pin_types.PASSIVE,unit=6),
            Pin(num='F18',name='Pin_18',func=pin_types.PASSIVE,unit=6),
            Pin(num='F19',name='Pin_19',func=pin_types.PASSIVE,unit=6),
            Pin(num='F2',name='Pin_2',func=pin_types.PASSIVE,unit=6),
            Pin(num='F20',name='Pin_20',func=pin_types.PASSIVE,unit=6),
            Pin(num='F21',name='Pin_21',func=pin_types.PASSIVE,unit=6),
            Pin(num='F22',name='Pin_22',func=pin_types.PASSIVE,unit=6),
            Pin(num='F23',name='Pin_23',func=pin_types.PASSIVE,unit=6),
            Pin(num='F24',name='Pin_24',func=pin_types.PASSIVE,unit=6),
            Pin(num='F25',name='Pin_25',func=pin_types.PASSIVE,unit=6),
            Pin(num='F26',name='Pin_26',func=pin_types.PASSIVE,unit=6),
            Pin(num='F27',name='Pin_27',func=pin_types.PASSIVE,unit=6),
            Pin(num='F28',name='Pin_28',func=pin_types.PASSIVE,unit=6),
            Pin(num='F29',name='Pin_29',func=pin_types.PASSIVE,unit=6),
            Pin(num='F3',name='Pin_3',func=pin_types.PASSIVE,unit=6),
            Pin(num='F30',name='Pin_30',func=pin_types.PASSIVE,unit=6),
            Pin(num='F31',name='Pin_31',func=pin_types.PASSIVE,unit=6),
            Pin(num='F32',name='Pin_32',func=pin_types.PASSIVE,unit=6),
            Pin(num='F33',name='Pin_33',func=pin_types.PASSIVE,unit=6),
            Pin(num='F34',name='Pin_34',func=pin_types.PASSIVE,unit=6),
            Pin(num='F35',name='Pin_35',func=pin_types.PASSIVE,unit=6),
            Pin(num='F36',name='Pin_36',func=pin_types.PASSIVE,unit=6),
            Pin(num='F37',name='Pin_37',func=pin_types.PASSIVE,unit=6),
            Pin(num='F38',name='Pin_38',func=pin_types.PASSIVE,unit=6),
            Pin(num='F39',name='Pin_39',func=pin_types.PASSIVE,unit=6),
            Pin(num='F4',name='Pin_4',func=pin_types.PASSIVE,unit=6),
            Pin(num='F40',name='Pin_40',func=pin_types.PASSIVE,unit=6),
            Pin(num='F5',name='Pin_5',func=pin_types.PASSIVE,unit=6),
            Pin(num='F6',name='Pin_6',func=pin_types.PASSIVE,unit=6),
            Pin(num='F7',name='Pin_7',func=pin_types.PASSIVE,unit=6),
            Pin(num='F8',name='Pin_8',func=pin_types.PASSIVE,unit=6),
            Pin(num='F9',name='Pin_9',func=pin_types.PASSIVE,unit=6),
            Pin(num='G1',name='Pin_1',func=pin_types.PASSIVE,unit=7),
            Pin(num='G10',name='Pin_10',func=pin_types.PASSIVE,unit=7),
            Pin(num='G11',name='Pin_11',func=pin_types.PASSIVE,unit=7),
            Pin(num='G12',name='Pin_12',func=pin_types.PASSIVE,unit=7),
            Pin(num='G13',name='Pin_13',func=pin_types.PASSIVE,unit=7),
            Pin(num='G14',name='Pin_14',func=pin_types.PASSIVE,unit=7),
            Pin(num='G15',name='Pin_15',func=pin_types.PASSIVE,unit=7),
            Pin(num='G16',name='Pin_16',func=pin_types.PASSIVE,unit=7),
            Pin(num='G17',name='Pin_17',func=pin_types.PASSIVE,unit=7),
            Pin(num='G18',name='Pin_18',func=pin_types.PASSIVE,unit=7),
            Pin(num='G19',name='Pin_19',func=pin_types.PASSIVE,unit=7),
            Pin(num='G2',name='Pin_2',func=pin_types.PASSIVE,unit=7),
            Pin(num='G20',name='Pin_20',func=pin_types.PASSIVE,unit=7),
            Pin(num='G21',name='Pin_21',func=pin_types.PASSIVE,unit=7),
            Pin(num='G22',name='Pin_22',func=pin_types.PASSIVE,unit=7),
            Pin(num='G23',name='Pin_23',func=pin_types.PASSIVE,unit=7),
            Pin(num='G24',name='Pin_24',func=pin_types.PASSIVE,unit=7),
            Pin(num='G25',name='Pin_25',func=pin_types.PASSIVE,unit=7),
            Pin(num='G26',name='Pin_26',func=pin_types.PASSIVE,unit=7),
            Pin(num='G27',name='Pin_27',func=pin_types.PASSIVE,unit=7),
            Pin(num='G28',name='Pin_28',func=pin_types.PASSIVE,unit=7),
            Pin(num='G29',name='Pin_29',func=pin_types.PASSIVE,unit=7),
            Pin(num='G3',name='Pin_3',func=pin_types.PASSIVE,unit=7),
            Pin(num='G30',name='Pin_30',func=pin_types.PASSIVE,unit=7),
            Pin(num='G31',name='Pin_31',func=pin_types.PASSIVE,unit=7),
            Pin(num='G32',name='Pin_32',func=pin_types.PASSIVE,unit=7),
            Pin(num='G33',name='Pin_33',func=pin_types.PASSIVE,unit=7),
            Pin(num='G34',name='Pin_34',func=pin_types.PASSIVE,unit=7),
            Pin(num='G35',name='Pin_35',func=pin_types.PASSIVE,unit=7),
            Pin(num='G36',name='Pin_36',func=pin_types.PASSIVE,unit=7),
            Pin(num='G37',name='Pin_37',func=pin_types.PASSIVE,unit=7),
            Pin(num='G38',name='Pin_38',func=pin_types.PASSIVE,unit=7),
            Pin(num='G39',name='Pin_39',func=pin_types.PASSIVE,unit=7),
            Pin(num='G4',name='Pin_4',func=pin_types.PASSIVE,unit=7),
            Pin(num='G40',name='Pin_40',func=pin_types.PASSIVE,unit=7),
            Pin(num='G5',name='Pin_5',func=pin_types.PASSIVE,unit=7),
            Pin(num='G6',name='Pin_6',func=pin_types.PASSIVE,unit=7),
            Pin(num='G7',name='Pin_7',func=pin_types.PASSIVE,unit=7),
            Pin(num='G8',name='Pin_8',func=pin_types.PASSIVE,unit=7),
            Pin(num='G9',name='Pin_9',func=pin_types.PASSIVE,unit=7),
            Pin(num='H1',name='Pin_1',func=pin_types.PASSIVE,unit=8),
            Pin(num='H10',name='Pin_10',func=pin_types.PASSIVE,unit=8),
            Pin(num='H11',name='Pin_11',func=pin_types.PASSIVE,unit=8),
            Pin(num='H12',name='Pin_12',func=pin_types.PASSIVE,unit=8),
            Pin(num='H13',name='Pin_13',func=pin_types.PASSIVE,unit=8),
            Pin(num='H14',name='Pin_14',func=pin_types.PASSIVE,unit=8),
            Pin(num='H15',name='Pin_15',func=pin_types.PASSIVE,unit=8),
            Pin(num='H16',name='Pin_16',func=pin_types.PASSIVE,unit=8),
            Pin(num='H17',name='Pin_17',func=pin_types.PASSIVE,unit=8),
            Pin(num='H18',name='Pin_18',func=pin_types.PASSIVE,unit=8),
            Pin(num='H19',name='Pin_19',func=pin_types.PASSIVE,unit=8),
            Pin(num='H2',name='Pin_2',func=pin_types.PASSIVE,unit=8),
            Pin(num='H20',name='Pin_20',func=pin_types.PASSIVE,unit=8),
            Pin(num='H21',name='Pin_21',func=pin_types.PASSIVE,unit=8),
            Pin(num='H22',name='Pin_22',func=pin_types.PASSIVE,unit=8),
            Pin(num='H23',name='Pin_23',func=pin_types.PASSIVE,unit=8),
            Pin(num='H24',name='Pin_24',func=pin_types.PASSIVE,unit=8),
            Pin(num='H25',name='Pin_25',func=pin_types.PASSIVE,unit=8),
            Pin(num='H26',name='Pin_26',func=pin_types.PASSIVE,unit=8),
            Pin(num='H27',name='Pin_27',func=pin_types.PASSIVE,unit=8),
            Pin(num='H28',name='Pin_28',func=pin_types.PASSIVE,unit=8),
            Pin(num='H29',name='Pin_29',func=pin_types.PASSIVE,unit=8),
            Pin(num='H3',name='Pin_3',func=pin_types.PASSIVE,unit=8),
            Pin(num='H30',name='Pin_30',func=pin_types.PASSIVE,unit=8),
            Pin(num='H31',name='Pin_31',func=pin_types.PASSIVE,unit=8),
            Pin(num='H32',name='Pin_32',func=pin_types.PASSIVE,unit=8),
            Pin(num='H33',name='Pin_33',func=pin_types.PASSIVE,unit=8),
            Pin(num='H34',name='Pin_34',func=pin_types.PASSIVE,unit=8),
            Pin(num='H35',name='Pin_35',func=pin_types.PASSIVE,unit=8),
            Pin(num='H36',name='Pin_36',func=pin_types.PASSIVE,unit=8),
            Pin(num='H37',name='Pin_37',func=pin_types.PASSIVE,unit=8),
            Pin(num='H38',name='Pin_38',func=pin_types.PASSIVE,unit=8),
            Pin(num='H39',name='Pin_39',func=pin_types.PASSIVE,unit=8),
            Pin(num='H4',name='Pin_4',func=pin_types.PASSIVE,unit=8),
            Pin(num='H40',name='Pin_40',func=pin_types.PASSIVE,unit=8),
            Pin(num='H5',name='Pin_5',func=pin_types.PASSIVE,unit=8),
            Pin(num='H6',name='Pin_6',func=pin_types.PASSIVE,unit=8),
            Pin(num='H7',name='Pin_7',func=pin_types.PASSIVE,unit=8),
            Pin(num='H8',name='Pin_8',func=pin_types.PASSIVE,unit=8),
            Pin(num='H9',name='Pin_9',func=pin_types.PASSIVE,unit=8),
            Pin(num='J1',name='Pin_1',func=pin_types.PASSIVE,unit=9),
            Pin(num='J10',name='Pin_10',func=pin_types.PASSIVE,unit=9),
            Pin(num='J11',name='Pin_11',func=pin_types.PASSIVE,unit=9),
            Pin(num='J12',name='Pin_12',func=pin_types.PASSIVE,unit=9),
            Pin(num='J13',name='Pin_13',func=pin_types.PASSIVE,unit=9),
            Pin(num='J14',name='Pin_14',func=pin_types.PASSIVE,unit=9),
            Pin(num='J15',name='Pin_15',func=pin_types.PASSIVE,unit=9),
            Pin(num='J16',name='Pin_16',func=pin_types.PASSIVE,unit=9),
            Pin(num='J17',name='Pin_17',func=pin_types.PASSIVE,unit=9),
            Pin(num='J18',name='Pin_18',func=pin_types.PASSIVE,unit=9),
            Pin(num='J19',name='Pin_19',func=pin_types.PASSIVE,unit=9),
            Pin(num='J2',name='Pin_2',func=pin_types.PASSIVE,unit=9),
            Pin(num='J20',name='Pin_20',func=pin_types.PASSIVE,unit=9),
            Pin(num='J21',name='Pin_21',func=pin_types.PASSIVE,unit=9),
            Pin(num='J22',name='Pin_22',func=pin_types.PASSIVE,unit=9),
            Pin(num='J23',name='Pin_23',func=pin_types.PASSIVE,unit=9),
            Pin(num='J24',name='Pin_24',func=pin_types.PASSIVE,unit=9),
            Pin(num='J25',name='Pin_25',func=pin_types.PASSIVE,unit=9),
            Pin(num='J26',name='Pin_26',func=pin_types.PASSIVE,unit=9),
            Pin(num='J27',name='Pin_27',func=pin_types.PASSIVE,unit=9),
            Pin(num='J28',name='Pin_28',func=pin_types.PASSIVE,unit=9),
            Pin(num='J29',name='Pin_29',func=pin_types.PASSIVE,unit=9),
            Pin(num='J3',name='Pin_3',func=pin_types.PASSIVE,unit=9),
            Pin(num='J30',name='Pin_30',func=pin_types.PASSIVE,unit=9),
            Pin(num='J31',name='Pin_31',func=pin_types.PASSIVE,unit=9),
            Pin(num='J32',name='Pin_32',func=pin_types.PASSIVE,unit=9),
            Pin(num='J33',name='Pin_33',func=pin_types.PASSIVE,unit=9),
            Pin(num='J34',name='Pin_34',func=pin_types.PASSIVE,unit=9),
            Pin(num='J35',name='Pin_35',func=pin_types.PASSIVE,unit=9),
            Pin(num='J36',name='Pin_36',func=pin_types.PASSIVE,unit=9),
            Pin(num='J37',name='Pin_37',func=pin_types.PASSIVE,unit=9),
            Pin(num='J38',name='Pin_38',func=pin_types.PASSIVE,unit=9),
            Pin(num='J39',name='Pin_39',func=pin_types.PASSIVE,unit=9),
            Pin(num='J4',name='Pin_4',func=pin_types.PASSIVE,unit=9),
            Pin(num='J40',name='Pin_40',func=pin_types.PASSIVE,unit=9),
            Pin(num='J5',name='Pin_5',func=pin_types.PASSIVE,unit=9),
            Pin(num='J6',name='Pin_6',func=pin_types.PASSIVE,unit=9),
            Pin(num='J7',name='Pin_7',func=pin_types.PASSIVE,unit=9),
            Pin(num='J8',name='Pin_8',func=pin_types.PASSIVE,unit=9),
            Pin(num='J9',name='Pin_9',func=pin_types.PASSIVE,unit=9),
            Pin(num='K1',name='Pin_1',func=pin_types.PASSIVE,unit=10),
            Pin(num='K10',name='Pin_10',func=pin_types.PASSIVE,unit=10),
            Pin(num='K11',name='Pin_11',func=pin_types.PASSIVE,unit=10),
            Pin(num='K12',name='Pin_12',func=pin_types.PASSIVE,unit=10),
            Pin(num='K13',name='Pin_13',func=pin_types.PASSIVE,unit=10),
            Pin(num='K14',name='Pin_14',func=pin_types.PASSIVE,unit=10),
            Pin(num='K15',name='Pin_15',func=pin_types.PASSIVE,unit=10),
            Pin(num='K16',name='Pin_16',func=pin_types.PASSIVE,unit=10),
            Pin(num='K17',name='Pin_17',func=pin_types.PASSIVE,unit=10),
            Pin(num='K18',name='Pin_18',func=pin_types.PASSIVE,unit=10),
            Pin(num='K19',name='Pin_19',func=pin_types.PASSIVE,unit=10),
            Pin(num='K2',name='Pin_2',func=pin_types.PASSIVE,unit=10),
            Pin(num='K20',name='Pin_20',func=pin_types.PASSIVE,unit=10),
            Pin(num='K21',name='Pin_21',func=pin_types.PASSIVE,unit=10),
            Pin(num='K22',name='Pin_22',func=pin_types.PASSIVE,unit=10),
            Pin(num='K23',name='Pin_23',func=pin_types.PASSIVE,unit=10),
            Pin(num='K24',name='Pin_24',func=pin_types.PASSIVE,unit=10),
            Pin(num='K25',name='Pin_25',func=pin_types.PASSIVE,unit=10),
            Pin(num='K26',name='Pin_26',func=pin_types.PASSIVE,unit=10),
            Pin(num='K27',name='Pin_27',func=pin_types.PASSIVE,unit=10),
            Pin(num='K28',name='Pin_28',func=pin_types.PASSIVE,unit=10),
            Pin(num='K29',name='Pin_29',func=pin_types.PASSIVE,unit=10),
            Pin(num='K3',name='Pin_3',func=pin_types.PASSIVE,unit=10),
            Pin(num='K30',name='Pin_30',func=pin_types.PASSIVE,unit=10),
            Pin(num='K31',name='Pin_31',func=pin_types.PASSIVE,unit=10),
            Pin(num='K32',name='Pin_32',func=pin_types.PASSIVE,unit=10),
            Pin(num='K33',name='Pin_33',func=pin_types.PASSIVE,unit=10),
            Pin(num='K34',name='Pin_34',func=pin_types.PASSIVE,unit=10),
            Pin(num='K35',name='Pin_35',func=pin_types.PASSIVE,unit=10),
            Pin(num='K36',name='Pin_36',func=pin_types.PASSIVE,unit=10),
            Pin(num='K37',name='Pin_37',func=pin_types.PASSIVE,unit=10),
            Pin(num='K38',name='Pin_38',func=pin_types.PASSIVE,unit=10),
            Pin(num='K39',name='Pin_39',func=pin_types.PASSIVE,unit=10),
            Pin(num='K4',name='Pin_4',func=pin_types.PASSIVE,unit=10),
            Pin(num='K40',name='Pin_40',func=pin_types.PASSIVE,unit=10),
            Pin(num='K5',name='Pin_5',func=pin_types.PASSIVE,unit=10),
            Pin(num='K6',name='Pin_6',func=pin_types.PASSIVE,unit=10),
            Pin(num='K7',name='Pin_7',func=pin_types.PASSIVE,unit=10),
            Pin(num='K8',name='Pin_8',func=pin_types.PASSIVE,unit=10),
            Pin(num='K9',name='Pin_9',func=pin_types.PASSIVE,unit=10)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['A34', 'A5', 'A20', 'A13', 'A28', 'A35', 'A6', 'A21', 'A14', 'A29', 'A36', 'A7', 'A22', 'A2', 'A1', 'A15', 'A27', 'A3', 'A37', 'A8', 'A23', 'A16', 'A30', 'A38', 'A9', 'A24', 'A17', 'A31', 'A39', 'A18', 'A10', 'A25', 'A32', 'A4', 'A26', 'A11', 'A19', 'A33', 'A40', 'A12']},{'label': 'uB', 'num': 2, 'pin_nums': ['B2', 'B5', 'B12', 'B27', 'B34', 'B13', 'B20', 'B28', 'B35', 'B6', 'B14', 'B21', 'B29', 'B36', 'B7', 'B15', 'B22', 'B3', 'B37', 'B8', 'B16', 'B23', 'B30', 'B38', 'B9', 'B1', 'B17', 'B24', 'B31', 'B39', 'B10', 'B18', 'B25', 'B32', 'B4', 'B11', 'B19', 'B26', 'B33', 'B40']},{'label': 'uC', 'num': 3, 'pin_nums': ['C24', 'C40', 'C12', 'C2', 'C26', 'C34', 'C5', 'C13', 'C6', 'C20', 'C7', 'C21', 'C14', 'C32', 'C30', 'C8', 'C23', 'C15', 'C35', 'C9', 'C4', 'C25', 'C36', 'C16', 'C3', 'C37', 'C19', 'C1', 'C27', 'C17', 'C38', 'C10', 'C18', 'C31', 'C39', 'C22', 'C33', 'C29', 'C28', 'C11']},{'label': 'uD', 'num': 4, 'pin_nums': ['D38', 'D23', 'D30', 'D9', 'D14', 'D15', 'D24', 'D31', 'D39', 'D16', 'D25', 'D32', 'D4', 'D17', 'D26', 'D33', 'D40', 'D18', 'D19', 'D27', 'D34', 'D5', 'D1', 'D2', 'D28', 'D35', 'D6', 'D10', 'D20', 'D11', 'D29', 'D36', 'D7', 'D21', 'D12', 'D22', 'D3', 'D37', 'D8', 'D13']},{'label': 'uE', 'num': 5, 'pin_nums': ['E38', 'E30', 'E9', 'E16', 'E23', 'E22', 'E1', 'E3', 'E17', 'E37', 'E24', 'E31', 'E39', 'E10', 'E32', 'E25', 'E18', 'E4', 'E11', 'E19', 'E26', 'E33', 'E40', 'E12', 'E2', 'E27', 'E34', 'E5', 'E13', 'E20', 'E28', 'E35', 'E6', 'E14', 'E21', 'E29', 'E36', 'E7', 'E15', 'E8']},{'label': 'uF', 'num': 6, 'pin_nums': ['F22', 'F15', 'F3', 'F8', 'F37', 'F16', 'F23', 'F30', 'F9', 'F38', 'F1', 'F17', 'F24', 'F31', 'F39', 'F10', 'F18', 'F25', 'F32', 'F4', 'F11', 'F19', 'F26', 'F33', 'F40', 'F12', 'F2', 'F27', 'F34', 'F5', 'F13', 'F20', 'F28', 'F35', 'F6', 'F14', 'F21', 'F29', 'F36', 'F7']},{'label': 'uG', 'num': 7, 'pin_nums': ['G8', 'G3', 'G37', 'G15', 'G22', 'G14', 'G30', 'G38', 'G9', 'G16', 'G23', 'G21', 'G36', 'G7', 'G1', 'G17', 'G24', 'G31', 'G39', 'G10', 'G18', 'G25', 'G32', 'G4', 'G11', 'G19', 'G26', 'G33', 'G40', 'G2', 'G12', 'G27', 'G34', 'G5', 'G13', 'G20', 'G28', 'G35', 'G6', 'G29']},{'label': 'uH', 'num': 8, 'pin_nums': ['H14', 'H36', 'H29', 'H7', 'H15', 'H22', 'H3', 'H37', 'H8', 'H16', 'H23', 'H30', 'H38', 'H9', 'H1', 'H17', 'H24', 'H31', 'H39', 'H10', 'H18', 'H25', 'H32', 'H4', 'H11', 'H19', 'H26', 'H33', 'H40', 'H12', 'H2', 'H21', 'H27', 'H34', 'H5', 'H13', 'H20', 'H28', 'H35', 'H6']},{'label': 'uI', 'num': 9, 'pin_nums': ['J21', 'J36', 'J14', 'J29', 'J7', 'J15', 'J22', 'J3', 'J37', 'J8', 'J23', 'J16', 'J30', 'J38', 'J9', 'J1', 'J17', 'J24', 'J31', 'J39', 'J25', 'J10', 'J18', 'J32', 'J4', 'J11', 'J19', 'J26', 'J33', 'J40', 'J2', 'J12', 'J27', 'J34', 'J13', 'J5', 'J20', 'J28', 'J35', 'J6']},{'label': 'uJ', 'num': 10, 'pin_nums': ['K7', 'K21', 'K14', 'K29', 'K36', 'K37', 'K8', 'K22', 'K15', 'K3', 'K23', 'K16', 'K30', 'K38', 'K9', 'K20', 'K1', 'K17', 'K24', 'K28', 'K31', 'K35', 'K39', 'K6', 'K25', 'K10', 'K18', 'K32', 'K4', 'K11', 'K19', 'K26', 'K33', 'K40', 'K12', 'K2', 'K27', 'K34', 'K5', 'K13']}] }),
        Part(**{ 'name':'Screw_Terminal_01x01', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Screw_Terminal_01x01'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'screw terminal', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nScrew_Terminal_01x01\n\nscrew terminal', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Screw_Terminal_01x02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Screw_Terminal_01x02'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'screw terminal', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nScrew_Terminal_01x02\n\nscrew terminal', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Screw_Terminal_01x03', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Screw_Terminal_01x03'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'screw terminal', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nScrew_Terminal_01x03\n\nscrew terminal', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Screw_Terminal_01x04', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Screw_Terminal_01x04'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'screw terminal', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nScrew_Terminal_01x04\n\nscrew terminal', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Screw_Terminal_01x05', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Screw_Terminal_01x05'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'screw terminal', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nScrew_Terminal_01x05\n\nscrew terminal', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Screw_Terminal_01x06', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Screw_Terminal_01x06'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'screw terminal', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nScrew_Terminal_01x06\n\nscrew terminal', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Screw_Terminal_01x07', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Screw_Terminal_01x07'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'screw terminal', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nScrew_Terminal_01x07\n\nscrew terminal', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Screw_Terminal_01x08', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Screw_Terminal_01x08'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'screw terminal', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nScrew_Terminal_01x08\n\nscrew terminal', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Screw_Terminal_01x09', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Screw_Terminal_01x09'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'screw terminal', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nScrew_Terminal_01x09\n\nscrew terminal', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Screw_Terminal_01x10', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Screw_Terminal_01x10'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'screw terminal', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nScrew_Terminal_01x10\n\nscrew terminal', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Screw_Terminal_01x11', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Screw_Terminal_01x11'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'screw terminal', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nScrew_Terminal_01x11\n\nscrew terminal', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Screw_Terminal_01x12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Screw_Terminal_01x12'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'screw terminal', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nScrew_Terminal_01x12\n\nscrew terminal', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Screw_Terminal_01x13', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Screw_Terminal_01x13'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'screw terminal', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nScrew_Terminal_01x13\n\nscrew terminal', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Screw_Terminal_01x14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Screw_Terminal_01x14'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'screw terminal', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nScrew_Terminal_01x14\n\nscrew terminal', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Screw_Terminal_01x15', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Screw_Terminal_01x15'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'screw terminal', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nScrew_Terminal_01x15\n\nscrew terminal', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Screw_Terminal_01x16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Screw_Terminal_01x16'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'screw terminal', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nScrew_Terminal_01x16\n\nscrew terminal', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Screw_Terminal_01x17', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Screw_Terminal_01x17'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'screw terminal', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nScrew_Terminal_01x17\n\nscrew terminal', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Screw_Terminal_01x18', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Screw_Terminal_01x18'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'screw terminal', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nScrew_Terminal_01x18\n\nscrew terminal', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Screw_Terminal_01x19', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Screw_Terminal_01x19'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'screw terminal', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nScrew_Terminal_01x19\n\nscrew terminal', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Screw_Terminal_01x20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Screw_Terminal_01x20'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'screw terminal', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nScrew_Terminal_01x20\n\nscrew terminal', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TestPoint', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TestPoint'}), 'ref_prefix':'TP', 'fplist':[''], 'footprint':'', 'keywords':'test point tp', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nTestPoint\n\ntest point tp', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TestPoint_2Pole', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TestPoint_2Pole'}), 'ref_prefix':'TP', 'fplist':[''], 'footprint':'', 'keywords':'point tp', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nTestPoint_2Pole\n\npoint tp', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE),
            Pin(num='2',name='2',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'TestPoint_Alt', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TestPoint_Alt'}), 'ref_prefix':'TP', 'fplist':[''], 'footprint':'', 'keywords':'test point tp', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nTestPoint_Alt\n\ntest point tp', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TestPoint_Flag', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TestPoint_Flag'}), 'ref_prefix':'TP', 'fplist':[''], 'footprint':'', 'keywords':'test point tp', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nTestPoint_Flag\n\ntest point tp', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TestPoint_Probe', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TestPoint_Probe'}), 'ref_prefix':'TP', 'fplist':[''], 'footprint':'', 'keywords':'test point tp', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nTestPoint_Probe\n\ntest point tp', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TestPoint_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TestPoint_Small'}), 'ref_prefix':'TP', 'fplist':[''], 'footprint':'', 'keywords':'test point tp', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nTestPoint_Small\n\ntest point tp', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'UEXT_Host', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'UEXT_Host'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'UEXT, SPI, UART, I2C', 'description':'', 'datasheet':'https://www.olimex.com/Products/Modules/UEXT/resources/UEXT_rev_B.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nUEXT_Host\n\nUEXT, SPI, UART, I2C', 'pins':[
            Pin(num='1',name='3V3',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{SSEL}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SCL',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='SCK',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'UEXT_Slave', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'UEXT_Slave'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'UEXT, SPI, UART, I2C', 'description':'', 'datasheet':'https://www.olimex.com/Products/Modules/UEXT/resources/UEXT_rev_B.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nUEXT_Slave\n\nUEXT, SPI, UART, I2C', 'pins':[
            Pin(num='1',name='3V3',func=pin_types.PWROUT,unit=1),
            Pin(num='10',name='~{SSEL}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TXD',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='RXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='MISO',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='MOSI',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='SCK',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USB3_A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USB3_A'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'usb universal serial bus', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nUSB3_A\n\nusb universal serial bus', 'pins':[
            Pin(num='1',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SHIELD',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SSRX-',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='SSRX+',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='DRAIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='SSTX-',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='SSTX+',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USB3_A_Stacked', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USB3_A_Stacked'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'usb universal serial bus', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nUSB3_A_Stacked\n\nusb universal serial bus', 'pins':[
            Pin(num='19',name='SHIELD',func=pin_types.PASSIVE),
            Pin(num='1',name='VBUS1',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='D1-',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='D1+',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND1',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SSRX1-',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='SSRX1+',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='DRAIN1',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='SSTX1-',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='SSTX1+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VBUS2',func=pin_types.PWRIN,unit=2),
            Pin(num='11',name='D2-',func=pin_types.BIDIR,unit=2),
            Pin(num='12',name='D2+',func=pin_types.BIDIR,unit=2),
            Pin(num='13',name='GND2',func=pin_types.PWRIN,unit=2),
            Pin(num='14',name='SSRX2-',func=pin_types.OUTPUT,unit=2),
            Pin(num='15',name='SSRX2+',func=pin_types.OUTPUT,unit=2),
            Pin(num='16',name='DRAIN2',func=pin_types.PASSIVE,unit=2),
            Pin(num='17',name='SSTX2-',func=pin_types.INPUT,unit=2),
            Pin(num='18',name='SSTX2+',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '7', '1', '5', '19', '3', '4', '6', '9', '8']},{'label': 'uB', 'num': 2, 'pin_nums': ['13', '15', '11', '17', '19', '14', '12', '10', '16', '18']}] }),
        Part(**{ 'name':'USB3_B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USB3_B'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'usb universal serial bus', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nUSB3_B\n\nusb universal serial bus', 'pins':[
            Pin(num='1',name='VBUS',func=pin_types.PWROUT,unit=1),
            Pin(num='10',name='SHIELD',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='SSTX-',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='SSTX+',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='DRAIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='SSRX-',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='SSRX+',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USB3_B_Micro', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USB3_B_Micro'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'usb universal serial bus', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nUSB3_B_Micro\n\nusb universal serial bus', 'pins':[
            Pin(num='1',name='VBUS',func=pin_types.PWROUT,unit=1),
            Pin(num='10',name='SSRX+',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SHIELD',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='ID',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='SSTX-',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='SSTX+',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='DRAIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='SSRX-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USB_A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USB_A'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector USB', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nUSB_A\n\nconnector USB', 'pins':[
            Pin(num='1',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Shield',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USB_A_Stacked', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USB_A_Stacked'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector USB', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nUSB_A_Stacked\n\nconnector USB', 'pins':[
            Pin(num='1',name='VBUS1',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='D1-',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='D1+',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND1',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VBUS2',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='D2-',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='D2+',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND2',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Shield',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USB_B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USB_B'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector USB', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nUSB_B\n\nconnector USB', 'pins':[
            Pin(num='1',name='VBUS',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Shield',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USB_B_Micro', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USB_B_Micro'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector USB micro', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nUSB_B_Micro\n\nconnector USB micro', 'pins':[
            Pin(num='1',name='VBUS',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='ID',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='Shield',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USB_C_Plug', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USB_C_Plug'}), 'ref_prefix':'P', 'fplist':[''], 'footprint':'', 'keywords':'usb universal serial bus', 'description':'', 'datasheet':'https://www.usb.org/sites/default/files/documents/usb_type-c.zip', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nUSB_C_Plug\n\nusb universal serial bus', 'pins':[
            Pin(num='A1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A10',name='RX2-',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='RX2+',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='TX1+',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='TX1-',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='CC',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='SBU1',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B10',name='RX1-',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='RX1+',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='TX2+',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='TX2-',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='VCONN',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='SBU2',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='S1',name='SHIELD',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USB_C_Plug_USB2.0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USB_C_Plug_USB2.0'}), 'ref_prefix':'P', 'fplist':[''], 'footprint':'', 'keywords':'usb universal serial bus type-C USB2.0', 'description':'', 'datasheet':'https://www.usb.org/sites/default/files/documents/usb_type-c.zip', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nUSB_C_Plug_USB2.0\n\nusb universal serial bus type-C USB2.0', 'pins':[
            Pin(num='A1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='CC',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='VCONN',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='S1',name='SHIELD',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USB_C_Receptacle', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USB_C_Receptacle'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'usb universal serial bus type-C full-featured', 'description':'', 'datasheet':'https://www.usb.org/sites/default/files/documents/usb_type-c.zip', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nUSB_C_Receptacle\n\nusb universal serial bus type-C full-featured', 'pins':[
            Pin(num='A1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A10',name='RX2-',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='RX2+',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='TX1+',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='TX1-',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='SBU1',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B10',name='RX1-',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='RX1+',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='TX2+',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='TX2-',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='SBU2',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='S1',name='SHIELD',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USB_C_Receptacle_PowerOnly_24P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USB_C_Receptacle_PowerOnly_24P'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'usb universal serial bus type-C power-only charging-only 24P 24C', 'description':'', 'datasheet':'https://www.usb.org/sites/default/files/documents/usb_type-c.zip', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nUSB_C_Receptacle_PowerOnly_24P\n\nusb universal serial bus type-C power-only charging-only 24P 24C', 'pins':[
            Pin(num='A1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='S1',name='SHIELD',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USB_C_Receptacle_PowerOnly_6P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USB_C_Receptacle_PowerOnly_6P'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'usb universal serial bus type-C power-only charging-only 6P 6C', 'description':'', 'datasheet':'https://www.usb.org/sites/default/files/documents/usb_type-c.zip', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nUSB_C_Receptacle_PowerOnly_6P\n\nusb universal serial bus type-C power-only charging-only 6P 6C', 'pins':[
            Pin(num='A12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='S1',name='SHIELD',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USB_C_Receptacle_USB2.0_14P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USB_C_Receptacle_USB2.0_14P'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'usb universal serial bus type-C USB2.0', 'description':'', 'datasheet':'https://www.usb.org/sites/default/files/documents/usb_type-c.zip', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nUSB_C_Receptacle_USB2.0_14P\n\nusb universal serial bus type-C USB2.0', 'pins':[
            Pin(num='A1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='S1',name='SHIELD',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USB_C_Receptacle_USB2.0_16P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USB_C_Receptacle_USB2.0_16P'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'usb universal serial bus type-C USB2.0', 'description':'', 'datasheet':'https://www.usb.org/sites/default/files/documents/usb_type-c.zip', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nUSB_C_Receptacle_USB2.0_16P\n\nusb universal serial bus type-C USB2.0', 'pins':[
            Pin(num='A1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='SBU1',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='SBU2',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='S1',name='SHIELD',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USB_OTG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USB_OTG'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector USB', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nUSB_OTG\n\nconnector USB', 'pins':[
            Pin(num='1',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='ID',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Shield',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_ARM_SWD_TagConnect_TC2030-NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_ARM_SWD_TagConnect_TC2030-NL'}), 'ref_prefix':'J', 'fplist':['Connector:Tag-Connect_TC2030-IDC-FP_2x03_P1.27mm_Vertical', 'Connector:Tag-Connect_TC2030-IDC-NL_2x03_P1.27mm_Vertical'], 'footprint':'Connector:Tag-Connect_TC2030-IDC-FP_2x03_P1.27mm_Vertical', 'keywords':'Cortex Debug Connector ARM SWD JTAG', 'description':'', 'datasheet':'https://www.tag-connect.com/wp-content/uploads/bsk-pdf-manager/TC2030-CTX_1.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nConn_ARM_SWD_TagConnect_TC2030-NL\n\nCortex Debug Connector ARM SWD JTAG', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN),
            Pin(num='2',name='SWDIO',func=pin_types.BIDIR),
            Pin(num='3',name='~{RESET}',func=pin_types.OPENCOLL),
            Pin(num='4',name='SWCLK',func=pin_types.OUTPUT),
            Pin(num='5',name='GND',func=pin_types.PWRIN),
            Pin(num='6',name='SWO',func=pin_types.INPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'Jack-DC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Jack-DC'}), 'ref_prefix':'J', 'fplist':['', ''], 'footprint':'', 'keywords':'DC power barrel jack connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nJack-DC\n\nDC power barrel jack connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Micro_SD_Card_Det_Hirose_DM3AT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Micro_SD_Card_Det_Hirose_DM3AT'}), 'ref_prefix':'J', 'fplist':['', ''], 'footprint':'', 'keywords':'connector SD microsd', 'description':'', 'datasheet':'https://www.hirose.com/product/en/download_file/key_name/DM3/category/Catalog/doc_file_id/49662/?file_category_id=4&item_id=195&is_series=1', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nMicro_SD_Card_Det_Hirose_DM3AT\n\nconnector SD microsd', 'pins':[
            Pin(num='1',name='DAT2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='DET_A',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='SHIELD',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='DAT3/CD',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CMD',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='DAT0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DAT1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='DET_B',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ10', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ10'}), 'ref_prefix':'J', 'fplist':['', ''], 'footprint':'', 'keywords':'4P4C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ10\n\n4P4C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ10_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ10_Shielded'}), 'ref_prefix':'J', 'fplist':['', ''], 'footprint':'', 'keywords':'4P4C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ10_Shielded\n\n4P4C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ11', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ11'}), 'ref_prefix':'J', 'fplist':['', ''], 'footprint':'', 'keywords':'6P2C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ11\n\n6P2C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ11_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ11_Shielded'}), 'ref_prefix':'J', 'fplist':['', ''], 'footprint':'', 'keywords':'6P2C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ11_Shielded\n\n6P2C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ12'}), 'ref_prefix':'J', 'fplist':['', ''], 'footprint':'', 'keywords':'6P6C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ12\n\n6P6C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ12_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ12_Shielded'}), 'ref_prefix':'J', 'fplist':['', ''], 'footprint':'', 'keywords':'6P6C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ12_Shielded\n\n6P6C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ13', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ13'}), 'ref_prefix':'J', 'fplist':['', ''], 'footprint':'', 'keywords':'6P4C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ13\n\n6P4C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ13_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ13_Shielded'}), 'ref_prefix':'J', 'fplist':['', ''], 'footprint':'', 'keywords':'6P4C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ13_Shielded\n\n6P4C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ14'}), 'ref_prefix':'J', 'fplist':['', '', ''], 'footprint':'', 'keywords':'6P4C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ14\n\n6P4C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ14_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ14_Shielded'}), 'ref_prefix':'J', 'fplist':['', '', ''], 'footprint':'', 'keywords':'6P4C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ14_Shielded\n\n6P4C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ18', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ18'}), 'ref_prefix':'J', 'fplist':['', '', ''], 'footprint':'', 'keywords':'6P6C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ18\n\n6P6C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ18_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ18_Shielded'}), 'ref_prefix':'J', 'fplist':['', '', ''], 'footprint':'', 'keywords':'6P6C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ18_Shielded\n\n6P6C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ22', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ22'}), 'ref_prefix':'J', 'fplist':['', '', ''], 'footprint':'', 'keywords':'4P4C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ22\n\n4P4C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ22_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ22_Shielded'}), 'ref_prefix':'J', 'fplist':['', '', ''], 'footprint':'', 'keywords':'4P4C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ22_Shielded\n\n4P4C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ25', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ25'}), 'ref_prefix':'J', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'6P6C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ25\n\n6P6C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ25_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ25_Shielded'}), 'ref_prefix':'J', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'6P6C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ25_Shielded\n\n6P6C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ31', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ31'}), 'ref_prefix':'J', 'fplist':['', ''], 'footprint':'', 'keywords':'8P8C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ31\n\n8P8C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ31_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ31_Shielded'}), 'ref_prefix':'J', 'fplist':['', ''], 'footprint':'', 'keywords':'8P8C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ31_Shielded\n\n8P8C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ32'}), 'ref_prefix':'J', 'fplist':['', '', ''], 'footprint':'', 'keywords':'8P8C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ32\n\n8P8C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ32_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ32_Shielded'}), 'ref_prefix':'J', 'fplist':['', '', ''], 'footprint':'', 'keywords':'8P8C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ32_Shielded\n\n8P8C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ33', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ33'}), 'ref_prefix':'J', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'8P8C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ33\n\n8P8C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ33_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ33_Shielded'}), 'ref_prefix':'J', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'8P8C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ33_Shielded\n\n8P8C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ34', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ34'}), 'ref_prefix':'J', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'8P8C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ34\n\n8P8C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ34_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ34_Shielded'}), 'ref_prefix':'J', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'8P8C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ34_Shielded\n\n8P8C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ35', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ35'}), 'ref_prefix':'J', 'fplist':['', '', '', '', '', ''], 'footprint':'', 'keywords':'8P8C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ35\n\n8P8C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ35_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ35_Shielded'}), 'ref_prefix':'J', 'fplist':['', '', '', '', '', ''], 'footprint':'', 'keywords':'8P8C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ35_Shielded\n\n8P8C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ38', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ38'}), 'ref_prefix':'J', 'fplist':['', ''], 'footprint':'', 'keywords':'8P4C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ38\n\n8P4C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ38_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ38_Shielded'}), 'ref_prefix':'J', 'fplist':['', ''], 'footprint':'', 'keywords':'8P4C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ38_Shielded\n\n8P4C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ41', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ41'}), 'ref_prefix':'J', 'fplist':['', '', '', '', '', '', ''], 'footprint':'', 'keywords':'8P8C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ41\n\n8P8C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ41_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ41_Shielded'}), 'ref_prefix':'J', 'fplist':['', '', '', '', '', '', ''], 'footprint':'', 'keywords':'8P8C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ41_Shielded\n\n8P8C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ45', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ45'}), 'ref_prefix':'J', 'fplist':['', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'8P8C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ45\n\n8P8C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ45_LED', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ45_LED'}), 'ref_prefix':'J', 'fplist':['', ''], 'footprint':'', 'keywords':'8P8C RJ socket jack connector led', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ45_LED\n\n8P8C RJ socket jack connector led', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ45_LED_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ45_LED_Shielded'}), 'ref_prefix':'J', 'fplist':['', ''], 'footprint':'', 'keywords':'8P8C RJ socket jack connector led', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ45_LED_Shielded\n\n8P8C RJ socket jack connector led', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ45_LED_Shielded_x2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ45_LED_Shielded_x2'}), 'ref_prefix':'J', 'fplist':['', ''], 'footprint':'', 'keywords':'8P8C RJ socket jack connector led', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ45_LED_Shielded_x2\n\n8P8C RJ socket jack connector led', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='15',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='16',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='17',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='18',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='19',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='20',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='21',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='22',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='23',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['10', '12', '7', '5', '3', '8', '1', '9', '11', '2', '6', '4', 'SH']},{'label': 'uB', 'num': 2, 'pin_nums': ['14', '18', '19', '20', '16', '22', 'SH', '23', '13', '21', '15', '17', '24']}] }),
        Part(**{ 'name':'RJ45_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ45_Shielded'}), 'ref_prefix':'J', 'fplist':['', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'8P8C RJ jack socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ45_Shielded\n\n8P8C RJ jack socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ48', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ48'}), 'ref_prefix':'J', 'fplist':['', '', ''], 'footprint':'', 'keywords':'8P4C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ48\n\n8P4C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ48_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ48_Shielded'}), 'ref_prefix':'J', 'fplist':['', '', ''], 'footprint':'', 'keywords':'8P4C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ48_Shielded\n\n8P4C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ49', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ49'}), 'ref_prefix':'J', 'fplist':['', '', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'8P8C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ49\n\n8P8C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ49_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ49_Shielded'}), 'ref_prefix':'J', 'fplist':['', '', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'8P8C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ49_Shielded\n\n8P8C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ61', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ61'}), 'ref_prefix':'J', 'fplist':['', '', '', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'8P8C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ61\n\n8P8C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ61_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ61_Shielded'}), 'ref_prefix':'J', 'fplist':['', '', '', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'8P8C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ61_Shielded\n\n8P8C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ9', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ9'}), 'ref_prefix':'J', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'4P4C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ9\n\n4P4C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RJ9_Shielded', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RJ9_Shielded'}), 'ref_prefix':'J', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'4P4C RJ socket connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nRJ9_Shielded\n\n4P4C RJ socket connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Samtec_ASP-134486-01', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Samtec_ASP-134486-01'}), 'ref_prefix':'J', 'fplist':['', ''], 'footprint':'', 'keywords':'FPGA Mezzanine Card FMC Terminal Connector Header', 'description':'', 'datasheet':'http://suddendocs.samtec.com/prints/asp-134486-01-mkt.pdf', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nSamtec_ASP-134486-01\n\nFPGA Mezzanine Card FMC Terminal Connector Header', 'pins':[
            Pin(num='A1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='A10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='A11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='A12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='A13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='A14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='A15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='A16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='A17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='A18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='A19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='A20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='A21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='A22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='A23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='A24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='A25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='A26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='A27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='A28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='A29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='A30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='A31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='A32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='A33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='A34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='A35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='A36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='A37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='A38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='A39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='A40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='A6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='A7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='A9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='Pin_1',func=pin_types.PASSIVE,unit=2),
            Pin(num='B10',name='Pin_10',func=pin_types.PASSIVE,unit=2),
            Pin(num='B11',name='Pin_11',func=pin_types.PASSIVE,unit=2),
            Pin(num='B12',name='Pin_12',func=pin_types.PASSIVE,unit=2),
            Pin(num='B13',name='Pin_13',func=pin_types.PASSIVE,unit=2),
            Pin(num='B14',name='Pin_14',func=pin_types.PASSIVE,unit=2),
            Pin(num='B15',name='Pin_15',func=pin_types.PASSIVE,unit=2),
            Pin(num='B16',name='Pin_16',func=pin_types.PASSIVE,unit=2),
            Pin(num='B17',name='Pin_17',func=pin_types.PASSIVE,unit=2),
            Pin(num='B18',name='Pin_18',func=pin_types.PASSIVE,unit=2),
            Pin(num='B19',name='Pin_19',func=pin_types.PASSIVE,unit=2),
            Pin(num='B2',name='Pin_2',func=pin_types.PASSIVE,unit=2),
            Pin(num='B20',name='Pin_20',func=pin_types.PASSIVE,unit=2),
            Pin(num='B21',name='Pin_21',func=pin_types.PASSIVE,unit=2),
            Pin(num='B22',name='Pin_22',func=pin_types.PASSIVE,unit=2),
            Pin(num='B23',name='Pin_23',func=pin_types.PASSIVE,unit=2),
            Pin(num='B24',name='Pin_24',func=pin_types.PASSIVE,unit=2),
            Pin(num='B25',name='Pin_25',func=pin_types.PASSIVE,unit=2),
            Pin(num='B26',name='Pin_26',func=pin_types.PASSIVE,unit=2),
            Pin(num='B27',name='Pin_27',func=pin_types.PASSIVE,unit=2),
            Pin(num='B28',name='Pin_28',func=pin_types.PASSIVE,unit=2),
            Pin(num='B29',name='Pin_29',func=pin_types.PASSIVE,unit=2),
            Pin(num='B3',name='Pin_3',func=pin_types.PASSIVE,unit=2),
            Pin(num='B30',name='Pin_30',func=pin_types.PASSIVE,unit=2),
            Pin(num='B31',name='Pin_31',func=pin_types.PASSIVE,unit=2),
            Pin(num='B32',name='Pin_32',func=pin_types.PASSIVE,unit=2),
            Pin(num='B33',name='Pin_33',func=pin_types.PASSIVE,unit=2),
            Pin(num='B34',name='Pin_34',func=pin_types.PASSIVE,unit=2),
            Pin(num='B35',name='Pin_35',func=pin_types.PASSIVE,unit=2),
            Pin(num='B36',name='Pin_36',func=pin_types.PASSIVE,unit=2),
            Pin(num='B37',name='Pin_37',func=pin_types.PASSIVE,unit=2),
            Pin(num='B38',name='Pin_38',func=pin_types.PASSIVE,unit=2),
            Pin(num='B39',name='Pin_39',func=pin_types.PASSIVE,unit=2),
            Pin(num='B4',name='Pin_4',func=pin_types.PASSIVE,unit=2),
            Pin(num='B40',name='Pin_40',func=pin_types.PASSIVE,unit=2),
            Pin(num='B5',name='Pin_5',func=pin_types.PASSIVE,unit=2),
            Pin(num='B6',name='Pin_6',func=pin_types.PASSIVE,unit=2),
            Pin(num='B7',name='Pin_7',func=pin_types.PASSIVE,unit=2),
            Pin(num='B8',name='Pin_8',func=pin_types.PASSIVE,unit=2),
            Pin(num='B9',name='Pin_9',func=pin_types.PASSIVE,unit=2),
            Pin(num='C1',name='Pin_1',func=pin_types.PASSIVE,unit=3),
            Pin(num='C10',name='Pin_10',func=pin_types.PASSIVE,unit=3),
            Pin(num='C11',name='Pin_11',func=pin_types.PASSIVE,unit=3),
            Pin(num='C12',name='Pin_12',func=pin_types.PASSIVE,unit=3),
            Pin(num='C13',name='Pin_13',func=pin_types.PASSIVE,unit=3),
            Pin(num='C14',name='Pin_14',func=pin_types.PASSIVE,unit=3),
            Pin(num='C15',name='Pin_15',func=pin_types.PASSIVE,unit=3),
            Pin(num='C16',name='Pin_16',func=pin_types.PASSIVE,unit=3),
            Pin(num='C17',name='Pin_17',func=pin_types.PASSIVE,unit=3),
            Pin(num='C18',name='Pin_18',func=pin_types.PASSIVE,unit=3),
            Pin(num='C19',name='Pin_19',func=pin_types.PASSIVE,unit=3),
            Pin(num='C2',name='Pin_2',func=pin_types.PASSIVE,unit=3),
            Pin(num='C20',name='Pin_20',func=pin_types.PASSIVE,unit=3),
            Pin(num='C21',name='Pin_21',func=pin_types.PASSIVE,unit=3),
            Pin(num='C22',name='Pin_22',func=pin_types.PASSIVE,unit=3),
            Pin(num='C23',name='Pin_23',func=pin_types.PASSIVE,unit=3),
            Pin(num='C24',name='Pin_24',func=pin_types.PASSIVE,unit=3),
            Pin(num='C25',name='Pin_25',func=pin_types.PASSIVE,unit=3),
            Pin(num='C26',name='Pin_26',func=pin_types.PASSIVE,unit=3),
            Pin(num='C27',name='Pin_27',func=pin_types.PASSIVE,unit=3),
            Pin(num='C28',name='Pin_28',func=pin_types.PASSIVE,unit=3),
            Pin(num='C29',name='Pin_29',func=pin_types.PASSIVE,unit=3),
            Pin(num='C3',name='Pin_3',func=pin_types.PASSIVE,unit=3),
            Pin(num='C30',name='Pin_30',func=pin_types.PASSIVE,unit=3),
            Pin(num='C31',name='Pin_31',func=pin_types.PASSIVE,unit=3),
            Pin(num='C32',name='Pin_32',func=pin_types.PASSIVE,unit=3),
            Pin(num='C33',name='Pin_33',func=pin_types.PASSIVE,unit=3),
            Pin(num='C34',name='Pin_34',func=pin_types.PASSIVE,unit=3),
            Pin(num='C35',name='Pin_35',func=pin_types.PASSIVE,unit=3),
            Pin(num='C36',name='Pin_36',func=pin_types.PASSIVE,unit=3),
            Pin(num='C37',name='Pin_37',func=pin_types.PASSIVE,unit=3),
            Pin(num='C38',name='Pin_38',func=pin_types.PASSIVE,unit=3),
            Pin(num='C39',name='Pin_39',func=pin_types.PASSIVE,unit=3),
            Pin(num='C4',name='Pin_4',func=pin_types.PASSIVE,unit=3),
            Pin(num='C40',name='Pin_40',func=pin_types.PASSIVE,unit=3),
            Pin(num='C5',name='Pin_5',func=pin_types.PASSIVE,unit=3),
            Pin(num='C6',name='Pin_6',func=pin_types.PASSIVE,unit=3),
            Pin(num='C7',name='Pin_7',func=pin_types.PASSIVE,unit=3),
            Pin(num='C8',name='Pin_8',func=pin_types.PASSIVE,unit=3),
            Pin(num='C9',name='Pin_9',func=pin_types.PASSIVE,unit=3),
            Pin(num='D1',name='Pin_1',func=pin_types.PASSIVE,unit=4),
            Pin(num='D10',name='Pin_10',func=pin_types.PASSIVE,unit=4),
            Pin(num='D11',name='Pin_11',func=pin_types.PASSIVE,unit=4),
            Pin(num='D12',name='Pin_12',func=pin_types.PASSIVE,unit=4),
            Pin(num='D13',name='Pin_13',func=pin_types.PASSIVE,unit=4),
            Pin(num='D14',name='Pin_14',func=pin_types.PASSIVE,unit=4),
            Pin(num='D15',name='Pin_15',func=pin_types.PASSIVE,unit=4),
            Pin(num='D16',name='Pin_16',func=pin_types.PASSIVE,unit=4),
            Pin(num='D17',name='Pin_17',func=pin_types.PASSIVE,unit=4),
            Pin(num='D18',name='Pin_18',func=pin_types.PASSIVE,unit=4),
            Pin(num='D19',name='Pin_19',func=pin_types.PASSIVE,unit=4),
            Pin(num='D2',name='Pin_2',func=pin_types.PASSIVE,unit=4),
            Pin(num='D20',name='Pin_20',func=pin_types.PASSIVE,unit=4),
            Pin(num='D21',name='Pin_21',func=pin_types.PASSIVE,unit=4),
            Pin(num='D22',name='Pin_22',func=pin_types.PASSIVE,unit=4),
            Pin(num='D23',name='Pin_23',func=pin_types.PASSIVE,unit=4),
            Pin(num='D24',name='Pin_24',func=pin_types.PASSIVE,unit=4),
            Pin(num='D25',name='Pin_25',func=pin_types.PASSIVE,unit=4),
            Pin(num='D26',name='Pin_26',func=pin_types.PASSIVE,unit=4),
            Pin(num='D27',name='Pin_27',func=pin_types.PASSIVE,unit=4),
            Pin(num='D28',name='Pin_28',func=pin_types.PASSIVE,unit=4),
            Pin(num='D29',name='Pin_29',func=pin_types.PASSIVE,unit=4),
            Pin(num='D3',name='Pin_3',func=pin_types.PASSIVE,unit=4),
            Pin(num='D30',name='Pin_30',func=pin_types.PASSIVE,unit=4),
            Pin(num='D31',name='Pin_31',func=pin_types.PASSIVE,unit=4),
            Pin(num='D32',name='Pin_32',func=pin_types.PASSIVE,unit=4),
            Pin(num='D33',name='Pin_33',func=pin_types.PASSIVE,unit=4),
            Pin(num='D34',name='Pin_34',func=pin_types.PASSIVE,unit=4),
            Pin(num='D35',name='Pin_35',func=pin_types.PASSIVE,unit=4),
            Pin(num='D36',name='Pin_36',func=pin_types.PASSIVE,unit=4),
            Pin(num='D37',name='Pin_37',func=pin_types.PASSIVE,unit=4),
            Pin(num='D38',name='Pin_38',func=pin_types.PASSIVE,unit=4),
            Pin(num='D39',name='Pin_39',func=pin_types.PASSIVE,unit=4),
            Pin(num='D4',name='Pin_4',func=pin_types.PASSIVE,unit=4),
            Pin(num='D40',name='Pin_40',func=pin_types.PASSIVE,unit=4),
            Pin(num='D5',name='Pin_5',func=pin_types.PASSIVE,unit=4),
            Pin(num='D6',name='Pin_6',func=pin_types.PASSIVE,unit=4),
            Pin(num='D7',name='Pin_7',func=pin_types.PASSIVE,unit=4),
            Pin(num='D8',name='Pin_8',func=pin_types.PASSIVE,unit=4),
            Pin(num='D9',name='Pin_9',func=pin_types.PASSIVE,unit=4),
            Pin(num='E1',name='Pin_1',func=pin_types.PASSIVE,unit=5),
            Pin(num='E10',name='Pin_10',func=pin_types.PASSIVE,unit=5),
            Pin(num='E11',name='Pin_11',func=pin_types.PASSIVE,unit=5),
            Pin(num='E12',name='Pin_12',func=pin_types.PASSIVE,unit=5),
            Pin(num='E13',name='Pin_13',func=pin_types.PASSIVE,unit=5),
            Pin(num='E14',name='Pin_14',func=pin_types.PASSIVE,unit=5),
            Pin(num='E15',name='Pin_15',func=pin_types.PASSIVE,unit=5),
            Pin(num='E16',name='Pin_16',func=pin_types.PASSIVE,unit=5),
            Pin(num='E17',name='Pin_17',func=pin_types.PASSIVE,unit=5),
            Pin(num='E18',name='Pin_18',func=pin_types.PASSIVE,unit=5),
            Pin(num='E19',name='Pin_19',func=pin_types.PASSIVE,unit=5),
            Pin(num='E2',name='Pin_2',func=pin_types.PASSIVE,unit=5),
            Pin(num='E20',name='Pin_20',func=pin_types.PASSIVE,unit=5),
            Pin(num='E21',name='Pin_21',func=pin_types.PASSIVE,unit=5),
            Pin(num='E22',name='Pin_22',func=pin_types.PASSIVE,unit=5),
            Pin(num='E23',name='Pin_23',func=pin_types.PASSIVE,unit=5),
            Pin(num='E24',name='Pin_24',func=pin_types.PASSIVE,unit=5),
            Pin(num='E25',name='Pin_25',func=pin_types.PASSIVE,unit=5),
            Pin(num='E26',name='Pin_26',func=pin_types.PASSIVE,unit=5),
            Pin(num='E27',name='Pin_27',func=pin_types.PASSIVE,unit=5),
            Pin(num='E28',name='Pin_28',func=pin_types.PASSIVE,unit=5),
            Pin(num='E29',name='Pin_29',func=pin_types.PASSIVE,unit=5),
            Pin(num='E3',name='Pin_3',func=pin_types.PASSIVE,unit=5),
            Pin(num='E30',name='Pin_30',func=pin_types.PASSIVE,unit=5),
            Pin(num='E31',name='Pin_31',func=pin_types.PASSIVE,unit=5),
            Pin(num='E32',name='Pin_32',func=pin_types.PASSIVE,unit=5),
            Pin(num='E33',name='Pin_33',func=pin_types.PASSIVE,unit=5),
            Pin(num='E34',name='Pin_34',func=pin_types.PASSIVE,unit=5),
            Pin(num='E35',name='Pin_35',func=pin_types.PASSIVE,unit=5),
            Pin(num='E36',name='Pin_36',func=pin_types.PASSIVE,unit=5),
            Pin(num='E37',name='Pin_37',func=pin_types.PASSIVE,unit=5),
            Pin(num='E38',name='Pin_38',func=pin_types.PASSIVE,unit=5),
            Pin(num='E39',name='Pin_39',func=pin_types.PASSIVE,unit=5),
            Pin(num='E4',name='Pin_4',func=pin_types.PASSIVE,unit=5),
            Pin(num='E40',name='Pin_40',func=pin_types.PASSIVE,unit=5),
            Pin(num='E5',name='Pin_5',func=pin_types.PASSIVE,unit=5),
            Pin(num='E6',name='Pin_6',func=pin_types.PASSIVE,unit=5),
            Pin(num='E7',name='Pin_7',func=pin_types.PASSIVE,unit=5),
            Pin(num='E8',name='Pin_8',func=pin_types.PASSIVE,unit=5),
            Pin(num='E9',name='Pin_9',func=pin_types.PASSIVE,unit=5),
            Pin(num='F1',name='Pin_1',func=pin_types.PASSIVE,unit=6),
            Pin(num='F10',name='Pin_10',func=pin_types.PASSIVE,unit=6),
            Pin(num='F11',name='Pin_11',func=pin_types.PASSIVE,unit=6),
            Pin(num='F12',name='Pin_12',func=pin_types.PASSIVE,unit=6),
            Pin(num='F13',name='Pin_13',func=pin_types.PASSIVE,unit=6),
            Pin(num='F14',name='Pin_14',func=pin_types.PASSIVE,unit=6),
            Pin(num='F15',name='Pin_15',func=pin_types.PASSIVE,unit=6),
            Pin(num='F16',name='Pin_16',func=pin_types.PASSIVE,unit=6),
            Pin(num='F17',name='Pin_17',func=pin_types.PASSIVE,unit=6),
            Pin(num='F18',name='Pin_18',func=pin_types.PASSIVE,unit=6),
            Pin(num='F19',name='Pin_19',func=pin_types.PASSIVE,unit=6),
            Pin(num='F2',name='Pin_2',func=pin_types.PASSIVE,unit=6),
            Pin(num='F20',name='Pin_20',func=pin_types.PASSIVE,unit=6),
            Pin(num='F21',name='Pin_21',func=pin_types.PASSIVE,unit=6),
            Pin(num='F22',name='Pin_22',func=pin_types.PASSIVE,unit=6),
            Pin(num='F23',name='Pin_23',func=pin_types.PASSIVE,unit=6),
            Pin(num='F24',name='Pin_24',func=pin_types.PASSIVE,unit=6),
            Pin(num='F25',name='Pin_25',func=pin_types.PASSIVE,unit=6),
            Pin(num='F26',name='Pin_26',func=pin_types.PASSIVE,unit=6),
            Pin(num='F27',name='Pin_27',func=pin_types.PASSIVE,unit=6),
            Pin(num='F28',name='Pin_28',func=pin_types.PASSIVE,unit=6),
            Pin(num='F29',name='Pin_29',func=pin_types.PASSIVE,unit=6),
            Pin(num='F3',name='Pin_3',func=pin_types.PASSIVE,unit=6),
            Pin(num='F30',name='Pin_30',func=pin_types.PASSIVE,unit=6),
            Pin(num='F31',name='Pin_31',func=pin_types.PASSIVE,unit=6),
            Pin(num='F32',name='Pin_32',func=pin_types.PASSIVE,unit=6),
            Pin(num='F33',name='Pin_33',func=pin_types.PASSIVE,unit=6),
            Pin(num='F34',name='Pin_34',func=pin_types.PASSIVE,unit=6),
            Pin(num='F35',name='Pin_35',func=pin_types.PASSIVE,unit=6),
            Pin(num='F36',name='Pin_36',func=pin_types.PASSIVE,unit=6),
            Pin(num='F37',name='Pin_37',func=pin_types.PASSIVE,unit=6),
            Pin(num='F38',name='Pin_38',func=pin_types.PASSIVE,unit=6),
            Pin(num='F39',name='Pin_39',func=pin_types.PASSIVE,unit=6),
            Pin(num='F4',name='Pin_4',func=pin_types.PASSIVE,unit=6),
            Pin(num='F40',name='Pin_40',func=pin_types.PASSIVE,unit=6),
            Pin(num='F5',name='Pin_5',func=pin_types.PASSIVE,unit=6),
            Pin(num='F6',name='Pin_6',func=pin_types.PASSIVE,unit=6),
            Pin(num='F7',name='Pin_7',func=pin_types.PASSIVE,unit=6),
            Pin(num='F8',name='Pin_8',func=pin_types.PASSIVE,unit=6),
            Pin(num='F9',name='Pin_9',func=pin_types.PASSIVE,unit=6),
            Pin(num='G1',name='Pin_1',func=pin_types.PASSIVE,unit=7),
            Pin(num='G10',name='Pin_10',func=pin_types.PASSIVE,unit=7),
            Pin(num='G11',name='Pin_11',func=pin_types.PASSIVE,unit=7),
            Pin(num='G12',name='Pin_12',func=pin_types.PASSIVE,unit=7),
            Pin(num='G13',name='Pin_13',func=pin_types.PASSIVE,unit=7),
            Pin(num='G14',name='Pin_14',func=pin_types.PASSIVE,unit=7),
            Pin(num='G15',name='Pin_15',func=pin_types.PASSIVE,unit=7),
            Pin(num='G16',name='Pin_16',func=pin_types.PASSIVE,unit=7),
            Pin(num='G17',name='Pin_17',func=pin_types.PASSIVE,unit=7),
            Pin(num='G18',name='Pin_18',func=pin_types.PASSIVE,unit=7),
            Pin(num='G19',name='Pin_19',func=pin_types.PASSIVE,unit=7),
            Pin(num='G2',name='Pin_2',func=pin_types.PASSIVE,unit=7),
            Pin(num='G20',name='Pin_20',func=pin_types.PASSIVE,unit=7),
            Pin(num='G21',name='Pin_21',func=pin_types.PASSIVE,unit=7),
            Pin(num='G22',name='Pin_22',func=pin_types.PASSIVE,unit=7),
            Pin(num='G23',name='Pin_23',func=pin_types.PASSIVE,unit=7),
            Pin(num='G24',name='Pin_24',func=pin_types.PASSIVE,unit=7),
            Pin(num='G25',name='Pin_25',func=pin_types.PASSIVE,unit=7),
            Pin(num='G26',name='Pin_26',func=pin_types.PASSIVE,unit=7),
            Pin(num='G27',name='Pin_27',func=pin_types.PASSIVE,unit=7),
            Pin(num='G28',name='Pin_28',func=pin_types.PASSIVE,unit=7),
            Pin(num='G29',name='Pin_29',func=pin_types.PASSIVE,unit=7),
            Pin(num='G3',name='Pin_3',func=pin_types.PASSIVE,unit=7),
            Pin(num='G30',name='Pin_30',func=pin_types.PASSIVE,unit=7),
            Pin(num='G31',name='Pin_31',func=pin_types.PASSIVE,unit=7),
            Pin(num='G32',name='Pin_32',func=pin_types.PASSIVE,unit=7),
            Pin(num='G33',name='Pin_33',func=pin_types.PASSIVE,unit=7),
            Pin(num='G34',name='Pin_34',func=pin_types.PASSIVE,unit=7),
            Pin(num='G35',name='Pin_35',func=pin_types.PASSIVE,unit=7),
            Pin(num='G36',name='Pin_36',func=pin_types.PASSIVE,unit=7),
            Pin(num='G37',name='Pin_37',func=pin_types.PASSIVE,unit=7),
            Pin(num='G38',name='Pin_38',func=pin_types.PASSIVE,unit=7),
            Pin(num='G39',name='Pin_39',func=pin_types.PASSIVE,unit=7),
            Pin(num='G4',name='Pin_4',func=pin_types.PASSIVE,unit=7),
            Pin(num='G40',name='Pin_40',func=pin_types.PASSIVE,unit=7),
            Pin(num='G5',name='Pin_5',func=pin_types.PASSIVE,unit=7),
            Pin(num='G6',name='Pin_6',func=pin_types.PASSIVE,unit=7),
            Pin(num='G7',name='Pin_7',func=pin_types.PASSIVE,unit=7),
            Pin(num='G8',name='Pin_8',func=pin_types.PASSIVE,unit=7),
            Pin(num='G9',name='Pin_9',func=pin_types.PASSIVE,unit=7),
            Pin(num='H1',name='Pin_1',func=pin_types.PASSIVE,unit=8),
            Pin(num='H10',name='Pin_10',func=pin_types.PASSIVE,unit=8),
            Pin(num='H11',name='Pin_11',func=pin_types.PASSIVE,unit=8),
            Pin(num='H12',name='Pin_12',func=pin_types.PASSIVE,unit=8),
            Pin(num='H13',name='Pin_13',func=pin_types.PASSIVE,unit=8),
            Pin(num='H14',name='Pin_14',func=pin_types.PASSIVE,unit=8),
            Pin(num='H15',name='Pin_15',func=pin_types.PASSIVE,unit=8),
            Pin(num='H16',name='Pin_16',func=pin_types.PASSIVE,unit=8),
            Pin(num='H17',name='Pin_17',func=pin_types.PASSIVE,unit=8),
            Pin(num='H18',name='Pin_18',func=pin_types.PASSIVE,unit=8),
            Pin(num='H19',name='Pin_19',func=pin_types.PASSIVE,unit=8),
            Pin(num='H2',name='Pin_2',func=pin_types.PASSIVE,unit=8),
            Pin(num='H20',name='Pin_20',func=pin_types.PASSIVE,unit=8),
            Pin(num='H21',name='Pin_21',func=pin_types.PASSIVE,unit=8),
            Pin(num='H22',name='Pin_22',func=pin_types.PASSIVE,unit=8),
            Pin(num='H23',name='Pin_23',func=pin_types.PASSIVE,unit=8),
            Pin(num='H24',name='Pin_24',func=pin_types.PASSIVE,unit=8),
            Pin(num='H25',name='Pin_25',func=pin_types.PASSIVE,unit=8),
            Pin(num='H26',name='Pin_26',func=pin_types.PASSIVE,unit=8),
            Pin(num='H27',name='Pin_27',func=pin_types.PASSIVE,unit=8),
            Pin(num='H28',name='Pin_28',func=pin_types.PASSIVE,unit=8),
            Pin(num='H29',name='Pin_29',func=pin_types.PASSIVE,unit=8),
            Pin(num='H3',name='Pin_3',func=pin_types.PASSIVE,unit=8),
            Pin(num='H30',name='Pin_30',func=pin_types.PASSIVE,unit=8),
            Pin(num='H31',name='Pin_31',func=pin_types.PASSIVE,unit=8),
            Pin(num='H32',name='Pin_32',func=pin_types.PASSIVE,unit=8),
            Pin(num='H33',name='Pin_33',func=pin_types.PASSIVE,unit=8),
            Pin(num='H34',name='Pin_34',func=pin_types.PASSIVE,unit=8),
            Pin(num='H35',name='Pin_35',func=pin_types.PASSIVE,unit=8),
            Pin(num='H36',name='Pin_36',func=pin_types.PASSIVE,unit=8),
            Pin(num='H37',name='Pin_37',func=pin_types.PASSIVE,unit=8),
            Pin(num='H38',name='Pin_38',func=pin_types.PASSIVE,unit=8),
            Pin(num='H39',name='Pin_39',func=pin_types.PASSIVE,unit=8),
            Pin(num='H4',name='Pin_4',func=pin_types.PASSIVE,unit=8),
            Pin(num='H40',name='Pin_40',func=pin_types.PASSIVE,unit=8),
            Pin(num='H5',name='Pin_5',func=pin_types.PASSIVE,unit=8),
            Pin(num='H6',name='Pin_6',func=pin_types.PASSIVE,unit=8),
            Pin(num='H7',name='Pin_7',func=pin_types.PASSIVE,unit=8),
            Pin(num='H8',name='Pin_8',func=pin_types.PASSIVE,unit=8),
            Pin(num='H9',name='Pin_9',func=pin_types.PASSIVE,unit=8),
            Pin(num='J1',name='Pin_1',func=pin_types.PASSIVE,unit=9),
            Pin(num='J10',name='Pin_10',func=pin_types.PASSIVE,unit=9),
            Pin(num='J11',name='Pin_11',func=pin_types.PASSIVE,unit=9),
            Pin(num='J12',name='Pin_12',func=pin_types.PASSIVE,unit=9),
            Pin(num='J13',name='Pin_13',func=pin_types.PASSIVE,unit=9),
            Pin(num='J14',name='Pin_14',func=pin_types.PASSIVE,unit=9),
            Pin(num='J15',name='Pin_15',func=pin_types.PASSIVE,unit=9),
            Pin(num='J16',name='Pin_16',func=pin_types.PASSIVE,unit=9),
            Pin(num='J17',name='Pin_17',func=pin_types.PASSIVE,unit=9),
            Pin(num='J18',name='Pin_18',func=pin_types.PASSIVE,unit=9),
            Pin(num='J19',name='Pin_19',func=pin_types.PASSIVE,unit=9),
            Pin(num='J2',name='Pin_2',func=pin_types.PASSIVE,unit=9),
            Pin(num='J20',name='Pin_20',func=pin_types.PASSIVE,unit=9),
            Pin(num='J21',name='Pin_21',func=pin_types.PASSIVE,unit=9),
            Pin(num='J22',name='Pin_22',func=pin_types.PASSIVE,unit=9),
            Pin(num='J23',name='Pin_23',func=pin_types.PASSIVE,unit=9),
            Pin(num='J24',name='Pin_24',func=pin_types.PASSIVE,unit=9),
            Pin(num='J25',name='Pin_25',func=pin_types.PASSIVE,unit=9),
            Pin(num='J26',name='Pin_26',func=pin_types.PASSIVE,unit=9),
            Pin(num='J27',name='Pin_27',func=pin_types.PASSIVE,unit=9),
            Pin(num='J28',name='Pin_28',func=pin_types.PASSIVE,unit=9),
            Pin(num='J29',name='Pin_29',func=pin_types.PASSIVE,unit=9),
            Pin(num='J3',name='Pin_3',func=pin_types.PASSIVE,unit=9),
            Pin(num='J30',name='Pin_30',func=pin_types.PASSIVE,unit=9),
            Pin(num='J31',name='Pin_31',func=pin_types.PASSIVE,unit=9),
            Pin(num='J32',name='Pin_32',func=pin_types.PASSIVE,unit=9),
            Pin(num='J33',name='Pin_33',func=pin_types.PASSIVE,unit=9),
            Pin(num='J34',name='Pin_34',func=pin_types.PASSIVE,unit=9),
            Pin(num='J35',name='Pin_35',func=pin_types.PASSIVE,unit=9),
            Pin(num='J36',name='Pin_36',func=pin_types.PASSIVE,unit=9),
            Pin(num='J37',name='Pin_37',func=pin_types.PASSIVE,unit=9),
            Pin(num='J38',name='Pin_38',func=pin_types.PASSIVE,unit=9),
            Pin(num='J39',name='Pin_39',func=pin_types.PASSIVE,unit=9),
            Pin(num='J4',name='Pin_4',func=pin_types.PASSIVE,unit=9),
            Pin(num='J40',name='Pin_40',func=pin_types.PASSIVE,unit=9),
            Pin(num='J5',name='Pin_5',func=pin_types.PASSIVE,unit=9),
            Pin(num='J6',name='Pin_6',func=pin_types.PASSIVE,unit=9),
            Pin(num='J7',name='Pin_7',func=pin_types.PASSIVE,unit=9),
            Pin(num='J8',name='Pin_8',func=pin_types.PASSIVE,unit=9),
            Pin(num='J9',name='Pin_9',func=pin_types.PASSIVE,unit=9),
            Pin(num='K1',name='Pin_1',func=pin_types.PASSIVE,unit=10),
            Pin(num='K10',name='Pin_10',func=pin_types.PASSIVE,unit=10),
            Pin(num='K11',name='Pin_11',func=pin_types.PASSIVE,unit=10),
            Pin(num='K12',name='Pin_12',func=pin_types.PASSIVE,unit=10),
            Pin(num='K13',name='Pin_13',func=pin_types.PASSIVE,unit=10),
            Pin(num='K14',name='Pin_14',func=pin_types.PASSIVE,unit=10),
            Pin(num='K15',name='Pin_15',func=pin_types.PASSIVE,unit=10),
            Pin(num='K16',name='Pin_16',func=pin_types.PASSIVE,unit=10),
            Pin(num='K17',name='Pin_17',func=pin_types.PASSIVE,unit=10),
            Pin(num='K18',name='Pin_18',func=pin_types.PASSIVE,unit=10),
            Pin(num='K19',name='Pin_19',func=pin_types.PASSIVE,unit=10),
            Pin(num='K2',name='Pin_2',func=pin_types.PASSIVE,unit=10),
            Pin(num='K20',name='Pin_20',func=pin_types.PASSIVE,unit=10),
            Pin(num='K21',name='Pin_21',func=pin_types.PASSIVE,unit=10),
            Pin(num='K22',name='Pin_22',func=pin_types.PASSIVE,unit=10),
            Pin(num='K23',name='Pin_23',func=pin_types.PASSIVE,unit=10),
            Pin(num='K24',name='Pin_24',func=pin_types.PASSIVE,unit=10),
            Pin(num='K25',name='Pin_25',func=pin_types.PASSIVE,unit=10),
            Pin(num='K26',name='Pin_26',func=pin_types.PASSIVE,unit=10),
            Pin(num='K27',name='Pin_27',func=pin_types.PASSIVE,unit=10),
            Pin(num='K28',name='Pin_28',func=pin_types.PASSIVE,unit=10),
            Pin(num='K29',name='Pin_29',func=pin_types.PASSIVE,unit=10),
            Pin(num='K3',name='Pin_3',func=pin_types.PASSIVE,unit=10),
            Pin(num='K30',name='Pin_30',func=pin_types.PASSIVE,unit=10),
            Pin(num='K31',name='Pin_31',func=pin_types.PASSIVE,unit=10),
            Pin(num='K32',name='Pin_32',func=pin_types.PASSIVE,unit=10),
            Pin(num='K33',name='Pin_33',func=pin_types.PASSIVE,unit=10),
            Pin(num='K34',name='Pin_34',func=pin_types.PASSIVE,unit=10),
            Pin(num='K35',name='Pin_35',func=pin_types.PASSIVE,unit=10),
            Pin(num='K36',name='Pin_36',func=pin_types.PASSIVE,unit=10),
            Pin(num='K37',name='Pin_37',func=pin_types.PASSIVE,unit=10),
            Pin(num='K38',name='Pin_38',func=pin_types.PASSIVE,unit=10),
            Pin(num='K39',name='Pin_39',func=pin_types.PASSIVE,unit=10),
            Pin(num='K4',name='Pin_4',func=pin_types.PASSIVE,unit=10),
            Pin(num='K40',name='Pin_40',func=pin_types.PASSIVE,unit=10),
            Pin(num='K5',name='Pin_5',func=pin_types.PASSIVE,unit=10),
            Pin(num='K6',name='Pin_6',func=pin_types.PASSIVE,unit=10),
            Pin(num='K7',name='Pin_7',func=pin_types.PASSIVE,unit=10),
            Pin(num='K8',name='Pin_8',func=pin_types.PASSIVE,unit=10),
            Pin(num='K9',name='Pin_9',func=pin_types.PASSIVE,unit=10)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['A1', 'A23', 'A34', 'A27', 'A18', 'A29', 'A2', 'A7', 'A28', 'A35', 'A30', 'A15', 'A24', 'A3', 'A19', 'A37', 'A40', 'A14', 'A25', 'A26', 'A22', 'A31', 'A32', 'A5', 'A33', 'A20', 'A13', 'A8', 'A4', 'A6', 'A39', 'A12', 'A21', 'A10', 'A11', 'A16', 'A36', 'A9', 'A38', 'A17']},{'label': 'uB', 'num': 2, 'pin_nums': ['B26', 'B30', 'B25', 'B5', 'B8', 'B2', 'B9', 'B18', 'B40', 'B22', 'B39', 'B19', 'B38', 'B12', 'B24', 'B20', 'B21', 'B23', 'B32', 'B14', 'B3', 'B27', 'B6', 'B10', 'B33', 'B36', 'B15', 'B28', 'B29', 'B16', 'B1', 'B7', 'B37', 'B11', 'B13', 'B31', 'B34', 'B4', 'B35', 'B17']},{'label': 'uC', 'num': 3, 'pin_nums': ['C24', 'C18', 'C25', 'C29', 'C21', 'C12', 'C33', 'C30', 'C34', 'C22', 'C28', 'C16', 'C26', 'C6', 'C15', 'C3', 'C9', 'C4', 'C31', 'C27', 'C2', 'C39', 'C5', 'C37', 'C20', 'C32', 'C35', 'C36', 'C40', 'C7', 'C11', 'C38', 'C13', 'C23', 'C8', 'C1', 'C19', 'C10', 'C14', 'C17']},{'label': 'uD', 'num': 4, 'pin_nums': ['D33', 'D11', 'D40', 'D34', 'D5', 'D12', 'D24', 'D35', 'D6', 'D36', 'D7', 'D2', 'D4', 'D8', 'D1', 'D37', 'D28', 'D20', 'D22', 'D23', 'D16', 'D21', 'D38', 'D9', 'D17', 'D29', 'D19', 'D3', 'D15', 'D10', 'D30', 'D13', 'D31', 'D39', 'D26', 'D14', 'D25', 'D32', 'D18', 'D27']},{'label': 'uE', 'num': 5, 'pin_nums': ['E11', 'E31', 'E7', 'E21', 'E4', 'E12', 'E34', 'E6', 'E24', 'E17', 'E13', 'E26', 'E33', 'E27', 'E23', 'E9', 'E16', 'E28', 'E36', 'E19', 'E8', 'E14', 'E35', 'E15', 'E25', 'E18', 'E38', 'E39', 'E30', 'E20', 'E1', 'E37', 'E3', 'E2', 'E5', 'E10', 'E32', 'E29', 'E22', 'E40']},{'label': 'uF', 'num': 6, 'pin_nums': ['F27', 'F19', 'F25', 'F31', 'F4', 'F7', 'F6', 'F21', 'F8', 'F32', 'F39', 'F20', 'F26', 'F33', 'F9', 'F23', 'F16', 'F34', 'F22', 'F15', 'F10', 'F24', 'F35', 'F28', 'F18', 'F1', 'F14', 'F40', 'F29', 'F36', 'F17', 'F12', 'F13', 'F37', 'F3', 'F38', 'F2', 'F5', 'F11', 'F30']},{'label': 'uG', 'num': 7, 'pin_nums': ['G5', 'G28', 'G20', 'G16', 'G7', 'G40', 'G21', 'G19', 'G31', 'G4', 'G35', 'G22', 'G9', 'G39', 'G33', 'G1', 'G23', 'G38', 'G17', 'G24', 'G14', 'G36', 'G10', 'G26', 'G13', 'G29', 'G18', 'G11', 'G27', 'G30', 'G25', 'G15', 'G37', 'G3', 'G32', 'G8', 'G12', 'G34', 'G2', 'G6']},{'label': 'uH', 'num': 8, 'pin_nums': ['H25', 'H40', 'H32', 'H2', 'H12', 'H26', 'H4', 'H22', 'H34', 'H13', 'H20', 'H27', 'H9', 'H33', 'H6', 'H28', 'H5', 'H10', 'H15', 'H29', 'H7', 'H11', 'H37', 'H16', 'H14', 'H3', 'H36', 'H17', 'H23', 'H30', 'H39', 'H18', 'H35', 'H21', 'H8', 'H38', 'H24', 'H1', 'H31', 'H19']},{'label': 'uI', 'num': 9, 'pin_nums': ['J25', 'J28', 'J21', 'J9', 'J37', 'J30', 'J20', 'J3', 'J4', 'J16', 'J1', 'J23', 'J32', 'J39', 'J15', 'J22', 'J24', 'J10', 'J31', 'J18', 'J5', 'J14', 'J38', 'J11', 'J40', 'J35', 'J17', 'J36', 'J27', 'J34', 'J6', 'J12', 'J7', 'J26', 'J33', 'J2', 'J29', 'J13', 'J19', 'J8']},{'label': 'uJ', 'num': 10, 'pin_nums': ['K26', 'K37', 'K30', 'K40', 'K20', 'K16', 'K25', 'K5', 'K3', 'K1', 'K11', 'K12', 'K2', 'K34', 'K15', 'K6', 'K10', 'K24', 'K29', 'K7', 'K36', 'K19', 'K33', 'K35', 'K4', 'K23', 'K8', 'K28', 'K9', 'K39', 'K32', 'K14', 'K22', 'K18', 'K38', 'K27', 'K17', 'K31', 'K21', 'K13']}] }),
        Part(**{ 'name':'USB_B_Mini', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USB_B_Mini'}), 'ref_prefix':'J', 'fplist':['', ''], 'footprint':'', 'keywords':'connector USB mini', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector.kicad_sym\nUSB_B_Mini\n\nconnector USB mini', 'pins':[
            Pin(num='1',name='VBUS',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='ID',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='Shield',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] })])