from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Interface_USB = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'ADUM4160', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADUM4160'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'usb isolation', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADuM4160.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nADUM4160\n\nusb isolation', 'pins':[
            Pin(num='1',name='VBUS1',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='DD+',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='DD-',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SPD',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VDD2',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND2',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VBUS2',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND1',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD1',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PDEN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SPU',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='UD-',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='UD+',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND1',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='GND2',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AP33771', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AP33771'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.7x2.7mm', 'keywords':'USB Type C PD Sink', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/AP33771.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nAP33771\n\nUSB Type C PD Sink', 'pins':[
            Pin(num='1',name='ISENP',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='VSEL2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='V3VD',func=pin_types.PWROUT,unit=1),
            Pin(num='13',name='PSEL',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VFB',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='IFB',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='20',name='V5V',func=pin_types.PWROUT,unit=1),
            Pin(num='21',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PWR_EN',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='GPIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VSEL1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSEL0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BQ24392', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BQ24392'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_R-PUQFN-N10'], 'footprint':'Package_DFN_QFN:Texas_R-PUQFN-N10', 'keywords':'USB BC detector charger', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/bq24392.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nBQ24392\n\nUSB BC detector charger', 'pins':[
            Pin(num='1',name='SW_OPEN',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='CHG_DET',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='DM_HOST',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='DP_HOST',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{CHG_AL}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='GOOD_BAT',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='DP_CON',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DM_CON',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VBUS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CH224K', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CH224K'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-10-1EP_3.9x4.9mm_P1mm_EP2.1x3.3mm'], 'footprint':'Package_SO:SSOP-10-1EP_3.9x4.9mm_P1mm_EP2.1x3.3mm', 'keywords':'USB-C WCH powered-device', 'description':'', 'datasheet':'https://www.wch.cn/downloads/file/301.html', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCH224K\n\nUSB-C WCH powered-device', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PG',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CFG2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='CFG3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='DP',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='DM',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='CFG1',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CH236D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CH236D'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_3x3mm_P0.4mm_EP1.65x1.65mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_3x3mm_P0.4mm_EP1.65x1.65mm', 'keywords':'USB PD', 'description':'', 'datasheet':'https://wch-ic.com/downloads/file/313.html', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCH236D\n\nUSB PD', 'pins':[
            Pin(num='0',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='1',name='FBOX',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='IS+',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='IS-',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='VFB',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='IFB',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VHV',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='FBO',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='GATEP',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='GATEN',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{NMOS}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='UD+',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='UD-',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CH246D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CH246D'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_3x3mm_P0.4mm_EP1.65x1.65mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_3x3mm_P0.4mm_EP1.65x1.65mm', 'keywords':'USB PD QII', 'description':'', 'datasheet':'https://wch-ic.com/downloads/file/307.html', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCH246D\n\nUSB PD QII', 'pins':[
            Pin(num='0',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='CC0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='LV0',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='LV1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='IS+',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='IS-',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='QII',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='LED1',func=pin_types.OPENEMIT,unit=1),
            Pin(num='18',name='NTC',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='OSC',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='VHV',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='LED0',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='HV1',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='HV0P',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='HV0N',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='UDP',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='UDM',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CH330N', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CH330N'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'usb uart wch serial', 'description':'', 'datasheet':'http://www.wch.cn/downloads/file/240.html', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCH330N\n\nusb uart wch serial', 'pins':[
            Pin(num='1',name='UD+',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='UD-',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~{RTS}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='V3',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CH334R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CH334R'}), 'ref_prefix':'U', 'fplist':['Package_SO:QSOP-16_3.9x4.9mm_P0.635mm'], 'footprint':'Package_SO:QSOP-16_3.9x4.9mm_P0.635mm', 'keywords':'USB HUB Controller Interface', 'description':'', 'datasheet':'https://www.wch-ic.com/downloads/file/327.html', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCH334R\n\nUSB HUB Controller Interface', 'pins':[
            Pin(num='1',name='DM4-',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='DMU-',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='DPU+',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='V5',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDD33',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='XO',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='XI',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='DP4+',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='DM3-',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='DP3+',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='DM2-',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='DP2+',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='DM1-',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DP1+',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RESET}/CDP',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CH340C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CH340C'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'USB UART Serial Converter Interface', 'description':'', 'datasheet':'https://datasheet.lcsc.com/szlcsc/Jiangsu-Qin-Heng-CH340C_C84681.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCH340C\n\nUSB UART Serial Converter Interface', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{DSR}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{RI}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{DCD}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{DTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='~{RTS}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='R232',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V3',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='UD+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='UD-',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='~{CTS}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CH340E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CH340E'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:MSOP-10_3x3mm_P0.5mm', 'keywords':'USB UART Serial Converter Interface', 'description':'', 'datasheet':'https://www.mpja.com/download/35227cpdata.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCH340E\n\nUSB UART Serial Converter Interface', 'pins':[
            Pin(num='1',name='UD+',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='V3',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='UD-',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~{RTS}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='~{CTS}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='TNOW',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='RXD',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CH340G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CH340G'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'USB UART Serial Converter Interface', 'description':'', 'datasheet':'http://www.datasheet5.com/pdf-local-2195953', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCH340G\n\nUSB UART Serial Converter Interface', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{DSR}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{RI}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{DCD}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{DTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='~{RTS}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='R232',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V3',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='UD+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='UD-',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='XI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='XO',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~{CTS}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CH340K', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CH340K'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-10-1EP_3.9x4.9mm_P1mm_EP2.1x3.3mm'], 'footprint':'Package_SO:SSOP-10-1EP_3.9x4.9mm_P1mm_EP2.1x3.3mm', 'keywords':'USB UART Serial Converter Interface', 'description':'', 'datasheet':'https://cdn.sparkfun.com/assets/5/0/a/8/5/CH340DS1.PDF', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCH340K\n\nUSB UART Serial Converter Interface', 'pins':[
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='UD+',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='V3',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='UD-',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~{DTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='~{CTS}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{RTS}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='RXD',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CH340T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CH340T'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-20_5.3x7.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'keywords':'USB UART Serial Converter Interface', 'description':'', 'datasheet':'https://cdn.sparkfun.com/datasheets/Dev/Arduino/Other/CH340DS1.PDF', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCH340T\n\nUSB UART Serial Converter Interface', 'pins':[
            Pin(num='1',name='CKOH',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='XO',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~{CTS}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{DSR}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{RI}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{DCD}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{DTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='~{RTS}',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='R232',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CKOL',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='~{NOS}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='V3',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='UD+',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='UD-',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='XI',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CH340X', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CH340X'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:MSOP-10_3x3mm_P0.5mm', 'keywords':'USB UART Serial Converter Interface', 'description':'', 'datasheet':'https://cdn.sparkfun.com/assets/5/0/a/8/5/CH340DS1.PDF', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCH340X\n\nUSB UART Serial Converter Interface', 'pins':[
            Pin(num='1',name='UD+',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='V3',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='UD-',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~{RTS}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='~{CTS}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='TNOW/~{DTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='RXD',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CH343G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CH343G'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'UART Interface crystalless', 'description':'', 'datasheet':'https://datasheet.lcsc.com/lcsc/2204111415_WCH-Jiangsu-Qin-Heng-CH343G_C2844153.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCH343G\n\nUART Interface crystalless', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{DTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~{RTS}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='~{DSR}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{CTS}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{RI}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='VIO',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD5',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V3',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='UD+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='UD-',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~{ACT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~{DCD}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CH344Q', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CH344Q'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'USB Quad UART Serial Converter Interface', 'description':'', 'datasheet':'https://www.wch-ic.com/downloads/file/299.html', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCH344Q\n\nUSB Quad UART Serial Converter Interface', 'pins':[
            Pin(num='19',name='~{DTR2}/TNOW2/GPIO9',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='~{CTS1}/GPIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='~{RTS1}/GPIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TXD1',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='RXD1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{ACT}/~{CFG}/~{DCD3}',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TX_S/~{RI3}',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RX_S/~{DSR3}',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='~{DSR1}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{DTR1}/TNOW1/GPIO9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='~{DSR2}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='TXD2',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='RXD2',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='~{RI1}',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='~{CTS2}/GPIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='~{RTS2}/GPIO5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='~{DCD1}/GPIO15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{DSR0}/GPIO14',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{RI2}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='TXD0',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='RXD0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='~{RI0}/GPIO13',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='~{DCD0}/GPIO12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='~{DTR3}/TNOW3/GPIO11',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='TXD3',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='RXD3',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='~{DTR0}/TNOW0/GPIO8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{DCD2}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='~{RTS0}/GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='~{CTS0}/GPIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='UD-',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='UD+',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='~{RTS3}/GPIO7',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='~{CTS3}/GPIO6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='XO',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CH9102F', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CH9102F'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'uart usb bridge interface transceiver CH9102F', 'description':'', 'datasheet':'http://www.wch-ic.com/downloads/CH9102DS1_PDF.html', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCH9102F\n\nuart usb bridge interface transceiver CH9102F', 'pins':[
            Pin(num='1',name='~{RI}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{ACT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~{WAKEUP}/GPIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TNOW/GPIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RXS/GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TXS/GPIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='~{SUSPEND}',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='GPIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SUSPEND',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='~{CTS}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{RTS}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='~{DSR}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{DTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='~{DCD}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VIO',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='V3',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='VDD5',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{RST}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CP2102N-Axx-xQFN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CP2102N-Axx-xQFN20'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:SiliconLabs_QFN-20-1EP_3x3mm_P0.5mm'], 'footprint':'Package_DFN_QFN:SiliconLabs_QFN-20-1EP_3x3mm_P0.5mm', 'keywords':'USB UART bridge', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/cp2102n-datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCP2102N-Axx-xQFN20\n\nUSB UART bridge', 'pins':[
            Pin(num='1',name='RS485/GPIO.1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='~{SUSPEND}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='~{WAKEUP}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SUSPEND',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~{CTS}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='~{RTS}',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='~{RXT}/GPIO.3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='CLK/GPIO.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{TXT}/GPIO.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{RST}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CP2102N-Axx-xQFN24', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CP2102N-Axx-xQFN24'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'USB UART bridge', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/cp2102n-datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCP2102N-Axx-xQFN24\n\nUSB UART bridge', 'pins':[
            Pin(num='1',name='~{RI}/CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='~{WAKEUP}/GPIO.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RS485/GPIO.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RXT}/GPIO.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='~{TXT}/GPIO.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='~{SUSPEND}',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='SUSPEND',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='~{CTS}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{RTS}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='~{DSR}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{DTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='~{DCD}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VIO',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{RST}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CP2102N-Axx-xQFN28', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CP2102N-Axx-xQFN28'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_5x5mm_P0.5mm_EP3.35x3.35mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_5x5mm_P0.5mm_EP3.35x3.35mm', 'keywords':'USB UART bridge', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/cp2102n-datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCP2102N-Axx-xQFN28\n\nUSB UART bridge', 'pins':[
            Pin(num='1',name='~{DCD}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='~{SUSPEND}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='SUSPEND',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='CHREN',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='CHR1',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='CHR0',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='~{WAKEUP}/GPIO.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RS485/GPIO.2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='~{RXT}/GPIO.1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='~{TXT}/GPIO.0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='~{RI}/CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GPIO.6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GPIO.5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='GPIO.4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='~{CTS}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='~{RTS}',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='~{DSR}',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='~{DTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{RST}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CP2104', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CP2104'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'uart usb bridge interface transceiver', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/cp2104.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCP2104\n\nuart usb bridge interface transceiver', 'pins':[
            Pin(num='1',name='~{RI}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='GPIO.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RS485/GPIO.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RXT/GPIO.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TXT/GPIO.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='~{SUSPEND}',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VPP',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='SUSPEND',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='~{CTS}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{RTS}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='~{DSR}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{DTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='~{DCD}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VIO',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='REGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{RST}',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CP2108-xxx-xM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CP2108-xxx-xM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP4.1x4.1mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP4.1x4.1mm', 'keywords':'USB Quad UART FIFO bridge', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/cp2108-datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCP2108-xxx-xM\n\nUSB Quad UART FIFO bridge', 'pins':[
            Pin(num='1',name='RX3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{DTR3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~{RI2}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{DCD2}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{CTS2}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{RTS2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='RX2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='TX2',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='~{DSR2}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{DTR2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='~{SUSPEND}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VSSHD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='SUSPEND',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='GPIO15',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='GPIO14',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='GPIO13',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VIO',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='GPIO12',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='GPIO11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='GPIO10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='GPIO9',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VIOHD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='GPIO8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='GPIO7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='GPIO6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GPIO5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GPIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='GPIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GPIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='TX3',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='GPIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='~{RI1}',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='~{DCD1}',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='~{DSR1}',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='~{DTR1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='~{CTS1}',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='~{RTS1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='RX1',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='TX1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='~{CTS3}',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='~{RI0}',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='~{DCD0}',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='~{DSR0}',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='~{DTR0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='54',name='~{CTS0}',func=pin_types.INPUT,unit=1),
            Pin(num='55',name='~{RTS0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='56',name='RX0',func=pin_types.INPUT,unit=1),
            Pin(num='57',name='TX0',func=pin_types.OUTPUT,unit=1),
            Pin(num='58',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='59',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~{RTS3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='60',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='61',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='62',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~{RI3}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{DCD3}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{DSR3}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CP2112', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CP2112'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'USB SMBUS bridge', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/cp2112-datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCP2112\n\nUSB SMBUS bridge', 'pins':[
            Pin(num='1',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='SUSPEND',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='GPIO.7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GPIO.6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GPIO.5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GPIO.4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VPP',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='~{SUSPEND}',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='GPIO.3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GPIO.2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='GPIO.1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='GPIO.0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='SCL',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VIO',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='REGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{RST}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CP2615-xx-xM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CP2615-xx-xM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.3x3.3mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.3x3.3mm', 'keywords':'usb i2s i2c uart audio bridge hid gpio', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/cp2615-datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCP2615-xx-xM\n\nusb i2s i2c uart audio bridge hid gpio', 'pins':[
            Pin(num='1',name='I2S_SDIN',func=pin_types.INPUT),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT),
            Pin(num='11',name='GPIO.7',func=pin_types.BIDIR),
            Pin(num='12',name='GPIO.6',func=pin_types.BIDIR),
            Pin(num='2',name='I2S_SCLK',func=pin_types.OUTPUT),
            Pin(num='21',name='~{CFGMODE}',func=pin_types.INPUT),
            Pin(num='22',name='GPIO.10/~{RESETOUT}',func=pin_types.BIDIR),
            Pin(num='23',name='GPIO.14/RX',func=pin_types.BIDIR),
            Pin(num='24',name='GPIO.13/TX',func=pin_types.BIDIR),
            Pin(num='25',name='GPIO.12/CLKOUT',func=pin_types.BIDIR),
            Pin(num='26',name='I2S_MCLK',func=pin_types.OUTPUT),
            Pin(num='27',name='GPIO.11/RTS',func=pin_types.BIDIR),
            Pin(num='28',name='I2S_LRCLK',func=pin_types.OUTPUT),
            Pin(num='29',name='I2C_SCL',func=pin_types.BIDIR),
            Pin(num='3',name='GND',func=pin_types.PWRIN),
            Pin(num='30',name='I2C_SDA',func=pin_types.BIDIR),
            Pin(num='31',name='GPIO.15/CTS',func=pin_types.BIDIR),
            Pin(num='32',name='I2S_SDOUT',func=pin_types.OUTPUT),
            Pin(num='4',name='D+',func=pin_types.BIDIR),
            Pin(num='5',name='D-',func=pin_types.BIDIR),
            Pin(num='6',name='VDD',func=pin_types.PWRIN),
            Pin(num='7',name='REGIN',func=pin_types.PWRIN),
            Pin(num='8',name='VBUS',func=pin_types.INPUT),
            Pin(num='9',name='~{RST}',func=pin_types.BIDIR),
            Pin(num='13',name='GPIO.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GPIO.4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GPIO.3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GPIO.2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='GPIO.1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GPIO.0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='GPIO.9/BUTTONS',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GPIO.8/ADC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY7C65211-24LTXI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY7C65211-24LTXI'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'USB-Serial single channel bridge', 'description':'', 'datasheet':'http://www.cypress.com/file/139886/download', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCY7C65211-24LTXI\n\nUSB-Serial single channel bridge', 'pins':[
            Pin(num='1',name='SCB_0/GPIO_6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='USBDM',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VCCD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='~{XRES}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='VBUS',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='GPIO_0',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='GPIO_1',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='SCB_5/GPIO_7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='SCB_1/GPIO_2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='SCB_2/GPIO_3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='SCB_3/GPIO_4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='SCB_4/GPIO_5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='1EP',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GPIO_8',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='GPIO_9',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='GPIO_10',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='GPIO_11',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='SUSPEND',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='WAKEUP',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY7C65213-28PVXI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY7C65213-28PVXI'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-28_5.3x10.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'keywords':'USB-UART LP Bridge Controller, full speed 12Mbps', 'description':'', 'datasheet':'http://www.cypress.com/file/139881/download', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCY7C65213-28PVXI\n\nUSB-UART LP Bridge Controller, full speed 12Mbps', 'pins':[
            Pin(num='1',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='DCD',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CTS',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='GPIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GPIO2',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='GPIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='USBDM',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCCD',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='DTR',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='GPIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='26',name='DNU',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='GPIO6',func=pin_types.TRISTATE,unit=1),
            Pin(num='28',name='GPIO7',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='RTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='RI',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GPIO5',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='DSR',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY7C65213-32LTXI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY7C65213-32LTXI'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'USB-UART LP Bridge Controller, full speed 12Mbps', 'description':'', 'datasheet':'http://www.cypress.com/file/139881/download', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCY7C65213-32LTXI\n\nUSB-UART LP Bridge Controller, full speed 12Mbps', 'pins':[
            Pin(num='1',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GPIO2',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='GPIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GPIO6',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='GPIO7',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='USBDM',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VCCD',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='GPIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='DNU',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='DNU',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='DNU',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='DNU',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='DNU',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='DNU',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RI',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='DTR',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='RTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='1EP',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GPIO5',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='DSR',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='DCD',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='CTS',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='GPIO4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY7C65215-32LTXI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY7C65215-32LTXI'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'USB-Serial single channel bridge', 'description':'', 'datasheet':'http://www.cypress.com/file/129956/download', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCY7C65215-32LTXI\n\nUSB-Serial single channel bridge', 'pins':[
            Pin(num='1',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SCB1_5/GPIO_15',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SUSPEND',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='WAKEUP',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GPIO_16',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='USBDM',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VCCD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='~{XRES}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='VBUS',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='SCB0_0/GPIO_8',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GPIO_17',func=pin_types.TRISTATE,unit=1),
            Pin(num='22',name='GPIO_18',func=pin_types.TRISTATE,unit=1),
            Pin(num='23',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='GPIO_0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='GPIO_1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='SCB0_1/GPIO_2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='SCB0_2/GPIO_3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='SCB0_3/GPIO_4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='SCB0_5/GPIO_9',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='SCB0_4/GPIO_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='GPIO_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='GPIO_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='1EP',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SCB1_0/GPIO_10',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCB1_1/GPIO_11',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SCB1_2/GPIO_12',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SCB1_3/GPIO_13',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SCB1_4/GPIO_14',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CYPD3171-24LQXQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CYPD3171-24LQXQ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.75x2.75mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.75x2.75mm', 'keywords':'USBPD Quickcharge', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-EZ-PD(TM)_CCG3PA_Datasheet_USB_Type-C_Port_Controller-DataSheet-v09_00-EN.pdf?fileId=8ac78c8c7d0d8da4017d0ee438366ac0', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCYPD3171-24LQXQ\n\nUSBPD Quickcharge', 'pins':[
            Pin(num='1',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VBUS_C_MON_DIS',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='DM0/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='DP0/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VBUS_IN_DIS',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='CSP',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='FB',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='COMP',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VBUS_P_CTRL',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='VBUS_C_CTRL',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='DP1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='DM1/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P0.0/SWD_DAT_0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P0.1/SWD_CLK_0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.0/AXRES',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CYPD3174-16SXQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CYPD3174-16SXQ'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'USBPD quickcharge', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-EZ-PD(TM)_CCG3PA_Datasheet_USB_Type-C_Port_Controller-DataSheet-v09_00-EN.pdf?fileId=8ac78c8c7d0d8da4017d0ee438366ac0', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCYPD3174-16SXQ\n\nUSBPD quickcharge', 'pins':[
            Pin(num='1',name='FB',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='DM0/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='DP0/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VBUS_IN_DIS',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='CSP',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='COMP',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='VBUS_P_CTRL',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='P0.0/SWD_DAT_0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P0.1/SWD_CLK_0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/AXRES',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VBUS_C_MON_DIS',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CYPD3177-24LQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CYPD3177-24LQ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.75x2.75mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.75x2.75mm', 'keywords':'usb pd type csink', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-EZ-PD_BCR_Datasheet_USB_Type-C_Port_Controller_for_Power_Sinks-DataSheet-v03_00-EN.pdf?fileId=8ac78c8c7d0d8da4017d0ee7ce9d70ad', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCYPD3177-24LQ\n\nusb pd type csink', 'pins':[
            Pin(num='1',name='VBUS_MIN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='FLIP',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='VDC_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='HPI_SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='HPI_SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='VBUS_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VBUS_MAX',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDDD',func=pin_types.PWROUT,unit=1),
            Pin(num='24',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VBUS_FET_EN',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='SAFE_PWR_EN',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='ISNK_COARSE',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='ISNK_FINE',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{HPI_INT}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GPIO_1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='FAULT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FE1.1s', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FE1.1s'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-28_3.9x9.9mm_P0.635mm'], 'footprint':'Package_SO:SSOP-28_3.9x9.9mm_P0.635mm', 'keywords':'4-Port, EEPROM, High Speed, Hub, USB2.0', 'description':'', 'datasheet':'https://cdn-shop.adafruit.com/product-files/2991/FE1.1s+Data+Sheet+(Rev.+1.0).pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFE1.1s\n\n4-Port, EEPROM, High Speed, Hub, USB2.0', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VD18_O',func=pin_types.PWROUT,unit=1),
            Pin(num='13',name='VD33',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='REXT',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='DMU',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='DPU',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='~{XRSTJ}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VBUSM',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='BUSJ',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='VDD5',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VD33_O',func=pin_types.PWROUT,unit=1),
            Pin(num='22',name='DRV',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='LED1/EESCL',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='LED2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PWRJ',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='OVCJ',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='TESTJ/EESDA',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VD18',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='DM4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='DP4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='DM3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='DP3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='DP2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FSUSB30MUX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FSUSB30MUX'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:MSOP-10_3x3mm_P0.5mm', 'keywords':'USB 2.0 High Speed Switch', 'description':'', 'datasheet':'https://www.onsemi.com/pdf/datasheet/fsusb30-d.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFSUSB30MUX\n\nUSB 2.0 High Speed Switch', 'pins':[
            Pin(num='1',name='S',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='HSD1+',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='HSD2+',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='HSD2-',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='HSD1-',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{OE}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FSUSB42MUX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FSUSB42MUX'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:MSOP-10_3x3mm_P0.5mm', 'keywords':'USB 2.0 UART High Speed Switch', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/FSUSB42-D.PDF', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFSUSB42MUX\n\nUSB 2.0 UART High Speed Switch', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='SEL',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='HSD1-',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='HSD1+',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='HSD2-',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='HSD2+',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FT200XD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FT200XD'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-10-1EP_3x3mm_P0.5mm_EP1.55x2.48mm'], 'footprint':'Package_DFN_QFN:DFN-10-1EP_3x3mm_P0.5mm_EP1.55x2.48mm', 'keywords':'FTDI USB I2C Interface Converter', 'description':'', 'datasheet':'https://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT200XD.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFT200XD\n\nFTDI USB I2C Interface Converter', 'pins':[
            Pin(num='1',name='USBDM',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='USBDP',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='3V3OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='CBUS0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FT201XQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FT201XQ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-16-1EP_4x4mm_P0.65mm_EP2.1x2.1mm'], 'footprint':'Package_DFN_QFN:QFN-16-1EP_4x4mm_P0.65mm_EP2.1x2.1mm', 'keywords':'FTDI USB I2C interface Converter', 'description':'', 'datasheet':'https://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT201X.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFT201XQ\n\nFTDI USB I2C interface Converter', 'pins':[
            Pin(num='1',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='CBUS1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='CBUS0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='CBUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='CBUS5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='CBUS4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CBUS2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='USBDM',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='3V3OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FT201XS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FT201XS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-16_3.9x4.9mm_P0.635mm'], 'footprint':'Package_SO:SSOP-16_3.9x4.9mm_P0.635mm', 'keywords':'FTDI USB I2C Interface Converter', 'description':'', 'datasheet':'https://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT201X.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFT201XS\n\nFTDI USB I2C Interface Converter', 'pins':[
            Pin(num='1',name='CBUS5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='3V3OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='11',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='CBUS1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='CBUS0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='CBUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VCCIO',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='CBUS4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CBUS2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='USBDM',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FT220XQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FT220XQ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-16-1EP_4x4mm_P0.65mm_EP2.1x2.1mm'], 'footprint':'Package_DFN_QFN:QFN-16-1EP_4x4mm_P0.65mm_EP2.1x2.1mm', 'keywords':'FTDI USB SPI FT1248 Interface Converter', 'description':'', 'datasheet':'https://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT220X.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFT220XQ\n\nFTDI USB SPI FT1248 Interface Converter', 'pins':[
            Pin(num='1',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='CBUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='MIOSI0',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='MIOSI2',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='MIOSI1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='MIOSI3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='MISO',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='USBDM',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='3V3OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FT220XS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FT220XS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-16_3.9x4.9mm_P0.635mm'], 'footprint':'Package_SO:SSOP-16_3.9x4.9mm_P0.635mm', 'keywords':'FTDI USB SPI FT1248 Interface Converter', 'description':'', 'datasheet':'https://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT220X.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFT220XS\n\nFTDI USB SPI FT1248 Interface Converter', 'pins':[
            Pin(num='1',name='MIOSI0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='3V3OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='11',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='CBUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='MIOSI2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='MIOSI1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='MIOSI3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='MISO',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='USBDM',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FT221XQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FT221XQ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.5x2.5mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.5x2.5mm', 'keywords':'FTDI USB SPI FT1248 interface converter', 'description':'', 'datasheet':'https://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT221X.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFT221XQ\n\nFTDI USB SPI FT1248 interface converter', 'pins':[
            Pin(num='1',name='MIOSI1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='3V3OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='11',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='CBUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='MIOSI0',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='MIOSI4',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='MIOSI2',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='MIOSI7',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='MIOSI5',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='MIOSI6',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='MIOSI3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='MISO',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='USBDM',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FT221XS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FT221XS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-20_3.9x8.7mm_P0.635mm'], 'footprint':'Package_SO:SSOP-20_3.9x8.7mm_P0.635mm', 'keywords':'FTDI USB SPI FT1248 interface converter', 'description':'', 'datasheet':'https://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT221X.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFT221XS\n\nFTDI USB SPI FT1248 interface converter', 'pins':[
            Pin(num='1',name='MIOSI4',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='MISO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='USBDM',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='3V3OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='14',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='CBUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='MIOSI2',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='MIOSI0',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='MIOSI1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='MIOSI7',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='MIOSI5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='MIOSI6',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='MIOSI3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FT2232D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FT2232D'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'USB Double UART FIFO', 'description':'', 'datasheet':'http://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT2232D.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFT2232D\n\nUSB Double UART FIFO', 'pins':[
            Pin(num='1',name='EECLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='SI/WUA',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='ACBUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='ACBUS2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='ACBUS1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VCCIOA',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='ACBUS0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='ADBUS7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='ADBUS6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADBUS5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='EEDATA',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='ADBUS4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='ADBUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='ADBUS2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='ADBUS1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='ADBUS0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='SI/WUB',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='BCBUS3',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='BCBUS2',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='BCBUS1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='BCBUS0',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='VCCIOB',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='BDBUS7',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='BDBUS6',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='BDBUS5',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='BDBUS4',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='BDBUS3',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='BDBUS2',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='BDBUS1',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='BDBUS0',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='~{PWREN}',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='XTIN',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='XTOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='EECS',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RSTOUT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='3V3OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='USBDM',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FT2232HL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FT2232HL'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'USB Double UART FIFO', 'description':'', 'datasheet':'https://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT2232H.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFT2232HL\n\nUSB Double UART FIFO', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='ADBUS0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='ADBUS1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='ADBUS2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='ADBUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='OSCI',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='ADBUS4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='ADBUS5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='ADBUS6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='ADBUS7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='ACBUS0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='ACBUS1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='ACBUS2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='ACBUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='OSCO',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='ACBUS4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='ACBUS5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='ACBUS6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='ACBUS7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='~{SUSPEND}',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='VCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='BDBUS0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='BDBUS1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VPHY',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='BDBUS2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='BDBUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='BDBUS4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BDBUS5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='BDBUS6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='BDBUS7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='BCBUS0',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VREGOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='BCBUS1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='BCBUS2',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='BCBUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='BCBUS4',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='BCBUS5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='BCBUS6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='BCBUS7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='REF',func=pin_types.OUTPUT,unit=1),
            Pin(num='60',name='~{PWREN}',func=pin_types.OUTPUT,unit=1),
            Pin(num='61',name='EEDATA',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='EECLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='63',name='EECS',func=pin_types.OUTPUT,unit=1),
            Pin(num='64',name='VCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='DM',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DP',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VPLL',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FT2232HQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FT2232HQ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP4.35x4.35mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP4.35x4.35mm', 'keywords':'USB Double UART FIFO', 'description':'', 'datasheet':'https://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT2232H.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFT2232HQ\n\nUSB Double UART FIFO', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='ADBUS0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='ADBUS1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='ADBUS2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='ADBUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='OSCI',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='ADBUS4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='ADBUS5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='ADBUS6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='ADBUS7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='ACBUS0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='ACBUS1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='ACBUS2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='ACBUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='OSCO',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='ACBUS4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='ACBUS5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='ACBUS6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='ACBUS7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='~{SUSPEND}',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='VCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='BDBUS0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='BDBUS1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VPHY',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='BDBUS2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='BDBUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='BDBUS4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BDBUS5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='BDBUS6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='BDBUS7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='BCBUS0',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VREGOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='BCBUS1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='BCBUS2',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='BCBUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='BCBUS4',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='BCBUS5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='BCBUS6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='BCBUS7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='REF',func=pin_types.OUTPUT,unit=1),
            Pin(num='60',name='~{PWREN}',func=pin_types.OUTPUT,unit=1),
            Pin(num='61',name='EEDATA',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='EECLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='63',name='EECS',func=pin_types.OUTPUT,unit=1),
            Pin(num='64',name='VCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='DM',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DP',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VPLL',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FT230XQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FT230XQ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-16-1EP_4x4mm_P0.65mm_EP2.1x2.1mm'], 'footprint':'Package_DFN_QFN:QFN-16-1EP_4x4mm_P0.65mm_EP2.1x2.1mm', 'keywords':'FTDI USB UART interface converter', 'description':'', 'datasheet':'https://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT230X.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFT230XQ\n\nFTDI USB UART interface converter', 'pins':[
            Pin(num='1',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='CBUS1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='CBUS0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='CBUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='~{RTS}',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~{CTS}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='CBUS2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='USBDM',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='3V3OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FT230XS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FT230XS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-16_3.9x4.9mm_P0.635mm'], 'footprint':'Package_SO:SSOP-16_3.9x4.9mm_P0.635mm', 'keywords':'FTDI USB UART interface converter', 'description':'', 'datasheet':'https://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT230X.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFT230XS\n\nFTDI USB UART interface converter', 'pins':[
            Pin(num='1',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='3V3OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='11',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='CBUS1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='CBUS0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='CBUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='~{RTS}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~{CTS}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='CBUS2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='USBDM',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FT231XQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FT231XQ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.5x2.5mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.5x2.5mm', 'keywords':'FTDI USB UART interface converter', 'description':'', 'datasheet':'https://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT231X.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFT231XQ\n\nFTDI USB UART interface converter', 'pins':[
            Pin(num='1',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='3V3OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='11',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='CBUS1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='CBUS0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='CBUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='~{DTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='~{RTS}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{RI}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~{DSR}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{DCD}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{CTS}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='CBUS2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='USBDM',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FT231XS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FT231XS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-20_3.9x8.7mm_P0.635mm'], 'footprint':'Package_SO:SSOP-20_3.9x8.7mm_P0.635mm', 'keywords':'FTDI USB UART interface converter', 'description':'', 'datasheet':'https://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT231X.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFT231XS\n\nFTDI USB UART interface converter', 'pins':[
            Pin(num='1',name='~{DTR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='CBUS2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='USBDM',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='3V3OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='14',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='CBUS1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='CBUS0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='CBUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='~{RTS}',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{RI}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='~{DSR}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{DCD}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{CTS}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FT232BM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FT232BM'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'FTDI USB Single UART FIFO', 'description':'', 'datasheet':'https://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT232BM.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFT232BM\n\nFTDI USB Single UART FIFO', 'pins':[
            Pin(num='1',name='EESK',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~{SLEEP}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~{RXLED}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='~{TXLED}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PWRCTL',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{PWREN}',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='TXDEN',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='D7/~{RI}',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='D6/~{DCD}',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='EEDATA',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='D5/~{DSR}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='D4/~{DTR}',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='D3/~{CTS}',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='D2/~{RST}',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='D1/RXD',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='D0/TXD',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='XTIN',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='XTOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='EECS',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{RSTOUT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='3V3OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='USBDM',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FT232H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FT232H'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FTDI USB Single UART FIFO', 'description':'', 'datasheet':'https://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT232H.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFT232H\n\nFTDI USB Single UART FIFO', 'pins':[
            Pin(num='1',name='XCSI',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='ADBUS0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='ADBUS1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='ADBUS2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='ADBUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='ADBUS4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='ADBUS5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='ADBUS6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XCSO',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='ADBUS7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='ACBUS0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='ACBUS1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='ACBUS2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='ACBUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='ACBUS4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='ACBUS5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VPHY',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='ACBUS6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='ACBUS7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='ACBUS8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='ACBUS9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VCCA',func=pin_types.PWROUT,unit=1),
            Pin(num='38',name='VCCCORE',func=pin_types.PWROUT,unit=1),
            Pin(num='39',name='VCCD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='EEDATA',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='EECLK',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='EECS',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='REF',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='DM',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='DP',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VPLL',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FT232RL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FT232RL'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-28_5.3x10.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'keywords':'FTDI USB Serial', 'description':'', 'datasheet':'https://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT232R.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFT232RL\n\nFTDI USB Serial', 'pins':[
            Pin(num='1',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='DCD',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CTS',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='CBUS4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='CBUS2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='CBUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='USBD+',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='USBD-',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='3V3OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='18',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DTR',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='CBUS1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='CBUS0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='OSCI',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='OSCO',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='RTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='RI',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='DCR',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FT240XQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FT240XQ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'FTDI USB FIFO interface converter', 'description':'', 'datasheet':'https://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT240X.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFT240XQ\n\nFTDI USB FIFO interface converter', 'pins':[
            Pin(num='1',name='DATA1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='USBDM',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='3V3OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='13',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VCORE',func=pin_types.PWROUT,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='~{TXE}',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='~{RXF}',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='CBUS6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='DATA7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='CBUS5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='DATA0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='DATA4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='DATA2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='DATA5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='DATA6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='DATA3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{SI/WU}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{RD}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{WR}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FT240XS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FT240XS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-24_3.9x8.7mm_P0.635mm'], 'footprint':'Package_SO:SSOP-24_3.9x8.7mm_P0.635mm', 'keywords':'FTDI USB FIFO interface converter', 'description':'', 'datasheet':'https://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT240X.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFT240XS\n\nFTDI USB FIFO interface converter', 'pins':[
            Pin(num='1',name='DATA4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='~{SI/WU}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{RD}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{WR}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='USBDM',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='3V3OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='VCORE',func=pin_types.PWROUT,unit=1),
            Pin(num='18',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='DATA2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{TXE}',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='~{RXF}',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='CBUS6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='CBUS5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='DATA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='DATA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='DATA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='DATA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DATA6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='DATA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FT245BM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FT245BM'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'FTDI USB FIFO Interface Converter', 'description':'', 'datasheet':'https://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT245BM.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFT245BM\n\nFTDI USB FIFO Interface Converter', 'pins':[
            Pin(num='1',name='EESK',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~{PWREN}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='SI/WU',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{RXF}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='~{TXE}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='WR',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='~{RD}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='EEDATA',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='XTIN',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='XTOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='EECS',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{RSTOUT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='3V3OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='USBDM',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FT4222HQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FT4222HQ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:VQFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'USB SPI I2C FTDI Bridge Converter Interface', 'description':'', 'datasheet':'https://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT4222H.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFT4222HQ\n\nUSB SPI I2C FTDI Bridge Converter Interface', 'pins':[
            Pin(num='1',name='DEBUGGER',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='MOSI',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GPIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GPIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GPIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='~{SS0O}',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='XSCI',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='XSCO',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{STEST_RST}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='UGND',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RREF',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='DM',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='DP',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='UGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VOUT3V3',func=pin_types.UNSPEC,unit=1),
            Pin(num='26',name='VCCIN',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='VPP',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='VBUS_DET',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='BCD_DET',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='~{SS}',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='EP',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='DCNF0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='DCNF1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='SCK',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='MISO',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FT4232H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FT4232H'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'FTDI USB Quad UART FIFO', 'description':'', 'datasheet':'https://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT4232H.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFT4232H\n\nFTDI USB Quad UART FIFO', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='ADBUS0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='ADBUS1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='ADBUS2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='ADBUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='OSCI',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='ADBUS4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='ADBUS5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='ADBUS6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='ADBUS7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='BDBUS0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='BDBUS1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='BDBUS2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='BDBUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='OSCO',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='BDBUS4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='BDBUS5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='BDBUS6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='BDBUS7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='~{SUSPEND}',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='VCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='CDBUS0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='CDBUS1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VPHY',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='CDBUS2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='CDBUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='CDBUS4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='CDBUS5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='CDBUS6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='CDBUS7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='DDBUS0',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VREGOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='DDBUS1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='DDBUS2',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='DDBUS3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='DDBUS4',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='DDBUS5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='DDBUS6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='DDBUS7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='REF',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='~{PWREN}',func=pin_types.OUTPUT,unit=1),
            Pin(num='61',name='EEDATA',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='EECLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='63',name='EECS',func=pin_types.OUTPUT,unit=1),
            Pin(num='64',name='VCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='DM',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DP',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VPLL',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FT601Q', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FT601Q'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-76-1EP_9x9mm_P0.4mm_EP5.81x6.31mm'], 'footprint':'Package_DFN_QFN:QFN-76-1EP_9x9mm_P0.4mm_EP5.81x6.31mm', 'keywords':'FTDI USB 3.0 FIFO', 'description':'', 'datasheet':'https://ftdichip.com/wp-content/uploads/2020/07/DS_FT600Q-FT601Q-IC-Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFT601Q\n\nFTDI USB 3.0 FIFO', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{SIWU}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{WR}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{RD}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='~{WAKEUP}',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='GPIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='VCC33',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='XI',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='XO',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='DP',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VCC33',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='DM',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='RREF',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VD10',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VD10',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='TODN',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='TODP',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='VD10',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='RIDN',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='RIDP',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VCC33',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='DV10',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='BE_0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='DATA_0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='DATA_1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='DATA_2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='DATA_3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='DATA_4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='DATA_5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='DATA_6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='DATA_7',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VD10',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VCCIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='BE_1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='DATA_8',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='DATA_9',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='DATA_10',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='DATA_11',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='DATA_12',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='DATA_13',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='DATA_14',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='DATA_15',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='59',name='VCCIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='BE_2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='DATA_16',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='DATA_17',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='DATA_18',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='DATA_19',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='DATA_20',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='DATA_21',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='DATA_22',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='DATA_23',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='VCCIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='DATA_24',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='BE_3',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='DATA_25',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='DATA_26',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='DATA_27',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='DATA_28',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='DATA_29',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='DATA_30',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='DATA_31',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~{TXE}',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~{RXF}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FUSB302BMPX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FUSB302BMPX'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:WQFN-14-1EP_2.5x2.5mm_P0.5mm_EP1.45x1.45mm'], 'footprint':'Package_DFN_QFN:WQFN-14-1EP_2.5x2.5mm_P0.5mm_EP1.45x1.45mm', 'keywords':'USB USB-C PD Power Delivery PHY', 'description':'', 'datasheet':'http://www.onsemi.com/pub/Collateral/FUSB302B-D.PDF', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFUSB302BMPX\n\nUSB USB-C PD Power Delivery PHY', 'pins':[
            Pin(num='1',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VCONN',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VCONN',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='INT_N',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FUSB303BTMX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FUSB303BTMX'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_X2QFN-12_1.6x1.6mm_P0.4mm'], 'footprint':'Package_DFN_QFN:Texas_X2QFN-12_1.6x1.6mm_P0.4mm', 'keywords':'usb type-c controller i2c gpio source sink drp', 'description':'', 'datasheet':'https://www.onsemi.com/pdf/datasheet/fusb303b-d.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFUSB303BTMX\n\nusb type-c controller i2c gpio source sink drp', 'pins':[
            Pin(num='1',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PORT/~{DEBUG}',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBUS_DET',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='ADDR/ORIENT',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='INT_N/OUT3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='SDA/OUT1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SCL/OUT2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='ID',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FUSB307BMPX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FUSB307BMPX'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:WQFN-16-1EP_3x3mm_P0.5mm_EP1.75x1.75mm'], 'footprint':'Package_DFN_QFN:WQFN-16-1EP_3x3mm_P0.5mm_EP1.75x1.75mm', 'keywords':'USB USB-C PD Power Delivery PHY TCPC', 'description':'', 'datasheet':'http://www.onsemi.com/pub/Collateral/FUSB307B-D.PDF', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFUSB307BMPX\n\nUSB USB-C PD Power Delivery PHY TCPC', 'pins':[
            Pin(num='1',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='INT_N',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='SCL1/SDA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SDA1/SCL2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='SRC',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='SNK',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VCONN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='ORIENT/I2C_ADDR',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='LDO',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='DBG_N',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='GPIO2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IP2721', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IP2721'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'USB TYPEC PD', 'description':'', 'datasheet':'https://datasheet.lcsc.com/lcsc/2006111335_INJOINIC-IP2721_C603176.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nIP2721\n\nUSB TYPEC PD', 'pins':[
            Pin(num='1',name='VBUSG',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='SEL',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MA8601', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MA8601'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-28_3.9x9.9mm_P0.635mm'], 'footprint':'Package_SO:SSOP-28_3.9x9.9mm_P0.635mm', 'keywords':'4-Port, EEPROM, High Speed, Hub, USB2.0', 'description':'', 'datasheet':'https://datasheetspdf.com/pdf-file/1312067/Prolific/MA8601/1', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nMA8601\n\n4-Port, EEPROM, High Speed, Hub, USB2.0', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VDDR12',func=pin_types.PWROUT,unit=1),
            Pin(num='13',name='VDD33',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='REXT',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='DMU',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='DPU',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='~{SRST}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VBUS_IN',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='PSELF',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='XO',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='VDD5',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VDDR33',func=pin_types.PWROUT,unit=1),
            Pin(num='22',name='DRV',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='LED1/EESCL',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='LED2/GLEDEN',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='~{PWRJ}',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='OVCJ',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='TEST/EESDA',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD12',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='XI',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='DM4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='DP4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='DM3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='DP3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='DP2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP2200-I-MQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP2200-I-MQ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_5x5mm_P0.65mm_EP3.35x3.35mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_5x5mm_P0.65mm_EP3.35x3.35mm', 'keywords':'USB UART Converter', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/200022228D.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nMCP2200-I-MQ\n\nUSB UART Converter', 'pins':[
            Pin(num='1',name='RST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CTS',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='GP2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GP1/USB-CFG',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GP0/SSPND',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='V_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='OSC1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GP7/TxLED',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='OSC2',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='EP',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='GP6/RxLED',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GP5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='GP4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GP3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TX',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='RTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='RX',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP2200-I-SO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP2200-I-SO'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'USB UART Converter', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/200022228D.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nMCP2200-I-SO\n\nUSB UART Converter', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TX',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='RTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='RX',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='CTS',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='GP2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GP1/USB-CFG',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GP0/SSPND',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='V_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='OSC1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='OSC2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='RST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GP7/TxLED',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GP6/RxLED',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GP5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GP4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GP3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP2200-I-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP2200-I-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-20_5.3x7.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'keywords':'USB UART Converter', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/200022228D.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nMCP2200-I-SS\n\nUSB UART Converter', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TX',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='RTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='RX',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='CTS',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='GP2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GP1/USB-CFG',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GP0/SSPND',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='V_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='OSC1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='OSC2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='RST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GP7/TxLED',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GP6/RxLED',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GP5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GP4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GP3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP2210x-MQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP2210x-MQ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_5x5mm_P0.65mm_EP3.35x3.35mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_5x5mm_P0.65mm_EP3.35x3.35mm', 'keywords':'USB SPI Master Converter Bridge', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/22288A.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nMCP2210x-MQ\n\nUSB SPI Master Converter Bridge', 'pins':[
            Pin(num='1',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='MISO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='GP6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GP7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GP8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VUSB',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='OSC1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GP0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='OSC2',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='EP',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GP1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GP2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='GP3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='MOSI',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GP4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SCK',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='GP5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP2210x-SO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP2210x-SO'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'USB SPI Master Converter Bridge', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/22288A.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nMCP2210x-SO\n\nUSB SPI Master Converter Bridge', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GP4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SCK',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='GP5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='MISO',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='GP6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GP7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GP8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VUSB',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='OSC1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='OSC2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GP0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GP1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GP2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GP3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='MOSI',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP2210x-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP2210x-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-20_5.3x7.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'keywords':'USB SPI Master Converter Bridge', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/22288A.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nMCP2210x-SS\n\nUSB SPI Master Converter Bridge', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GP4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SCK',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='GP5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='MISO',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='GP6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GP7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GP8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VUSB',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='OSC1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='OSC2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GP0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GP1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GP2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GP3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='MOSI',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP2221AxML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP2221AxML'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-16-1EP_4x4mm_P0.65mm_EP2.5x2.5mm'], 'footprint':'Package_DFN_QFN:QFN-16-1EP_4x4mm_P0.65mm_EP2.5x2.5mm', 'keywords':'USB I2C UART Converter Bridge', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005565B.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nMCP2221AxML\n\nUSB I2C UART Converter Bridge', 'pins':[
            Pin(num='1',name='GP0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VUSB',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='GP1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='URx',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='UTx',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='GP2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GP3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SCL',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP2221AxP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP2221AxP'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-14_W7.62mm'], 'footprint':'Package_DIP:DIP-14_W7.62mm', 'keywords':'USB I2C UART Converter Bridge', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005565B.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nMCP2221AxP\n\nUSB I2C UART Converter Bridge', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VUSB',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GP0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GP1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='URx',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='UTx',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GP2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GP3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SDA',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP2221AxSL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP2221AxSL'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'USB I2C UART Converter Bridge', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005565B.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nMCP2221AxSL\n\nUSB I2C UART Converter Bridge', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VUSB',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GP0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GP1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='URx',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='UTx',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GP2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GP3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SDA',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP2221AxST', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP2221AxST'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'USB I2C UART Converter Bridge', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/20005565B.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nMCP2221AxST\n\nUSB I2C UART Converter Bridge', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VUSB',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GP0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GP1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='URx',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='UTx',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GP2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GP3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SDA',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MP5034GJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MP5034GJ'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:TSOT-23-8'], 'footprint':'Package_TO_SOT_SMD:TSOT-23-8', 'keywords':'USB Quick Charge', 'description':'', 'datasheet':'https://www.monolithicpower.com/en/documentview/productdocument/index/version/2/document_type/Datasheet/lang/en/sku/MP5034/', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nMP5034GJ\n\nUSB Quick Charge', 'pins':[
            Pin(num='1',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='ADJ',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='DM',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='DP',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STULPI01A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STULPI01A'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_uTFBGA-36_3.6x3.6mm_Layout6x6_P0.5mm'], 'footprint':'Package_BGA:ST_uTFBGA-36_3.6x3.6mm_Layout6x6_P0.5mm', 'keywords':'USB OTG HS PHY ULPI Interface', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stulpi01a.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nSTULPI01A\n\nUSB OTG HS PHY ULPI Interface', 'pins':[
            Pin(num='A1',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='A5',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VDVIO',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='VDVIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='VDVIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='B6',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='DM',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='RREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='~{CS}/PWRDN',func=pin_types.INPUT,unit=1),
            Pin(num='C4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='C5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='DP',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='ID',func=pin_types.INPUT,unit=1),
            Pin(num='D4',name='~{PSW}',func=pin_types.OUTPUT,unit=1),
            Pin(num='D5',name='NXT',func=pin_types.OUTPUT,unit=1),
            Pin(num='D6',name='STP',func=pin_types.INPUT,unit=1),
            Pin(num='E1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='VB_REF_FAULT',func=pin_types.INPUT,unit=1),
            Pin(num='E3',name='3V3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='DIR',func=pin_types.OUTPUT,unit=1),
            Pin(num='E6',name='1V2V',func=pin_types.PASSIVE,unit=1),
            Pin(num='F1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='XI',func=pin_types.INPUT,unit=1),
            Pin(num='F6',name='XO',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STUSB4500QTR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STUSB4500QTR'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.7x2.7mm', 'keywords':'USB PD Type C Sink', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stusb4500.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nSTUSB4500QTR\n\nUSB PD Type C Sink', 'pins':[
            Pin(num='1',name='CC1DB',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='ATTACH',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='ADDR0',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='ADDR1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='POWER_OK3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='GPIO',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='VBUS_EN_SNK',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='A_B_SIDE',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='VBUS_VS_DISCH',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='ALERT',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='POWER_OK2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='21',name='VREG_1V2',func=pin_types.PWROUT,unit=1),
            Pin(num='22',name='VSYS',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VREG_2V7',func=pin_types.PWROUT,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CC2DB',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='DISCH',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPS2500DRC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPS2500DRC'}), 'ref_prefix':'U', 'fplist':['Package_SON:Texas_S-PVSON-N10'], 'footprint':'Package_SON:Texas_S-PVSON-N10', 'keywords':'USB switch boost', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tps2500.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nTPS2500DRC\n\nUSB switch boost', 'pins':[
            Pin(num='1',name='SW',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='AUX',func=pin_types.PWROUT,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='ILIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='ENUSB',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{FAULT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='USB',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPS2513', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPS2513'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'USB Charge', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tps2513.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nTPS2513\n\nUSB Charge', 'pins':[
            Pin(num='1',name='DP1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='DP2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='DM2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='DM1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPS2514', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPS2514'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'USB Charge', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tps2513.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nTPS2514\n\nUSB Charge', 'pins':[
            Pin(num='1',name='DP1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='DM1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPS2560', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPS2560'}), 'ref_prefix':'U', 'fplist':['Package_SON:VSON-10-1EP_3x3mm_P0.5mm_EP1.65x2.4mm_ThermalVias'], 'footprint':'Package_SON:VSON-10-1EP_3x3mm_P0.5mm_EP1.65x2.4mm_ThermalVias', 'keywords':'power switche current limited usb port', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tps2560.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nTPS2560\n\npower switche current limited usb port', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{FAULT1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='PAD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='EN1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='EN2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{FAULT2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='ILM',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='OUT1',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPS2561', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPS2561'}), 'ref_prefix':'U', 'fplist':['Package_SON:VSON-10-1EP_3x3mm_P0.5mm_EP1.65x2.4mm_ThermalVias'], 'footprint':'Package_SON:VSON-10-1EP_3x3mm_P0.5mm_EP1.65x2.4mm_ThermalVias', 'keywords':'power switche current limited usb port', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tps2561.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nTPS2561\n\npower switche current limited usb port', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{FAULT1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='PAD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='EN1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='EN2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{FAULT2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='ILM',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='OUT1',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPS25730D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPS25730D'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_REF0038A_WQFN-38-2EP_6x4mm_P0.4'], 'footprint':'Package_DFN_QFN:Texas_REF0038A_WQFN-38-2EP_6x4mm_P0.4', 'keywords':'USB CC PD', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tps25730.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nTPS25730D\n\nUSB CC PD', 'pins':[
            Pin(num='1',name='LDO_3V3',func=pin_types.PWROUT,unit=1),
            Pin(num='10',name='DBG_ACC',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='PLUG_FLIP',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='DRAIN',func=pin_types.UNSPEC,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='~{FAULT_IN}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{SINK_EN}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='ADCIN1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PPHV',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VBUS_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='RESERVED',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='RESERVED',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='ADCIN2',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='DRAIN',func=pin_types.UNSPEC,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='RESERVED',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='PLUG_EVENT',func=pin_types.OPENCOLL,unit=1),
            Pin(num='38',name='VIN_3V3',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='LDO_1V5',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='DRAIN',func=pin_types.UNSPEC,unit=1),
            Pin(num='5',name='ADCIN3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='CAP_MIS',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='ADCIN4',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='I2Ct_SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='I2Ct_SCL',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TS3USB30EDGSR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TS3USB30EDGSR'}), 'ref_prefix':'U', 'fplist':['Package_SO:VSSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:VSSOP-10_3x3mm_P0.5mm', 'keywords':'usb mux', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/ts3usb30e.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nTS3USB30EDGSR\n\nusb mux', 'pins':[
            Pin(num='1',name='S',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='D1+',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='D2+',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='D2-',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='D1-',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{OE}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TS3USB30ERSWR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TS3USB30ERSWR'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:UQFN-10_1.4x1.8mm_P0.4mm'], 'footprint':'Package_DFN_QFN:UQFN-10_1.4x1.8mm_P0.4mm', 'keywords':'usb mux', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/ts3usb30e.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nTS3USB30ERSWR\n\nusb mux', 'pins':[
            Pin(num='1',name='D1+',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='S',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D2+',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='D2-',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='D1-',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TUSB2036', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TUSB2036'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'2-Port, 3-Port, 3.3V, EEPROM, Full Speed, Hub, Texas Instruments, USB1.1', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tusb2036.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nTUSB2036\n\n2-Port, 3-Port, 3.3V, EEPROM, Full Speed, Hub, Texas Instruments, USB1.1', 'pins':[
            Pin(num='1',name='DP0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='~{OVRCUR1}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{PWRON2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='~{OVRCUR2}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='~{PWRON3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='~{OVRCUR3}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='DM3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='DM0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DP3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='~{OCPROT}/~{PWRSW}',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='NPINT0',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='NPINT1',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='~{NP3}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='~{EXTMEM}',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='DP0PUR',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='XTAL1/CLK48',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='SUSPND',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='EECLK',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='EEDATA/~{GANGED}',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='~{BUSPWR}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{PWRON1}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TUSB320', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TUSB320'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_X2QFN-12_1.6x1.6mm_P0.4mm'], 'footprint':'Package_DFN_QFN:Texas_X2QFN-12_1.6x1.6mm_P0.4mm', 'keywords':'USB PD CC', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tusb320.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nTUSB320\n\nUSB PD CC', 'pins':[
            Pin(num='1',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PORT',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VBUS_DET',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='ADDR',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{INT}/OUT3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='SDA/OUT1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SCL/OUT2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='ID',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TUSB321', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TUSB321'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_X2QFN-12_1.6x1.6mm_P0.4mm'], 'footprint':'Package_DFN_QFN:Texas_X2QFN-12_1.6x1.6mm_P0.4mm', 'keywords':'USB CC PD VCONN', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tusb321.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nTUSB321\n\nUSB CC PD VCONN', 'pins':[
            Pin(num='1',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DIR',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CURRENT_MODE',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='PORT',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VBUS_DET',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{VCONN_FAULT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='OUT1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='OUT2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='ID',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TUSB322I', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TUSB322I'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_X2QFN-12_1.6x1.6mm_P0.4mm'], 'footprint':'Package_DFN_QFN:Texas_X2QFN-12_1.6x1.6mm_P0.4mm', 'keywords':'USB VCONN PD CC', 'description':'', 'datasheet':'www.ti.com/lit/ds/symlink/tusb322i.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nTUSB322I\n\nUSB VCONN PD CC', 'pins':[
            Pin(num='1',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VBUS_DET',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='DIR',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='ADDR',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{INT}/OUT3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='SDA/OUT1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SCL/OUT2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='ID',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TUSB4041I', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TUSB4041I'}), 'ref_prefix':'U', 'fplist':['Package_QFP:HTQFP-64-1EP_10x10mm_P0.5mm_EP8x8mm_Mask4.4x4.4mm_ThermalVias'], 'footprint':'Package_QFP:HTQFP-64-1EP_10x10mm_P0.5mm_EP8x8mm_Mask4.4x4.4mm_ThermalVias', 'keywords':'USB2.0 hub', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tusb4041i.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nTUSB4041I\n\nUSB2.0 hub', 'pins':[
            Pin(num='1',name='PWRCTL3/BATEN3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GANGED/SMBA2/HS_UP',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='OVERCUR4z',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='OVERCUR3z',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='AUTOENz/HS_SUSPEND',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='OVERCUR1z',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='OVERCUR2z',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='USB_VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='GRSTz',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VDD33',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='VDD33',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='USB_DP_UP',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='USB_DM_UP',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='24',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='27',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='29',name='XO',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='PWRCTL2/BATEN2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='XI',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='VDD33',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='USB_R1',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='USB_DP_DN1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='USB_DM_DN1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='39',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='PWRCTL1/BATEN1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='41',name='USB_DP_DN2',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='USB_DM_DN2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='44',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='45',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='47',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='48',name='VDD33',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='USB_DP_DN3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SDA/SMBDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='USB_DM_DN3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='52',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='53',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='54',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='55',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='56',name='USB_DP_DN4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='USB_DM_DN4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='59',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='SCL/SMBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='61',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='62',name='RSVD',func=pin_types.NOCONNECT,unit=1),
            Pin(num='63',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='PWRCTL4/BATEN4',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='SMBUSz',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='FULLPWRMGMTz/SMBA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PWRCTL_POL',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TUSB7340', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TUSB7340'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_S-PWQFN-N100_EP5.5x5.5mm_ThermalVias'], 'footprint':'Package_DFN_QFN:Texas_S-PWQFN-N100_EP5.5x5.5mm_ThermalVias', 'keywords':'USB HUB PCIE', 'description':'', 'datasheet':'http://www.ti.com/general/docs/lit/getliterature.tsp?genericPartNumber=tusb7320&fileType=pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nTUSB7340\n\nUSB HUB PCIE', 'pins':[
            Pin(num='A1',name='VDD11',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='USB_SSRXN_DN2',func=pin_types.INPUT,unit=1),
            Pin(num='A11',name='USB_SSTXP_DN2',func=pin_types.OUTPUT,unit=1),
            Pin(num='A12',name='VDD11',func=pin_types.PWRIN,unit=1),
            Pin(num='A13',name='USB_DM_DN2',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A15',name='GRST#',func=pin_types.INPUT,unit=1),
            Pin(num='A16',name='VDD11',func=pin_types.PWRIN,unit=1),
            Pin(num='A17',name='USB_SSTXP_DN1',func=pin_types.OUTPUT,unit=1),
            Pin(num='A18',name='USB_SSRXP_DN1',func=pin_types.INPUT,unit=1),
            Pin(num='A19',name='VDDA_3P3',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='USB_DP_DN1',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='VDDA_3P3',func=pin_types.PWRIN,unit=1),
            Pin(num='A22',name='XO',func=pin_types.OUTPUT,unit=1),
            Pin(num='A23',name='XI',func=pin_types.INPUT,unit=1),
            Pin(num='A24',name='R1EXT',func=pin_types.BIDIR,unit=1),
            Pin(num='A25',name='VDDA_3P3',func=pin_types.PWRIN,unit=1),
            Pin(num='A26',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A27',name='USB_DM_DN3',func=pin_types.BIDIR,unit=1),
            Pin(num='A28',name='VDD11',func=pin_types.PWRIN,unit=1),
            Pin(num='A29',name='USB_SSRXN_DN3',func=pin_types.INPUT,unit=1),
            Pin(num='A3',name='VDD33',func=pin_types.PWRIN,unit=1),
            Pin(num='A30',name='USB_SSTXN_DN3',func=pin_types.OUTPUT,unit=1),
            Pin(num='A31',name='VDD11',func=pin_types.PWRIN,unit=1),
            Pin(num='A32',name='JTAG_TCK',func=pin_types.INPUT,unit=1),
            Pin(num='A33',name='VDD11',func=pin_types.PWRIN,unit=1),
            Pin(num='A34',name='VDD33',func=pin_types.PWRIN,unit=1),
            Pin(num='A35',name='JTAG_TDI',func=pin_types.INPUT,unit=1),
            Pin(num='A36',name='OVERCUR1#',func=pin_types.INPUT,unit=1),
            Pin(num='A37',name='OVERCUR2#',func=pin_types.INPUT,unit=1),
            Pin(num='A38',name='VDD11',func=pin_types.PWRIN,unit=1),
            Pin(num='A39',name='VDD33',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='VDD11',func=pin_types.PWRIN,unit=1),
            Pin(num='A40',name='PERST#',func=pin_types.INPUT,unit=1),
            Pin(num='A41',name='PCIE_TXN',func=pin_types.OUTPUT,unit=1),
            Pin(num='A42',name='PCIE_RXN',func=pin_types.INPUT,unit=1),
            Pin(num='A43',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A44',name='VDDA_3P3',func=pin_types.PWRIN,unit=1),
            Pin(num='A45',name='PCIE_REFCLKP',func=pin_types.INPUT,unit=1),
            Pin(num='A46',name='PWRON3#',func=pin_types.OUTPUT,unit=1),
            Pin(num='A47',name='VDD33',func=pin_types.PWRIN,unit=1),
            Pin(num='A48',name='PWRON4#',func=pin_types.OUTPUT,unit=1),
            Pin(num='A49',name='GPIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='USB_DM_DN4',func=pin_types.BIDIR,unit=1),
            Pin(num='A50',name='VDD11',func=pin_types.PWRIN,unit=1),
            Pin(num='A51',name='VDD33',func=pin_types.PWRIN,unit=1),
            Pin(num='A52',name='AUX_DET',func=pin_types.INPUT,unit=1),
            Pin(num='A53',name='VSS_EP',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='VDD11',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='USB_SSRXN_DN4',func=pin_types.INPUT,unit=1),
            Pin(num='A8',name='USB_SSTXN_DN4',func=pin_types.INPUT,unit=1),
            Pin(num='A9',name='VDD11',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VDD11',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='USB_SSTXN_DN2',func=pin_types.OUTPUT,unit=1),
            Pin(num='B11',name='VDDA_3P3',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='USB_DP_DN2',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B14',name='FREQSEL',func=pin_types.INPUT,unit=1),
            Pin(num='B15',name='USB_SSTXN_DN1',func=pin_types.OUTPUT,unit=1),
            Pin(num='B16',name='USB_SSRXN_DN1',func=pin_types.INPUT,unit=1),
            Pin(num='B17',name='VDD11',func=pin_types.PWRIN,unit=1),
            Pin(num='B18',name='USB_DM_DN1',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='VDD11',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B21',name='VSS_OSC',func=pin_types.INPUT,unit=1),
            Pin(num='B22',name='VDDA_3P3',func=pin_types.PWRIN,unit=1),
            Pin(num='B23',name='R1EXTRTN',func=pin_types.BIDIR,unit=1),
            Pin(num='B24',name='VDD11',func=pin_types.PWRIN,unit=1),
            Pin(num='B25',name='USB_DP_DN3',func=pin_types.BIDIR,unit=1),
            Pin(num='B26',name='VDDA_3P3',func=pin_types.PWRIN,unit=1),
            Pin(num='B27',name='USB_SSRXP_DN3',func=pin_types.INPUT,unit=1),
            Pin(num='B28',name='USB_SSTXP_DN3',func=pin_types.OUTPUT,unit=1),
            Pin(num='B29',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B3',name='SMI',func=pin_types.OUTPUT,unit=1),
            Pin(num='B30',name='JTAG_TMS',func=pin_types.INPUT,unit=1),
            Pin(num='B31',name='JTAG_TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='B32',name='JTAG_RST#',func=pin_types.INPUT,unit=1),
            Pin(num='B33',name='PWRON1#',func=pin_types.OUTPUT,unit=1),
            Pin(num='B34',name='PWRON2#',func=pin_types.OUTPUT,unit=1),
            Pin(num='B35',name='WAKE#',func=pin_types.OUTPUT,unit=1),
            Pin(num='B36',name='CLKREQ#',func=pin_types.INPUT,unit=1),
            Pin(num='B37',name='VDD11',func=pin_types.PWRIN,unit=1),
            Pin(num='B38',name='PCIE_TXP',func=pin_types.OUTPUT,unit=1),
            Pin(num='B39',name='PCIE_RXP',func=pin_types.INPUT,unit=1),
            Pin(num='B4',name='VDDA_3P3',func=pin_types.PWRIN,unit=1),
            Pin(num='B40',name='VDD11',func=pin_types.PWRIN,unit=1),
            Pin(num='B41',name='PCIE_REFCLKN',func=pin_types.INPUT,unit=1),
            Pin(num='B42',name='VDD11',func=pin_types.PWRIN,unit=1),
            Pin(num='B43',name='OVERCUR3#',func=pin_types.INPUT,unit=1),
            Pin(num='B44',name='VDD11',func=pin_types.PWRIN,unit=1),
            Pin(num='B45',name='OVERCUR4#',func=pin_types.INPUT,unit=1),
            Pin(num='B46',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='B47',name='GPIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='B48',name='GPIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='USB_DP_DN4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='USB_SSRXP_DN4',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='USB_SSTXP_DN4',func=pin_types.INPUT,unit=1),
            Pin(num='B8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B9',name='USB_SSRXP_DN2',func=pin_types.INPUT,unit=1),
            Pin(num='C1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C4',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TUSB8041', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TUSB8041'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP6x6mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP6x6mm_ThermalVias', 'keywords':'USB3.0 hub', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tusb8041.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nTUSB8041\n\nUSB3.0 hub', 'pins':[
            Pin(num='1',name='USB_DP_DN1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='USB_DM_DN2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='USB_SSTXP_DN2',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='USB_SSTXM_DN2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='USB_SSRXP_DN2',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='USB_SSRXM_DN2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VDD33',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='USB_DP_DN3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='USB_DM_DN3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='USB_SSTXP_DN3',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='USB_DM_DN1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='USB_SSTXM_DN3',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='USB_SSRXP_DN3',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='USB_SSRXM_DN3',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='USB_DP_DN4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='USB_DM_DN4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='USB_SSTXP_DN4',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='USB_SSTXM_DN4',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='USB_SSRXP_DN4',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='USB_SSTXP_DN1',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='USB_SSRXM_DN4',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='PWRCTL4/BATEN4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PWRCTL3/BATEN3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VDD33',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='PWRCTL2/BATEN2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PWRCTL1/BATEN1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='SDA/SMBDAT',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='SCL/SMBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='SMBUSz/SS_SUSPEND',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='USB_SSTXM_DN1',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='FULLPWRMGMTz/SMBA1/SS_UP',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PWRCTL_POL',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='GANGED/SMBA2/HS_UP',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='OVERCUR4z',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='OVERCUR3z',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='AUTOENz/HS_SUSPEND',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='OVERCUR1z',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='OVERCUR2z',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='USB_VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='GRSTz',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='VDD33',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='USB_DP_UP',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='USB_DM_UP',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='USB_SSTXP_UP',func=pin_types.OUTPUT,unit=1),
            Pin(num='56',name='USB_SSTXM_UP',func=pin_types.OUTPUT,unit=1),
            Pin(num='57',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='USB_SSRXP_UP',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='USB_SSRXM_UP',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='USB_SSRXP_DN1',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='61',name='XO',func=pin_types.OUTPUT,unit=1),
            Pin(num='62',name='XI',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='VDD33',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='USB_R1',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='USB_SSRXM_DN1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='USB_DP_DN2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'UPD720202K8-7x1-BAA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'UPD720202K8-7x1-BAA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.7x5.7mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.7x5.7mm', 'keywords':'PCIe USB 3.0', 'description':'', 'datasheet':'https://www.renesas.com/us/en/document/dst/upd720201upd720202-datasheet', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nUPD720202K8-7x1-BAA\n\nPCIe USB 3.0', 'pins':[
            Pin(num='1',name='PECLKP',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{PECREQ}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='PONRSTB',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VDD33',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='SPISO',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{SPICS}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SPISCK',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='SPISI',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='~{OCI2}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='PPON2',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='~{OCI1}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PECLKN',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='PPON1',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='VDD10',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='VDD33',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='XT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XT1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='AVDD33',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='RREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='U3TXDP1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='U3TXDN1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='AVDD33',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VDD10',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='U3RXDP1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='U3RXDN1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VDD10',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VDD33',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='U2DP1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='U2DM1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='U3TXDP2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='U3TXDN2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD10',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PETXP',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='U3RXDP2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='U3RXDN2',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VDD10',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='VDD33',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='U2DP2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='U2DM2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='SMIB',func=pin_types.OPENCOLL,unit=1),
            Pin(num='47',name='~{PERST}',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='~{PEWAKE}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='49',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PETXN',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD10',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PERXP',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PERXN',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VDD10',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USB2504', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USB2504'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'USB2.0 Hi-Speed-USB-Hub Hub-Controller', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/00002250A.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nUSB2504\n\nUSB2.0 Hi-Speed-USB-Hub Hub-Controller', 'pins':[
            Pin(num='1',name='VDDA33',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='USBD3_N',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='USBD3_P',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA33',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='USBD4_P',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='USBD4_N',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='AM4/LED_EN',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='USBD0_P',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GR4/PRT_DIS1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='AM3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='GR3/PRT_DIS0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PRTPWR_POL',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='AM2/MTT_EN',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GR2/NON_REM1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='AM1/GANG_EN',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='GR1/NON_REM0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD33',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='USBD0_N',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD18',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='TEST0',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='33',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='34',name='SDA/SMBDATA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='SCL/SMBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='CFG_SEL0',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='PRTPWR4',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='~{OCS4}',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='PRTPWR3',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='~{OCS3}',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VDD18',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='PRTPWR2',func=pin_types.OUTPUT,unit=1),
            Pin(num='44',name='~{OCS2}',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PRTPWR1',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='~{OCS1}',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='CLKIN_EN',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='TEST1',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='USBD1_N',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='CFG_SEL1',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='SELF_PWR',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='VBUS_DET',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='VDD18',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='57',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='58',name='XTAL1/CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='CFG_SEL2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='USBD1_P',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='VDDA18PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='61',name='VDDA33PLL',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='ATEST/REG_EN',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='RBIAS',func=pin_types.INPUT,unit=1),
            Pin(num='64',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDDA33',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='USBD2_P',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='USBD2_N',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USB2514B_Bi', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USB2514B_Bi'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP3.7x3.7mm'], 'footprint':'Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP3.7x3.7mm', 'keywords':'USB2.0 Hi-Speed-USB-Hub Hub-Controller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/00001692C.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nUSB2514B_Bi\n\nUSB2.0 Hi-Speed-USB-Hub Hub-Controller', 'pins':[
            Pin(num='1',name='USBDM_DN1/PRT_DIS_M1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDDA33',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='PRTPWR1/BC_EN1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='OCS_N1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='CRFILT',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='VDD33',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PRTPWR2/BC_EN2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='OCS_N2',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='PRTPWR3/BC_EN3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='OCS_N3',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='USBDP_DN1/PRT_DIS_P1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PRTPWR4/BC_EN4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='OCS_N4',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SDA/SMBDATA/NON_REM1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDD33',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='SCL/SMBCLK/CFG_SEL0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='HS_IND/CFG_SEL1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='RESET_N',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='VBUS_DET',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='SUSP_IND/LOCAL_PWR/NON_REM0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDDA33',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='USBDM_DN2/PRT_DIS_M2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='USBDM_UP',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='USBDP_UP',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='XTALIN/CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='PLLFILT',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='RBIAS',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='VDDA33',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='USBDP_DN2/PRT_DIS_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDDA33',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='USBDM_DN3/PRT_DIS_M3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='USBDP_DN3/PRT_DIS_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='USBDM_DN4/PRT_DIS_M4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='USBDP_DN4/PRT_DIS_P4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USB3250-ABZJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USB3250-ABZJ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-56-1EP_8x8mm_P0.5mm_EP4.3x4.3mm'], 'footprint':'Package_DFN_QFN:QFN-56-1EP_8x8mm_P0.5mm_EP4.3x4.3mm', 'keywords':'HS FS Device USB PHY UTMI', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/00002142A.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nUSB3250-ABZJ\n\nHS FS Device USB PHY UTMI', 'pins':[
            Pin(num='1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='XI',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='XO',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='VDDA1.8',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='~{SUSPEND}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD3.3',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD1.8',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='XCVRSELECT',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='TERMSELECT',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='OPMODE1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DM',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='OPMODE0',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='LINESTATE1',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='LINESTATE0',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='VDD1.8',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='DATA15',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='DATA14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='DATA13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD3.3',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='DATA12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='DP',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='DATA11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='DATA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='DATA9',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='DATA8',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='DATA7',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='DATA6',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='DATA5',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD1.8',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='DATA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDDA3.3',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='DATA3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='DATA2',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='DATA1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VDD3.3',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='DATA0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='TXVALID',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='RXVALID',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='VALIDH',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='RXACTIVE',func=pin_types.OUTPUT,unit=1),
            Pin(num='51',name='TXREADY',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='RXERROR',func=pin_types.OUTPUT,unit=1),
            Pin(num='53',name='VDD1.8',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='DATABUS16_8',func=pin_types.INPUT,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='EP',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RBIAS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDDA3.3',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='VSSA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USB3300-EZK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USB3300-EZK'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'USB OTG Hi-Speed PHY ULPI Interface', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/00001783C.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nUSB3300-EZK\n\nUSB OTG Hi-Speed PHY ULPI Interface', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='EXTVBUS',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='NXT',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='DIR',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='STP',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='VDD1.8',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VDD3.3',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='DATA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='DATA6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='DATA5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='DATA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='DATA3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='DATA2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='DATA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='DATA0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VDD3.3',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='VDD1.8',func=pin_types.PWROUT,unit=1),
            Pin(num='27',name='XO',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='XI',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VDDA1.8',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='CPEN',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='VDD3.3',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='REG_EN',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RBIAS',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='ID',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD3.3',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='DP',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DM',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RESET',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USB3341', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USB3341'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'USB ULPI Transceiver', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/334x.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nUSB3341\n\nUSB ULPI Transceiver', 'pins':[
            Pin(num='1',name='CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='DATA7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SPK_L',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SPK_R',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='DP',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DM',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD33',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='ID',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='RBIAS',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NXT',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='REFCLK',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='~{RESETB}',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDD18',func=pin_types.PWROUT,unit=1),
            Pin(num='23',name='STP',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='DIR',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='DATA0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='DATA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='DATA2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='DATA3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='DATA4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DATA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='DATA6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USB3343', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USB3343'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'USB ULPI Transceiver', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/334x.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nUSB3343\n\nUSB ULPI Transceiver', 'pins':[
            Pin(num='1',name='DIR',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='DATA5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='DATA6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='DATA7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='DP',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DM',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD33',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='ID',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='RBIAS',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='XO',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='REFCLK/XI',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='~{RESETB}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='VDD18',func=pin_types.PWROUT,unit=1),
            Pin(num='24',name='STP',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NXT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='DATA0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='DATA1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='DATA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='DATA3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DATA4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDIO',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USB3740B-AI2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USB3740B-AI2'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'USB 2.0 High Speed Switch', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/00001725D.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nUSB3740B-AI2\n\nUSB 2.0 High Speed Switch', 'pins':[
            Pin(num='1',name='DM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='DP',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='DP_1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='OE_N',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='S',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='DP_2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='DM_2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='DM',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XR21B1424', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XR21B1424'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'USB Quad UART FIFO', 'description':'', 'datasheet':'https://assets.maxlinear.com/web/documents/xr21b1424.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nXR21B1424\n\nUSB Quad UART FIFO', 'pins':[
            Pin(num='1',name='RXA',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='USB_D-',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VIO',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VCC_REG',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VBUS_SENSE',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{RESET}',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='USB_STAT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='GPIOC9/RXTC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GPIOA5/~{RTSA}/RS485A',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GPIOC8/TXTC',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GPIOC7/RS485C',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='GPIOC6/CLKC',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TXC',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='USB_STAT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='RXC',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='GPIOC5/~{RTSC}/RS485C',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='GPIOC4/~{CTSC}',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='GPIOC3/~{DTRC}',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GPIOA4/~{CTSA}',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='GPIOC2/~{DSRC}',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='GPIOC1/~{CDC}',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='~{TEST}',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='GPIOC0/~{RIC}/~{RWKC}',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GPIOB9/RXTB',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='GPIOB8/TXTB',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='GPIOB7/RS485B',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='GPIOB6/CLKB',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GPIOA3/~{DTRA}',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='TXB',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='RXB',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='GPIOB5/~{RTSB}/RS485B',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='GPIOB4/~{CTSB}',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GPIOB3/~{DTRB}',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GPIOB2/~{DSRB}',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='GPIOB1/~{CDB}',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='GPIOB0/~{RIB}/~{RWKB}',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='GPIOD9/RXTD',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='GPIOD8/TXTD',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='GPIOA2/~{DSRA}',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='GPIOD7/RS485D',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='GPIOD6/CLKD',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='53',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='54',name='GPIOD5/~{RTSD}/RS485D',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='GPIOD4/~{CTSD}',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='GPIOD3/~{DTRD}',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='GPIOD2/~{DSRD}',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='GPIOD1/~{CDD}',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='GPIOD0/~{RID}/~{RWKD}',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GPIOA1/~{CDA}',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GPIOA9/RXTA',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='GPIOA8/TXTA',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='GPIOA7/RS485A',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='GPIOA6/CLKA',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='TXA',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GPIOA0/~{RIA}/~{RWKA}',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='USB_D+',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADUM3160', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADUM3160'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'usb isolation', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADuM3160.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nADUM3160\n\nusb isolation', 'pins':[
            Pin(num='1',name='VBUS1',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='DD+',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='DD-',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SPD',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VDD2',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND2',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VBUS2',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND1',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD1',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PDEN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SPU',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='UD-',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='UD+',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND1',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='GND2',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CH340N', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CH340N'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOP-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'USB UART Serial Converter Interface', 'description':'', 'datasheet':'https://aitendo3.sakura.ne.jp/aitendo_data/product_img/ic/inteface/CH340N/ch340n.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCH340N\n\nUSB UART Serial Converter Interface', 'pins':[
            Pin(num='1',name='UD+',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='UD-',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~{RTS}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='V3',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY7C65211A-24LTXI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY7C65211A-24LTXI'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'USB-Serial single channel bridge', 'description':'', 'datasheet':'http://www.cypress.com/file/139886/download', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCY7C65211A-24LTXI\n\nUSB-Serial single channel bridge', 'pins':[
            Pin(num='1',name='SCB_0/GPIO_6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='USBDM',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VCCD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='~{XRES}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='VBUS',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='GPIO_0',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='GPIO_1',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='SCB_5/GPIO_7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='SCB_1/GPIO_2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='SCB_2/GPIO_3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='SCB_3/GPIO_4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='SCB_4/GPIO_5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='1EP',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GPIO_8',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='GPIO_9',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='GPIO_10',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='GPIO_11',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='SUSPEND',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='WAKEUP',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY7C65213A-28PVXI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY7C65213A-28PVXI'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'keywords':'USB-UART LP Bridge Controller, full speed 12Mbps', 'description':'', 'datasheet':'http://www.cypress.com/file/139881/download', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCY7C65213A-28PVXI\n\nUSB-UART LP Bridge Controller, full speed 12Mbps', 'pins':[
            Pin(num='1',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='DCD',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CTS',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='GPIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GPIO2',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='GPIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='USBDM',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCCD',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='DTR',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='GPIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='26',name='DNU',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='GPIO6',func=pin_types.TRISTATE,unit=1),
            Pin(num='28',name='GPIO7',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='RTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='RI',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GPIO5',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='DSR',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY7C65213A-32LTXI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY7C65213A-32LTXI'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'USB-UART LP Bridge Controller, full speed 12Mbps', 'description':'', 'datasheet':'http://www.cypress.com/file/139881/download', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCY7C65213A-32LTXI\n\nUSB-UART LP Bridge Controller, full speed 12Mbps', 'pins':[
            Pin(num='1',name='VCCIO',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GPIO2',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='GPIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GPIO6',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='GPIO7',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='USBDM',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VCCD',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='GPIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='DNU',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='DNU',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='DNU',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='DNU',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='DNU',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='DNU',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RI',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='DTR',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='RTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='1EP',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GPIO5',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='DSR',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='DCD',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='CTS',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='GPIO4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY7C65215A-32LTXI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY7C65215A-32LTXI'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'USB-Serial single channel bridge', 'description':'', 'datasheet':'http://www.cypress.com/file/129956/download', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCY7C65215A-32LTXI\n\nUSB-Serial single channel bridge', 'pins':[
            Pin(num='1',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SCB1_5/GPIO_15',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SUSPEND',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='WAKEUP',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GPIO_16',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='USBDP',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='USBDM',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VCCD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='~{XRES}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='VBUS',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='SCB0_0/GPIO_8',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GPIO_17',func=pin_types.TRISTATE,unit=1),
            Pin(num='22',name='GPIO_18',func=pin_types.TRISTATE,unit=1),
            Pin(num='23',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='GPIO_0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='GPIO_1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='SCB0_1/GPIO_2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='SCB0_2/GPIO_3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='SCB0_3/GPIO_4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='SCB0_5/GPIO_9',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='SCB0_4/GPIO_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='GPIO_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='GPIO_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='1EP',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='VSSD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SCB1_0/GPIO_10',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCB1_1/GPIO_11',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SCB1_2/GPIO_12',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SCB1_3/GPIO_13',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SCB1_4/GPIO_14',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CYPD3174-24LQXQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CYPD3174-24LQXQ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.75x2.75mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.75x2.75mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.75x2.75mm', 'keywords':'USBPD Quickcharge', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-EZ-PD(TM)_CCG3PA_Datasheet_USB_Type-C_Port_Controller-DataSheet-v09_00-EN.pdf?fileId=8ac78c8c7d0d8da4017d0ee438366ac0', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCYPD3174-24LQXQ\n\nUSBPD Quickcharge', 'pins':[
            Pin(num='1',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VBUS_C_MON_DIS',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='DM0/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='DP0/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VBUS_IN_DIS',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='CSP',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='FB',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='COMP',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VBUS_P_CTRL',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='VBUS_C_CTRL',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='DP1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='DM1/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P0.0/SWD_DAT_0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P0.1/SWD_CLK_0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.0/AXRES',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CYPD3175-24LQXQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CYPD3175-24LQXQ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.75x2.75mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.75x2.75mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.75x2.75mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.75x2.75mm', 'keywords':'USBPD Quickcharge', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-EZ-PD(TM)_CCG3PA_Datasheet_USB_Type-C_Port_Controller-DataSheet-v09_00-EN.pdf?fileId=8ac78c8c7d0d8da4017d0ee438366ac0', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nCYPD3175-24LQXQ\n\nUSBPD Quickcharge', 'pins':[
            Pin(num='1',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VBUS_C_MON_DIS',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='DM0/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='DP0/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VBUS_IN_DIS',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='CSP',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='FB',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='COMP',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VDDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VCCD',func=pin_types.PWROUT,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VBUS_P_CTRL',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='VBUS_C_CTRL',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='DP1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='DM1/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P0.0/SWD_DAT_0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P0.1/SWD_CLK_0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.0/AXRES',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FUSB302B01MPX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FUSB302B01MPX'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:WQFN-14-1EP_2.5x2.5mm_P0.5mm_EP1.45x1.45mm', 'Package_DFN_QFN:WQFN-14-1EP_2.5x2.5mm_P0.5mm_EP1.45x1.45mm'], 'footprint':'Package_DFN_QFN:WQFN-14-1EP_2.5x2.5mm_P0.5mm_EP1.45x1.45mm', 'keywords':'USB USB-C PD Power Delivery PHY', 'description':'', 'datasheet':'http://www.onsemi.com/pub/Collateral/FUSB302B-D.PDF', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFUSB302B01MPX\n\nUSB USB-C PD Power Delivery PHY', 'pins':[
            Pin(num='1',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VCONN',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VCONN',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='INT_N',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FUSB302B10MPX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FUSB302B10MPX'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:WQFN-14-1EP_2.5x2.5mm_P0.5mm_EP1.45x1.45mm', 'Package_DFN_QFN:WQFN-14-1EP_2.5x2.5mm_P0.5mm_EP1.45x1.45mm', 'Package_DFN_QFN:WQFN-14-1EP_2.5x2.5mm_P0.5mm_EP1.45x1.45mm'], 'footprint':'Package_DFN_QFN:WQFN-14-1EP_2.5x2.5mm_P0.5mm_EP1.45x1.45mm', 'keywords':'USB USB-C PD Power Delivery PHY', 'description':'', 'datasheet':'http://www.onsemi.com/pub/Collateral/FUSB302B-D.PDF', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFUSB302B10MPX\n\nUSB USB-C PD Power Delivery PHY', 'pins':[
            Pin(num='1',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VCONN',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VCONN',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='INT_N',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FUSB302B11MPX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FUSB302B11MPX'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:WQFN-14-1EP_2.5x2.5mm_P0.5mm_EP1.45x1.45mm', 'Package_DFN_QFN:WQFN-14-1EP_2.5x2.5mm_P0.5mm_EP1.45x1.45mm', 'Package_DFN_QFN:WQFN-14-1EP_2.5x2.5mm_P0.5mm_EP1.45x1.45mm', 'Package_DFN_QFN:WQFN-14-1EP_2.5x2.5mm_P0.5mm_EP1.45x1.45mm'], 'footprint':'Package_DFN_QFN:WQFN-14-1EP_2.5x2.5mm_P0.5mm_EP1.45x1.45mm', 'keywords':'USB USB-C PD Power Delivery PHY', 'description':'', 'datasheet':'http://www.onsemi.com/pub/Collateral/FUSB302B-D.PDF', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nFUSB302B11MPX\n\nUSB USB-C PD Power Delivery PHY', 'pins':[
            Pin(num='1',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VCONN',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VCONN',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='INT_N',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP2200-E-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP2200-E-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'keywords':'USB UART Converter', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/200022228D.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nMCP2200-E-SS\n\nUSB UART Converter', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TX',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='RTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='RX',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='CTS',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='GP2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GP1/USB-CFG',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GP0/SSPND',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='V_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='OSC1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='OSC2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='RST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GP7/TxLED',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GP6/RxLED',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GP5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GP4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GP3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP2200T-E-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP2200T-E-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'keywords':'USB UART Converter', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/200022228D.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nMCP2200T-E-SS\n\nUSB UART Converter', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TX',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='RTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='RX',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='CTS',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='GP2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GP1/USB-CFG',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GP0/SSPND',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='V_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='OSC1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='OSC2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='RST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GP7/TxLED',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GP6/RxLED',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GP5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GP4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GP3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP2200T-I-MQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP2200T-I-MQ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_5x5mm_P0.65mm_EP3.35x3.35mm', 'Package_DFN_QFN:QFN-20-1EP_5x5mm_P0.65mm_EP3.35x3.35mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_5x5mm_P0.65mm_EP3.35x3.35mm', 'keywords':'USB UART Converter', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/200022228D.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nMCP2200T-I-MQ\n\nUSB UART Converter', 'pins':[
            Pin(num='1',name='RST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CTS',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='GP2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GP1/USB-CFG',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GP0/SSPND',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='V_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='OSC1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GP7/TxLED',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='OSC2',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='EP',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='GP6/RxLED',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GP5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='GP4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GP3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TX',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='RTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='RX',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP2200T-I-SO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP2200T-I-SO'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'USB UART Converter', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/200022228D.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nMCP2200T-I-SO\n\nUSB UART Converter', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TX',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='RTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='RX',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='CTS',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='GP2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GP1/USB-CFG',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GP0/SSPND',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='V_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='OSC1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='OSC2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='RST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GP7/TxLED',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GP6/RxLED',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GP5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GP4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GP3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP2200T-I-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP2200T-I-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'keywords':'USB UART Converter', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/200022228D.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nMCP2200T-I-SS\n\nUSB UART Converter', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TX',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='RTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='RX',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='CTS',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='GP2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GP1/USB-CFG',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GP0/SSPND',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='V_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='OSC1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='OSC2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='RST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GP7/TxLED',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GP6/RxLED',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='GP5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GP4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GP3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STULPI01B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STULPI01B'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_uTFBGA-36_3.6x3.6mm_Layout6x6_P0.5mm', 'Package_BGA:ST_uTFBGA-36_3.6x3.6mm_Layout6x6_P0.5mm'], 'footprint':'Package_BGA:ST_uTFBGA-36_3.6x3.6mm_Layout6x6_P0.5mm', 'keywords':'USB OTG HS PHY ULPI Interface', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stulpi01b.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nSTULPI01B\n\nUSB OTG HS PHY ULPI Interface', 'pins':[
            Pin(num='A1',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='A5',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VDVIO',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='VDVIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='VDVIO',func=pin_types.PASSIVE,unit=1),
            Pin(num='B6',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='DM',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='RREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='~{CS}/PWRDN',func=pin_types.INPUT,unit=1),
            Pin(num='C4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='C5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='DP',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='ID',func=pin_types.INPUT,unit=1),
            Pin(num='D4',name='~{PSW}',func=pin_types.OUTPUT,unit=1),
            Pin(num='D5',name='NXT',func=pin_types.OUTPUT,unit=1),
            Pin(num='D6',name='STP',func=pin_types.INPUT,unit=1),
            Pin(num='E1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='VB_REF_FAULT',func=pin_types.INPUT,unit=1),
            Pin(num='E3',name='3V3V',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='DIR',func=pin_types.OUTPUT,unit=1),
            Pin(num='E6',name='1V2V',func=pin_types.PASSIVE,unit=1),
            Pin(num='F1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='XI',func=pin_types.INPUT,unit=1),
            Pin(num='F6',name='XO',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPS2501DRC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPS2501DRC'}), 'ref_prefix':'U', 'fplist':['Package_SON:Texas_S-PVSON-N10', 'Package_SON:Texas_S-PVSON-N10'], 'footprint':'Package_SON:Texas_S-PVSON-N10', 'keywords':'USB switch boost', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tps2500.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nTPS2501DRC\n\nUSB switch boost', 'pins':[
            Pin(num='1',name='SW',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='AUX',func=pin_types.PWROUT,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='ILIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='ENUSB',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{FAULT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='USB',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPS2513A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPS2513A'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'USB Charge', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tps2513.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nTPS2513A\n\nUSB Charge', 'pins':[
            Pin(num='1',name='DP1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='DP2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='DM2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='DM1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPS2514A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPS2514A'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'USB Charge', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tps2513.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nTPS2514A\n\nUSB Charge', 'pins':[
            Pin(num='1',name='DP1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='DM1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TUSB320I', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TUSB320I'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_X2QFN-12_1.6x1.6mm_P0.4mm', 'Package_DFN_QFN:Texas_X2QFN-12_1.6x1.6mm_P0.4mm'], 'footprint':'Package_DFN_QFN:Texas_X2QFN-12_1.6x1.6mm_P0.4mm', 'keywords':'USB PD CC', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tusb320.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nTUSB320I\n\nUSB PD CC', 'pins':[
            Pin(num='1',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PORT',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VBUS_DET',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='ADDR',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{INT}/OUT3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='SDA/OUT1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SCL/OUT2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='ID',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USB3346', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USB3346'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'USB ULPI Transceiver', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/334x.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nUSB3346\n\nUSB ULPI Transceiver', 'pins':[
            Pin(num='1',name='CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='DATA7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SPK_L',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SPK_R',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='DP',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DM',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD33',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='ID',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='RBIAS',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NXT',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='REFCLK',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='~{RESETB}',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDD18',func=pin_types.PWROUT,unit=1),
            Pin(num='23',name='STP',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='DIR',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='DATA0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='DATA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='DATA2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='DATA3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='DATA4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DATA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='DATA6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USB3347', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USB3347'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'USB ULPI Transceiver', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/334x.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nUSB3347\n\nUSB ULPI Transceiver', 'pins':[
            Pin(num='1',name='CLKOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='DATA7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SPK_L',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='SPK_R',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='DP',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DM',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD33',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='ID',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='RBIAS',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NXT',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='REFCLK',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='~{RESETB}',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDD18',func=pin_types.PWROUT,unit=1),
            Pin(num='23',name='STP',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='DIR',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='DATA0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='DATA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='DATA2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='DATA3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='DATA4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DATA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='DATA6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USB3740B-AI9', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USB3740B-AI9'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'USB 2.0 High Speed Switch', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/00001725D.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_USB.kicad_sym\nUSB3740B-AI9\n\nUSB 2.0 High Speed Switch', 'pins':[
            Pin(num='1',name='DM_1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='DP',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='DP_1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='OE_N',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='S',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='DP_2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='DM_2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='DM',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])