from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

_74xx_IEEE = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'7400', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7400'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7400\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '14', '7', '3', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '4', '14', '7', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '9', '14', '8', '7']},{'label': 'uD', 'num': 4, 'pin_nums': ['14', '11', '13', '7', '12']}] }),
        Part(**{ 'name':'7401', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7401'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7401\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['14', '2', '7', '3', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '14', '7', '6', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '8', '14', '7', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['14', '13', '7', '12', '11']}] }),
        Part(**{ 'name':'7402', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7402'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7402\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.OUTPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '14', '7', '1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '14', '7', '4', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['7', '9', '14', '10', '8']},{'label': 'uD', 'num': 4, 'pin_nums': ['14', '7', '13', '11', '12']}] }),
        Part(**{ 'name':'7404', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7404'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7404\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=6),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '14', '1', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '14', '3', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '14', '6', '7']},{'label': 'uD', 'num': 4, 'pin_nums': ['9', '14', '7', '8']},{'label': 'uE', 'num': 5, 'pin_nums': ['10', '14', '11', '7']},{'label': 'uF', 'num': 6, 'pin_nums': ['13', '14', '12', '7']}] }),
        Part(**{ 'name':'7405', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7405'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7405\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='10',name='~',func=pin_types.OPENCOLL,unit=5),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OPENCOLL,unit=6),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['7', '1', '14', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['14', '4', '7', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['14', '5', '6', '7']},{'label': 'uD', 'num': 4, 'pin_nums': ['7', '8', '9', '14']},{'label': 'uE', 'num': 5, 'pin_nums': ['7', '14', '10', '11']},{'label': 'uF', 'num': 6, 'pin_nums': ['7', '12', '13', '14']}] }),
        Part(**{ 'name':'7406', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7406'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7406\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='10',name='~',func=pin_types.OPENCOLL,unit=5),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OPENCOLL,unit=6),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '14', '2', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '14', '4', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '7', '14', '6']},{'label': 'uD', 'num': 4, 'pin_nums': ['9', '14', '8', '7']},{'label': 'uE', 'num': 5, 'pin_nums': ['10', '14', '11', '7']},{'label': 'uF', 'num': 6, 'pin_nums': ['14', '12', '13', '7']}] }),
        Part(**{ 'name':'7407', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7407'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7407\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='10',name='~',func=pin_types.OPENCOLL,unit=5),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OPENCOLL,unit=6),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['14', '1', '7', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['14', '3', '7', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['14', '5', '7', '6']},{'label': 'uD', 'num': 4, 'pin_nums': ['14', '9', '7', '8']},{'label': 'uE', 'num': 5, 'pin_nums': ['14', '11', '7', '10']},{'label': 'uF', 'num': 6, 'pin_nums': ['14', '13', '7', '12']}] }),
        Part(**{ 'name':'7408', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7408'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7408\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '1', '14', '7', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['14', '5', '4', '6', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['14', '10', '7', '9', '8']},{'label': 'uD', 'num': 4, 'pin_nums': ['14', '11', '12', '7', '13']}] }),
        Part(**{ 'name':'7409', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7409'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7409\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '14', '3', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '4', '14', '5', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['9', '14', '8', '10', '7']},{'label': 'uD', 'num': 4, 'pin_nums': ['12', '11', '13', '14', '7']}] }),
        Part(**{ 'name':'7410', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7410'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7410\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['12', '13', '1', '7', '14', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '3', '4', '14', '7', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['11', '8', '9', '7', '10', '14']}] }),
        Part(**{ 'name':'7411', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7411'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7411\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '13', '7', '14', '12']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '3', '6', '14', '4', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '7', '11', '14', '10', '9']}] }),
        Part(**{ 'name':'7412', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7412'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7412\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['12', '2', '7', '13', '14', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '7', '5', '14', '6', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '7', '9', '8', '14', '11']}] }),
        Part(**{ 'name':'74126', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74126'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74126\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='O',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='EN',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='D',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='O',func=pin_types.TRISTATE,unit=2),
            Pin(num='10',name='EN',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='O',func=pin_types.TRISTATE,unit=3),
            Pin(num='9',name='D',func=pin_types.INPUT,unit=3),
            Pin(num='13',name='EN',func=pin_types.INPUT,unit=4),
            Pin(num='11',name='O',func=pin_types.TRISTATE,unit=4),
            Pin(num='12',name='D',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['7', '14', '2', '1', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '5', '14', '4', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['14', '7', '9', '10', '8']},{'label': 'uD', 'num': 4, 'pin_nums': ['13', '7', '12', '14', '11']}] }),
        Part(**{ 'name':'74128', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74128'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74128\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.OUTPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '14', '1', '7', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '14', '6', '7', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '9', '14', '7', '10']},{'label': 'uD', 'num': 4, 'pin_nums': ['13', '14', '12', '7', '11']}] }),
        Part(**{ 'name':'7413', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7413'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7413\n\n', 'pins':[
            Pin(num='14',name='VDD',func=pin_types.PWRIN),
            Pin(num='7',name='VSS',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '2', '7', '14', '5', '4', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['8', '12', '13', '7', '9', '10', '14']}] }),
        Part(**{ 'name':'74132', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74132'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74132\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['7', '2', '1', '3', '14']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '4', '6', '14', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '7', '9', '14', '10']},{'label': 'uD', 'num': 4, 'pin_nums': ['7', '12', '11', '13', '14']}] }),
        Part(**{ 'name':'74136', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74136'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74136\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['7', '3', '1', '2', '14']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '5', '6', '14', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '7', '8', '9', '14']},{'label': 'uD', 'num': 4, 'pin_nums': ['13', '7', '11', '12', '14']}] }),
        Part(**{ 'name':'7414', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7414'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7414\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=5),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=6),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['14', '1', '2', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['14', '3', '4', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['14', '5', '6', '7']},{'label': 'uD', 'num': 4, 'pin_nums': ['14', '9', '8', '7']},{'label': 'uE', 'num': 5, 'pin_nums': ['10', '7', '14', '11']},{'label': 'uF', 'num': 6, 'pin_nums': ['14', '12', '13', '7']}] }),
        Part(**{ 'name':'74141', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74141'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74141\n\n', 'pins':[
            Pin(num='12',name='GND',func=pin_types.PWRIN),
            Pin(num='5',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='~{Q8}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='~{Q7}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='~{Q6}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='~{Q4}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='~{Q5}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='~{Q1}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='~{Q0}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='~{Q9}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{Q2}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='~{Q3}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74147', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74147'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74147\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{E4}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{E9}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{E1}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{E2}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{E3}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{S3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{E5}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{E6}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{E7}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{E8}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{S2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{S1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~{S0}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74148', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74148'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74148\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{I4}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{IO}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{I1}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{I2}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{I3}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{GS}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~{EO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{I5}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{I6}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{I7}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{EI}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{S2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{S1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~{S0}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74151', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74151'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74151\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='S1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='S0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{E}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='S2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74153', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74153'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74153\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{ENa}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='I0b',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='I1b',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='I2b',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='I3b',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{ENb}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3a',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I2a',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I1a',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I0a',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Qa',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Qb',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74154', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74154'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'demux', 'description':'', 'datasheet':'https://www.ti.com/lit/gpn/CD74HCT154', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74154\n\ndemux', 'pins':[
            Pin(num='12',name='GND',func=pin_types.PWRIN),
            Pin(num='24',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='~{S0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~{S9}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~{S10}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{S11}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='~{S12}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~{S13}',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='~{S14}',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='~{S15}',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='~{E0}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{E1}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{S1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{S2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{S3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='~{S4}',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{S5}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{S6}',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='~{S7}',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~{S8}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74155', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74155'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74155\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='Ea1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{Q1b}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~{Q2b}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='~{Q3b}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{ENb}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{Eb2}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{ENa}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{Q3a}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='~{Q2a}',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{Q1a}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{Q0a}',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~{Q0b}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74156', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74156'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74156\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='Ea1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{Q1b}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='~{Q2b}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='~{Q3b}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{ENb}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{Eb2}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{ENa}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{Q3a}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='~{Q2a}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='~{Q1a}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='~{Q0a}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='~{Q0b}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74157', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74157'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74157\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='A/B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='I1d',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='I0d',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Qc',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='I1c',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='I0c',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='I0a',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I1a',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Qa',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='I0b',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I1b',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Qb',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Qd',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74158', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74158'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74158\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='Sens',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='I1d',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='I0d',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{Qc}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='I1c',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='I0c',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='I0a',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I1a',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{Qa}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='I0b',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I1b',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{Qb}',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~{Qd}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74159', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74159'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74159\n\n', 'pins':[
            Pin(num='12',name='GND',func=pin_types.PWRIN),
            Pin(num='24',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='~{S0}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='~{S9}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='~{S10}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='~{S11}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='~{S12}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='~{S13}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='~{S14}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='~{S15}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='~{E0}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{E1}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{S1}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='20',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{S2}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='~{S3}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='~{S4}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='~{S5}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='~{S6}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='~{S7}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='~{S8}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74164', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74164'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74164\n\n', 'pins':[
            Pin(num='1',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Qe',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Qf',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Qg',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Qh',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Qa',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Qb',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Qc',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Qd',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='CK',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{R}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74165', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74165'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74165\n\n', 'pins':[
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='SH',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='SER',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='CLK_Inh',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='E',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='F',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='H',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{QH}',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='QH',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74166', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74166'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74166\n\n', 'pins':[
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='SER',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='E',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='F',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='QH',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='H',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SH',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='CLK_Inh',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{R}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74173', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74173'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74173\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{M}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{G2}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='R',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{N}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='CK',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{G1}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74176', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74176'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74176\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{LD}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Qd',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{CLR}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='Qc',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Qa',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{CK2}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{CK1}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Qb',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'7420', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7420'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7420\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '14', '2', '5', '6', '7', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['10', '9', '14', '7', '8', '12', '13']}] }),
        Part(**{ 'name':'7421', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7421'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7421\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '14', '4', '7', '1', '5', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['13', '12', '14', '7', '9', '10', '8']}] }),
        Part(**{ 'name':'7422', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7422'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7422\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['7', '2', '5', '1', '4', '14', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['9', '7', '10', '8', '12', '14', '13']}] }),
        Part(**{ 'name':'7425', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7425'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7425\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='G',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['5', '2', '1', '7', '14', '6', '3', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['8', '11', '10', '7', '13', '9', '14', '12']}] }),
        Part(**{ 'name':'74251', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74251'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74251\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='S1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='S0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='~{Q}',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='~{E}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='S2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74253', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74253'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74253\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{ENa}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='I0b',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='I1b',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='I2b',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='I3b',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{ENb}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3a',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I2a',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I1a',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I0a',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Qa',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='Qb',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'7426', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7426'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7426\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'u', 'num': 0, 'pin_nums': ['7', '14']},{'label': 'uA', 'num': 1, 'pin_nums': ['1', '3', '2', '7', '14']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '7', '6', '4', '14']},{'label': 'uC', 'num': 3, 'pin_nums': ['9', '10', '8', '7', '14']},{'label': 'uD', 'num': 4, 'pin_nums': ['11', '13', '12', '7', '14']}] }),
        Part(**{ 'name':'7427', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7427'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7427\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['12', '13', '14', '7', '1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '3', '6', '14', '7', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['11', '9', '14', '7', '8', '10']}] }),
        Part(**{ 'name':'74278', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74278'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74278\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='Str',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Y1',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{P0}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Y4',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{P1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='Y3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Y2',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'7428', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7428'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7428\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.OUTPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['14', '7', '1', '2', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['14', '7', '6', '4', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '14', '7', '8', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['12', '14', '7', '13', '11']}] }),
        Part(**{ 'name':'74293', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74293'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74293\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='10',name='~{CKA}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{CKB}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='R0(1)',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='R0(2)',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Q0',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'7430', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7430'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7430\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'7432', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7432'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7432\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '1', '14', '2', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5', '14', '6', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '10', '14', '9', '7']},{'label': 'uD', 'num': 4, 'pin_nums': ['13', '11', '7', '12', '14']}] }),
        Part(**{ 'name':'7433', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7433'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7433\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.OPENCOLL,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '7', '3', '1', '14']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '7', '5', '6', '14']},{'label': 'uC', 'num': 3, 'pin_nums': ['7', '10', '8', '14', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['12', '7', '13', '11', '14']}] }),
        Part(**{ 'name':'7437', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7437'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7437\n\n', 'pins':[
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'u', 'num': 0, 'pin_nums': ['14', '7']},{'label': 'uA', 'num': 1, 'pin_nums': ['14', '2', '7', '1', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['14', '6', '4', '7', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['14', '9', '7', '10', '8']},{'label': 'uD', 'num': 4, 'pin_nums': ['13', '14', '11', '7', '12']}] }),
        Part(**{ 'name':'7440', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7440'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7440\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['5', '2', '7', '6', '14', '1', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '8', '12', '9', '14', '13', '10']}] }),
        Part(**{ 'name':'7442', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7442'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7442\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{Q0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~{Q8}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~{Q9}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{Q1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{Q2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{Q3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='~{Q4}',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{Q5}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{Q6}',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~{Q7}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74425', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74425'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74425\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='O',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='EN',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='D',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='O',func=pin_types.TRISTATE,unit=2),
            Pin(num='10',name='EN',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='O',func=pin_types.TRISTATE,unit=3),
            Pin(num='9',name='D',func=pin_types.INPUT,unit=3),
            Pin(num='13',name='EN',func=pin_types.INPUT,unit=4),
            Pin(num='11',name='O',func=pin_types.TRISTATE,unit=4),
            Pin(num='12',name='D',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '1', '2', '7', '14']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '4', '5', '7', '14']},{'label': 'uC', 'num': 3, 'pin_nums': ['7', '8', '9', '10', '14']},{'label': 'uD', 'num': 4, 'pin_nums': ['11', '13', '12', '7', '14']}] }),
        Part(**{ 'name':'7443', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7443'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7443\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{Q0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~{Q8}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~{Q9}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{Q1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{Q2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{Q3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='~{Q4}',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{Q5}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{Q6}',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~{Q7}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'7444', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7444'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7444\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{Q0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~{Q8}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~{Q9}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{Q1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{Q2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{Q3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='~{Q4}',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{Q5}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{Q6}',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~{Q7}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'7445', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7445'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7445\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{Q0}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='~{Q8}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='~{Q9}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{Q1}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='~{Q2}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='~{Q3}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='~{Q4}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='~{Q5}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='~{Q6}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='~{Q7}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'7446', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7446'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7446\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{d}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='~{c}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='~{b}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='~{a}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='~{g}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='~{f}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{LT}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{BI}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{RBI}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{e}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'7448', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7448'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7448\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='d',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='c',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='b',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='a',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='g',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='f',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{LT}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{BI}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{RBI}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='e',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'7451', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7451'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7451\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['9', '7', '10', '2', '14', '8', '13']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '7', '3', '4', '14', '6', '2']}] }),
        Part(**{ 'name':'7454', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7454'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7454\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=1)], 'unit_defs':[{'label': 'u', 'num': 0, 'pin_nums': ['14', '7']},{'label': 'uA', 'num': 1, 'pin_nums': ['2', '8', '14', '10', '5', '13', '9', '7', '1', '4', '3']}] }),
        Part(**{ 'name':'7483', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7483'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7483\n\n', 'pins':[
            Pin(num='12',name='GND',func=pin_types.PWRIN),
            Pin(num='5',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='B1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='C0',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='C4',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='S4',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='B4',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='S3',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='B3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='S2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='B2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='S1',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'7485', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7485'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7485\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='B3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='B1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='B2',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='Ia<b',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Ia=b',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Ia>b',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Oa>b',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Oa=b',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Oa<b',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='B0',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'7486', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7486'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7486\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['14', '7', '3', '2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['14', '5', '7', '6', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['14', '9', '7', '10', '8']},{'label': 'uD', 'num': 4, 'pin_nums': ['14', '13', '7', '12', '11']}] }),
        Part(**{ 'name':'7490', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7490'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7490\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='5',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='~{CKB}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='~{CKA}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='R0(1)',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='R0(2)',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='R9(1)',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='R9(2)',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Q1',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'7491', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7491'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7491\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='5',name='VCC',func=pin_types.PWRIN),
            Pin(num='11',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='Qh',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='~{Qh}',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Ck',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'7492', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7492'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7492\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='5',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='~{CP1}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='~{CP0}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='R0(1)',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='R0(2)',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Q2',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'7493', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7493'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7493\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='5',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='~{CKB}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='~{CKA}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='R0(1)',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='R0(2)',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Q1',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'7495', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7495'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7495\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='Ser',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Mode',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{CK2}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{CK1}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'7496', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7496'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7496\n\n', 'pins':[
            Pin(num='12',name='GND',func=pin_types.PWRIN),
            Pin(num='5',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='CK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Q4',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='~{R}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='P4',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PE',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Ser',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HC237', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC237'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74HC237\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Y5',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Y4',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Y3',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Y2',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Y1',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Y0',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{GL}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{G2}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='G1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Y7',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Y6',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[{'label': 'u', 'num': 0, 'pin_nums': ['8', '16']},{'label': 'uA', 'num': 1, 'pin_nums': ['6', '4', '9', '14', '1', '12', '10', '3', '5', '7', '11', '13', '15', '8', '2', '16']}] }),
        Part(**{ 'name':'74HC238', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC238'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74HC238\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Y5',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Y4',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Y3',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Y2',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Y1',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Y0',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{G2A}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{G2B}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='G1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Y7',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Y6',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74HC36', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC36'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74HC36\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['14', '3', '1', '2', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '14', '4', '5', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['14', '8', '9', '10', '7']},{'label': 'uD', 'num': 4, 'pin_nums': ['14', '11', '12', '13', '7']}] }),
        Part(**{ 'name':'74HC804', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC804'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74HC804\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='14',name='~',func=pin_types.OUTPUT,unit=5),
            Pin(num='15',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='16',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='17',name='~',func=pin_types.OUTPUT,unit=6),
            Pin(num='18',name='~',func=pin_types.INPUT,unit=6),
            Pin(num='19',name='~',func=pin_types.INPUT,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '10', '1', '2', '20']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '5', '10', '4', '20']},{'label': 'uC', 'num': 3, 'pin_nums': ['7', '8', '10', '9', '20']},{'label': 'uD', 'num': 4, 'pin_nums': ['12', '10', '11', '13', '20']},{'label': 'uE', 'num': 5, 'pin_nums': ['14', '16', '10', '15', '20']},{'label': 'uF', 'num': 6, 'pin_nums': ['10', '18', '19', '17', '20']}] }),
        Part(**{ 'name':'74HC805', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC805'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74HC805\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='14',name='~',func=pin_types.OUTPUT,unit=5),
            Pin(num='15',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='16',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='17',name='~',func=pin_types.OUTPUT,unit=6),
            Pin(num='18',name='~',func=pin_types.INPUT,unit=6),
            Pin(num='19',name='~',func=pin_types.INPUT,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '3', '10', '20', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '6', '10', '20', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['7', '8', '10', '20', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['13', '11', '10', '12', '20']},{'label': 'uE', 'num': 5, 'pin_nums': ['15', '10', '16', '20', '14']},{'label': 'uF', 'num': 6, 'pin_nums': ['18', '17', '19', '10', '20']}] }),
        Part(**{ 'name':'74HC808', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC808'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74HC808\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='14',name='~',func=pin_types.OUTPUT,unit=5),
            Pin(num='15',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='16',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='17',name='~',func=pin_types.OUTPUT,unit=6),
            Pin(num='18',name='~',func=pin_types.INPUT,unit=6),
            Pin(num='19',name='~',func=pin_types.INPUT,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '3', '10', '1', '20']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5', '10', '6', '20']},{'label': 'uC', 'num': 3, 'pin_nums': ['7', '8', '10', '20', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['13', '11', '10', '12', '20']},{'label': 'uE', 'num': 5, 'pin_nums': ['14', '16', '15', '10', '20']},{'label': 'uF', 'num': 6, 'pin_nums': ['18', '19', '17', '10', '20']}] }),
        Part(**{ 'name':'74HC832', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74HC832'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74HC832\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='14',name='~',func=pin_types.OUTPUT,unit=5),
            Pin(num='15',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='16',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='17',name='~',func=pin_types.OUTPUT,unit=6),
            Pin(num='18',name='~',func=pin_types.INPUT,unit=6),
            Pin(num='19',name='~',func=pin_types.INPUT,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1', '3', '10', '20']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5', '6', '10', '20']},{'label': 'uC', 'num': 3, 'pin_nums': ['9', '7', '10', '20', '8']},{'label': 'uD', 'num': 4, 'pin_nums': ['12', '13', '11', '10', '20']},{'label': 'uE', 'num': 5, 'pin_nums': ['10', '14', '16', '15', '20']},{'label': 'uF', 'num': 6, 'pin_nums': ['18', '17', '19', '10', '20']}] }),
        Part(**{ 'name':'74LS133', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS133'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS133\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS137', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS137'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS137\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{Y5}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~{Y4}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='~{Y3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{Y2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='~{Y1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~{Y0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{GL}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{G2}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='G1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{Y7}',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{Y6}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS138', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS138'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS138\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{Y5}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~{Y4}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='~{Y3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{Y2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='~{Y1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~{Y0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{G2A}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{G2B}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='G1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{Y7}',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{Y6}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS139', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS139'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL DECOD4', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74ls139a.pdf', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS139\n\nTTL DECOD4', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{Q0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='~{Q1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{Q2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{Q3}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~{Q2}',func=pin_types.OUTPUT,unit=2),
            Pin(num='11',name='~{Q1}',func=pin_types.OUTPUT,unit=2),
            Pin(num='12',name='~{Q0}',func=pin_types.OUTPUT,unit=2),
            Pin(num='13',name='B',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='A',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='~{EN}',func=pin_types.INPUT,unit=2),
            Pin(num='9',name='~{Q3}',func=pin_types.OUTPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '4', '16', '2', '7', '5', '3', '8', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['9', '10', '14', '12', '16', '11', '13', '15', '8']}] }),
        Part(**{ 'name':'74LS15', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS15'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS15\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['12', '2', '1', '14', '13', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '14', '5', '6', '3', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['9', '11', '14', '10', '8', '7']}] }),
        Part(**{ 'name':'74LS152', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS152'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS152\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='S0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I0',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='S2',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='S1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS161', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS161'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS161\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='ENT',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Tc',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='CK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='ENP',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{Pe}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS168', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS168'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS168\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='U/D',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{ENP}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~{Tc}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='CK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{ENP}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{LD}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS170', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS170'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS170\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Q1',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='~{RD}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{WR}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='Wb',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='Wa',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Rb',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Ra',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Q4',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='Q3',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='Q2',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS177', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS177'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS177\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{Ld}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{CLR}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{CK2}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{CK1}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Q1',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS190', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS190'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS190\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{LD}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Max/Min',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{RCO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='CK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D/U',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='P3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS192', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS192'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'TTL CNT CNT4', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74ls193.pdf', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS192\n\nTTL CNT CNT4', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{LOAD}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{CO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{BO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='CLR',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='QB',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='QA',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='DOWN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='UP',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='QC',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='QD',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='D',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS194', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS194'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS194\n\n', 'pins':[
            Pin(num='7',name='Lser',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='16',name='VDD',func=pin_types.PWRIN),
            Pin(num='1',name='~{R}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='S1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='Rser',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='SO',func=pin_types.INPUT,unit=1)], 'unit_defs':[{'label': 'u', 'num': 0, 'pin_nums': ['8', '7', '16']},{'label': 'uA', 'num': 1, 'pin_nums': ['4', '6', '2', '1', '12', '14', '8', '10', '15', '7', '16', '3', '5', '9', '13', '11']}] }),
        Part(**{ 'name':'74LS195', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS195'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS195\n\n', 'pins':[
            Pin(num='7',name='Lser',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='16',name='VDD',func=pin_types.PWRIN),
            Pin(num='1',name='~{R}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CK',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{Q3}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='J',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{K}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='SH',func=pin_types.INPUT,unit=1)], 'unit_defs':[{'label': 'u', 'num': 0, 'pin_nums': ['8', '7', '16']},{'label': 'uA', 'num': 1, 'pin_nums': ['8', '13', '10', '5', '9', '11', '2', '4', '6', '1', '14', '16', '15', '7', '12', '3']}] }),
        Part(**{ 'name':'74LS239', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS239'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS239\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='Q2',func=pin_types.OUTPUT,unit=2),
            Pin(num='11',name='Q1',func=pin_types.OUTPUT,unit=2),
            Pin(num='12',name='Q0',func=pin_types.OUTPUT,unit=2),
            Pin(num='13',name='A',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='B',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='~{EN}',func=pin_types.INPUT,unit=2),
            Pin(num='9',name='Q3',func=pin_types.OUTPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['7', '16', '5', '3', '8', '1', '2', '6', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['15', '16', '11', '9', '13', '8', '14', '10', '12']}] }),
        Part(**{ 'name':'74LS240', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS240'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'7400 logic ttl low power schottky', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74ls240.pdf', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS240\n\n7400 logic ttl low power schottky', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{O3}',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='~{O2}',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='~{O1}',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='~{O0}',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='I0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='I0',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='I1',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='I2',func=pin_types.INPUT,unit=2),
            Pin(num='17',name='I3',func=pin_types.INPUT,unit=2),
            Pin(num='19',name='~{OE}',func=pin_types.INPUT,unit=2),
            Pin(num='3',name='~{O3}',func=pin_types.TRISTATE,unit=2),
            Pin(num='5',name='~{O2}',func=pin_types.TRISTATE,unit=2),
            Pin(num='7',name='~{O1}',func=pin_types.TRISTATE,unit=2),
            Pin(num='9',name='~{O0}',func=pin_types.TRISTATE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['14', '12', '18', '1', '10', '20', '2', '8', '16', '6', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '13', '17', '9', '3', '10', '20', '15', '19', '5', '11']}] }),
        Part(**{ 'name':'74LS241', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS241'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'7400 logic ttl low power schottky', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74ls241.pdf', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS241\n\n7400 logic ttl low power schottky', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='O3',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='O2',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='O1',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='O0',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='I0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='I0',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='I1',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='I2',func=pin_types.INPUT,unit=2),
            Pin(num='17',name='I3',func=pin_types.INPUT,unit=2),
            Pin(num='19',name='OE',func=pin_types.INPUT,unit=2),
            Pin(num='3',name='O3',func=pin_types.TRISTATE,unit=2),
            Pin(num='5',name='O2',func=pin_types.TRISTATE,unit=2),
            Pin(num='7',name='O1',func=pin_types.TRISTATE,unit=2),
            Pin(num='9',name='O0',func=pin_types.TRISTATE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '8', '20', '16', '4', '6', '10', '18', '12', '14', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['13', '20', '19', '9', '10', '5', '11', '17', '7', '3', '15']}] }),
        Part(**{ 'name':'74LS242', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS242'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS242\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{GAB}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{B1}',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='~{B0}',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='GBA',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{B3}',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='~{B2}',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS243', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS243'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS243\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{GAB}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='B1',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='B0',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='GBA',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='B3',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='B2',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS244', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS244'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'7400 logic ttl low power schottky', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74ls244.pdf', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS244\n\n7400 logic ttl low power schottky', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='O3',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='O2',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='O1',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='O0',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='I0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='I0',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='I1',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='I2',func=pin_types.INPUT,unit=2),
            Pin(num='17',name='I3',func=pin_types.INPUT,unit=2),
            Pin(num='19',name='~{OE}',func=pin_types.INPUT,unit=2),
            Pin(num='3',name='O3',func=pin_types.TRISTATE,unit=2),
            Pin(num='5',name='O2',func=pin_types.TRISTATE,unit=2),
            Pin(num='7',name='O1',func=pin_types.TRISTATE,unit=2),
            Pin(num='9',name='O0',func=pin_types.TRISTATE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['14', '6', '18', '20', '1', '2', '10', '16', '12', '8', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['13', '17', '7', '11', '15', '19', '5', '9', '10', '20', '3']}] }),
        Part(**{ 'name':'74LS245', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS245'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS245\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='~{DIR}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='B7',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='B6',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='B5',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='B4',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='B3',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='B2',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='B1',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='B0',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A0',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='A1',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='A2',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='A3',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='A4',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='A5',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='A6',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='A7',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS257', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS257'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS257\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='S',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='I1d',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='I0d',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Qc',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='I1c',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='I0c',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='I0a',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I1a',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Qa',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='I0b',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I1b',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Qb',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='Qd',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS258', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS258'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS258\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='S',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='I1d',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='I0d',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{Qc}',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='I1c',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='I0c',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='I0a',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I1a',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{Qa}',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='I0b',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I1b',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{Qb}',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='~{Qd}',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS266', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS266'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS266\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '3', '7', '14', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '6', '14', '4', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '7', '14', '9', '10']},{'label': 'uD', 'num': 4, 'pin_nums': ['7', '12', '14', '13', '11']}] }),
        Part(**{ 'name':'74LS280', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS280'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS280\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='E',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='F',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='H',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Even',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{Odd}',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='B',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS283', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS283'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS283\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='S2',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='S4',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='B4',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='S3',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='B3',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='B2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='S1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='B1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='C0',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='C4',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS290', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS290'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS290\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='R9(1)',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{CKA}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{CKB}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='R0(1)',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='R0(2)',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='R9(2)',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Q0',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS295', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS295'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS295\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='Ds',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='LD',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{CK}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS298', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS298'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS298\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='I1b',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='WS',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{CK}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Qd',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='Qc',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='Qb',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='Qa',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='I1a',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I0a',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I0b',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I1c',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I1d',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I0d',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='I0c',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS299', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS299'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS299\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='S0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Ds0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='CK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='IO1',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='IO3',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='IO5',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='IO7',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='Q7',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='Ds7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='S1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{G1}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{G2}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IO6',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='IO4',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='IO2',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='IO0',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~{CLR}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS348', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS348'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS348\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{I4}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{IO}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{I1}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{I2}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{I3}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{GS}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~{EO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{I5}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{I6}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{I7}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{EI}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{S2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{S1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~{S0}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS352', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS352'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS352\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{ENa}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='I0b',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='I1b',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='I2b',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='I3b',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{ENb}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3a',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I2a',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I1a',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I0a',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{Qa}',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~{Qb}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS353', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS353'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS353\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{ENa}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='I0b',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='I1b',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='I2b',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='I3b',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{ENb}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3a',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I2a',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I1a',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I0a',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{Qa}',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='~{Qb}',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS365', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS365'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS365\n\n', 'pins':[
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='~{E1}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='O5',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='O6',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{E2}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='O1',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='O2',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='O3',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='O4',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[{'label': 'u', 'num': 0, 'pin_nums': ['16', '8']},{'label': 'uA', 'num': 1, 'pin_nums': ['6', '4', '9', '14', '1', '12', '10', '8', '3', '5', '7', '11', '13', '15', '2', '16']}] }),
        Part(**{ 'name':'74LS366', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS366'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS366\n\n', 'pins':[
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='~{E1}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{O5}',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{O6}',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{E2}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{O1}',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{O2}',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{O3}',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='~{O4}',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[{'label': 'u', 'num': 0, 'pin_nums': ['8', '16']},{'label': 'uA', 'num': 1, 'pin_nums': ['14', '5', '11', '3', '9', '8', '16', '6', '1', '15', '12', '4', '10', '13', '7', '2']}] }),
        Part(**{ 'name':'74LS367', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS367'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS367\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{1G}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='1I4',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='2Y1',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='2I1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='2Y2',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='2I2',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{2G}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='1I1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='1Y1',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='1I2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='1Y2',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='1I3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='1Y3',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='1Y4',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS368', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS368'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS368\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{1G}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='1I4',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{2Y1}',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='2I1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{2Y2}',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='2I2',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{2G}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='1I1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{1Y1}',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='1I2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{1Y2}',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='1I3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{1Y3}',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='~{1Y4}',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS386', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS386'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS386\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '7', '2', '3', '14']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '7', '5', '14', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['7', '10', '14', '8', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['12', '7', '11', '13', '14']}] }),
        Part(**{ 'name':'74LS390', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS390'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS390\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{CK0}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='CLR',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{Ck1}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='Q2',func=pin_types.OUTPUT,unit=2),
            Pin(num='11',name='Q1',func=pin_types.OUTPUT,unit=2),
            Pin(num='12',name='~{Ck1}',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='Q0',func=pin_types.OUTPUT,unit=2),
            Pin(num='14',name='CLR',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='~{CK0}',func=pin_types.INPUT,unit=2),
            Pin(num='9',name='Q3',func=pin_types.OUTPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['4', '2', '7', '8', '16', '5', '1', '3', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['15', '11', '13', '8', '16', '14', '12', '9', '10']}] }),
        Part(**{ 'name':'74LS395', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS395'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS395\n\n', 'pins':[
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='16',name='VDD',func=pin_types.PWRIN),
            Pin(num='1',name='~{R}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{CK}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q4',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='Ds',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='LD',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{EN}',func=pin_types.INPUT,unit=1)], 'unit_defs':[{'label': 'u', 'num': 0, 'pin_nums': ['8', '16']},{'label': 'uA', 'num': 1, 'pin_nums': ['11', '4', '6', '9', '1', '14', '10', '8', '16', '12', '3', '5', '7', '15', '2', '13']}] }),
        Part(**{ 'name':'74LS396', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS396'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS396\n\n', 'pins':[
            Pin(num='1',name='2Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='1Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='2Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='1Q4',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='2Q4',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='1Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='2Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='1Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='CK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='D3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS398', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS398'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS398\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='WS',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Qc',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='~{Qc}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='I0c',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='I1c',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='I1d',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='I0d',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{Qd}',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='Qd',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='Qa',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='~{Qa}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='I0a',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I1a',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I1b',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I0b',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{Qb}',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Qb',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS399', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS399'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS399\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='WS',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Qc',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='I0c',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='I1c',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='I1d',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='I0d',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='Qd',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='Qa',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='I0a',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I1a',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I1b',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I0b',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Qb',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='CK',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS445', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS445'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS445\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{Q0}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='~{Q8}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='~{Q9}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{Q1}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='~{Q2}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='~{Q3}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='~{Q4}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='~{Q5}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='~{Q6}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='~{Q7}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS465', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS465'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS465\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='~{G1}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='B4',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='A4',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='B5',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='A5',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='B6',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='A6',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='B7',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='A7',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='~{G2}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A0',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='B0',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='A1',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='B1',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='A2',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='B2',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='A3',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='B3',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS466', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS466'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS466\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='~{G1}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{B4}',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='A4',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='~{B5}',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='A5',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='~{B6}',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='A6',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='~{B7}',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='A7',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='~{G2}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A0',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='~{B0}',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='A1',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='~{B1}',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='A2',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='~{B2}',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='A3',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='~{B3}',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS467', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS467'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS467\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='I0',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='O0',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='O1',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='O2',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='O3',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='O0',func=pin_types.TRISTATE,unit=2),
            Pin(num='12',name='I0',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='O1',func=pin_types.TRISTATE,unit=2),
            Pin(num='14',name='I1',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='O2',func=pin_types.TRISTATE,unit=2),
            Pin(num='16',name='I2',func=pin_types.INPUT,unit=2),
            Pin(num='17',name='O3',func=pin_types.TRISTATE,unit=2),
            Pin(num='18',name='I3',func=pin_types.INPUT,unit=2),
            Pin(num='19',name='~{OE}',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['10', '8', '20', '5', '9', '3', '7', '1', '6', '2', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['10', '20', '12', '14', '16', '18', '13', '15', '17', '19', '11']}] }),
        Part(**{ 'name':'74LS468', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS468'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS468\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{O3}',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='~{O2}',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='~{O1}',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='~{O0}',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='I0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='I0',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='I1',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='I2',func=pin_types.INPUT,unit=2),
            Pin(num='17',name='I3',func=pin_types.INPUT,unit=2),
            Pin(num='19',name='~{OE}',func=pin_types.INPUT,unit=2),
            Pin(num='3',name='~{O3}',func=pin_types.TRISTATE,unit=2),
            Pin(num='5',name='~{O2}',func=pin_types.TRISTATE,unit=2),
            Pin(num='7',name='~{O1}',func=pin_types.TRISTATE,unit=2),
            Pin(num='9',name='~{O0}',func=pin_types.TRISTATE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['18', '1', '14', '12', '20', '2', '16', '8', '10', '4', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['11', '15', '19', '5', '9', '3', '7', '17', '20', '10', '13']}] }),
        Part(**{ 'name':'74LS49', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS49'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS49\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{b}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='~{a}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='~{g}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='~{f}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{BI}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{e}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='~{d}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='~{c}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS540', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS540'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS540\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='~{G1}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{B7}',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='~{B6}',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='~{B5}',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='~{B4}',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='~{B3}',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='~{B2}',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='~{B1}',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='~{B0}',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='~{G2}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A7',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS541', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS541'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS541\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='~{G1}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='B7',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='B6',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='B5',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='B4',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='B3',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='B2',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='B1',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='B0',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='~{G2}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A7',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS55', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS55'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS55\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{Y}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS56', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS56'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS56\n\n', 'pins':[
            Pin(num='2',name='VCC',func=pin_types.PWRIN),
            Pin(num='4',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{CLKB}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Qa',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='~{CLKA}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='CLR',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Qb',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='Qc',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS590', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS590'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS590\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='Qb',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~{CCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CCK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{CCKEN}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='RCK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='Qa',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='Qc',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Qd',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Qe',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Qf',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Qg',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Qh',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~{RCO}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS591', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS591'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS591\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='Qb',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~{CCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CCK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{CCKEN}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='RCK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='Qa',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='Qc',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Qd',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Qe',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Qf',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Qg',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Qh',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~{RCO}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS594', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS594'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS594\n\n', 'pins':[
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='QB',func=pin_types.TRISTATE,unit=1),
            Pin(num='10',name='~{SCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='RCLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{G}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SER',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='QA',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='QC',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='QD',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='QE',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='QF',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='QG',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='QH',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='QHser',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS595', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS595'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS595\n\n', 'pins':[
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='QB',func=pin_types.TRISTATE,unit=1),
            Pin(num='10',name='~{SCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='RCLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{G}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SER',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='QA',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='QC',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='QD',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='QE',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='QF',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='QG',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='QH',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='QHser',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS596', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS596'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS596\n\n', 'pins':[
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='QB',func=pin_types.TRISTATE,unit=1),
            Pin(num='10',name='~{SCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='RCLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{G}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SER',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='QA',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='QC',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='QD',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='QE',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='QF',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='QG',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='QH',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='QHser',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS597', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS597'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS597\n\n', 'pins':[
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{R}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{SLoad}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SER',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='E',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='F',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='H',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='QH',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS599', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS599'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS599\n\n', 'pins':[
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='QB',func=pin_types.TRISTATE,unit=1),
            Pin(num='10',name='~{SCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='RCLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{G}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SER',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='QA',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='QC',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='QD',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='QE',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='QF',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='QG',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='QH',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='QHser',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS620', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS620'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS620\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='GAB',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{B7}',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='~{B6}',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='~{B5}',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='~{B4}',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='~{B3}',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='~{B2}',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='~{B1}',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='~{B0}',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='~{GBA}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A0',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='A1',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='A2',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='A3',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='A4',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='A5',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='A6',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='A7',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS621', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS621'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS621\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='GAB',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='B7',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='B6',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='B5',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='B4',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='B3',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='B2',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='B1',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='B0',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='~{GBA}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A0',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='A1',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='A2',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='A3',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='A4',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='A5',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='A6',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='A7',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS622', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS622'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS622\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='GAB',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{B7}',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='~{B6}',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='~{B5}',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='~{B4}',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='~{B3}',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='~{B2}',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='~{B1}',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='~{B0}',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='~{GBA}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A0',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='A1',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='A2',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='A3',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='A4',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='A5',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='A6',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='A7',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS623', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS623'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS623\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='GAB',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='B7',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='B6',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='B5',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='B4',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='B3',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='B2',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='B1',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='B0',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='~{GBA}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A0',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='A1',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='A2',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='A3',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='A4',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='A5',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='A6',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='A7',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS638', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS638'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS638\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='~{DIR}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{B7}',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='~{B6}',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='~{B5}',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='~{B4}',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='~{B3}',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='~{B2}',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='~{B1}',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='~{B0}',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='~{G}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A0',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='A1',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='A2',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='A3',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='A4',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='A5',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='A6',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='A7',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS670', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS670'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS670\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Q1',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='~{RD}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{WR}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='Wb',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='Wa',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Rb',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Ra',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Q4',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='Q3',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='Q2',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS682', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS682'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS682\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{P>Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='P4',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q4',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='P5',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='Q5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='P6',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='Q6',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='P7',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='Q7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{P=Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Q0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Q2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Q3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS683', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS683'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS683\n\n', 'pins':[
            Pin(num='1',name='~{P>Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='P4',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q4',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='P5',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='Q5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='P6',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='Q6',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='P7',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='Q7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{P=Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Q0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Q2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Q3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS686', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS686'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS686\n\n', 'pins':[
            Pin(num='1',name='~{P>Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q3',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='P4',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='Q4',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='P5',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='Q5',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='P6',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='Q6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{G1}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='P7',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='Q7',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='~{P=Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='~{G2}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Q0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Q1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Q2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS687', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS687'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS687\n\n', 'pins':[
            Pin(num='1',name='~{P>Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q3',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='P4',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='Q4',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='P5',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='Q5',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='P6',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='Q6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{G1}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='P7',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='Q7',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='~{P=Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='~{G2}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Q0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Q1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Q2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS688', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS688'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS688\n\n', 'pins':[
            Pin(num='1',name='~{G1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='P4',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q4',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='P5',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='Q5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='P6',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='Q6',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='P7',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='Q7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{P=Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Q0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Q2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Q3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS689', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS689'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS689\n\n', 'pins':[
            Pin(num='1',name='~{G1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='P4',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q4',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='P5',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='Q5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='P6',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='Q6',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='P7',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='Q7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{P=Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Q0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Q2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Q3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74S140', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74S140'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74S140\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '1', '2', '7', '5', '14', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['8', '12', '13', '9', '7', '10', '14']}] }),
        Part(**{ 'name':'7403', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7403'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7403\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['7', '1', '2', '3', '14']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '4', '6', '14', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['7', '8', '9', '14', '10']},{'label': 'uD', 'num': 4, 'pin_nums': ['7', '13', '11', '12', '14']}] }),
        Part(**{ 'name':'74125', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74125'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74125\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='O',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='EN',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='D',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='O',func=pin_types.TRISTATE,unit=2),
            Pin(num='10',name='EN',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='O',func=pin_types.TRISTATE,unit=3),
            Pin(num='9',name='D',func=pin_types.INPUT,unit=3),
            Pin(num='13',name='EN',func=pin_types.INPUT,unit=4),
            Pin(num='11',name='O',func=pin_types.TRISTATE,unit=4),
            Pin(num='12',name='D',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['7', '3', '14', '1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '14', '5', '4', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['7', '9', '14', '10', '8']},{'label': 'uD', 'num': 4, 'pin_nums': ['7', '13', '11', '14', '12']}] }),
        Part(**{ 'name':'74145', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74145'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74145\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{Q0}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='~{Q8}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='~{Q9}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{Q1}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='~{Q2}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='~{Q3}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='~{Q4}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='~{Q5}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='~{Q6}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='~{Q7}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'7416', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7416'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7416\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='10',name='~',func=pin_types.OPENCOLL,unit=5),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OPENCOLL,unit=6),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['14', '7', '2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '14', '3', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '14', '6', '7']},{'label': 'uD', 'num': 4, 'pin_nums': ['9', '14', '8', '7']},{'label': 'uE', 'num': 5, 'pin_nums': ['10', '11', '14', '7']},{'label': 'uF', 'num': 6, 'pin_nums': ['13', '14', '12', '7']}] }),
        Part(**{ 'name':'7417', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7417'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7417\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='10',name='~',func=pin_types.OPENCOLL,unit=5),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OPENCOLL,unit=6),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '14', '7', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '14', '7', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '14', '7', '6']},{'label': 'uD', 'num': 4, 'pin_nums': ['9', '8', '7', '14']},{'label': 'uE', 'num': 5, 'pin_nums': ['11', '14', '7', '10']},{'label': 'uF', 'num': 6, 'pin_nums': ['12', '14', '7', '13']}] }),
        Part(**{ 'name':'74196', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74196'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74196\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{LD}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Qd',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{CLR}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='Qc',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Qa',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{CK2}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{CK1}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Qb',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74246', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74246'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74246\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{d}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='~{c}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='~{b}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='~{a}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='~{g}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='~{f}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{LT}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{BI}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{RBI}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{e}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74247', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74247'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74247\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{d}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='~{c}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='~{b}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='~{a}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='~{g}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='~{f}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{LT}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{BI}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{RBI}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{e}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74248', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74248'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74248\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='d',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='c',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='b',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='a',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='g',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='f',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{LT}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{BI}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{RBI}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='e',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74249', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74249'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74249\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='d',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='c',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='b',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='a',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='g',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='f',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{LT}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{BI}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{RBI}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='e',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'7438', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7438'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7438\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'u', 'num': 0, 'pin_nums': ['7', '14']},{'label': 'uA', 'num': 1, 'pin_nums': ['2', '7', '14', '1', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '7', '14', '6', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['9', '10', '7', '14', '8']},{'label': 'uD', 'num': 4, 'pin_nums': ['12', '7', '14', '13', '11']}] }),
        Part(**{ 'name':'7439', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7439'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7439\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '14', '2', '1', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['14', '4', '5', '6', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '8', '14', '9', '7']},{'label': 'uD', 'num': 4, 'pin_nums': ['11', '14', '12', '13', '7']}] }),
        Part(**{ 'name':'74426', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74426'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74426\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='O',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='EN',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='D',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='O',func=pin_types.TRISTATE,unit=2),
            Pin(num='10',name='EN',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='O',func=pin_types.TRISTATE,unit=3),
            Pin(num='9',name='D',func=pin_types.INPUT,unit=3),
            Pin(num='13',name='EN',func=pin_types.INPUT,unit=4),
            Pin(num='11',name='O',func=pin_types.TRISTATE,unit=4),
            Pin(num='12',name='D',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['14', '2', '1', '3', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['14', '4', '6', '5', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '14', '9', '10', '7']},{'label': 'uD', 'num': 4, 'pin_nums': ['13', '12', '14', '11', '7']}] }),
        Part(**{ 'name':'7447', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'7447'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n7447\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{d}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='~{c}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='~{b}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='~{a}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='~{g}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='~{f}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{LT}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{BI}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{RBI}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{e}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS160', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS160'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS160\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='ENT',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Tc',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='CK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='ENP',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{Pe}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS162', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS162'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS162\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='ENT',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Tc',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='CK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='ENP',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{Pe}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS163', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS163'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS163\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='ENT',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='Tc',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='CK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='ENP',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{Pe}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS169', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS169'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS169\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='U/D',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{ENP}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~{Tc}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='CK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{ENP}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{LD}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS18', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS18'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS18\n\n', 'pins':[
            Pin(num='14',name='VDD',func=pin_types.PWRIN),
            Pin(num='7',name='VSS',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['5', '6', '2', '7', '4', '1', '14']},{'label': 'uB', 'num': 2, 'pin_nums': ['8', '12', '7', '9', '13', '10', '14']}] }),
        Part(**{ 'name':'74LS19', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS19'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS19\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=5),
            Pin(num='11',name='~',func=pin_types.INPUT,unit=5),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=6),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['7', '2', '1', '14']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '3', '4', '14']},{'label': 'uC', 'num': 3, 'pin_nums': ['7', '14', '5', '6']},{'label': 'uD', 'num': 4, 'pin_nums': ['7', '9', '8', '14']},{'label': 'uE', 'num': 5, 'pin_nums': ['7', '10', '11', '14']},{'label': 'uF', 'num': 6, 'pin_nums': ['7', '12', '13', '14']}] }),
        Part(**{ 'name':'74LS191', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS191'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS191\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{LD}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Max/Min',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{RCO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='CK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D/U',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='P3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS193', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS193'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'TTL CNT CNT4', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74ls193.pdf', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS193\n\nTTL CNT CNT4', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{LOAD}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{CO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{BO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='CLR',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='QB',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='QA',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='DOWN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='UP',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='QC',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='QD',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='D',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS197', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS197'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS197\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{Ld}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{CLR}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{CK2}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{CK1}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Q1',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS24', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS24'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS24\n\n', 'pins':[
            Pin(num='14',name='VCC',func=pin_types.PWRIN),
            Pin(num='7',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='9',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='12',name='~',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='~',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '14', '1', '3', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '7', '14', '5', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['9', '14', '10', '8', '7']},{'label': 'uD', 'num': 4, 'pin_nums': ['14', '12', '11', '7', '13']}] }),
        Part(**{ 'name':'74LS323', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS323'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS323\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='S0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Ds0',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='CK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='IO1',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='IO3',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='IO5',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='IO7',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='Q7',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='Ds7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='S1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{G1}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{G2}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IO6',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='IO4',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='IO2',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='IO0',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~{CLR}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS347', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS347'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS347\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{d}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='~{c}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='~{b}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='~{a}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='~{g}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='~{f}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{LT}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{BI}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{RBI}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{e}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS447', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS447'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS447\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{d}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='~{c}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='~{b}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='~{a}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='~{g}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='~{f}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{LT}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{BI}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{RBI}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{e}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS57', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS57'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS57\n\n', 'pins':[
            Pin(num='2',name='VCC',func=pin_types.PWRIN),
            Pin(num='4',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{CLKB}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Qa',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='~{CLKA}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='CLR',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Qb',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='Qc',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS639', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS639'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS639\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='~{DIR}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{B7}',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='~{B6}',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='~{B5}',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='~{B4}',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='~{B3}',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='~{B2}',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='~{B1}',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='~{B0}',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='~{G}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A0',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='A1',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='A2',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='A3',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='A4',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='A5',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='A6',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='A7',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS640', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS640'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS640\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='GAB',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{B7}',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='~{B6}',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='~{B5}',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='~{B4}',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='~{B3}',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='~{B2}',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='~{B1}',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='~{B0}',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='~{GBA}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A0',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='A1',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='A2',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='A3',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='A4',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='A5',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='A6',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='A7',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS641', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS641'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS641\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='GAB',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='B7',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='B6',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='B5',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='B4',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='B3',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='B2',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='B1',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='B0',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='~{GBA}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A0',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='A1',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='A2',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='A3',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='A4',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='A5',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='A6',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='A7',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS642', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS642'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS642\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='GAB',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{B7}',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='~{B6}',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='~{B5}',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='~{B4}',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='~{B3}',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='~{B2}',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='~{B1}',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='~{B0}',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='~{GBA}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A0',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='A1',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='A2',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='A3',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='A4',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='A5',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='A6',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='A7',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS645', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS645'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS645\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='20',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='GAB',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='B7',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='B6',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='B5',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='B4',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='B3',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='B2',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='B1',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='B0',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='~{GBA}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A0',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='A1',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='A2',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='A3',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='A4',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='A5',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='A6',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='A7',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS668', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS668'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS668\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='U/D',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{ENP}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~{Tc}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='CK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{ENP}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{LD}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS669', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS669'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS669\n\n', 'pins':[
            Pin(num='16',name='VCC',func=pin_types.PWRIN),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='U/D',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{ENP}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~{Tc}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='CK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{ENP}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{LD}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS684', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS684'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS684\n\n', 'pins':[
            Pin(num='10',name='GND',func=pin_types.PWRIN),
            Pin(num='1',name='~{P>Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='P4',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q4',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='P5',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='Q5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='P6',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='Q6',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='P7',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='Q7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{P=Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Q0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Q2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Q3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LS685', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LS685'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/74xx_IEEE.kicad_sym\n74LS685\n\n', 'pins':[
            Pin(num='1',name='~{P>Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='P4',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Q4',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='P5',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='Q5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='P6',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='Q6',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='P7',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='Q7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{P=Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='P0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Q0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='P1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Q2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='Q3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] })])