from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_ST_STM32H7 = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'STM32H723VEHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H723VEHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H723/733', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h723ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H723VEHx\n\nArm Cortex-M7 STM32H7 STM32H723/733', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H723VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H723VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H723/733', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h723ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H723VETx\n\nArm Cortex-M7 STM32H7 STM32H723/733', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H723VGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H723VGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H723/733', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h723vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H723VGHx\n\nArm Cortex-M7 STM32H7 STM32H723/733', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H723VGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H723VGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H723/733', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h723vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H723VGTx\n\nArm Cortex-M7 STM32H7 STM32H723/733', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H723ZEIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H723ZEIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-144_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-144_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H723/733', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h723ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H723ZEIx\n\nArm Cortex-M7 STM32H7 STM32H723/733', 'pins':[
            Pin(num='A1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H723ZETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H723ZETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H723/733', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h723ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H723ZETx\n\nArm Cortex-M7 STM32H7 STM32H723/733', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H723ZGIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H723ZGIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-144_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-144_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H723/733', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h723zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H723ZGIx\n\nArm Cortex-M7 STM32H7 STM32H723/733', 'pins':[
            Pin(num='A1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H723ZGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H723ZGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H723/733', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h723zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H723ZGTx\n\nArm Cortex-M7 STM32H7 STM32H723/733', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H725AEIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H725AEIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H725/735', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h725ae.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H725AEIx\n\nArm Cortex-M7 STM32H7 STM32H725/735', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A11',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='F3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VDD50USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='N11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H725AGIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H725AGIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H725/735', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h725ag.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H725AGIx\n\nArm Cortex-M7 STM32H7 STM32H725/735', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A11',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='F3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VDD50USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='N11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H725IEKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H725IEKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H725/735', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h725ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H725IEKx\n\nArm Cortex-M7 STM32H7 STM32H725/735', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A14',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='C6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='D5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='VDD50USB',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F14',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='L12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R14',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='R15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H725IETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H725IETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H725/735', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h725ie.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H725IETx\n\nArm Cortex-M7 STM32H7 STM32H725/735', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='101',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='107',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='113',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='114',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='120',name='VDD50USB',func=pin_types.PWRIN,unit=1),
            Pin(num='121',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='127',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='134',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='135',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='138',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='149',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='152',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='153',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='159',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='160',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='161',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='168',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='170',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='172',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='173',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='174',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='175',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='176',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='66',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='81',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H725IGKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H725IGKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H725/735', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h725ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H725IGKx\n\nArm Cortex-M7 STM32H7 STM32H725/735', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A14',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='C6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='D5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='VDD50USB',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F14',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='L12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R14',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='R15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H725IGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H725IGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H725/735', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h725ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H725IGTx\n\nArm Cortex-M7 STM32H7 STM32H725/735', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='101',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='107',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='113',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='114',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='120',name='VDD50USB',func=pin_types.PWRIN,unit=1),
            Pin(num='121',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='127',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='134',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='135',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='138',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='149',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='152',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='153',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='159',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='160',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='161',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='168',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='170',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='172',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='173',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='174',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='175',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='176',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='66',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='81',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H725REVx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H725REVx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-68-1EP_8x8mm_P0.4mm_EP6.4x6.4mm'], 'footprint':'Package_DFN_QFN:QFN-68-1EP_8x8mm_P0.4mm_EP6.4x6.4mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H725/735', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h725re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H725REVx\n\nArm Cortex-M7 STM32H7 STM32H725/735', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='34',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='64',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='67',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='69',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H725RGVx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H725RGVx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-68-1EP_8x8mm_P0.4mm_EP6.4x6.4mm'], 'footprint':'Package_DFN_QFN:QFN-68-1EP_8x8mm_P0.4mm_EP6.4x6.4mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H725/735', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h725rg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H725RGVx\n\nArm Cortex-M7 STM32H7 STM32H725/735', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='34',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='64',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='67',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='69',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H725VEHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H725VEHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H725/735', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h725ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H725VEHx\n\nArm Cortex-M7 STM32H7 STM32H725/735', 'pins':[
            Pin(num='A1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='D10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='D4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='E3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='G7',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB14',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H725VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H725VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H725/735', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h725ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H725VETx\n\nArm Cortex-M7 STM32H7 STM32H725/735', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='73',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='77',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='89',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='90',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='98',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='VDDLDO',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H725VGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H725VGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H725/735', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h725vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H725VGHx\n\nArm Cortex-M7 STM32H7 STM32H725/735', 'pins':[
            Pin(num='A1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='D10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='D4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='E3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='G7',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB14',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H725VGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H725VGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H725/735', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h725vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H725VGTx\n\nArm Cortex-M7 STM32H7 STM32H725/735', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='73',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='77',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='89',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='90',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='98',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='VDDLDO',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H725VGYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H725VGYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-115_3.73x4.15mm_P0.35mm_Stagger'], 'footprint':'Package_CSP:ST_WLCSP-115_3.73x4.15mm_P0.35mm_Stagger', 'keywords':'Arm Cortex-M7 STM32H7 STM32H725/735', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h725vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H725VGYx\n\nArm Cortex-M7 STM32H7 STM32H725/735', 'pins':[
            Pin(num='A10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='AA10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='AA2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='AA6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA8',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='C10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='C4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C8',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D1',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D11',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='H3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD50USB',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='K3',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='L2',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M3',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='R2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='U10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U4',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='V1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='V11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='V3',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V9',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='W2',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='W4',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='Y11',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='Y3',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='Y5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='Y9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H725ZETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H725ZETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H725/735', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h725ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H725ZETx\n\nArm Cortex-M7 STM32H7 STM32H725/735', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='104',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='105',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='107',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='119',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='120',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='129',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='136',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='141',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='142',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='143',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='69',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='71',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VDD50USB',func=pin_types.PWRIN,unit=1),
            Pin(num='91',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='93',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PA10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H725ZGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H725ZGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H725/735', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h725zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H725ZGTx\n\nArm Cortex-M7 STM32H7 STM32H725/735', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='104',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='105',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='107',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='119',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='120',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='129',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='136',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='141',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='142',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='143',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='69',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='71',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VDD50USB',func=pin_types.PWRIN,unit=1),
            Pin(num='91',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='93',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PA10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H730ABIxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H730ABIxQ'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H730 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h730ab.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H730ABIxQ\n\nArm Cortex-M7 STM32H7 STM32H730 Value line', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A11',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='F3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VDD50USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='N11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H730IBKxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H730IBKxQ'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H730 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h730ib.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H730IBKxQ\n\nArm Cortex-M7 STM32H7 STM32H730 Value line', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A14',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='C6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='D5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='VDD50USB',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F14',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='L12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R14',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='R15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H730IBTxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H730IBTxQ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H730 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h730ib.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H730IBTxQ\n\nArm Cortex-M7 STM32H7 STM32H730 Value line', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='101',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='107',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='113',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='114',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='120',name='VDD50USB',func=pin_types.PWRIN,unit=1),
            Pin(num='121',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='127',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='134',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='135',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='138',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='149',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='152',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='153',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='159',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='160',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='161',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='168',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='170',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='172',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='173',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='174',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='175',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='176',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='66',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='81',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H730VBHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H730VBHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H730 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h730vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H730VBHx\n\nArm Cortex-M7 STM32H7 STM32H730 Value line', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H730VBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H730VBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H730 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h730vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H730VBTx\n\nArm Cortex-M7 STM32H7 STM32H730 Value line', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H730ZBIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H730ZBIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-144_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-144_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H730 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h730zb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H730ZBIx\n\nArm Cortex-M7 STM32H7 STM32H730 Value line', 'pins':[
            Pin(num='A1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H730ZBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H730ZBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H730 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h730zb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H730ZBTx\n\nArm Cortex-M7 STM32H7 STM32H730 Value line', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H733VGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H733VGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H723/733', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h733vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H733VGHx\n\nArm Cortex-M7 STM32H7 STM32H723/733', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H733VGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H733VGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H723/733', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h733vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H733VGTx\n\nArm Cortex-M7 STM32H7 STM32H723/733', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H733ZGIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H733ZGIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-144_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-144_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H723/733', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h733zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H733ZGIx\n\nArm Cortex-M7 STM32H7 STM32H723/733', 'pins':[
            Pin(num='A1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='H8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H733ZGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H733ZGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H723/733', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h733zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H733ZGTx\n\nArm Cortex-M7 STM32H7 STM32H723/733', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H735AGIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H735AGIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H725/735', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h735ag.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H735AGIx\n\nArm Cortex-M7 STM32H7 STM32H725/735', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A11',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='F3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VDD50USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='N11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H735IGKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H735IGKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H725/735', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h735ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H735IGKx\n\nArm Cortex-M7 STM32H7 STM32H725/735', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A14',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='C6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='D5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='VDD50USB',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F14',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='L12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R14',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='R15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H735IGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H735IGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H725/735', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h735ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H735IGTx\n\nArm Cortex-M7 STM32H7 STM32H725/735', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='101',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='107',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='113',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='114',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='120',name='VDD50USB',func=pin_types.PWRIN,unit=1),
            Pin(num='121',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='127',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='134',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='135',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='138',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='149',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='152',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='153',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='159',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='160',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='161',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='168',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='170',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='172',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='173',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='174',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='175',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='176',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='66',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='81',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H735RGVx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H735RGVx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-68-1EP_8x8mm_P0.4mm_EP6.4x6.4mm'], 'footprint':'Package_DFN_QFN:QFN-68-1EP_8x8mm_P0.4mm_EP6.4x6.4mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H725/735', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h735rg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H735RGVx\n\nArm Cortex-M7 STM32H7 STM32H725/735', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='34',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='64',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='67',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='69',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H735VGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H735VGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H725/735', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h735vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H735VGHx\n\nArm Cortex-M7 STM32H7 STM32H725/735', 'pins':[
            Pin(num='A1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='D10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='D4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='E3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='G7',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB14',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H735VGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H735VGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H725/735', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h735vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H735VGTx\n\nArm Cortex-M7 STM32H7 STM32H725/735', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='73',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='77',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='89',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='90',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='98',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='VDDLDO',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H735VGYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H735VGYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-115_3.73x4.15mm_P0.35mm_Stagger'], 'footprint':'Package_CSP:ST_WLCSP-115_3.73x4.15mm_P0.35mm_Stagger', 'keywords':'Arm Cortex-M7 STM32H7 STM32H725/735', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h735vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H735VGYx\n\nArm Cortex-M7 STM32H7 STM32H725/735', 'pins':[
            Pin(num='A10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='AA10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='AA2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='AA4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='AA6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='AA8',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='C10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='C4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C8',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D1',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D11',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='H3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD50USB',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='K3',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='L2',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M3',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N2',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='P11',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='R2',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='U10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U4',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='V1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='V11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='V3',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='V7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='V9',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='W10',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='W2',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='W4',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='Y11',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='Y3',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='Y5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='Y7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='Y9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H735ZGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H735ZGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H725/735', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h735zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H735ZGTx\n\nArm Cortex-M7 STM32H7 STM32H725/735', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA13(JTMS',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='104',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='105',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='107',name='PA14(JTCK',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PA15(JTDI)',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='119',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='120',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='129',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='PB3(JTDO',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PB4(NJTRST)',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='136',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='141',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='142',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='143',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='69',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='71',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VDD50USB',func=pin_types.PWRIN,unit=1),
            Pin(num='91',name='VDD33USB',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='93',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PA10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H742A_G-I_Ix', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H742A_G-I_Ix'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H742', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h742ag.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H742A_G-I_Ix\n\nArm Cortex-M7 STM32H7 STM32H742', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A11',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='N11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H742B_G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H742B_G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H742', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h742bg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H742B_G-I_Tx\n\nArm Cortex-M7 STM32H7 STM32H742', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='125',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='126',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H742I_G-I_Kx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H742I_G-I_Kx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H742', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h742ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H742I_G-I_Kx\n\nArm Cortex-M7 STM32H7 STM32H742', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H742I_G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H742I_G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H742', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h742ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H742I_G-I_Tx\n\nArm Cortex-M7 STM32H7 STM32H742', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H742V_G-I_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H742V_G-I_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H742', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h742vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H742V_G-I_Hx\n\nArm Cortex-M7 STM32H7 STM32H742', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H742V_G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H742V_G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H742', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h742vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H742V_G-I_Tx\n\nArm Cortex-M7 STM32H7 STM32H742', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H742X_G-I_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H742X_G-I_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-265_14x14mm_Layout17x17_P0.8mm'], 'footprint':'Package_BGA:TFBGA-265_14x14mm_Layout17x17_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H742', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h742xg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H742X_G-I_Hx\n\nArm Cortex-M7 STM32H7 STM32H742', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A8',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C14',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E10',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E8',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G17',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L14',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='L17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='L2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='M17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='M2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='U12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H742Z_G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H742Z_G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H742', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h742zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H742Z_G-I_Tx\n\nArm Cortex-M7 STM32H7 STM32H742', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H743A_G-I_Ix', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H743A_G-I_Ix'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H743/753', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h743ag.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H743A_G-I_Ix\n\nArm Cortex-M7 STM32H7 STM32H743/753', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A11',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='N11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H743BGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H743BGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H743/753', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h743bg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H743BGTx\n\nArm Cortex-M7 STM32H7 STM32H743/753', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='125',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='126',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H743BITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H743BITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H743/753', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h743bi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H743BITx\n\nArm Cortex-M7 STM32H7 STM32H743/753', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='125',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='126',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H743IGKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H743IGKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H743/753', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h743ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H743IGKx\n\nArm Cortex-M7 STM32H7 STM32H743/753', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H743IGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H743IGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H743/753', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h743ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H743IGTx\n\nArm Cortex-M7 STM32H7 STM32H743/753', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H743IIKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H743IIKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H743/753', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h743ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H743IIKx\n\nArm Cortex-M7 STM32H7 STM32H743/753', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H743IITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H743IITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H743/753', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h743ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H743IITx\n\nArm Cortex-M7 STM32H7 STM32H743/753', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H743VGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H743VGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H743/753', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h743vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H743VGTx\n\nArm Cortex-M7 STM32H7 STM32H743/753', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H743VITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H743VITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H743/753', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h743vi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H743VITx\n\nArm Cortex-M7 STM32H7 STM32H743/753', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H743V_G-I_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H743V_G-I_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H743/753', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h743vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H743V_G-I_Hx\n\nArm Cortex-M7 STM32H7 STM32H743/753', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H743XGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H743XGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-265_14x14mm_Layout17x17_P0.8mm'], 'footprint':'Package_BGA:TFBGA-265_14x14mm_Layout17x17_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H743/753', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h743xg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H743XGHx\n\nArm Cortex-M7 STM32H7 STM32H743/753', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A8',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C14',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E10',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E8',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G17',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L14',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='L17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='L2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='M17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='M2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='U12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H743XIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H743XIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-265_14x14mm_Layout17x17_P0.8mm'], 'footprint':'Package_BGA:TFBGA-265_14x14mm_Layout17x17_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H743/753', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h743xi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H743XIHx\n\nArm Cortex-M7 STM32H7 STM32H743/753', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A8',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C14',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E10',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E8',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G17',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L14',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='L17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='L2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='M17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='M2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='U12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H743ZGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H743ZGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H743/753', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h743zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H743ZGTx\n\nArm Cortex-M7 STM32H7 STM32H743/753', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H743ZITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H743ZITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H743/753', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h743zi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H743ZITx\n\nArm Cortex-M7 STM32H7 STM32H743/753', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H745BGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H745BGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H745/755', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h745bg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H745BGTx\n\nArm Cortex-M7 STM32H7 STM32H745/755', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='101',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='133',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='134',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='141',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='142',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='149',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='150',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='153',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='154',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='155',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='156',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='159',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='160',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='161',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='162',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='170',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='172',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='179',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='180',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='185',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='186',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='187',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='188',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='190',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='195',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='198',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='200',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='201',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='202',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='203',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='204',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='205',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='208',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='75',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='81',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H745BITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H745BITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H745/755', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h745bi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H745BITx\n\nArm Cortex-M7 STM32H7 STM32H745/755', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='101',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='133',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='134',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='141',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='142',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='149',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='150',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='153',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='154',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='155',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='156',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='159',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='160',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='161',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='162',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='170',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='172',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='179',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='180',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='185',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='186',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='187',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='188',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='190',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='195',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='198',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='200',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='201',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='202',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='203',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='204',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='205',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='208',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='75',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='81',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H745IGKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H745IGKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H745/755', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h745ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H745IGKx\n\nArm Cortex-M7 STM32H7 STM32H745/755', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A14',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='C6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='D5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F14',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='L12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R14',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='R15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H745IGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H745IGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H745/755', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h745ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H745IGTx\n\nArm Cortex-M7 STM32H7 STM32H745/755', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='101',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='107',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='113',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='114',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='120',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='121',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='127',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='134',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='135',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='138',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='149',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='152',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='153',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='159',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='160',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='161',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='168',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='170',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='172',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='173',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='174',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='175',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='176',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='66',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='81',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H745IIKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H745IIKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H745/755', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h745ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H745IIKx\n\nArm Cortex-M7 STM32H7 STM32H745/755', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A14',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='C6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='D5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F14',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='L12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R14',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='R15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H745IITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H745IITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H745/755', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h745ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H745IITx\n\nArm Cortex-M7 STM32H7 STM32H745/755', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='101',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='107',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='113',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='114',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='120',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='121',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='127',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='134',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='135',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='138',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='149',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='152',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='153',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='159',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='160',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='161',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='168',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='170',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='172',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='173',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='174',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='175',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='176',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='66',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='81',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H745XGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H745XGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-265_14x14mm_Layout17x17_P0.8mm'], 'footprint':'Package_BGA:TFBGA-265_14x14mm_Layout17x17_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H745/755', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h745xg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H745XGHx\n\nArm Cortex-M7 STM32H7 STM32H745/755', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A8',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C14',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E8',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G17',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L14',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='L17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='L2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='M17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='M2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='U12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H745XIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H745XIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-265_14x14mm_Layout17x17_P0.8mm'], 'footprint':'Package_BGA:TFBGA-265_14x14mm_Layout17x17_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H745/755', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h745xi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H745XIHx\n\nArm Cortex-M7 STM32H7 STM32H745/755', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A8',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C14',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E8',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G17',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L14',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='L17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='L2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='M17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='M2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='U12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H745ZGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H745ZGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H745/755', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h745zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H745ZGTx\n\nArm Cortex-M7 STM32H7 STM32H745/755', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='104',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='105',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='107',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='119',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='120',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='129',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='136',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='141',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='142',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='143',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='69',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='71',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='91',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='93',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PA10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H745ZITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H745ZITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H745/755', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h745zi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H745ZITx\n\nArm Cortex-M7 STM32H7 STM32H745/755', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='104',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='105',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='107',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='119',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='120',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='129',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='136',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='141',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='142',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='143',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='69',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='71',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='91',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='93',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PA10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H747A_G-I_Ix', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H747A_G-I_Ix'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H747/757', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h747ag.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H747A_G-I_Ix\n\nArm Cortex-M7 STM32H7 STM32H747/757', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A13',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B13',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='B4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D10',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='F4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='DSI_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='DSI_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H3',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='DSI_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DSI_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='DSI_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='DSI_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='L13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='M2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N10',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VCAP',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H747BGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H747BGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H747/757', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h747bg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H747BGTx\n\nArm Cortex-M7 STM32H7 STM32H747/757', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='101',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='118',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='119',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='12',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='121',name='DSI_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='DSI_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='124',name='DSI_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='DSI_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='127',name='DSI_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='DSI_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='133',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='134',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='141',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='142',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='149',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='150',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='153',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='154',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='155',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='156',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='159',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='160',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='161',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='162',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='170',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='172',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='179',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='180',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='185',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='186',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='187',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='188',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='190',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='195',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='198',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='200',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='201',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='202',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='203',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='204',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='205',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='208',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='75',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='81',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H747BITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H747BITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H747/757', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h747bi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H747BITx\n\nArm Cortex-M7 STM32H7 STM32H747/757', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='101',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='118',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='119',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='12',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='121',name='DSI_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='DSI_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='124',name='DSI_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='DSI_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='127',name='DSI_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='DSI_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='133',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='134',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='141',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='142',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='149',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='150',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='153',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='154',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='155',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='156',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='159',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='160',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='161',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='162',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='170',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='172',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='179',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='180',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='185',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='186',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='187',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='188',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='190',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='195',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='198',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='200',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='201',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='202',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='203',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='204',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='205',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='208',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='75',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='81',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H747IGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H747IGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H747/757', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h747ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H747IGTx\n\nArm Cortex-M7 STM32H7 STM32H747/757', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='101',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='102',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='103',name='DSI_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='DSI_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='DSI_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='DSI_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='113',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='114',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='120',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='121',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='127',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='134',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='135',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='138',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='149',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='152',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='153',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='159',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='160',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='161',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='168',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='170',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='172',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='173',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='174',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='175',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='176',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='66',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='81',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H747IITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H747IITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H747/757', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h747ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H747IITx\n\nArm Cortex-M7 STM32H7 STM32H747/757', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='101',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='102',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='103',name='DSI_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='DSI_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='DSI_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='DSI_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='113',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='114',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='120',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='121',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='127',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='134',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='135',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='138',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='149',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='152',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='153',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='159',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='160',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='161',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='168',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='170',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='172',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='173',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='174',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='175',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='176',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='66',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='81',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H747XGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H747XGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-265_14x14mm_Layout17x17_P0.8mm'], 'footprint':'Package_BGA:TFBGA-265_14x14mm_Layout17x17_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H747/757', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h747xg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H747XGHx\n\nArm Cortex-M7 STM32H7 STM32H747/757', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A8',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C14',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E8',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G17',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='K16',name='DSI_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='DSI_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L14',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='DSI_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DSI_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='DSI_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DSI_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='N2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='P2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='U12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H747XIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H747XIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-265_14x14mm_Layout17x17_P0.8mm'], 'footprint':'Package_BGA:TFBGA-265_14x14mm_Layout17x17_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H747/757', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h747xi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H747XIHx\n\nArm Cortex-M7 STM32H7 STM32H747/757', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A8',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C14',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E8',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G17',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='K16',name='DSI_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='DSI_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L14',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='DSI_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DSI_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='DSI_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DSI_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='N2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='P2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='U12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H747ZIYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H747ZIYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-156_4.96x4.64mm_Layout13x12_P0.35mm'], 'footprint':'Package_CSP:ST_WLCSP-156_4.96x4.64mm_Layout13x12_P0.35mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H747/757', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h747zi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H747ZIYx\n\nArm Cortex-M7 STM32H7 STM32H747/757', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A13',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A2',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='B3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C11',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C5',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D12',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='E12',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F4',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='DSI_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='DSI_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='DSI_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='DSI_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H4',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='DSI_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J13',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='DSI_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K3',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L10',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='L5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L6',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M2',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='M6',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M8',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H750IBKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H750IBKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H750 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h750ib.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H750IBKx\n\nArm Cortex-M7 STM32H7 STM32H750 Value line', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H750IBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H750IBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H750 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h750ib.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H750IBTx\n\nArm Cortex-M7 STM32H7 STM32H750 Value line', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H750VBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H750VBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H750 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h750vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H750VBTx\n\nArm Cortex-M7 STM32H7 STM32H750 Value line', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H750XBHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H750XBHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-265_14x14mm_Layout17x17_P0.8mm'], 'footprint':'Package_BGA:TFBGA-265_14x14mm_Layout17x17_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H750 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h750xb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H750XBHx\n\nArm Cortex-M7 STM32H7 STM32H750 Value line', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A8',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C14',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E10',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E8',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G17',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L14',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='L17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='L2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='M17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='M2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='U12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H750ZBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H750ZBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H750 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h750zb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H750ZBTx\n\nArm Cortex-M7 STM32H7 STM32H750 Value line', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H753AIIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H753AIIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H743/753', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h753ai.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H753AIIx\n\nArm Cortex-M7 STM32H7 STM32H743/753', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A11',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='N11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H753BITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H753BITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H743/753', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h753bi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H753BITx\n\nArm Cortex-M7 STM32H7 STM32H743/753', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='125',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='126',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H753IIKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H753IIKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H743/753', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h753ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H753IIKx\n\nArm Cortex-M7 STM32H7 STM32H743/753', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H753IITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H753IITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H743/753', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h753ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H753IITx\n\nArm Cortex-M7 STM32H7 STM32H743/753', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H753VIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H753VIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H743/753', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h753vi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H753VIHx\n\nArm Cortex-M7 STM32H7 STM32H743/753', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H753VITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H753VITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H743/753', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h753vi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H753VITx\n\nArm Cortex-M7 STM32H7 STM32H743/753', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H753XIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H753XIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-265_14x14mm_Layout17x17_P0.8mm'], 'footprint':'Package_BGA:TFBGA-265_14x14mm_Layout17x17_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H743/753', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h753xi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H753XIHx\n\nArm Cortex-M7 STM32H7 STM32H743/753', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A8',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C14',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E10',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E8',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G17',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L14',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='L17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='L2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='M17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='M2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='U12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H753ZITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H753ZITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H743/753', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h753zi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H753ZITx\n\nArm Cortex-M7 STM32H7 STM32H743/753', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H755BITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H755BITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H745/755', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h755bi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H755BITx\n\nArm Cortex-M7 STM32H7 STM32H745/755', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='101',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='133',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='134',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='141',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='142',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='149',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='150',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='153',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='154',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='155',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='156',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='159',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='160',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='161',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='162',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='170',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='172',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='179',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='180',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='185',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='186',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='187',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='188',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='190',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='195',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='198',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='200',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='201',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='202',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='203',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='204',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='205',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='208',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='75',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='81',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H755IIKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H755IIKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H745/755', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h755ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H755IIKx\n\nArm Cortex-M7 STM32H7 STM32H745/755', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A14',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='C6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='D5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F14',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='L12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R14',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='R15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H755IITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H755IITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H745/755', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h755ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H755IITx\n\nArm Cortex-M7 STM32H7 STM32H745/755', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='101',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='107',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='113',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='114',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='120',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='121',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='127',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='134',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='135',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='138',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='149',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='152',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='153',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='159',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='160',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='161',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='168',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='170',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='172',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='173',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='174',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='175',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='176',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='66',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='81',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H755XIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H755XIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-265_14x14mm_Layout17x17_P0.8mm'], 'footprint':'Package_BGA:TFBGA-265_14x14mm_Layout17x17_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H745/755', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h755xi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H755XIHx\n\nArm Cortex-M7 STM32H7 STM32H745/755', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A8',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C14',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E8',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G17',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L14',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='L17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='L2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='M17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='M2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='U12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H755ZITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H755ZITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H745/755', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h755zi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H755ZITx\n\nArm Cortex-M7 STM32H7 STM32H745/755', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='104',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='105',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='107',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='119',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='120',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='129',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='136',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='141',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='142',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='143',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='69',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='71',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='91',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='93',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PA10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H757AIIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H757AIIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H747/757', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h757ai.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H757AIIx\n\nArm Cortex-M7 STM32H7 STM32H747/757', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A13',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B13',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='B4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D10',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='F4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='DSI_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='DSI_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H3',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='DSI_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DSI_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='DSI_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='DSI_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='L13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='M2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N10',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VCAP',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H757BITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H757BITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H747/757', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h757bi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H757BITx\n\nArm Cortex-M7 STM32H7 STM32H747/757', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='101',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='118',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='119',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='12',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='121',name='DSI_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='DSI_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='124',name='DSI_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='DSI_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='127',name='DSI_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='DSI_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='133',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='134',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='141',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='142',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='149',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='150',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='153',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='154',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='155',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='156',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='159',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='160',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='161',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='162',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='170',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='172',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='179',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='180',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='185',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='186',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='187',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='188',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='190',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='195',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='198',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='200',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='201',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='202',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='203',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='204',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='205',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='208',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='75',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='81',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H757IITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H757IITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H747/757', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h757ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H757IITx\n\nArm Cortex-M7 STM32H7 STM32H747/757', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='101',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='102',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='103',name='DSI_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='DSI_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='DSI_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='DSI_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='VDD12DSI',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='113',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='114',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='120',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='121',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='127',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='134',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='135',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='138',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='149',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='152',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='153',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='159',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='160',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='161',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='168',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='170',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='172',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='173',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='174',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='175',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='176',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='66',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='81',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H757XIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H757XIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-265_14x14mm_Layout17x17_P0.8mm'], 'footprint':'Package_BGA:TFBGA-265_14x14mm_Layout17x17_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H747/757', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h757xi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H757XIHx\n\nArm Cortex-M7 STM32H7 STM32H747/757', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A8',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C14',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E8',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G17',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='K16',name='DSI_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='DSI_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L14',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='DSI_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='DSI_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='DSI_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='DSI_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='N2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='P2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='U12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H757ZIYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H757ZIYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-156_4.96x4.64mm_Layout13x12_P0.35mm'], 'footprint':'Package_CSP:ST_WLCSP-156_4.96x4.64mm_Layout13x12_P0.35mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H747/757', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h757zi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H757ZIYx\n\nArm Cortex-M7 STM32H7 STM32H747/757', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A13',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A2',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='B3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C11',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C5',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D12',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='E12',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F4',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='DSI_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='DSI_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='DSI_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='DSI_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='H4',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='DSI_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J13',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='DSI_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='K10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K3',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L10',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='L5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L6',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M2',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='M6',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M8',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3A_G-I_IxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3A_G-I_IxQ'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3ag.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3A_G-I_IxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A11',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='F3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='N11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3I_G-I_Kx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3I_G-I_Kx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3I_G-I_Kx\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3I_G-I_KxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3I_G-I_KxQ'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3I_G-I_KxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A14',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='C6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='D5',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F14',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='L12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R14',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='R15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3I_G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3I_G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3I_G-I_Tx\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3I_G-I_TxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3I_G-I_TxQ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3I_G-I_TxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='101',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='107',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='113',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='114',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='120',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='121',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='127',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='134',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='135',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='138',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='149',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='152',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='153',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='159',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='160',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='161',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='168',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='170',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='172',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='173',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='174',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='175',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='176',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='66',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='81',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3L_G-I_HxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3L_G-I_HxQ'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-225_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:ST_TFBGA-225_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3lg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3L_G-I_HxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='C6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D15',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E10',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='E7',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='F3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='G3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='K4',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PF12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3N_G-I_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3N_G-I_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3ng.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3N_G-I_Hx\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3QIYxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3QIYxQ'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-132_4.57x4.37mm_Layout12x11_P0.35mm'], 'footprint':'Package_CSP:ST_WLCSP-132_4.57x4.37mm_Layout12x11_P0.35mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3qi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3QIYxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A11',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A6',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='B1',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='C3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E1',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='E12',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='K4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K5',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L4',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='L5',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3R_G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3R_G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3rg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3R_G-I_Tx\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3V_G-I_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3V_G-I_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3V_G-I_Hx\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3V_G-I_HxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3V_G-I_HxQ'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3V_G-I_HxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='D10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='D4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='E3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='G7',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB14',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3V_G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3V_G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3V_G-I_Tx\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3V_G-I_TxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3V_G-I_TxQ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3V_G-I_TxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='73',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='77',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='VDDLDO',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3Z_G-I_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3Z_G-I_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3Z_G-I_Tx\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3Z_G-I_TxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3Z_G-I_TxQ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3Z_G-I_TxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='104',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='105',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='107',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='119',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='120',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='129',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='136',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='141',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='142',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='143',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='69',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='71',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='91',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='93',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PA10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7B0ABIxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7B0ABIxQ'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7B0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7b0ab.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7B0ABIxQ\n\nArm Cortex-M7 STM32H7 STM32H7B0 Value line', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A11',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='F3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='N11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7B0IBKxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7B0IBKxQ'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7B0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7b0ib.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7B0IBKxQ\n\nArm Cortex-M7 STM32H7 STM32H7B0 Value line', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A14',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='C6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='D5',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F14',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='L12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R14',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='R15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7B0IBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7B0IBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7B0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7b0ib.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7B0IBTx\n\nArm Cortex-M7 STM32H7 STM32H7B0 Value line', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7B0RBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7B0RBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7B0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7b0rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7B0RBTx\n\nArm Cortex-M7 STM32H7 STM32H7B0 Value line', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7B0VBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7B0VBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7B0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7b0vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7B0VBTx\n\nArm Cortex-M7 STM32H7 STM32H7B0 Value line', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7B0ZBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7B0ZBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7B0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7b0zb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7B0ZBTx\n\nArm Cortex-M7 STM32H7 STM32H7B0 Value line', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7B3AIIxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7B3AIIxQ'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7b3ai.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7B3AIIxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A11',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='F3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='N11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7B3IIKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7B3IIKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7b3ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7B3IIKx\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7B3IIKxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7B3IIKxQ'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7b3ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7B3IIKxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A14',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='C6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='D5',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F14',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='L12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R14',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='R15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7B3IITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7B3IITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7b3ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7B3IITx\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7B3IITxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7B3IITxQ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7b3ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7B3IITxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='101',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='107',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='113',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='114',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='120',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='121',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='127',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='134',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='135',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='138',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='149',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='152',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='153',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='159',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='160',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='161',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='168',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='170',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='172',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='173',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='174',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='175',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='176',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='66',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='81',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7B3LIHxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7B3LIHxQ'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-225_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:ST_TFBGA-225_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7b3li.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7B3LIHxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='C6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D15',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E10',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='E7',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='F3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='G3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='K4',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PF12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7B3NIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7B3NIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7b3ni.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7B3NIHx\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7B3QIYxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7B3QIYxQ'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-132_4.57x4.37mm_Layout12x11_P0.35mm'], 'footprint':'Package_CSP:ST_WLCSP-132_4.57x4.37mm_Layout12x11_P0.35mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7b3qi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7B3QIYxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A11',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A6',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='B1',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='C3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E1',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='E12',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K2',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='K4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K5',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L4',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='L5',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7B3RITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7B3RITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7b3ri.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7B3RITx\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7B3VIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7B3VIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7b3vi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7B3VIHx\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7B3VIHxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7B3VIHxQ'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7b3vi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7B3VIHxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='D10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='D4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='E3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='G7',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB14',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7B3VITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7B3VITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7b3vi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7B3VITx\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7B3VITxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7B3VITxQ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7b3vi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7B3VITxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='73',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='77',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='VDDLDO',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7B3ZITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7B3ZITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7b3zi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7B3ZITx\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7B3ZITxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7B3ZITxQ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7b3zi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7B3ZITxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='104',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='105',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='107',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='119',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='120',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='129',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='136',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='141',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='142',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='143',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='69',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='71',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='91',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='93',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PA10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H742AGIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H742AGIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H742', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h742ag.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H742AGIx\n\nArm Cortex-M7 STM32H7 STM32H742', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A11',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='N11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H742AIIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H742AIIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H742', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h742ai.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H742AIIx\n\nArm Cortex-M7 STM32H7 STM32H742', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A11',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='N11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H742BGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H742BGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H742', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h742bg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H742BGTx\n\nArm Cortex-M7 STM32H7 STM32H742', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='125',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='126',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H742BITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H742BITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'Package_QFP:LQFP-208_28x28mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-208_28x28mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H742', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h742bi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H742BITx\n\nArm Cortex-M7 STM32H7 STM32H742', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='115',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='125',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='126',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='137',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='138',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='149',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='151',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='159',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='171',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='172',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='173',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='177',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='178',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='179',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='180',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='181',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='182',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='183',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='184',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='185',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='186',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='187',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='188',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='189',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='190',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='191',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='192',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='193',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='194',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='195',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='196',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='197',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='198',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='199',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='200',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='201',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='202',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='203',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='204',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='205',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='206',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='207',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='208',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PH9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H742IGKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H742IGKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H742', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h742ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H742IGKx\n\nArm Cortex-M7 STM32H7 STM32H742', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H742IGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H742IGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H742', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h742ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H742IGTx\n\nArm Cortex-M7 STM32H7 STM32H742', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H742IIKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H742IIKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H742', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h742ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H742IIKx\n\nArm Cortex-M7 STM32H7 STM32H742', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H742IITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H742IITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H742', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h742ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H742IITx\n\nArm Cortex-M7 STM32H7 STM32H742', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H742VGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H742VGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H742', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h742vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H742VGHx\n\nArm Cortex-M7 STM32H7 STM32H742', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H742VGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H742VGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H742', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h742vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H742VGTx\n\nArm Cortex-M7 STM32H7 STM32H742', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H742VIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H742VIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H742', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h742vi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H742VIHx\n\nArm Cortex-M7 STM32H7 STM32H742', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H742VITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H742VITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H742', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h742vi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H742VITx\n\nArm Cortex-M7 STM32H7 STM32H742', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H742XGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H742XGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-265_14x14mm_Layout17x17_P0.8mm', 'Package_BGA:TFBGA-265_14x14mm_Layout17x17_P0.8mm'], 'footprint':'Package_BGA:TFBGA-265_14x14mm_Layout17x17_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H742', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h742xg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H742XGHx\n\nArm Cortex-M7 STM32H7 STM32H742', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A8',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C14',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E10',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E8',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G17',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L14',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='L17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='L2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='M17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='M2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='U12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H742XIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H742XIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-265_14x14mm_Layout17x17_P0.8mm', 'Package_BGA:TFBGA-265_14x14mm_Layout17x17_P0.8mm', 'Package_BGA:TFBGA-265_14x14mm_Layout17x17_P0.8mm'], 'footprint':'Package_BGA:TFBGA-265_14x14mm_Layout17x17_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H742', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h742xi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H742XIHx\n\nArm Cortex-M7 STM32H7 STM32H742', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A8',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C14',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C17',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D17',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E10',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E8',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='F17',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G17',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='H17',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L14',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='L17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='L2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M14',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='M17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='M2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N13',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='N2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='P17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P2',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='R16',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='R17',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R9',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='T10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='T13',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='T15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='T17',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='T4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U10',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='U12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='U13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='U14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='U15',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='U16',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='U17',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='U2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='U5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='U6',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='U7',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='U8',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H742ZGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H742ZGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H742', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h742zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H742ZGTx\n\nArm Cortex-M7 STM32H7 STM32H742', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H742ZITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H742ZITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H742', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h742zi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H742ZITx\n\nArm Cortex-M7 STM32H7 STM32H742', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H743AGIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H743AGIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H743/753', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h743ag.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H743AGIx\n\nArm Cortex-M7 STM32H7 STM32H743/753', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A11',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='N11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H743AIIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H743AIIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H743/753', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h743ai.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H743AIIx\n\nArm Cortex-M7 STM32H7 STM32H743/753', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A11',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='N11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H743VGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H743VGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H743/753', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h743vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H743VGHx\n\nArm Cortex-M7 STM32H7 STM32H743/753', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H743VIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H743VIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H743/753', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h743vi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H743VIHx\n\nArm Cortex-M7 STM32H7 STM32H743/753', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H747AGIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H747AGIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H747/757', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h747ag.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H747AGIx\n\nArm Cortex-M7 STM32H7 STM32H747/757', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A13',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B13',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='B4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D10',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='F4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='DSI_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='DSI_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H3',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='DSI_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DSI_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='DSI_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='DSI_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='L13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='M2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N10',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VCAP',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H747AIIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H747AIIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H747/757', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h747ai.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H747AIIx\n\nArm Cortex-M7 STM32H7 STM32H747/757', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A13',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B13',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='B4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D10',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='F4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VSSDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VSSDSI',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='DSI_D1P',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='DSI_D1N',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H3',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='DSI_CKP',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='DSI_CKN',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='DSI_D0P',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='DSI_D0N',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L12',name='VCAPDSI',func=pin_types.PWROUT,unit=1),
            Pin(num='L13',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L2',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M10',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='VDDDSI',func=pin_types.PWRIN,unit=1),
            Pin(num='M2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N10',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='VCAP',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3AGIxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3AGIxQ'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3ag.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3AGIxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A11',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='F3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='N11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3AIIxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3AIIxQ'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm'], 'footprint':'Package_BGA:UFBGA-169_7x7mm_Layout13x13_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3ai.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3AIIxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A11',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='F3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='G7',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='M11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M3',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='N11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3IGKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3IGKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3IGKx\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3IGKxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3IGKxQ'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3IGKxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A14',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='C6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='D5',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F14',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='L12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R14',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='R15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3IGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3IGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3IGTx\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3IGTxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3IGTxQ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3ig.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3IGTxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='101',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='107',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='113',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='114',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='120',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='121',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='127',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='134',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='135',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='138',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='149',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='152',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='153',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='159',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='160',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='161',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='168',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='170',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='172',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='173',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='174',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='175',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='176',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='66',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='81',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3IIKx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3IIKx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3IIKx\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N11',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3IIKxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3IIKxQ'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm'], 'footprint':'Package_BGA:UFBGA-201_10x10mm_Layout15x15_P0.65mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3IIKxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A14',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='A5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='C6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='D5',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E13',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F13',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F14',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H13',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J15',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K13',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='L12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L13',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='M4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='N4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='R14',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='R15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3IITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3IITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3IITx\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='103',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='104',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='114',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='115',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='126',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='127',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='128',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='149',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='159',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='161',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='168',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='173',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='82',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='91',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PD11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3IITxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3IITxQ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3ii.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3IITxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='101',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='107',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='113',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='114',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='120',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='121',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='127',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='134',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='135',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='136',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='138',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='145',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='149',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='150',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='151',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='152',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='153',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='159',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='160',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='161',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='162',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='163',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='164',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='165',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='166',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='167',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='168',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='169',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='170',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='171',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='172',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='173',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='174',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='175',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='176',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='66',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='81',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='93',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3LGHxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3LGHxQ'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-225_13x13mm_Layout15x15_P0.8mm', 'Package_BGA:ST_TFBGA-225_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:ST_TFBGA-225_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3lg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3LGHxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='C6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D15',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E10',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='E7',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='F3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='G3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='K4',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PF12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3LIHxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3LIHxQ'}), 'ref_prefix':'U', 'fplist':['Package_BGA:ST_TFBGA-225_13x13mm_Layout15x15_P0.8mm', 'Package_BGA:ST_TFBGA-225_13x13mm_Layout15x15_P0.8mm', 'Package_BGA:ST_TFBGA-225_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:ST_TFBGA-225_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3li.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3LIHxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='C6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D15',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E10',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='E7',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='F3',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='G3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='K4',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='L6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='P10',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA0_C',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R10',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA1_C',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PF12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3NGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3NGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3ng.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3NGHx\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3NIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3NIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm'], 'footprint':'Package_BGA:TFBGA-216_13x13mm_Layout15x15_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3ni.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3NIHx\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PJ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PJ13',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='PI3',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='PI2',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PI8',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PI4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PJ14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PJ15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='PH15',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='PI1',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PI5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PI7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PI10',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PI6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='E12',name='PH13',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='PH14',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='PI0',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PI12',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PI9',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='E6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PI11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='PJ11',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='G14',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PI13',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PI15',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='PJ8',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PJ10',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PI14',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='PJ9',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K12',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K14',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L11',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='L12',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='PH12',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='N10',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='PH9',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='PH11',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='P10',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='PH8',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='PH10',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='R10',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='PE10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3RGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3RGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3rg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3RGTx\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3RITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3RITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3ri.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3RITx\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3VGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3VGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3VGHx\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3VGHxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3VGHxQ'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3VGHxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='D10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='D4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='E3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='G7',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB14',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3VGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3VGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3VGTx\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3VGTxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3VGTxQ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3VGTxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='73',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='77',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='VDDLDO',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3VIHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3VIHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3vi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3VIHx\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3VIHxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3VIHxQ'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_8x8mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3vi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3VIHxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='A1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='D10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='D4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='D9',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='E10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='E3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='G7',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PB14',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3VITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3VITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3vi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3VITx\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3VITxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3VITxQ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3vi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3VITxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='73',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='77',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='VDDLDO',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3ZGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3ZGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3ZGTx\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3ZGTxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3ZGTxQ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3ZGTxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='104',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='105',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='107',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='119',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='120',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='129',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='136',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='141',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='142',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='143',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='69',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='71',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='91',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='93',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PA10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3ZITx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3ZITx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3zi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3ZITx\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32H7A3ZITxQ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32H7A3ZITxQ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M7 STM32H7 STM32H7A3/7B3', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32h7a3zi.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32H7.kicad_sym\nSTM32H7A3ZITxQ\n\nArm Cortex-M7 STM32H7 STM32H7A3/7B3', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='104',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='105',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='106',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='107',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='119',name='VDDMMC',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='120',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='129',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='136',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSSSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='141',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='142',name='PDR_ON',func=pin_types.INPUT,unit=1),
            Pin(num='143',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VLXSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDDSMPS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VFBSMPS',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC2_C',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC3_C',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='69',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='VDDLDO',func=pin_types.PWRIN,unit=1),
            Pin(num='71',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='VDD50_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='91',name='VDD33_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='93',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PA10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])