from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_Microchip_ATmega = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'ATmega1281V-8A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega1281V-8A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2549-8-bit-AVR-Microcontroller-ATmega640-1280-1281-2560-2561_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega1281V-8A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega1281V-8M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega1281V-8M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2549-8-bit-AVR-Microcontroller-ATmega640-1280-1281-2560-2561_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega1281V-8M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega162V-8A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega162V-8A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2513-8-bit-AVR-Microntroller-ATmega162_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega162V-8A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega162V-8M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega162V-8M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2513-8-bit-AVR-Microntroller-ATmega162_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega162V-8M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega162V-8P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega162V-8P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2513-8-bit-AVR-Microntroller-ATmega162_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega162V-8P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega164A-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega164A-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega164A-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega164A-C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega164A-C'}), 'ref_prefix':'U', 'fplist':['Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm'], 'footprint':'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega164A-C\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='D1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D2',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='D3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='E2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega164A-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega164A-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega164A-M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega164A-MC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega164A-MC'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Microchip_DRQFN-44-1EP_5x5mm_P0.7mm_EP2.65x2.65mm'], 'footprint':'Package_DFN_QFN:Microchip_DRQFN-44-1EP_5x5mm_P0.7mm_EP2.65x2.65mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega164A-MC\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='A1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A16',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='A17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='A22',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='A23',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='A24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='A5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='B20',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='B5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='EP',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega164A-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega164A-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega164A-P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega164PV-10A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega164PV-10A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-42742-ATmega164P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega164PV-10A\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega164PV-10M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega164PV-10M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-42742-ATmega164P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega164PV-10M\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega164PV-10P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega164PV-10P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-42742-ATmega164P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega164PV-10P\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega165A-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega165A-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8285-8-bit-avr-microcontroller-atmega165a_pa_325a_pa_3250a_pa_645a_p_6450a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega165A-A\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega165A-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega165A-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8285-8-bit-avr-microcontroller-atmega165a_pa_325a_pa_3250a_pa_645a_p_6450a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega165A-M\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega165PV-8A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega165PV-8A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8019.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega165PV-8A\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega165PV-8M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega165PV-8M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8019.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega165PV-8M\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega169PV-8A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega169PV-8A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR LCD PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8018.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega169PV-8A\n\nAVR 8bit Microcontroller MegaAVR LCD PicoPower', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega169PV-8M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega169PV-8M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR LCD PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8018.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega169PV-8M\n\nAVR 8bit Microcontroller MegaAVR LCD PicoPower', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega169PV-8MC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega169PV-8MC'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Microchip_DRQFN-64-1EP_7x7mm_P0.65mm_EP4.1x4.1mm'], 'footprint':'Package_DFN_QFN:Microchip_DRQFN-64-1EP_7x7mm_P0.65mm_EP4.1x4.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR LCD PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8018.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega169PV-8MC\n\nAVR 8bit Microcontroller MegaAVR LCD PicoPower', 'pins':[
            Pin(num='A1',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A13',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='A14',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A23',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='A24',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='A25',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='A26',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='A27',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='A28',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A29',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A30',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='A31',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='A32',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='A33',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='A34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='B10',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='B23',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='B24',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='B25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B26',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='B27',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='B28',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='B29',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='EP',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega16L-8A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega16L-8A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2466.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega16L-8A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega16L-8M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega16L-8M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2466.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega16L-8M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega16L-8P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega16L-8P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2466.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega16L-8P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega16M1-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega16M1-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8209-8-bit%20AVR%20ATmega16M1-32M1-64M1_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega16M1-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL1/PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='XTAL2/PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF/ISRC',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='~{RESET}/PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega16M1-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega16M1-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.65x4.65mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.65x4.65mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8209-8-bit%20AVR%20ATmega16M1-32M1-64M1_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega16M1-M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL1/PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='XTAL2/PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF/ISRC',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='~{RESET}/PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega16U4-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega16U4-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-7766-8-bit-AVR-ATmega16U4-32U4_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega16U4-A\n\nAVR 8bit Microcontroller MegaAVR USB', 'pins':[
            Pin(num='1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='~{HWB}/PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='UGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega16U4-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega16U4-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-7766-8-bit-AVR-ATmega16U4-32U4_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega16U4-M\n\nAVR 8bit Microcontroller MegaAVR USB', 'pins':[
            Pin(num='1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='~{HWB}/PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='UGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega3208-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega3208-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40002017A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega3208-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF0/TOSC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF1/TOSC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF6/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='UPDI',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='EXTCLK/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega3208-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega3208-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm_ThermalVias', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40002017A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega3208-M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF0/TOSC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF1/TOSC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF6/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='UPDI',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='EXTCLK/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega3208-X', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega3208-X'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-28_5.3x10.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40002018A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega3208-X\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0/TOSC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1/TOSC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF6/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='UPDI',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='EXTCLK/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega3209-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega3209-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-48_7x7mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40002016A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega3209-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PF6/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='UPDI',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega3209-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega3209-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:UQFN-48-1EP_6x6mm_P0.4mm_EP4.62x4.62mm'], 'footprint':'Package_DFN_QFN:UQFN-48-1EP_6x6mm_P0.4mm_EP4.62x4.62mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40002016A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega3209-M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PF6/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='UPDI',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega324PB-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega324PB-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001908A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega324PB-A\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='PE4/AREF',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega324PB-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega324PB-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001908A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega324PB-M\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='PE4/AREF',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega3250V-8A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega3250V-8A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2570.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega3250V-8A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='61',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='62',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='63',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='68',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='83',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='84',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='89',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega325V-8A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega325V-8A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2570.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega325V-8A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega325V-8M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega325V-8M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2570.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega325V-8M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega3290V-8A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega3290V-8A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2552.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega3290V-8A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='61',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='62',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='63',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='68',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='83',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='84',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='89',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega329V-8A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega329V-8A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2552.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega329V-8A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega329V-8M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega329V-8M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2552.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega329V-8M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega406-1AA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega406-1AA'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR battery management', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2548-8-bit-AVR-Microcontroller-Battery-Management-ATmega406_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega406-1AA\n\nAVR 8bit Microcontroller MegaAVR battery management', 'pins':[
            Pin(num='1',name='SGND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC0',func=pin_types.OPENCOLL,unit=1),
            Pin(num='31',name='BATT',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='OPC',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='OC',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='VFET',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='OD',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='PVT',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='PV4',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='PV3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PV2',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='PV1',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='NV',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='VREFGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='PPI',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='PI',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='NI',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='NNI',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VREG',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega48A-CC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega48A-CC'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm'], 'footprint':'Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48A_88A_168A-Data-Sheet-40002007A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega48A-CC\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='A1',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C5',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='E1',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PB4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega48PB-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega48PB-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001909A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega48PB-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega48PB-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega48PB-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001909A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega48PB-M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega48PV-10A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega48PV-10A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8025-8-bit-AVR-Microcontroller-ATmega48P-88P-168P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega48PV-10A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega48PV-10M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega48PV-10M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8025-8-bit-AVR-Microcontroller-ATmega48P-88P-168P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega48PV-10M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega48PV-10MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega48PV-10MM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8025-8-bit-AVR-Microcontroller-ATmega48P-88P-168P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega48PV-10MM\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega48PV-10P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega48PV-10P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8025-8-bit-AVR-Microcontroller-ATmega48P-88P-168P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega48PV-10P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega48V-10A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega48V-10A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2545-8-bit-AVR-Microcontroller-ATmega48-88-168_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega48V-10A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega48V-10M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega48V-10M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2545-8-bit-AVR-Microcontroller-ATmega48-88-168_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega48V-10M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega48V-10MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega48V-10MM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2545-8-bit-AVR-Microcontroller-ATmega48-88-168_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega48V-10MM\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega48V-10P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega48V-10P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2545-8-bit-AVR-Microcontroller-ATmega48-88-168_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega48V-10P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega640V-8A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega640V-8A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2549-8-bit-AVR-Microcontroller-ATmega640-1280-1281-2560-2561_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega640V-8A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PL0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PL1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PL2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PL3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PL4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PL5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PL6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PL7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega640V-8C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega640V-8C'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2549-8-bit-AVR-Microcontroller-ATmega640-1280-1281-2560-2561_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega640V-8C\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='F10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PL4',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G10',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PL2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='H4',name='PL1',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PL3',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PL7',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PL0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='J6',name='PL6',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K5',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='K6',name='PL5',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega644V-10A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega644V-10A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2593.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega644V-10A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega644V-10M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega644V-10M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2593.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega644V-10M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega644V-10P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega644V-10P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2593.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega644V-10P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega64L-8A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega64L-8A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2490-8-bit-avr-microcontroller-atmega64-l_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega64L-8A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='~{PEN}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega64L-8M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega64L-8M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2490-8-bit-avr-microcontroller-atmega64-l_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega64L-8M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='~{PEN}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega8515L-8A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega8515L-8A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2512.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega8515L-8A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='29',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega8515L-8J', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega8515L-8J'}), 'ref_prefix':'U', 'fplist':['Package_LCC:PLCC-44'], 'footprint':'Package_LCC:PLCC-44', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2512.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega8515L-8J\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='24',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='35',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega8515L-8M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega8515L-8M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2512.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega8515L-8M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='29',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega8515L-8P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega8515L-8P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2512.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega8515L-8P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega8535L-8A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega8535L-8A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2502.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega8535L-8A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega8535L-8J', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega8535L-8J'}), 'ref_prefix':'U', 'fplist':['Package_LCC:PLCC-44'], 'footprint':'Package_LCC:PLCC-44', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2502.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega8535L-8J\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega8535L-8M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega8535L-8M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2502.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega8535L-8M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega8535L-8P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega8535L-8P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2502.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega8535L-8P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega8L-8A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega8L-8A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2486-8-bit-avr-microcontroller-atmega8_l_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega8L-8A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC6/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PB6/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega8L-8M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega8L-8M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2486-8-bit-avr-microcontroller-atmega8_l_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega8L-8M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC6/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PB6/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega8L-8P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega8L-8P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2486-8-bit-avr-microcontroller-atmega8_l_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega8L-8P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PC6/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB7/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PB6/XTAL1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega8U2-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega8U2-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7799.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega8U2-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{HWB}/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='UGND',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega8U2-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega8U2-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7799.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega8U2-M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{HWB}/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='UGND',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega128B3-MC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega128B3-MC'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Microchip_DRQFN-64-1EP_7x7mm_P0.65mm_EP4.1x4.1mm'], 'footprint':'Package_DFN_QFN:Microchip_DRQFN-64-1EP_7x7mm_P0.65mm_EP4.1x4.1mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8074-8-and-16-bit-AVR-Microcontroller-XMEGA-B-ATxmega64B3-ATxmega128B3_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega128B3-MC\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='A1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PG2/SEG22',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PG3/SEG21',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PG5/SEG19',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PG7/SEG17',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PM1/SEG15',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PM3/SEG13',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PM4/SEG12',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='PM6/SEG10',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='SEG7',func=pin_types.OUTPUT,unit=1),
            Pin(num='A19',name='SEG6',func=pin_types.OUTPUT,unit=1),
            Pin(num='A2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='SEG4',func=pin_types.OUTPUT,unit=1),
            Pin(num='A21',name='SEG2',func=pin_types.OUTPUT,unit=1),
            Pin(num='A22',name='SEG0',func=pin_types.OUTPUT,unit=1),
            Pin(num='A23',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='A24',name='BIAS2',func=pin_types.PWROUT,unit=1),
            Pin(num='A25',name='CAPL',func=pin_types.PASSIVE,unit=1),
            Pin(num='A26',name='CAPH',func=pin_types.PASSIVE,unit=1),
            Pin(num='A27',name='COM1',func=pin_types.OUTPUT,unit=1),
            Pin(num='A28',name='COM3',func=pin_types.OUTPUT,unit=1),
            Pin(num='A29',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='A30',name='PB0/AREF',func=pin_types.BIDIR,unit=1),
            Pin(num='A31',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='A32',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A33',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A34',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='PG0/SEG24',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PG4/SEG20',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PG6/SEG18',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PM0/SEG16',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PM2/SEG14',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PM5/SEG11',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PM7/SEG9',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='SEG8',func=pin_types.OUTPUT,unit=1),
            Pin(num='B17',name='SEG5',func=pin_types.OUTPUT,unit=1),
            Pin(num='B18',name='SEG3',func=pin_types.OUTPUT,unit=1),
            Pin(num='B19',name='SEG1',func=pin_types.OUTPUT,unit=1),
            Pin(num='B2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B21',name='BIAS1',func=pin_types.PWROUT,unit=1),
            Pin(num='B22',name='VLCD',func=pin_types.PWROUT,unit=1),
            Pin(num='B23',name='COM0',func=pin_types.OUTPUT,unit=1),
            Pin(num='B24',name='COM2',func=pin_types.OUTPUT,unit=1),
            Pin(num='B25',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='B26',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='B27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='B28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='B29',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='B30',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='PG1/SEG23',func=pin_types.BIDIR,unit=1),
            Pin(num='EP',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega16A4U-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega16A4U-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8387-8-and16-bit-AVR-Microcontroller-XMEGA-A4U_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega16A4U-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega16A4U-C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega16A4U-C'}), 'ref_prefix':'U', 'fplist':['Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm'], 'footprint':'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8387-8-and16-bit-AVR-Microcontroller-XMEGA-A4U_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega16A4U-C\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='A1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='PD2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega16A4U-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega16A4U-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8387-8-and16-bit-AVR-Microcontroller-XMEGA-A4U_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega16A4U-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega16C4-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega16C4-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8493-8-and-32-bit-AVR-XMEGA-Microcontrollers-ATxmega16C4-ATxmega32C4_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega16C4-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='PR0/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PR1/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega16C4-C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega16C4-C'}), 'ref_prefix':'U', 'fplist':['Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm'], 'footprint':'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8493-8-and-32-bit-AVR-XMEGA-Microcontrollers-ATxmega16C4-ATxmega32C4_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega16C4-C\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='A1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PR1/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PR0/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='PD2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega16C4-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega16C4-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8493-8-and-32-bit-AVR-XMEGA-Microcontrollers-ATxmega16C4-ATxmega32C4_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega16C4-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='PR0/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PR1/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega16D4-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega16D4-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8135-8-and-16-bit-AVR-microcontroller-ATxmega16D4-32D4-64D4-128D4_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega16D4-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega16D4-C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega16D4-C'}), 'ref_prefix':'U', 'fplist':['Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm'], 'footprint':'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8135-8-and-16-bit-AVR-microcontroller-ATxmega16D4-32D4-64D4-128D4_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega16D4-C\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='A1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='PD2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega16D4-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega16D4-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8135-8-and-16-bit-AVR-microcontroller-ATxmega16D4-32D4-64D4-128D4_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega16D4-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega256A3B-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega256A3B-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8116-8-and-16-bit-AVR-XMEGA-A3B-Microcontroller_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega256A3B-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='TOSC2',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='TOSC1',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega256A3B-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega256A3B-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8116-8-and-16-bit-AVR-XMEGA-A3B-Microcontroller_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega256A3B-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='TOSC2',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='TOSC1',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega256A3BU-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega256A3BU-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8362-8-and-16bit-AVR-microcontroller-ATxmega256A3BU_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega256A3BU-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='TOSC2',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='TOSC1',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega256A3BU-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega256A3BU-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8362-8-and-16bit-AVR-microcontroller-ATxmega256A3BU_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega256A3BU-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='TOSC2',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='TOSC1',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega32C3-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega32C3-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8492-8-and-16-bit-AVR-microcontroller-ATxmega32C3_64C3_128C3_192C3_256C3_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega32C3-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega32C3-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega32C3-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8492-8-and-16-bit-AVR-microcontroller-ATxmega32C3_64C3_128C3_192C3_256C3_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega32C3-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega32D3-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega32D3-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8134-8-16-bit-Atmel-XMEGA-D3-Microcontroller_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega32D3-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega32D3-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega32D3-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8134-8-16-bit-Atmel-XMEGA-D3-Microcontroller_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega32D3-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega64A1-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega64A1-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8067-8-and-16-bit-AVR-Microcontrollers-ATxmega64A1-ATxmega128A1_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega64A1-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='85',name='PQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='91',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega64A1-C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega64A1-C'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8067-8-and-16-bit-AVR-Microcontrollers-ATxmega64A1-ATxmega128A1_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega64A1-C\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='A1',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='A6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A7',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A9',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D2',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='F4',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega64A1-C7', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega64A1-C7'}), 'ref_prefix':'U', 'fplist':['Package_BGA:VFBGA-100_7.0x7.0mm_Layout10x10_P0.65mm'], 'footprint':'Package_BGA:VFBGA-100_7.0x7.0mm_Layout10x10_P0.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8067-8-and-16-bit-AVR-Microcontrollers-ATxmega64A1-ATxmega128A1_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega64A1-C7\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='A1',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='A6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A7',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A9',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D2',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='F4',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega64A1U-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega64A1U-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8385-8-and-16-bit-AVR-Microcontroller-ATxmega64A1U-ATxmega128A1U_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega64A1U-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='85',name='PQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='91',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega64A1U-C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega64A1U-C'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8385-8-and-16-bit-AVR-Microcontroller-ATxmega64A1U-ATxmega128A1U_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega64A1U-C\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='A1',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='A6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A7',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A9',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D2',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='F4',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega64A1U-C7', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega64A1U-C7'}), 'ref_prefix':'U', 'fplist':['Package_BGA:VFBGA-100_7.0x7.0mm_Layout10x10_P0.65mm'], 'footprint':'Package_BGA:VFBGA-100_7.0x7.0mm_Layout10x10_P0.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8385-8-and-16-bit-AVR-Microcontroller-ATxmega64A1U-ATxmega128A1U_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega64A1U-C7\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='A1',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='A6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A7',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A9',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D2',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='F4',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega64A3-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega64A3-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8068-8-and16-bit-AVR-XMEGA-A3-Microcontrollers_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega64A3-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega64A3-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega64A3-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8068-8-and16-bit-AVR-XMEGA-A3-Microcontrollers_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega64A3-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega64A3U-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega64A3U-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8386-8-and-16-bit-AVR-Microcontroller-ATxmega64A3U-128A3U-192A3U-256A3U_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega64A3U-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega64A3U-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega64A3U-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8386-8-and-16-bit-AVR-Microcontroller-ATxmega64A3U-128A3U-192A3U-256A3U_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega64A3U-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega64B1-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega64B1-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8330-8-and-16-bit-AVR-Microcontroller-XMEGA-B-ATxmega64B1-ATxmega128B1_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega64B1-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='PG0/SEG39',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PG1/SEG38',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PG2/SEG37',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PG3/SEG36',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG4/SEG35',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG5/SEG34',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PG6/SEG33',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PG7/SEG32',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PM0/SEG31',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PM1/SEG30',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PM2/SEG29',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PM3/SEG28',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PM4/SEG27',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PM5/SEG26',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PM6/SEG25',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PM7/SEG24',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='SEG23',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='SEG22',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='SEG21',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='SEG20',func=pin_types.OUTPUT,unit=1),
            Pin(num='49',name='SEG19',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='SEG18',func=pin_types.OUTPUT,unit=1),
            Pin(num='51',name='SEG17',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='SEG16',func=pin_types.OUTPUT,unit=1),
            Pin(num='53',name='SEG15',func=pin_types.OUTPUT,unit=1),
            Pin(num='54',name='SEG14',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='SEG13',func=pin_types.OUTPUT,unit=1),
            Pin(num='56',name='SEG12',func=pin_types.OUTPUT,unit=1),
            Pin(num='57',name='SEG11',func=pin_types.OUTPUT,unit=1),
            Pin(num='58',name='SEG10',func=pin_types.OUTPUT,unit=1),
            Pin(num='59',name='SEG9',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='SEG8',func=pin_types.OUTPUT,unit=1),
            Pin(num='61',name='SEG7',func=pin_types.OUTPUT,unit=1),
            Pin(num='62',name='SEG6',func=pin_types.OUTPUT,unit=1),
            Pin(num='63',name='SEG5',func=pin_types.OUTPUT,unit=1),
            Pin(num='64',name='SEG4',func=pin_types.OUTPUT,unit=1),
            Pin(num='65',name='SEG3',func=pin_types.OUTPUT,unit=1),
            Pin(num='66',name='SEG2',func=pin_types.OUTPUT,unit=1),
            Pin(num='67',name='SEG1',func=pin_types.OUTPUT,unit=1),
            Pin(num='68',name='SEG0',func=pin_types.OUTPUT,unit=1),
            Pin(num='69',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='BIAS1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='BIAS2',func=pin_types.PWROUT,unit=1),
            Pin(num='73',name='VLCD',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='CAPL',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='CAPH',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='COM0',func=pin_types.OUTPUT,unit=1),
            Pin(num='77',name='COM1',func=pin_types.OUTPUT,unit=1),
            Pin(num='78',name='COM2',func=pin_types.OUTPUT,unit=1),
            Pin(num='79',name='COM3',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PA0/AREF',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='91',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PB7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega64B1-C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega64B1-C'}), 'ref_prefix':'U', 'fplist':['Package_BGA:VFBGA-100_7.0x7.0mm_Layout10x10_P0.65mm'], 'footprint':'Package_BGA:VFBGA-100_7.0x7.0mm_Layout10x10_P0.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8330-8-and-16-bit-AVR-Microcontroller-XMEGA-B-ATxmega64B1-ATxmega128B1_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega64B1-C\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='A1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='CAPH',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='COM2',func=pin_types.OUTPUT,unit=1),
            Pin(num='B1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='CAPL',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PA0/AREF',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='COM1',func=pin_types.OUTPUT,unit=1),
            Pin(num='C1',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='BIAS1',func=pin_types.PWROUT,unit=1),
            Pin(num='C2',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='COM3',func=pin_types.OUTPUT,unit=1),
            Pin(num='C8',name='COM0',func=pin_types.OUTPUT,unit=1),
            Pin(num='C9',name='BIAS2',func=pin_types.PWROUT,unit=1),
            Pin(num='D1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='D10',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='D2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='SEG0',func=pin_types.OUTPUT,unit=1),
            Pin(num='D8',name='VLCD',func=pin_types.PWROUT,unit=1),
            Pin(num='D9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='SEG2',func=pin_types.OUTPUT,unit=1),
            Pin(num='E2',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='E3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='SEG1',func=pin_types.OUTPUT,unit=1),
            Pin(num='E8',name='SEG4',func=pin_types.OUTPUT,unit=1),
            Pin(num='E9',name='SEG3',func=pin_types.OUTPUT,unit=1),
            Pin(num='F1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='F10',name='SEG5',func=pin_types.OUTPUT,unit=1),
            Pin(num='F2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PM2/SEG29',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='SEG10',func=pin_types.OUTPUT,unit=1),
            Pin(num='F8',name='SEG7',func=pin_types.OUTPUT,unit=1),
            Pin(num='F9',name='SEG6',func=pin_types.OUTPUT,unit=1),
            Pin(num='G1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='SEG8',func=pin_types.OUTPUT,unit=1),
            Pin(num='G2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='SEG23',func=pin_types.OUTPUT,unit=1),
            Pin(num='G7',name='SEG15',func=pin_types.OUTPUT,unit=1),
            Pin(num='G8',name='SEG13',func=pin_types.OUTPUT,unit=1),
            Pin(num='G9',name='SEG9',func=pin_types.OUTPUT,unit=1),
            Pin(num='H1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='SEG11',func=pin_types.OUTPUT,unit=1),
            Pin(num='H2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PG1/SEG38',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PG4/SEG35',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PG7/SEG32',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PM5/SEG26',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='SEG21',func=pin_types.OUTPUT,unit=1),
            Pin(num='H8',name='SEG18',func=pin_types.OUTPUT,unit=1),
            Pin(num='H9',name='SEG12',func=pin_types.OUTPUT,unit=1),
            Pin(num='J1',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='SEG14',func=pin_types.OUTPUT,unit=1),
            Pin(num='J2',name='PG0/SEG39',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PG3/SEG36',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PG6/SEG33',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PM1/SEG30',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PM4/SEG27',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PM7/SEG24',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='SEG20',func=pin_types.OUTPUT,unit=1),
            Pin(num='J9',name='SEG16',func=pin_types.OUTPUT,unit=1),
            Pin(num='K1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='SEG17',func=pin_types.OUTPUT,unit=1),
            Pin(num='K2',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PG2/SEG37',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PG5/SEG34',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PM0/SEG31',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PM3/SEG28',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PM6/SEG25',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='SEG22',func=pin_types.OUTPUT,unit=1),
            Pin(num='K9',name='SEG19',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega64B3-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega64B3-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8074-8-and-16-bit-AVR-Microcontroller-XMEGA-B-ATxmega64B3-ATxmega128B3_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega64B3-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='PG0/SEG24',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG1/SEG23',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG2/SEG22',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG3/SEG21',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PG4/SEG20',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PG5/SEG19',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PG6/SEG18',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PG7/SEG17',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PM0/SEG16',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PM1/SEG15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PM2/SEG14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PM3/SEG13',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PM4/SEG12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM5/SEG11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PM6/SEG10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PM7/SEG9',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='SEG8',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='SEG7',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='SEG6',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='SEG5',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='SEG4',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='SEG3',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='SEG2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='SEG1',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='SEG0',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='BIAS1',func=pin_types.PWROUT,unit=1),
            Pin(num='45',name='BIAS2',func=pin_types.PWROUT,unit=1),
            Pin(num='46',name='VLCD',func=pin_types.PWROUT,unit=1),
            Pin(num='47',name='CAPL',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='CAPH',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='COM0',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='COM1',func=pin_types.OUTPUT,unit=1),
            Pin(num='51',name='COM2',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='COM3',func=pin_types.OUTPUT,unit=1),
            Pin(num='53',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PB0/AREF',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega64B3-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega64B3-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8074-8-and-16-bit-AVR-Microcontroller-XMEGA-B-ATxmega64B3-ATxmega128B3_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega64B3-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='PG0/SEG24',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG1/SEG23',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG2/SEG22',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG3/SEG21',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PG4/SEG20',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PG5/SEG19',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PG6/SEG18',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PG7/SEG17',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PM0/SEG16',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PM1/SEG15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PM2/SEG14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PM3/SEG13',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PM4/SEG12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM5/SEG11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PM6/SEG10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PM7/SEG9',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='SEG8',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='SEG7',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='SEG6',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='SEG5',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='SEG4',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='SEG3',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='SEG2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='SEG1',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='SEG0',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='BIAS1',func=pin_types.PWROUT,unit=1),
            Pin(num='45',name='BIAS2',func=pin_types.PWROUT,unit=1),
            Pin(num='46',name='VLCD',func=pin_types.PWROUT,unit=1),
            Pin(num='47',name='CAPL',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='CAPH',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='COM0',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='COM1',func=pin_types.OUTPUT,unit=1),
            Pin(num='51',name='COM2',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='COM3',func=pin_types.OUTPUT,unit=1),
            Pin(num='53',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PB0/AREF',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega8E5-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega8E5-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8153-8-and-16-bit-AVR-Microcontroller-XMEGA-E-ATxmega8E5-ATxmega16E5-ATxmega32E5_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega8E5-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD0/AREF',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega8E5-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega8E5-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8153-8-and-16-bit-AVR-Microcontroller-XMEGA-E-ATxmega8E5-ATxmega16E5-ATxmega32E5_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega8E5-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD0/AREF',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega8E5-M4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega8E5-M4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_4x4mm_P0.4mm_EP2.9x2.9mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_4x4mm_P0.4mm_EP2.9x2.9mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8153-8-and-16-bit-AVR-Microcontroller-XMEGA-E-ATxmega8E5-ATxmega16E5-ATxmega32E5_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega8E5-M4\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD0/AREF',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega128-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega128-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2467.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega128-16A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='~{PEN}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega128-16M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega128-16M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2467.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega128-16M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='~{PEN}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega1280-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega1280-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2549-8-bit-AVR-Microcontroller-ATmega640-1280-1281-2560-2561_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega1280-16A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PL0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PL1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PL2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PL3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PL4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PL5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PL6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PL7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega1280-16C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega1280-16C'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2549-8-bit-AVR-Microcontroller-ATmega640-1280-1281-2560-2561_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega1280-16C\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='F10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PL4',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G10',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PL2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='H4',name='PL1',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PL3',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PL7',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PL0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='J6',name='PL6',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K5',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='K6',name='PL5',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega1280V-8A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega1280V-8A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2549-8-bit-AVR-Microcontroller-ATmega640-1280-1281-2560-2561_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega1280V-8A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PL0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PL1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PL2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PL3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PL4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PL5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PL6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PL7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega1280V-8C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega1280V-8C'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2549-8-bit-AVR-Microcontroller-ATmega640-1280-1281-2560-2561_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega1280V-8C\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='F10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PL4',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G10',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PL2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='H4',name='PL1',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PL3',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PL7',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PL0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='J6',name='PL6',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K5',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='K6',name='PL5',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega1281-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega1281-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2549-8-bit-AVR-Microcontroller-ATmega640-1280-1281-2560-2561_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega1281-16A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega1281-16M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega1281-16M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2549-8-bit-AVR-Microcontroller-ATmega640-1280-1281-2560-2561_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega1281-16M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega1284-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega1284-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega1284-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega1284-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega1284-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega1284-M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega1284-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega1284-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega1284-P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega1284P-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega1284P-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega1284P-A\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega1284P-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega1284P-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega1284P-M\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega1284P-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega1284P-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega1284P-P\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega128A-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega128A-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8151-8-bit-AVR-ATmega128A_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega128A-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='~{PEN}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega128A-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega128A-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8151-8-bit-AVR-ATmega128A_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega128A-M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='~{PEN}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega128L-8A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega128L-8A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2467.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega128L-8A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='~{PEN}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega128L-8M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega128L-8M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2467.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega128L-8M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='~{PEN}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega16-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega16-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2466.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega16-16A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega16-16M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega16-16M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2466.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega16-16M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega16-16P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega16-16P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2466.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega16-16P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega162-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega162-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2513-8-bit-AVR-Microntroller-ATmega162_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega162-16A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega162-16M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega162-16M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2513-8-bit-AVR-Microntroller-ATmega162_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega162-16M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega162-16P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega162-16P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2513-8-bit-AVR-Microntroller-ATmega162_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega162-16P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega164P-20A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega164P-20A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-42742-ATmega164P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega164P-20A\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega164P-20M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega164P-20M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-42742-ATmega164P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega164P-20M\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega164P-20P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega164P-20P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-42742-ATmega164P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega164P-20P\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega164PA-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega164PA-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega164PA-A\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega164PA-C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega164PA-C'}), 'ref_prefix':'U', 'fplist':['Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm'], 'footprint':'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega164PA-C\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='D1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D2',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='D3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='E2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega164PA-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega164PA-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega164PA-M\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega164PA-MC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega164PA-MC'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Microchip_DRQFN-44-1EP_5x5mm_P0.7mm_EP2.65x2.65mm', 'Package_DFN_QFN:Microchip_DRQFN-44-1EP_5x5mm_P0.7mm_EP2.65x2.65mm'], 'footprint':'Package_DFN_QFN:Microchip_DRQFN-44-1EP_5x5mm_P0.7mm_EP2.65x2.65mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega164PA-MC\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='A1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A16',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='A17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='A22',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='A23',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='A24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='A5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='B20',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='B5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='EP',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega164PA-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega164PA-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega164PA-P\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega165P-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega165P-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8019.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega165P-16A\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega165P-16M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega165P-16M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8019.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega165P-16M\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega165PA-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega165PA-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8285-8-bit-avr-microcontroller-atmega165a_pa_325a_pa_3250a_pa_645a_p_6450a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega165PA-A\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega165PA-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega165PA-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8285-8-bit-avr-microcontroller-atmega165a_pa_325a_pa_3250a_pa_645a_p_6450a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega165PA-M\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega168-20A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega168-20A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2545-8-bit-AVR-Microcontroller-ATmega48-88-168_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega168-20A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega168-20M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega168-20M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2545-8-bit-AVR-Microcontroller-ATmega48-88-168_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega168-20M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega168-20P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega168-20P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2545-8-bit-AVR-Microcontroller-ATmega48-88-168_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega168-20P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega168A-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega168A-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48A_88A_168A-Data-Sheet-40002007A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega168A-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega168A-CC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega168A-CC'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm', 'Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm'], 'footprint':'Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48A_88A_168A-Data-Sheet-40002007A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega168A-CC\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='A1',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C5',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='E1',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PB4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega168A-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega168A-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48A_88A_168A-Data-Sheet-40002007A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega168A-M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega168A-MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega168A-MM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48A_88A_168A-Data-Sheet-40002007A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega168A-MM\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega168A-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega168A-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48A_88A_168A-Data-Sheet-40002007A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega168A-P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega168P-20A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega168P-20A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8025-8-bit-AVR-Microcontroller-ATmega48P-88P-168P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega168P-20A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega168P-20M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega168P-20M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8025-8-bit-AVR-Microcontroller-ATmega48P-88P-168P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega168P-20M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega168P-20P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega168P-20P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8025-8-bit-AVR-Microcontroller-ATmega48P-88P-168P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega168P-20P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega168PA-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega168PA-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48PA_88PA_168PA-Data-Sheet-40002011A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega168PA-A\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega168PA-CC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega168PA-CC'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm', 'Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm', 'Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm'], 'footprint':'Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48PA_88PA_168PA-Data-Sheet-40002011A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega168PA-CC\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='A1',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C5',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='E1',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PB4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega168PA-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega168PA-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48PA_88PA_168PA-Data-Sheet-40002011A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega168PA-M\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega168PA-MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega168PA-MM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48PA_88PA_168PA-Data-Sheet-40002011A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega168PA-MM\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega168PA-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega168PA-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48PA_88PA_168PA-Data-Sheet-40002011A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega168PA-P\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega168PB-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega168PB-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001909A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega168PB-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega168PB-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega168PB-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001909A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega168PB-M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega168PV-10A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega168PV-10A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8025-8-bit-AVR-Microcontroller-ATmega48P-88P-168P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega168PV-10A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega168PV-10M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega168PV-10M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8025-8-bit-AVR-Microcontroller-ATmega48P-88P-168P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega168PV-10M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega168PV-10P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega168PV-10P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8025-8-bit-AVR-Microcontroller-ATmega48P-88P-168P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega168PV-10P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega168V-10A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega168V-10A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2545-8-bit-AVR-Microcontroller-ATmega48-88-168_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega168V-10A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega168V-10M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega168V-10M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2545-8-bit-AVR-Microcontroller-ATmega48-88-168_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega168V-10M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega168V-10P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega168V-10P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2545-8-bit-AVR-Microcontroller-ATmega48-88-168_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega168V-10P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega169A-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega169A-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR LCD PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8284-8-bit-avr-microcontroller-atmega169a_pa_329a_pa_3290a_pa_649a_p_6490a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega169A-A\n\nAVR 8bit Microcontroller MegaAVR LCD PicoPower', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega169A-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega169A-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR LCD PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8284-8-bit-avr-microcontroller-atmega169a_pa_329a_pa_3290a_pa_649a_p_6490a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega169A-M\n\nAVR 8bit Microcontroller MegaAVR LCD PicoPower', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega169A-MC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega169A-MC'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Microchip_DRQFN-64-1EP_7x7mm_P0.65mm_EP4.1x4.1mm', 'Package_DFN_QFN:Microchip_DRQFN-64-1EP_7x7mm_P0.65mm_EP4.1x4.1mm'], 'footprint':'Package_DFN_QFN:Microchip_DRQFN-64-1EP_7x7mm_P0.65mm_EP4.1x4.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR LCD PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8284-8-bit-avr-microcontroller-atmega169a_pa_329a_pa_3290a_pa_649a_p_6490a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega169A-MC\n\nAVR 8bit Microcontroller MegaAVR LCD PicoPower', 'pins':[
            Pin(num='A1',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A13',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='A14',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A23',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='A24',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='A25',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='A26',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='A27',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='A28',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A29',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A30',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='A31',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='A32',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='A33',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='A34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='B10',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='B23',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='B24',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='B25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B26',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='B27',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='B28',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='B29',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='EP',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega169P-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega169P-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR LCD PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8018.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega169P-16A\n\nAVR 8bit Microcontroller MegaAVR LCD PicoPower', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega169P-16M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega169P-16M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR LCD PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8018.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega169P-16M\n\nAVR 8bit Microcontroller MegaAVR LCD PicoPower', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega169P-16MC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega169P-16MC'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Microchip_DRQFN-64-1EP_7x7mm_P0.65mm_EP4.1x4.1mm', 'Package_DFN_QFN:Microchip_DRQFN-64-1EP_7x7mm_P0.65mm_EP4.1x4.1mm', 'Package_DFN_QFN:Microchip_DRQFN-64-1EP_7x7mm_P0.65mm_EP4.1x4.1mm'], 'footprint':'Package_DFN_QFN:Microchip_DRQFN-64-1EP_7x7mm_P0.65mm_EP4.1x4.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR LCD PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8018.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega169P-16MC\n\nAVR 8bit Microcontroller MegaAVR LCD PicoPower', 'pins':[
            Pin(num='A1',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A13',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='A14',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A23',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='A24',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='A25',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='A26',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='A27',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='A28',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A29',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A30',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='A31',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='A32',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='A33',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='A34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='B10',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='B23',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='B24',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='B25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B26',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='B27',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='B28',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='B29',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='EP',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega169PA-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega169PA-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR LCD PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8284-8-bit-avr-microcontroller-atmega169a_pa_329a_pa_3290a_pa_649a_p_6490a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega169PA-A\n\nAVR 8bit Microcontroller MegaAVR LCD PicoPower', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega169PA-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega169PA-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR LCD PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8284-8-bit-avr-microcontroller-atmega169a_pa_329a_pa_3290a_pa_649a_p_6490a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega169PA-M\n\nAVR 8bit Microcontroller MegaAVR LCD PicoPower', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega169PA-MC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega169PA-MC'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Microchip_DRQFN-64-1EP_7x7mm_P0.65mm_EP4.1x4.1mm', 'Package_DFN_QFN:Microchip_DRQFN-64-1EP_7x7mm_P0.65mm_EP4.1x4.1mm', 'Package_DFN_QFN:Microchip_DRQFN-64-1EP_7x7mm_P0.65mm_EP4.1x4.1mm', 'Package_DFN_QFN:Microchip_DRQFN-64-1EP_7x7mm_P0.65mm_EP4.1x4.1mm'], 'footprint':'Package_DFN_QFN:Microchip_DRQFN-64-1EP_7x7mm_P0.65mm_EP4.1x4.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR LCD PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8284-8-bit-avr-microcontroller-atmega169a_pa_329a_pa_3290a_pa_649a_p_6490a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega169PA-MC\n\nAVR 8bit Microcontroller MegaAVR LCD PicoPower', 'pins':[
            Pin(num='A1',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A13',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='A14',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='A22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A23',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='A24',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='A25',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='A26',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='A27',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='A28',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A29',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A30',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='A31',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='A32',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='A33',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='A34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='B10',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='B11',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='B12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B21',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='B22',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='B23',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='B24',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='B25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B26',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='B27',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='B28',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='B29',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='EP',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega16A-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega16A-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8154-8-bit-AVR-ATmega16A_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega16A-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega16A-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega16A-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8154-8-bit-AVR-ATmega16A_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega16A-M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega16A-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega16A-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8154-8-bit-AVR-ATmega16A_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega16A-P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega16U2-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega16U2-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7799.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega16U2-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{HWB}/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='UGND',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega16U2-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega16U2-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7799.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega16U2-M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{HWB}/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='UGND',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega16U4RC-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega16U4RC-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-7766-8-bit-AVR-ATmega16U4-32U4_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega16U4RC-A\n\nAVR 8bit Microcontroller MegaAVR USB', 'pins':[
            Pin(num='1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='~{HWB}/PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='UGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega16U4RC-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega16U4RC-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-7766-8-bit-AVR-ATmega16U4-32U4_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega16U4RC-M\n\nAVR 8bit Microcontroller MegaAVR USB', 'pins':[
            Pin(num='1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='~{HWB}/PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='UGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega2560-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega2560-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2549-8-bit-AVR-Microcontroller-ATmega640-1280-1281-2560-2561_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega2560-16A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PL0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PL1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PL2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PL3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PL4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PL5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PL6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PL7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega2560-16C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega2560-16C'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2549-8-bit-AVR-Microcontroller-ATmega640-1280-1281-2560-2561_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega2560-16C\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='F10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PL4',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G10',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PL2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='H4',name='PL1',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PL3',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PL7',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PL0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='J6',name='PL6',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K5',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='K6',name='PL5',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega2560V-8A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega2560V-8A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2549-8-bit-AVR-Microcontroller-ATmega640-1280-1281-2560-2561_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega2560V-8A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PL0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PL1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PL2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PL3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PL4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PL5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PL6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PL7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega2560V-8C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega2560V-8C'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2549-8-bit-AVR-Microcontroller-ATmega640-1280-1281-2560-2561_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega2560V-8C\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='F10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PL4',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G10',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PL2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='H4',name='PL1',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PL3',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PL7',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PL0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='J6',name='PL6',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K5',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='K6',name='PL5',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega2561-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega2561-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2549-8-bit-AVR-Microcontroller-ATmega640-1280-1281-2560-2561_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega2561-16A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega2561-16M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega2561-16M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2549-8-bit-AVR-Microcontroller-ATmega640-1280-1281-2560-2561_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega2561-16M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega2561V-8A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega2561V-8A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2549-8-bit-AVR-Microcontroller-ATmega640-1280-1281-2560-2561_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega2561V-8A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega2561V-8M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega2561V-8M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2549-8-bit-AVR-Microcontroller-ATmega640-1280-1281-2560-2561_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega2561V-8M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega32-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega32-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2503.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega32-16A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega32-16M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega32-16M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2503.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega32-16M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega32-16P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega32-16P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2503.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega32-16P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega324A-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega324A-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega324A-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega324A-C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega324A-C'}), 'ref_prefix':'U', 'fplist':['Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm'], 'footprint':'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega324A-C\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='D1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D2',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='D3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='E2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega324A-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega324A-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega324A-M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega324A-MC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega324A-MC'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Microchip_DRQFN-44-1EP_5x5mm_P0.7mm_EP2.65x2.65mm', 'Package_DFN_QFN:Microchip_DRQFN-44-1EP_5x5mm_P0.7mm_EP2.65x2.65mm', 'Package_DFN_QFN:Microchip_DRQFN-44-1EP_5x5mm_P0.7mm_EP2.65x2.65mm'], 'footprint':'Package_DFN_QFN:Microchip_DRQFN-44-1EP_5x5mm_P0.7mm_EP2.65x2.65mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega324A-MC\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='A1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A16',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='A17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='A22',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='A23',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='A24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='A5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='B20',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='B5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='EP',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega324A-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega324A-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega324A-P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega324P-20A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega324P-20A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-42743-ATmega324P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega324P-20A\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega324P-20M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega324P-20M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-42743-ATmega324P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega324P-20M\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega324P-20P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega324P-20P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-42743-ATmega324P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega324P-20P\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega324PA-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega324PA-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega324PA-A\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega324PA-C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega324PA-C'}), 'ref_prefix':'U', 'fplist':['Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm'], 'footprint':'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega324PA-C\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='D1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D2',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='D3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='E2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega324PA-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega324PA-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega324PA-M\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega324PA-MC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega324PA-MC'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Microchip_DRQFN-44-1EP_5x5mm_P0.7mm_EP2.65x2.65mm', 'Package_DFN_QFN:Microchip_DRQFN-44-1EP_5x5mm_P0.7mm_EP2.65x2.65mm', 'Package_DFN_QFN:Microchip_DRQFN-44-1EP_5x5mm_P0.7mm_EP2.65x2.65mm', 'Package_DFN_QFN:Microchip_DRQFN-44-1EP_5x5mm_P0.7mm_EP2.65x2.65mm'], 'footprint':'Package_DFN_QFN:Microchip_DRQFN-44-1EP_5x5mm_P0.7mm_EP2.65x2.65mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega324PA-MC\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='A1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A16',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='A17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='A21',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='A22',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='A23',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='A24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='A5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='B20',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='B5',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='EP',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega324PA-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega324PA-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega324PA-P\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega324PV-10A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega324PV-10A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-42743-ATmega324P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega324PV-10A\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega324PV-10M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega324PV-10M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-42743-ATmega324P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega324PV-10M\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega324PV-10P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega324PV-10P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-42743-ATmega324P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega324PV-10P\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega325-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega325-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2570.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega325-16A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega325-16M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega325-16M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2570.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega325-16M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega3250-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega3250-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2570.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega3250-16A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='61',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='62',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='63',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='68',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='83',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='84',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='89',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega3250A-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega3250A-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8285-8-bit-avr-microcontroller-atmega165a_pa_325a_pa_3250a_pa_645a_p_6450a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega3250A-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='61',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='62',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='63',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='68',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='83',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='84',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='89',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega3250P-20A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega3250P-20A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8023.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega3250P-20A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='61',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='62',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='63',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='68',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='83',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='84',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='89',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega3250PA-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega3250PA-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8285-8-bit-avr-microcontroller-atmega165a_pa_325a_pa_3250a_pa_645a_p_6450a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega3250PA-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='61',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='62',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='63',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='68',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='83',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='84',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='89',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega3250PV-10A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega3250PV-10A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8023.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega3250PV-10A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='61',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='62',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='63',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='68',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='83',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='84',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='89',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega325A-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega325A-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8285-8-bit-avr-microcontroller-atmega165a_pa_325a_pa_3250a_pa_645a_p_6450a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega325A-A\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega325A-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega325A-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8285-8-bit-avr-microcontroller-atmega165a_pa_325a_pa_3250a_pa_645a_p_6450a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega325A-M\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega325P-20A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega325P-20A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8023.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega325P-20A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega325P-20M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega325P-20M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8023.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega325P-20M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega325PA-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega325PA-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8285-8-bit-avr-microcontroller-atmega165a_pa_325a_pa_3250a_pa_645a_p_6450a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega325PA-A\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega325PA-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega325PA-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8285-8-bit-avr-microcontroller-atmega165a_pa_325a_pa_3250a_pa_645a_p_6450a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega325PA-M\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega325PV-10A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega325PV-10A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8023.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega325PV-10A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega325PV-10M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega325PV-10M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8023.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega325PV-10M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega328-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega328-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega328_P%20AVR%20MCU%20with%20picoPower%20Technology%20Data%20Sheet%2040001984A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega328-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega328-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega328-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega328_P%20AVR%20MCU%20with%20picoPower%20Technology%20Data%20Sheet%2040001984A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega328-M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega328-MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega328-MM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega328_P%20AVR%20MCU%20with%20picoPower%20Technology%20Data%20Sheet%2040001984A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega328-MM\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega328-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega328-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega328_P%20AVR%20MCU%20with%20picoPower%20Technology%20Data%20Sheet%2040001984A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega328-P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega328P-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega328P-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega328_P%20AVR%20MCU%20with%20picoPower%20Technology%20Data%20Sheet%2040001984A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega328P-A\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega328P-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega328P-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega328_P%20AVR%20MCU%20with%20picoPower%20Technology%20Data%20Sheet%2040001984A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega328P-M\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega328P-MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega328P-MM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega328_P%20AVR%20MCU%20with%20picoPower%20Technology%20Data%20Sheet%2040001984A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega328P-MM\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega328P-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega328P-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega328_P%20AVR%20MCU%20with%20picoPower%20Technology%20Data%20Sheet%2040001984A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega328P-P\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega328PB-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega328PB-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001906C.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega328PB-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega328PB-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega328PB-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001906C.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega328PB-M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega329-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega329-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2552.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega329-16A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega329-16M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega329-16M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2552.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega329-16M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega3290-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega3290-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2552.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega3290-16A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='61',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='62',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='63',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='68',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='83',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='84',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='89',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega3290A-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega3290A-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8284-8-bit-avr-microcontroller-atmega169a_pa_329a_pa_3290a_pa_649a_p_6490a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega3290A-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='61',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='62',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='63',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='68',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='83',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='84',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='89',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega3290P-20A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega3290P-20A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8021-AVR-ATmega329P-3290P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega3290P-20A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='61',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='62',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='63',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='68',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='83',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='84',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='89',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega3290PA-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega3290PA-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8284-8-bit-avr-microcontroller-atmega169a_pa_329a_pa_3290a_pa_649a_p_6490a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega3290PA-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='61',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='62',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='63',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='68',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='83',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='84',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='89',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega3290PV-10A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega3290PV-10A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8021-AVR-ATmega329P-3290P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega3290PV-10A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='61',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='62',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='63',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='68',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='83',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='84',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='89',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega329A-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega329A-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR LCD PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8284-8-bit-avr-microcontroller-atmega169a_pa_329a_pa_3290a_pa_649a_p_6490a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega329A-A\n\nAVR 8bit Microcontroller MegaAVR LCD PicoPower', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega329A-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega329A-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR LCD PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8284-8-bit-avr-microcontroller-atmega169a_pa_329a_pa_3290a_pa_649a_p_6490a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega329A-M\n\nAVR 8bit Microcontroller MegaAVR LCD PicoPower', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega329P-20A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega329P-20A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8021-AVR-ATmega329P-3290P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega329P-20A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega329P-20M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega329P-20M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8021-AVR-ATmega329P-3290P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega329P-20M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega329PA-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega329PA-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR LCD PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8284-8-bit-avr-microcontroller-atmega169a_pa_329a_pa_3290a_pa_649a_p_6490a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega329PA-A\n\nAVR 8bit Microcontroller MegaAVR LCD PicoPower', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega329PA-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega329PA-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR LCD PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8284-8-bit-avr-microcontroller-atmega169a_pa_329a_pa_3290a_pa_649a_p_6490a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega329PA-M\n\nAVR 8bit Microcontroller MegaAVR LCD PicoPower', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega329PV-10A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega329PV-10A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8021-AVR-ATmega329P-3290P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega329PV-10A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega329PV-10M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega329PV-10M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8021-AVR-ATmega329P-3290P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega329PV-10M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega32A-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega32A-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8155-8-bit-microcontroller-avr-atmega32a_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega32A-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega32A-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega32A-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8155-8-bit-microcontroller-avr-atmega32a_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega32A-M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega32A-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega32A-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8155-8-bit-microcontroller-avr-atmega32a_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega32A-P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega32L-8A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega32L-8A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2503.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega32L-8A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega32L-8M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega32L-8M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2503.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega32L-8M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega32L-8P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega32L-8P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2503.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega32L-8P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega32M1-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega32M1-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8209-8-bit%20AVR%20ATmega16M1-32M1-64M1_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega32M1-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL1/PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='XTAL2/PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF/ISRC',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='~{RESET}/PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega32M1-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega32M1-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.65x4.65mm', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.65x4.65mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.65x4.65mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8209-8-bit%20AVR%20ATmega16M1-32M1-64M1_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega32M1-M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL1/PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='XTAL2/PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF/ISRC',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='~{RESET}/PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega32U2-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega32U2-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7799.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega32U2-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{HWB}/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='UGND',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega32U2-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega32U2-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7799.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega32U2-M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{HWB}/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='UGND',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega32U4-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega32U4-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-7766-8-bit-AVR-ATmega16U4-32U4_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega32U4-A\n\nAVR 8bit Microcontroller MegaAVR USB', 'pins':[
            Pin(num='1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='~{HWB}/PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='UGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega32U4-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega32U4-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-7766-8-bit-AVR-ATmega16U4-32U4_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega32U4-M\n\nAVR 8bit Microcontroller MegaAVR USB', 'pins':[
            Pin(num='1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='~{HWB}/PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='UGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega32U4RC-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega32U4RC-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-7766-8-bit-AVR-ATmega16U4-32U4_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega32U4RC-A\n\nAVR 8bit Microcontroller MegaAVR USB', 'pins':[
            Pin(num='1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='~{HWB}/PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='UGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega32U4RC-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega32U4RC-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-7766-8-bit-AVR-ATmega16U4-32U4_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega32U4RC-M\n\nAVR 8bit Microcontroller MegaAVR USB', 'pins':[
            Pin(num='1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='~{HWB}/PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='UGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega48-20A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega48-20A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2545-8-bit-AVR-Microcontroller-ATmega48-88-168_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega48-20A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega48-20M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega48-20M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2545-8-bit-AVR-Microcontroller-ATmega48-88-168_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega48-20M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega48-20MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega48-20MM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2545-8-bit-AVR-Microcontroller-ATmega48-88-168_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega48-20MM\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega48-20P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega48-20P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2545-8-bit-AVR-Microcontroller-ATmega48-88-168_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega48-20P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega4808-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega4808-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40002017A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega4808-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF0/TOSC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF1/TOSC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF6/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='UPDI',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='EXTCLK/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega4808-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega4808-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm_ThermalVias', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40002017A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega4808-M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF0/TOSC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF1/TOSC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PF6/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='UPDI',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='EXTCLK/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega4808-X', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega4808-X'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40002018A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega4808-X\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PF0/TOSC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF1/TOSC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF6/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='UPDI',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='EXTCLK/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega4809-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega4809-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-48_7x7mm_P0.5mm', 'Package_QFP:TQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-48_7x7mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40002016A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega4809-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PF6/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='UPDI',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega4809-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega4809-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:UQFN-48-1EP_6x6mm_P0.4mm_EP4.62x4.62mm', 'Package_DFN_QFN:UQFN-48-1EP_6x6mm_P0.4mm_EP4.62x4.62mm'], 'footprint':'Package_DFN_QFN:UQFN-48-1EP_6x6mm_P0.4mm_EP4.62x4.62mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40002016A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega4809-M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PF6/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='UPDI',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega48A-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega48A-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48A_88A_168A-Data-Sheet-40002007A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega48A-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega48A-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega48A-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48A_88A_168A-Data-Sheet-40002007A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega48A-M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega48A-MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega48A-MM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48A_88A_168A-Data-Sheet-40002007A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega48A-MM\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega48A-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega48A-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48A_88A_168A-Data-Sheet-40002007A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega48A-P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega48P-20A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega48P-20A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8025-8-bit-AVR-Microcontroller-ATmega48P-88P-168P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega48P-20A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega48P-20M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega48P-20M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8025-8-bit-AVR-Microcontroller-ATmega48P-88P-168P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega48P-20M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega48P-20MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega48P-20MM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8025-8-bit-AVR-Microcontroller-ATmega48P-88P-168P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega48P-20MM\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega48P-20P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega48P-20P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8025-8-bit-AVR-Microcontroller-ATmega48P-88P-168P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega48P-20P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega48PA-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega48PA-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48PA_88PA_168PA-Data-Sheet-40002011A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega48PA-A\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega48PA-CC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega48PA-CC'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm', 'Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm', 'Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm', 'Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm'], 'footprint':'Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48PA_88PA_168PA-Data-Sheet-40002011A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega48PA-CC\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='A1',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C5',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='E1',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PB4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega48PA-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega48PA-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48PA_88PA_168PA-Data-Sheet-40002011A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega48PA-M\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega48PA-MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega48PA-MM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48PA_88PA_168PA-Data-Sheet-40002011A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega48PA-MM\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega48PA-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega48PA-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48PA_88PA_168PA-Data-Sheet-40002011A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega48PA-P\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega64-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega64-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2490-8-bit-avr-microcontroller-atmega64-l_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega64-16A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='~{PEN}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega64-16M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega64-16M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2490-8-bit-avr-microcontroller-atmega64-l_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega64-16M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='~{PEN}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega640-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega640-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2549-8-bit-AVR-Microcontroller-ATmega640-1280-1281-2560-2561_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega640-16A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PL0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PL1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PL2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PL3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PL4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PL5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PL6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PL7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega640-16C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega640-16C'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2549-8-bit-AVR-Microcontroller-ATmega640-1280-1281-2560-2561_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega640-16C\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='B10',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='F10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PL4',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G10',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PL2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='H4',name='PL1',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PL3',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PL7',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PL0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='J6',name='PL6',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K5',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='K6',name='PL5',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega644-20A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega644-20A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2593.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega644-20A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega644-20M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega644-20M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2593.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega644-20M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega644-20P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega644-20P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2593.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega644-20P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega644A-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega644A-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega644A-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega644A-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega644A-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega644A-M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega644A-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega644A-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega644A-P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega644P-20A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega644P-20A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-42744-ATmega644P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega644P-20A\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega644P-20M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega644P-20M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-42744-ATmega644P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega644P-20M\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega644P-20P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega644P-20P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-42744-ATmega644P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega644P-20P\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega644PA-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega644PA-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega644PA-A\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega644PA-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega644PA-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega644PA-M\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega644PA-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega644PA-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8272-8-bit-AVR-microcontroller-ATmega164A_PA-324A_PA-644A_PA-1284_P_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega644PA-P\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega644PV-10A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega644PV-10A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-42744-ATmega644P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega644PV-10A\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega644PV-10M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega644PV-10M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-42744-ATmega644P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega644PV-10M\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega644PV-10P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega644PV-10P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-42744-ATmega644P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega644PV-10P\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega645-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega645-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2570.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega645-16A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega645-16M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega645-16M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2570.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega645-16M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega6450-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega6450-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2570.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega6450-16A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='61',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='62',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='63',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='68',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='83',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='84',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='89',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega6450A-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega6450A-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8285-8-bit-avr-microcontroller-atmega165a_pa_325a_pa_3250a_pa_645a_p_6450a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega6450A-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='61',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='62',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='63',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='68',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='83',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='84',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='89',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega6450P-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega6450P-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8285-8-bit-avr-microcontroller-atmega165a_pa_325a_pa_3250a_pa_645a_p_6450a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega6450P-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='61',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='62',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='63',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='68',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='83',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='84',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='89',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega6450V-8A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega6450V-8A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2570.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega6450V-8A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='61',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='62',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='63',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='68',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='83',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='84',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='89',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega645A-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega645A-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8285-8-bit-avr-microcontroller-atmega165a_pa_325a_pa_3250a_pa_645a_p_6450a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega645A-A\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega645A-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega645A-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8285-8-bit-avr-microcontroller-atmega165a_pa_325a_pa_3250a_pa_645a_p_6450a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega645A-M\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega645P-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega645P-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8285-8-bit-avr-microcontroller-atmega165a_pa_325a_pa_3250a_pa_645a_p_6450a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega645P-A\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega645P-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega645P-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8285-8-bit-avr-microcontroller-atmega165a_pa_325a_pa_3250a_pa_645a_p_6450a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega645P-M\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega645V-8A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega645V-8A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2570.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega645V-8A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega645V-8M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega645V-8M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2570.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega645V-8M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega649-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega649-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2552.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega649-16A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega649-16M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega649-16M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2552.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega649-16M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega6490-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega6490-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2552.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega6490-16A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='61',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='62',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='63',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='68',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='83',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='84',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='89',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega6490A-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega6490A-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8284-8-bit-avr-microcontroller-atmega169a_pa_329a_pa_3290a_pa_649a_p_6490a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega6490A-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='61',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='62',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='63',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='68',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='83',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='84',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='89',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega6490P-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega6490P-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8284-8-bit-avr-microcontroller-atmega169a_pa_329a_pa_3290a_pa_649a_p_6490a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega6490P-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='61',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='62',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='63',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='68',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='83',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='84',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='89',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega6490V-8A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega6490V-8A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2552.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega6490V-8A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='61',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='62',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='63',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='68',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='81',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='82',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='83',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='84',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='89',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='99',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega649A-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega649A-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR LCD PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8284-8-bit-avr-microcontroller-atmega169a_pa_329a_pa_3290a_pa_649a_p_6490a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega649A-A\n\nAVR 8bit Microcontroller MegaAVR LCD PicoPower', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega649A-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega649A-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR LCD PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8284-8-bit-avr-microcontroller-atmega169a_pa_329a_pa_3290a_pa_649a_p_6490a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega649A-M\n\nAVR 8bit Microcontroller MegaAVR LCD PicoPower', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega649P-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega649P-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR LCD PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8284-8-bit-avr-microcontroller-atmega169a_pa_329a_pa_3290a_pa_649a_p_6490a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega649P-A\n\nAVR 8bit Microcontroller MegaAVR LCD PicoPower', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega649P-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega649P-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR LCD PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8284-8-bit-avr-microcontroller-atmega169a_pa_329a_pa_3290a_pa_649a_p_6490a_p_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega649P-M\n\nAVR 8bit Microcontroller MegaAVR LCD PicoPower', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega649V-8A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega649V-8A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2552.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega649V-8A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega649V-8M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega649V-8M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2552.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega649V-8M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='LCDCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG5/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega64A-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega64A-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8160-8-bit-avr-microcontroller-atmega64a-datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega64A-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='~{PEN}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega64A-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega64A-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.4x5.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8160-8-bit-avr-microcontroller-atmega64a-datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega64A-M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='~{PEN}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega64M1-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega64M1-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8209-8-bit%20AVR%20ATmega16M1-32M1-64M1_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega64M1-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL1/PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='XTAL2/PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF/ISRC',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='~{RESET}/PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega64M1-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega64M1-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.65x4.65mm', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.65x4.65mm', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.65x4.65mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.65x4.65mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8209-8-bit%20AVR%20ATmega16M1-32M1-64M1_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega64M1-M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL1/PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='XTAL2/PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF/ISRC',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='~{RESET}/PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega8-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega8-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2486-8-bit-avr-microcontroller-atmega8_l_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega8-16A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC6/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PB6/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega8-16M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega8-16M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2486-8-bit-avr-microcontroller-atmega8_l_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega8-16M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC6/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PB6/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega8-16P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega8-16P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2486-8-bit-avr-microcontroller-atmega8_l_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega8-16P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PC6/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB7/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PB6/XTAL1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega8515-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega8515-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2512.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega8515-16A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='29',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega8515-16J', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega8515-16J'}), 'ref_prefix':'U', 'fplist':['Package_LCC:PLCC-44', 'Package_LCC:PLCC-44'], 'footprint':'Package_LCC:PLCC-44', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2512.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega8515-16J\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='24',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='35',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega8515-16M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega8515-16M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2512.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega8515-16M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='29',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega8515-16P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega8515-16P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2512.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega8515-16P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega8535-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega8535-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2502.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega8535-16A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega8535-16J', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega8535-16J'}), 'ref_prefix':'U', 'fplist':['Package_LCC:PLCC-44', 'Package_LCC:PLCC-44'], 'footprint':'Package_LCC:PLCC-44', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2502.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega8535-16J\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega8535-16M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega8535-16M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2502.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega8535-16M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PD0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega8535-16P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega8535-16P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2502.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega8535-16P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega88-20A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega88-20A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2545-8-bit-AVR-Microcontroller-ATmega48-88-168_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega88-20A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega88-20M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega88-20M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2545-8-bit-AVR-Microcontroller-ATmega48-88-168_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega88-20M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega88-20P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega88-20P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2545-8-bit-AVR-Microcontroller-ATmega48-88-168_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega88-20P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega88A-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega88A-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48A_88A_168A-Data-Sheet-40002007A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega88A-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega88A-CC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega88A-CC'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm', 'Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm', 'Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm', 'Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm', 'Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm'], 'footprint':'Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48A_88A_168A-Data-Sheet-40002007A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega88A-CC\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='A1',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C5',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='E1',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PB4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega88A-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega88A-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48A_88A_168A-Data-Sheet-40002007A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega88A-M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega88A-MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega88A-MM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48A_88A_168A-Data-Sheet-40002007A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega88A-MM\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega88A-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega88A-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48A_88A_168A-Data-Sheet-40002007A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega88A-P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega88P-20A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega88P-20A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8025-8-bit-AVR-Microcontroller-ATmega48P-88P-168P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega88P-20A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega88P-20M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega88P-20M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8025-8-bit-AVR-Microcontroller-ATmega48P-88P-168P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega88P-20M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega88P-20P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega88P-20P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8025-8-bit-AVR-Microcontroller-ATmega48P-88P-168P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega88P-20P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega88PA-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega88PA-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48PA_88PA_168PA-Data-Sheet-40002011A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega88PA-A\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega88PA-CC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega88PA-CC'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm', 'Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm', 'Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm', 'Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm', 'Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm', 'Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm'], 'footprint':'Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48PA_88PA_168PA-Data-Sheet-40002011A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega88PA-CC\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='A1',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C5',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='E1',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PB4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega88PA-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega88PA-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48PA_88PA_168PA-Data-Sheet-40002011A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega88PA-M\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega88PA-MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega88PA-MM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48PA_88PA_168PA-Data-Sheet-40002011A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega88PA-MM\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega88PA-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega88PA-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'AVR 8bit Microcontroller MegaAVR PicoPower', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATmega48PA_88PA_168PA-Data-Sheet-40002011A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega88PA-P\n\nAVR 8bit Microcontroller MegaAVR PicoPower', 'pins':[
            Pin(num='1',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega88PB-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega88PB-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001909A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega88PB-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega88PB-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega88PB-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001909A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega88PB-M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega88PV-10A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega88PV-10A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8025-8-bit-AVR-Microcontroller-ATmega48P-88P-168P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega88PV-10A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega88PV-10M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega88PV-10M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8025-8-bit-AVR-Microcontroller-ATmega48P-88P-168P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega88PV-10M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega88PV-10P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega88PV-10P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8025-8-bit-AVR-Microcontroller-ATmega48P-88P-168P_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega88PV-10P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega88V-10A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega88V-10A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2545-8-bit-AVR-Microcontroller-ATmega48-88-168_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega88V-10A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega88V-10M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega88V-10M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2545-8-bit-AVR-Microcontroller-ATmega48-88-168_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega88V-10M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega88V-10P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega88V-10P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2545-8-bit-AVR-Microcontroller-ATmega48-88-168_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega88V-10P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL2/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='XTAL1/PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega8A-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega8A-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Microchip%208bit%20mcu%20AVR%20ATmega8A%20data%20sheet%2040001974A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega8A-A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC6/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PB6/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega8A-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega8A-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Microchip%208bit%20mcu%20AVR%20ATmega8A%20data%20sheet%2040001974A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega8A-M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='ADC6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='ADC7',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC6/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PB6/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATmega8A-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATmega8A-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Microchip%208bit%20mcu%20AVR%20ATmega8A%20data%20sheet%2040001974A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATmega8A-P\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='PC6/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB7/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PB6/XTAL1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega128A1-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega128A1-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8067-8-and-16-bit-AVR-Microcontrollers-ATxmega64A1-ATxmega128A1_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega128A1-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='85',name='PQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='91',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega128A1-C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega128A1-C'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8067-8-and-16-bit-AVR-Microcontrollers-ATxmega64A1-ATxmega128A1_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega128A1-C\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='A1',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='A6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A7',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A9',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D2',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='F4',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega128A1-C7', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega128A1-C7'}), 'ref_prefix':'U', 'fplist':['Package_BGA:VFBGA-100_7.0x7.0mm_Layout10x10_P0.65mm', 'Package_BGA:VFBGA-100_7.0x7.0mm_Layout10x10_P0.65mm'], 'footprint':'Package_BGA:VFBGA-100_7.0x7.0mm_Layout10x10_P0.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8067-8-and-16-bit-AVR-Microcontrollers-ATxmega64A1-ATxmega128A1_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega128A1-C7\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='A1',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='A6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A7',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A9',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D2',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='F4',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega128A1U-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega128A1U-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8385-8-and-16-bit-AVR-Microcontroller-ATxmega64A1U-ATxmega128A1U_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega128A1U-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='85',name='PQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='91',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='94',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega128A1U-C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega128A1U-C'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm', 'Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:TFBGA-100_9.0x9.0mm_Layout10x10_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8385-8-and-16-bit-AVR-Microcontroller-ATxmega64A1U-ATxmega128A1U_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega128A1U-C\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='A1',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='A6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A7',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A9',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D2',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='F4',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega128A1U-C7', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega128A1U-C7'}), 'ref_prefix':'U', 'fplist':['Package_BGA:VFBGA-100_7.0x7.0mm_Layout10x10_P0.65mm', 'Package_BGA:VFBGA-100_7.0x7.0mm_Layout10x10_P0.65mm'], 'footprint':'Package_BGA:VFBGA-100_7.0x7.0mm_Layout10x10_P0.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8385-8-and-16-bit-AVR-Microcontroller-ATxmega64A1U-ATxmega128A1U_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega128A1U-C7\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='A1',name='PK0',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PJ3',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='A6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A7',name='PH1',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A9',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='PK3',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PK2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PK1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PJ4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PH7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PH4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PH2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PH0',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='PK5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PK4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PJ5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PJ0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PH5',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PH3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D2',name='PK6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PK7',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PJ6',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PJ1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PH6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PJ7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PJ2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='F4',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='H10',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='AVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega128A3-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega128A3-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8068-8-and16-bit-AVR-XMEGA-A3-Microcontrollers_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega128A3-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega128A3-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega128A3-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8068-8-and16-bit-AVR-XMEGA-A3-Microcontrollers_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega128A3-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega128A3U-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega128A3U-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8386-8-and-16-bit-AVR-Microcontroller-ATxmega64A3U-128A3U-192A3U-256A3U_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega128A3U-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega128A3U-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega128A3U-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8386-8-and-16-bit-AVR-Microcontroller-ATxmega64A3U-128A3U-192A3U-256A3U_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega128A3U-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega128A4U-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega128A4U-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8387-8-and16-bit-AVR-Microcontroller-XMEGA-A4U_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega128A4U-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega128A4U-C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega128A4U-C'}), 'ref_prefix':'U', 'fplist':['Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm'], 'footprint':'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8387-8-and16-bit-AVR-Microcontroller-XMEGA-A4U_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega128A4U-C\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='A1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='PD2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega128A4U-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega128A4U-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8387-8-and16-bit-AVR-Microcontroller-XMEGA-A4U_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega128A4U-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega128B1-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega128B1-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm', 'Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8330-8-and-16-bit-AVR-Microcontroller-XMEGA-B-ATxmega64B1-ATxmega128B1_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega128B1-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='PG0/SEG39',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PG1/SEG38',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PG2/SEG37',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PG3/SEG36',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG4/SEG35',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG5/SEG34',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PG6/SEG33',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PG7/SEG32',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PM0/SEG31',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PM1/SEG30',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PM2/SEG29',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PM3/SEG28',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PM4/SEG27',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PM5/SEG26',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PM6/SEG25',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PM7/SEG24',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='SEG23',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='SEG22',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='SEG21',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='SEG20',func=pin_types.OUTPUT,unit=1),
            Pin(num='49',name='SEG19',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='SEG18',func=pin_types.OUTPUT,unit=1),
            Pin(num='51',name='SEG17',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='SEG16',func=pin_types.OUTPUT,unit=1),
            Pin(num='53',name='SEG15',func=pin_types.OUTPUT,unit=1),
            Pin(num='54',name='SEG14',func=pin_types.OUTPUT,unit=1),
            Pin(num='55',name='SEG13',func=pin_types.OUTPUT,unit=1),
            Pin(num='56',name='SEG12',func=pin_types.OUTPUT,unit=1),
            Pin(num='57',name='SEG11',func=pin_types.OUTPUT,unit=1),
            Pin(num='58',name='SEG10',func=pin_types.OUTPUT,unit=1),
            Pin(num='59',name='SEG9',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='SEG8',func=pin_types.OUTPUT,unit=1),
            Pin(num='61',name='SEG7',func=pin_types.OUTPUT,unit=1),
            Pin(num='62',name='SEG6',func=pin_types.OUTPUT,unit=1),
            Pin(num='63',name='SEG5',func=pin_types.OUTPUT,unit=1),
            Pin(num='64',name='SEG4',func=pin_types.OUTPUT,unit=1),
            Pin(num='65',name='SEG3',func=pin_types.OUTPUT,unit=1),
            Pin(num='66',name='SEG2',func=pin_types.OUTPUT,unit=1),
            Pin(num='67',name='SEG1',func=pin_types.OUTPUT,unit=1),
            Pin(num='68',name='SEG0',func=pin_types.OUTPUT,unit=1),
            Pin(num='69',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='BIAS1',func=pin_types.PWROUT,unit=1),
            Pin(num='72',name='BIAS2',func=pin_types.PWROUT,unit=1),
            Pin(num='73',name='VLCD',func=pin_types.PWROUT,unit=1),
            Pin(num='74',name='CAPL',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='CAPH',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='COM0',func=pin_types.OUTPUT,unit=1),
            Pin(num='77',name='COM1',func=pin_types.OUTPUT,unit=1),
            Pin(num='78',name='COM2',func=pin_types.OUTPUT,unit=1),
            Pin(num='79',name='COM3',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PA0/AREF',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='91',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PB7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega128B1-C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega128B1-C'}), 'ref_prefix':'U', 'fplist':['Package_BGA:VFBGA-100_7.0x7.0mm_Layout10x10_P0.65mm', 'Package_BGA:VFBGA-100_7.0x7.0mm_Layout10x10_P0.65mm'], 'footprint':'Package_BGA:VFBGA-100_7.0x7.0mm_Layout10x10_P0.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8330-8-and-16-bit-AVR-Microcontroller-XMEGA-B-ATxmega64B1-ATxmega128B1_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega128B1-C\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='A1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='CAPH',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='COM2',func=pin_types.OUTPUT,unit=1),
            Pin(num='B1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='CAPL',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PA0/AREF',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='COM1',func=pin_types.OUTPUT,unit=1),
            Pin(num='C1',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='BIAS1',func=pin_types.PWROUT,unit=1),
            Pin(num='C2',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='COM3',func=pin_types.OUTPUT,unit=1),
            Pin(num='C8',name='COM0',func=pin_types.OUTPUT,unit=1),
            Pin(num='C9',name='BIAS2',func=pin_types.PWROUT,unit=1),
            Pin(num='D1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='D10',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='D2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='SEG0',func=pin_types.OUTPUT,unit=1),
            Pin(num='D8',name='VLCD',func=pin_types.PWROUT,unit=1),
            Pin(num='D9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='SEG2',func=pin_types.OUTPUT,unit=1),
            Pin(num='E2',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='E3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='SEG1',func=pin_types.OUTPUT,unit=1),
            Pin(num='E8',name='SEG4',func=pin_types.OUTPUT,unit=1),
            Pin(num='E9',name='SEG3',func=pin_types.OUTPUT,unit=1),
            Pin(num='F1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='F10',name='SEG5',func=pin_types.OUTPUT,unit=1),
            Pin(num='F2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PM2/SEG29',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='SEG10',func=pin_types.OUTPUT,unit=1),
            Pin(num='F8',name='SEG7',func=pin_types.OUTPUT,unit=1),
            Pin(num='F9',name='SEG6',func=pin_types.OUTPUT,unit=1),
            Pin(num='G1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='SEG8',func=pin_types.OUTPUT,unit=1),
            Pin(num='G2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='SEG23',func=pin_types.OUTPUT,unit=1),
            Pin(num='G7',name='SEG15',func=pin_types.OUTPUT,unit=1),
            Pin(num='G8',name='SEG13',func=pin_types.OUTPUT,unit=1),
            Pin(num='G9',name='SEG9',func=pin_types.OUTPUT,unit=1),
            Pin(num='H1',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='SEG11',func=pin_types.OUTPUT,unit=1),
            Pin(num='H2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PG1/SEG38',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PG4/SEG35',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PG7/SEG32',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PM5/SEG26',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='SEG21',func=pin_types.OUTPUT,unit=1),
            Pin(num='H8',name='SEG18',func=pin_types.OUTPUT,unit=1),
            Pin(num='H9',name='SEG12',func=pin_types.OUTPUT,unit=1),
            Pin(num='J1',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='SEG14',func=pin_types.OUTPUT,unit=1),
            Pin(num='J2',name='PG0/SEG39',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PG3/SEG36',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PG6/SEG33',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PM1/SEG30',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PM4/SEG27',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PM7/SEG24',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='SEG20',func=pin_types.OUTPUT,unit=1),
            Pin(num='J9',name='SEG16',func=pin_types.OUTPUT,unit=1),
            Pin(num='K1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='SEG17',func=pin_types.OUTPUT,unit=1),
            Pin(num='K2',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='PG2/SEG37',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PG5/SEG34',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PM0/SEG31',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PM3/SEG28',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PM6/SEG25',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='SEG22',func=pin_types.OUTPUT,unit=1),
            Pin(num='K9',name='SEG19',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega128B3-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega128B3-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8074-8-and-16-bit-AVR-Microcontroller-XMEGA-B-ATxmega64B3-ATxmega128B3_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega128B3-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='PG0/SEG24',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG1/SEG23',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG2/SEG22',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG3/SEG21',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PG4/SEG20',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PG5/SEG19',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PG6/SEG18',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PG7/SEG17',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PM0/SEG16',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PM1/SEG15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PM2/SEG14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PM3/SEG13',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PM4/SEG12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM5/SEG11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PM6/SEG10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PM7/SEG9',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='SEG8',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='SEG7',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='SEG6',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='SEG5',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='SEG4',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='SEG3',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='SEG2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='SEG1',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='SEG0',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='BIAS1',func=pin_types.PWROUT,unit=1),
            Pin(num='45',name='BIAS2',func=pin_types.PWROUT,unit=1),
            Pin(num='46',name='VLCD',func=pin_types.PWROUT,unit=1),
            Pin(num='47',name='CAPL',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='CAPH',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='COM0',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='COM1',func=pin_types.OUTPUT,unit=1),
            Pin(num='51',name='COM2',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='COM3',func=pin_types.OUTPUT,unit=1),
            Pin(num='53',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PB0/AREF',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega128B3-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega128B3-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8074-8-and-16-bit-AVR-Microcontroller-XMEGA-B-ATxmega64B3-ATxmega128B3_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega128B3-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='PG0/SEG24',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG1/SEG23',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG2/SEG22',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PG3/SEG21',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PG4/SEG20',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PG5/SEG19',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PG6/SEG18',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PG7/SEG17',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PM0/SEG16',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PM1/SEG15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PM2/SEG14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PM3/SEG13',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PM4/SEG12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM5/SEG11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PM6/SEG10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PM7/SEG9',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='SEG8',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='SEG7',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='SEG6',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='SEG5',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='SEG4',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='SEG3',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='SEG2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='SEG1',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='SEG0',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='BIAS1',func=pin_types.PWROUT,unit=1),
            Pin(num='45',name='BIAS2',func=pin_types.PWROUT,unit=1),
            Pin(num='46',name='VLCD',func=pin_types.PWROUT,unit=1),
            Pin(num='47',name='CAPL',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='CAPH',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='COM0',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='COM1',func=pin_types.OUTPUT,unit=1),
            Pin(num='51',name='COM2',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='COM3',func=pin_types.OUTPUT,unit=1),
            Pin(num='53',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='PB0/AREF',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega128C3-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega128C3-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8492-8-and-16-bit-AVR-microcontroller-ATxmega32C3_64C3_128C3_192C3_256C3_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega128C3-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega128C3-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega128C3-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8492-8-and-16-bit-AVR-microcontroller-ATxmega32C3_64C3_128C3_192C3_256C3_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega128C3-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega128D3-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega128D3-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8134-8-16-bit-Atmel-XMEGA-D3-Microcontroller_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega128D3-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega128D3-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega128D3-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8134-8-16-bit-Atmel-XMEGA-D3-Microcontroller_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega128D3-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega128D4-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega128D4-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8135-8-and-16-bit-AVR-microcontroller-ATxmega16D4-32D4-64D4-128D4_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega128D4-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega128D4-C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega128D4-C'}), 'ref_prefix':'U', 'fplist':['Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm'], 'footprint':'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8135-8-and-16-bit-AVR-microcontroller-ATxmega16D4-32D4-64D4-128D4_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega128D4-C\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='A1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='PD2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega128D4-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega128D4-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8135-8-and-16-bit-AVR-microcontroller-ATxmega16D4-32D4-64D4-128D4_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega128D4-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega16E5-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega16E5-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8153-8-and-16-bit-AVR-Microcontroller-XMEGA-E-ATxmega8E5-ATxmega16E5-ATxmega32E5_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega16E5-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD0/AREF',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega16E5-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega16E5-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8153-8-and-16-bit-AVR-Microcontroller-XMEGA-E-ATxmega8E5-ATxmega16E5-ATxmega32E5_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega16E5-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD0/AREF',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega16E5-M4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega16E5-M4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_4x4mm_P0.4mm_EP2.9x2.9mm', 'Package_DFN_QFN:QFN-32-1EP_4x4mm_P0.4mm_EP2.9x2.9mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_4x4mm_P0.4mm_EP2.9x2.9mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8153-8-and-16-bit-AVR-Microcontroller-XMEGA-E-ATxmega8E5-ATxmega16E5-ATxmega32E5_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega16E5-M4\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD0/AREF',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega192A3-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega192A3-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8068-8-and16-bit-AVR-XMEGA-A3-Microcontrollers_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega192A3-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega192A3-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega192A3-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8068-8-and16-bit-AVR-XMEGA-A3-Microcontrollers_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega192A3-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega192A3U-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega192A3U-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8386-8-and-16-bit-AVR-Microcontroller-ATxmega64A3U-128A3U-192A3U-256A3U_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega192A3U-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega192A3U-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega192A3U-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8386-8-and-16-bit-AVR-Microcontroller-ATxmega64A3U-128A3U-192A3U-256A3U_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega192A3U-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega192C3-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega192C3-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8492-8-and-16-bit-AVR-microcontroller-ATxmega32C3_64C3_128C3_192C3_256C3_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega192C3-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega192C3-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega192C3-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8492-8-and-16-bit-AVR-microcontroller-ATxmega32C3_64C3_128C3_192C3_256C3_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega192C3-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega192D3-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega192D3-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8134-8-16-bit-Atmel-XMEGA-D3-Microcontroller_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega192D3-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega192D3-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega192D3-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8134-8-16-bit-Atmel-XMEGA-D3-Microcontroller_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega192D3-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega256A3-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega256A3-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8068-8-and16-bit-AVR-XMEGA-A3-Microcontrollers_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega256A3-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega256A3-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega256A3-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8068-8-and16-bit-AVR-XMEGA-A3-Microcontrollers_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega256A3-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega256A3U-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega256A3U-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8386-8-and-16-bit-AVR-Microcontroller-ATxmega64A3U-128A3U-192A3U-256A3U_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega256A3U-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega256A3U-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega256A3U-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8386-8-and-16-bit-AVR-Microcontroller-ATxmega64A3U-128A3U-192A3U-256A3U_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega256A3U-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega256C3-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega256C3-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8492-8-and-16-bit-AVR-microcontroller-ATxmega32C3_64C3_128C3_192C3_256C3_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega256C3-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega256C3-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega256C3-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8492-8-and-16-bit-AVR-microcontroller-ATxmega32C3_64C3_128C3_192C3_256C3_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega256C3-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega256D3-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega256D3-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8134-8-16-bit-Atmel-XMEGA-D3-Microcontroller_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega256D3-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega256D3-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega256D3-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8134-8-16-bit-Atmel-XMEGA-D3-Microcontroller_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega256D3-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega32A4U-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega32A4U-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8387-8-and16-bit-AVR-Microcontroller-XMEGA-A4U_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega32A4U-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega32A4U-C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega32A4U-C'}), 'ref_prefix':'U', 'fplist':['Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm'], 'footprint':'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8387-8-and16-bit-AVR-Microcontroller-XMEGA-A4U_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega32A4U-C\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='A1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='PD2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega32A4U-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega32A4U-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8387-8-and16-bit-AVR-Microcontroller-XMEGA-A4U_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega32A4U-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega32C4-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega32C4-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8493-8-and-32-bit-AVR-XMEGA-Microcontrollers-ATxmega16C4-ATxmega32C4_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega32C4-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='PR0/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PR1/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega32C4-C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega32C4-C'}), 'ref_prefix':'U', 'fplist':['Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm'], 'footprint':'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8493-8-and-32-bit-AVR-XMEGA-Microcontrollers-ATxmega16C4-ATxmega32C4_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega32C4-C\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='A1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PR1/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PR0/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='PD2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega32C4-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega32C4-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8493-8-and-32-bit-AVR-XMEGA-Microcontrollers-ATxmega16C4-ATxmega32C4_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega32C4-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='PR0/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PR1/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega32D4-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega32D4-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8135-8-and-16-bit-AVR-microcontroller-ATxmega16D4-32D4-64D4-128D4_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega32D4-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega32D4-C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega32D4-C'}), 'ref_prefix':'U', 'fplist':['Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm'], 'footprint':'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8135-8-and-16-bit-AVR-microcontroller-ATxmega16D4-32D4-64D4-128D4_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega32D4-C\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='A1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='PD2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega32D4-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega32D4-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8135-8-and-16-bit-AVR-microcontroller-ATxmega16D4-32D4-64D4-128D4_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega32D4-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega32E5-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega32E5-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8153-8-and-16-bit-AVR-Microcontroller-XMEGA-E-ATxmega8E5-ATxmega16E5-ATxmega32E5_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega32E5-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD0/AREF',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega32E5-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega32E5-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8153-8-and-16-bit-AVR-Microcontroller-XMEGA-E-ATxmega8E5-ATxmega16E5-ATxmega32E5_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega32E5-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD0/AREF',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega32E5-M4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega32E5-M4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_4x4mm_P0.4mm_EP2.9x2.9mm', 'Package_DFN_QFN:QFN-32-1EP_4x4mm_P0.4mm_EP2.9x2.9mm', 'Package_DFN_QFN:QFN-32-1EP_4x4mm_P0.4mm_EP2.9x2.9mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_4x4mm_P0.4mm_EP2.9x2.9mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8153-8-and-16-bit-AVR-Microcontroller-XMEGA-E-ATxmega8E5-ATxmega16E5-ATxmega32E5_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega32E5-M4\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD0/AREF',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PC7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega384C3-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega384C3-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8361-8-and-16-bit-AVR-XMEGA-Microcontrollers-ATxmega384C3_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega384C3-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega384C3-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega384C3-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8361-8-and-16-bit-AVR-XMEGA-Microcontrollers-ATxmega384C3_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega384C3-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega384D3-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega384D3-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8134-8-16-bit-Atmel-XMEGA-D3-Microcontroller_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega384D3-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega384D3-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega384D3-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8134-8-16-bit-Atmel-XMEGA-D3-Microcontroller_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega384D3-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega64A4U-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega64A4U-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8387-8-and16-bit-AVR-Microcontroller-XMEGA-A4U_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega64A4U-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega64A4U-C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega64A4U-C'}), 'ref_prefix':'U', 'fplist':['Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm'], 'footprint':'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8387-8-and16-bit-AVR-Microcontroller-XMEGA-A4U_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega64A4U-C\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='A1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='PD2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega64A4U-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega64A4U-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8387-8-and16-bit-AVR-Microcontroller-XMEGA-A4U_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega64A4U-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega64C3-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega64C3-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8492-8-and-16-bit-AVR-microcontroller-ATxmega32C3_64C3_128C3_192C3_256C3_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega64C3-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega64C3-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega64C3-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8492-8-and-16-bit-AVR-microcontroller-ATxmega32C3_64C3_128C3_192C3_256C3_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega64C3-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega64D3-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega64D3-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8134-8-16-bit-Atmel-XMEGA-D3-Microcontroller_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega64D3-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega64D3-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega64D3-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.65x7.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8134-8-16-bit-Atmel-XMEGA-D3-Microcontroller_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega64D3-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AREFB/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='62',name='AREFA/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega64D4-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega64D4-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8135-8-and-16-bit-AVR-microcontroller-ATxmega16D4-32D4-64D4-128D4_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega64D4-A\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega64D4-C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega64D4-C'}), 'ref_prefix':'U', 'fplist':['Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm'], 'footprint':'Package_BGA:VFBGA-49_5.0x5.0mm_Layout7x7_P0.65mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8135-8-and-16-bit-AVR-microcontroller-ATxmega16D4-32D4-64D4-128D4_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega64D4-C\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='A1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='PD2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATxmega64D4-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATxmega64D4-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm'], 'footprint':'Package_DFN_QFN:QFN-44-1EP_7x7mm_P0.5mm_EP5.2x5.2mm', 'keywords':'AVR 8/16bit Microcontroller XMegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8135-8-and-16-bit-AVR-microcontroller-ATxmega16D4-32D4-64D4-128D4_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATmega.kicad_sym\nATxmega64D4-M\n\nAVR 8/16bit Microcontroller XMegaAVR', 'pins':[
            Pin(num='1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PDI_DATA',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='~{RESET}/PDI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='PR0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PR1/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] })])