from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Interface = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'5PB1108PGxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'5PB1108PGxx'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'clock buffer lvcmos', 'description':'', 'datasheet':'https://www.renesas.com/us/en/document/dst/5pb11xx-family-datasheet', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\n5PB1108PGxx\n\nclock buffer lvcmos', 'pins':[
            Pin(num='1',name='CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Y5',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Y2',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Y3',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='Y1',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='1G',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Y0',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='Y4',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Y6',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Y7',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'6821', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'6821'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'PIA', 'description':'', 'datasheet':'http://pdf.datasheetcatalog.com/datasheet/motorola/6821.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\n6821\n\nPIA', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='CB1',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='R/~{W}',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='CS0',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{CS2}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='CS1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='ENABLE',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='RS1',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='RS0',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='~{IRQB}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='38',name='~{IRQA}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='39',name='CA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='CA1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'68230', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'68230'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'MPRO', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\n68230\n\nMPRO', 'pins':[
            Pin(num='1',name='D5',func=pin_types.TRISTATE,unit=1),
            Pin(num='10',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='H1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='H2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='H3',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='H4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='D6',func=pin_types.TRISTATE,unit=1),
            Pin(num='20',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RS5',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='RS4',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='RS3',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='RS2',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='RS1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='D7',func=pin_types.TRISTATE,unit=1),
            Pin(num='30',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='TIN/PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC3/TOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='DMAREQ/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC5/PIRQ',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC6/PIACK',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC7/TIACK',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='CS',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='DTACK',func=pin_types.OPENCOLL,unit=1),
            Pin(num='43',name='R/W',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='D0',func=pin_types.TRISTATE,unit=1),
            Pin(num='45',name='D1',func=pin_types.TRISTATE,unit=1),
            Pin(num='46',name='D2',func=pin_types.TRISTATE,unit=1),
            Pin(num='47',name='D3',func=pin_types.TRISTATE,unit=1),
            Pin(num='48',name='D4',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'68681', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'68681'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'MPRO', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\n68681\n\nMPRO', 'pins':[
            Pin(num='1',name='RS1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RXDB',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='TXDB',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='OP1',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='OP3',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='OP5',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='OP7',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='D1',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='D3',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='D5',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='D7',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='IP3',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='IRQ',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='D6',func=pin_types.TRISTATE,unit=1),
            Pin(num='23',name='D4',func=pin_types.TRISTATE,unit=1),
            Pin(num='24',name='D2',func=pin_types.TRISTATE,unit=1),
            Pin(num='25',name='D0',func=pin_types.TRISTATE,unit=1),
            Pin(num='26',name='OP6',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='OP4',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='OP2',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='OP0',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='RS2',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='TXDA',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='RXDA',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='X1/CLK',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='X2',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='CS',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='IP2',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='IACK',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='IP5',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='IP4',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IP1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='RS3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='RS4',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IP0',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='R/W',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='DTACK',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'68901_PLCC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'68901_PLCC'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'MPRO', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\n68901_PLCC\n\nMPRO', 'pins':[
            Pin(num='10',name='SI',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='RC',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='MPX',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='TAO',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='TBO',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='TCO',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='X1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='R/W',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='X2',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='TAI',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='TBI',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='I0',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='RS1',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='TR',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='RR',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='IRQ',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='IEO',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='IEI',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='RS2',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='D7',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='IACK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RS3',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='DTACK',func=pin_types.OUTPUT,unit=1),
            Pin(num='51',name='DS',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='CS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='RS4',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='RS5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='TC',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='SO',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'8237', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'8237'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'8237 DMA', 'description':'', 'datasheet':'https://pdos.csail.mit.edu/6.828/2012/readings/hardware/8237A.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\n8237\n\n8237 DMA', 'pins':[
            Pin(num='1',name='~{IOR}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='HRQ',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='DACK2',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='DACK3',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='DREQ3',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='DREQ2',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='DREQ1',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='DREQ0',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{IOW}',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='DB7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='DB6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='DB5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='DACK1',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='DACK0',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='DB4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='DB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='DB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='DB1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~{MEMR}',func=pin_types.TRISTATE,unit=1),
            Pin(num='30',name='DB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='Vcc',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='A0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='A1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='A3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='~{EOP}',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='A4',func=pin_types.TRISTATE,unit=1),
            Pin(num='38',name='A5',func=pin_types.TRISTATE,unit=1),
            Pin(num='39',name='A6',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='~{MEMW}',func=pin_types.TRISTATE,unit=1),
            Pin(num='40',name='A7',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='PIN5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='READY',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='HLDA',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='ADSTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='AEN',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'8255', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'8255'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'8255 PPI', 'description':'', 'datasheet':'http://aturing.umcs.maine.edu/~meadow/courses/cos335/Intel8255A.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\n8255\n\n8255 PPI', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='~{WR}',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RD}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A0',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'8259', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'8259'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W15.24mm'], 'footprint':'Package_DIP:DIP-28_W15.24mm', 'keywords':'PIC', 'description':'', 'datasheet':'http://pdos.csail.mit.edu/6.828/2005/readings/hardware/8259A.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\n8259\n\nPIC', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='CAS0',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='CAS1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='CAS2',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='~{SP}/~{EN}',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='INT',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='IR0',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='IR1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{WR}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='IR2',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='IR3',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='IR4',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='IR5',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='IR6',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='IR7',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='~{INTA}',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{RD}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='D2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'8288', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'8288'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'Bus Controller', 'description':'', 'datasheet':'http://www.datasheets360.com/pdf/7208679415653955300', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\n8288\n\nBus Controller', 'pins':[
            Pin(num='1',name='IOB',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{IOWC}',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='~{AIOWC}',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='~{IORC}',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='~{INTA}',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='CEN',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='DEN',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='MCE/~{PDEN}',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='~{S2}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{S0}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{S1}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='DT/~{R}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='ALE',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{AEN}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{MRDC}',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='~{AMWC}',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='~{MWTC}',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'82C55A_PLCC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'82C55A_PLCC'}), 'ref_prefix':'U', 'fplist':['Package_LCC:PLCC-44'], 'footprint':'Package_LCC:PLCC-44', 'keywords':'8255 PPI', 'description':'', 'datasheet':'http://jap.hu/electronic/8255.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\n82C55A_PLCC\n\n8255 PPI', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='24',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='35',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='~{WR}',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='~{RD}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='A1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'88SE9125C0-NAA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'88SE9125C0-NAA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-76-1EP_9x9mm_P0.4mm_EP3.8x3.8mm'], 'footprint':'Package_DFN_QFN:QFN-76-1EP_9x9mm_P0.4mm_EP3.8x3.8mm', 'keywords':'PCIe2.0 SATA3.0', 'description':'', 'datasheet':'https://www.marvell.com/documents/bqcwxsoiqfjkcjdjhkvc/', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\n88SE9125C0-NAA\n\nPCIe2.0 SATA3.0', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='GPIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GPIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='GPIO5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='20',name='TESTMODE',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='TP',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RXP_1',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='RXN_1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='VAA2_1',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='TXN_1',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='TXP_1',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='RXP_0',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='30',name='RXN_0',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='VAA2_0',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='TXN_0',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='TXP_0',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='VAA1',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='XTLIN_OSC',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='XTLOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='ISET',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VCONT_10',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='PTXN',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='40',name='PTXP',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='AVDDT',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='PRXN',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='PRXP',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='CLKP',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='CLKN',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='SPI_DO',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='SPI_CS',func=pin_types.OUTPUT,unit=1),
            Pin(num='49',name='SPI_DI',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='SPI_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='~{WAKE}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='53',name='~{PERST}',func=pin_types.INPUT,unit=1),
            Pin(num='54',name='GPIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='56',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='57',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='59',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='60',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='61',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='62',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='63',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='66',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='67',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='68',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='69',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='70',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='71',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='73',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='74',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='GPIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='77',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='VDDIO',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD9833xRM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD9833xRM'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:MSOP-10_3x3mm_P0.5mm', 'keywords':'Direct Digital Synthesizer DDS', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ad9833.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nAD9833xRM\n\nDirect Digital Synthesizer DDS', 'pins':[
            Pin(num='1',name='COMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CAP/2.5V',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SDATA',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{FSYNC}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD9834', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD9834'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'Direct Digital Synthesizer DDS', 'description':'', 'datasheet':'https://www.analog.com/static/imported-files/data_sheets/AD9834.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nAD9834\n\nDirect Digital Synthesizer DDS', 'pins':[
            Pin(num='1',name='FS_ADJUST',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='PSELECT',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SLEEP',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SDATA',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{FSYNC}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='SIGNBITOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='IOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='REFOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='IOUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='COMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='CAP/2.5V',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='FSELECT',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD9850', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD9850'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-28_5.3x10.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'keywords':'DDS direct digital synthesizer', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD9850.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nAD9850\n\nDDS direct digital synthesizer', 'pins':[
            Pin(num='1',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='RSET',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='QOUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='QOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='VINN',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VINP',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='DACBL',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='IOUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='IOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='D7',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='W_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='FQ_UD',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='CLKIN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD9851', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD9851'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-28_5.3x10.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-28_5.3x10.2mm_P0.65mm', 'keywords':'DDS direct digital synthesizer', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD9851.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nAD9851\n\nDDS direct digital synthesizer', 'pins':[
            Pin(num='1',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='RSET',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='VOUTN',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VOUTP',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='VINN',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VINP',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='DACBP',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='IOUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='IOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='D7',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PGND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='W_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='FQ_UD',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='REFCLK',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD9910', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD9910'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100-1EP_14x14mm_P0.5mm_EP5x5mm'], 'footprint':'Package_QFP:TQFP-100-1EP_14x14mm_P0.5mm_EP5x5mm', 'keywords':'dds direct digital synthesizer', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD9910.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nAD9910\n\ndds direct digital synthesizer', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='SYNC_OUT-',func=pin_types.OUTPUT,unit=1),
            Pin(num='100',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='101',name='EP',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DVDD_IO_3V3',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='SYNC_SMP_ERR',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='MASTER_RESET',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='DVDD_IO_3V3',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='DVDD_1V8',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='EXT_PWR_DWN',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='PLL_LOCK',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='PLL_LOOP_FILTER',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='DVDD_IO_3V3',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='DVDD_1V8',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='RAM_SWP_OVR',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='D15',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='D14',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='D13',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='DVDD_IO_3V3',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='AVDD_1V8',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='DVDD_1V8',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='D12',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='D11',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='D10',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='D9',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='D8',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='D7',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PDCLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='TxENABLE',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='DVDD_IO_3V3',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='DVDD_1V8',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='F1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='F0',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='PROFILE2',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='PROFILE1',func=pin_types.INPUT,unit=1),
            Pin(num='54',name='PROFILE0',func=pin_types.INPUT,unit=1),
            Pin(num='55',name='SYNC_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='56',name='DVDD_IO_3V3',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='DVDD_1V8',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='I/O_UPDATE',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AVDD_1V8',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='OSK',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='DROVER',func=pin_types.OUTPUT,unit=1),
            Pin(num='62',name='DRCTL',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='DRHOLD',func=pin_types.INPUT,unit=1),
            Pin(num='64',name='DVDD_1V8',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='DVDD_IO_3V3',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='69',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SYNC_IN+',func=pin_types.INPUT,unit=1),
            Pin(num='70',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='71',name='I/O_RESET',func=pin_types.INPUT,unit=1),
            Pin(num='72',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='73',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='AVDD_3V3',func=pin_types.PWRIN,unit=1),
            Pin(num='75',name='AVDD_3V3',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='AVDD_3V3',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='AVDD_3V3',func=pin_types.PASSIVE,unit=1),
            Pin(num='78',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='SYNC_IN-',func=pin_types.INPUT,unit=1),
            Pin(num='80',name='~{IOUT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='81',name='IOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='82',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='83',name='AVDD_3V3',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='DAC_RSET',func=pin_types.OUTPUT,unit=1),
            Pin(num='85',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='87',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='88',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='89',name='AVDD_1V8',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='SYNC_OUT+',func=pin_types.OUTPUT,unit=1),
            Pin(num='90',name='REF_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='91',name='~{REF_CLK}',func=pin_types.INPUT,unit=1),
            Pin(num='92',name='AVDD_1V8',func=pin_types.PASSIVE,unit=1),
            Pin(num='93',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='94',name='REFCLK_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='95',name='XTAL_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='96',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='97',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='98',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='99',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD9912', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD9912'}), 'ref_prefix':'U', 'fplist':['Package_CSP:LFCSP-64-1EP_9x9mm_P0.5mm_EP5.21x5.21mm'], 'footprint':'Package_CSP:LFCSP-64-1EP_9x9mm_P0.5mm_EP5.21x5.21mm', 'keywords':'Direct Digital Synthesizer DDS', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ad9912.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nAD9912\n\nDirect Digital Synthesizer DDS', 'pins':[
            Pin(num='1',name='DVDD_I/O',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='S2',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='AVDD3',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='SYSCLK',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='SYSCLK_B',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='LOOP_FILTER',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='CLKMODESEL',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='OUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='AVDD3',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='OUT_CMOS',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='AVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='FDBK_INB',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='FDBK_IN',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='AVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='AVDD3',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='AVDD3',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='DAC_RSET',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='AVDD3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='DVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='DAC_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='51',name='DAC_OUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='AVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='54',name='S3',func=pin_types.TRISTATE,unit=1),
            Pin(num='55',name='S4',func=pin_types.TRISTATE,unit=1),
            Pin(num='56',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='PWRDOWN',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='IO_UPDATE',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='~{CSB}',func=pin_types.INPUT,unit=1),
            Pin(num='62',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='63',name='SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='AVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='DVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='S1',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD9951', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD9951'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm'], 'footprint':'Package_QFP:TQFP-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm', 'keywords':'Direct Digital Synthesizer DDS', 'description':'', 'datasheet':'https://www.analog.com/static/imported-files/data_sheets/AD9951.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nAD9951\n\nDirect Digital Synthesizer DDS', 'pins':[
            Pin(num='1',name='I/OUPDATE',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='CRYSTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='CLKMODESELECT',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='LOOP_FILTER',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='~{IOUT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='IOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='DACBP',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='DAC_R_{SET}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='DVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='PWRDWNCTL',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='IOSYNC',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='DVDD_I/O',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='SYNC_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='SYNC_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='OSK',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~{OSC/REFCLK}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='OSC/REFCLK',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AD9954', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD9954'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm'], 'footprint':'Package_QFP:TQFP-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm', 'keywords':'Direct Digital Synthesizer DDS', 'description':'', 'datasheet':'https://www.analog.com/static/imported-files/data_sheets/AD9954.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nAD9954\n\nDirect Digital Synthesizer DDS', 'pins':[
            Pin(num='1',name='I/OUPDATE',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='CRYSTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='CLKMODESELECT',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='LOOP_FILTER',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='~{IOUT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='IOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='DACBP',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='DAC_R_{SET}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='COMP_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='COMP_IN',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='~{COMP_IN}',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='DVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='PWRDWNCTL',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='IOSYNC',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='SDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='SDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='DVDD_I/O',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='SYNC_IN',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='SYNC_CLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='OSK',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='PS0',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='PS1',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~{OSC/REFCLK}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='OSC/REFCLK',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AM26LS31CD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AM26LS31CD'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'driver rs485 rs422 differential', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/am26ls31.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nAM26LS31CD\n\ndriver rs485 rs422 differential', 'pins':[
            Pin(num='1',name='1A',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='3Y',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='3Z',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='~{G}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='4Z',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='4Y',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='4A',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='1Y',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='1Z',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='2Z',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='2Y',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='2A',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='3A',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AM26LV32xD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AM26LV32xD'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'receiver rs485 rs422 differential', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/am26lv32.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nAM26LV32xD\n\nreceiver rs485 rs422 differential', 'pins':[
            Pin(num='1',name='1B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='3A',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='3Y',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='~{G}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='4Y',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='4A',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='4B',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='1A',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='1Y',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='2Y',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='2A',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='2B',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='3B',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AM26LV32xNS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AM26LV32xNS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_5.3x10.2mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_5.3x10.2mm_P1.27mm', 'keywords':'receiver rs485 rs422 differential', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/am26lv32.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nAM26LV32xNS\n\nreceiver rs485 rs422 differential', 'pins':[
            Pin(num='1',name='1B',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='3A',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='3Y',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='~{G}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='4Y',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='4A',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='4B',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='1A',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='1Y',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='2Y',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='2A',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='2B',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='3B',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CDCLVP1102RGT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CDCLVP1102RGT'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-16-1EP_3x3mm_P0.5mm_EP1.6x1.6mm_ThermalVias'], 'footprint':'Package_DFN_QFN:VQFN-16-1EP_3x3mm_P0.5mm_EP1.6x1.6mm_ThermalVias', 'keywords':'Clock Buffer LVDS', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/cdclvp1102.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nCDCLVP1102RGT\n\nClock Buffer LVDS', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN),
            Pin(num='10',name='OUTN0',func=pin_types.OUTPUT),
            Pin(num='11',name='OUTP1',func=pin_types.OUTPUT),
            Pin(num='12',name='OUTN1',func=pin_types.OUTPUT),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT),
            Pin(num='16',name='GND',func=pin_types.PASSIVE),
            Pin(num='17',name='GND',func=pin_types.PASSIVE),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT),
            Pin(num='5',name='VCC',func=pin_types.PWRIN),
            Pin(num='6',name='INP',func=pin_types.INPUT),
            Pin(num='7',name='INN',func=pin_types.INPUT),
            Pin(num='8',name='VAC_REF',func=pin_types.OUTPUT),
            Pin(num='9',name='OUTP0',func=pin_types.OUTPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'CH376T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CH376T'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-20_5.3x7.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'keywords':'USB Mass-Storage SD Card Interface', 'description':'', 'datasheet':'https://www.mpja.com/download/ch376ds1.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nCH376T\n\nUSB Mass-Storage SD Card Interface', 'pins':[
            Pin(num='1',name='~{INT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='XI',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='XO',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{SCS}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='SDO',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='SD_CS',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='SD_DO',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='SD_CK',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='RSTI',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SPI}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='TXD',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SD_DI',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='V3',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='UD+',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='UD-',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DS90C124', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DS90C124'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-48_7x7mm_P0.5mm', 'keywords':'DC-Balanced 24-Bit FPD-Link II Deserializer', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ds90c241.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nDS90C124\n\nDC-Balanced 24-Bit FPD-Link II Deserializer', 'pins':[
            Pin(num='1',name='RPWDNB',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='ROUT18',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='ROUT17',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='ROUT16',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='ROUT15',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='ROUT14',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='ROUT13',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='ROUT12',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='LOCK',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='RCLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='VSSOR2',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RESRVD',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VDDOR2',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='ROUT11',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='ROUT10',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='ROUT9',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='ROUT8',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='ROUT7',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='ROUT6',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='ROUT5',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='ROUT4',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='VSSOR1',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ROUT23',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='VDDOR1',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='ROUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='ROUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='ROUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='ROUT0',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='VSSR0',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='VDDR0',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='VDDR1',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='VSSR1',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='VDDIR',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='ROUT22',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='VSSIR',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='RIN+',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='RIN-',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='RRFB',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='VSSPR1',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VDDPR1',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='VSSPR0',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='VDDPR0',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='REN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='ROUT21',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='ROUT20',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='VDDOR3',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSSOR3',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='ROUT19',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DS90C241', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DS90C241'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-48_7x7mm_P0.5mm', 'keywords':'DC-Balanced 24-Bit FPD-Link II Serializer', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ds90c241.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nDS90C241\n\nDC-Balanced 24-Bit FPD-Link II Serializer', 'pins':[
            Pin(num='1',name='DIN20',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='TCLK',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='TRFB',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VODSEL',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='RESRVD',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VDDPT1',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VSSPT1',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDDPT0',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VSSPT0',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='DEN',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='DOUT-',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='DIN21',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='DOUT+',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='VSSDR',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='VDDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PRE',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='DIN0',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='DIN1',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='DIN2',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='DIN3',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='DIN4',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='DIN22',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='VDDT',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSST',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='DIN5',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='DIN6',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='DIN7',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='DIN8',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='DIN9',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='DIN10',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='DIN11',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='DIN12',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='DIN23',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='DIN13',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='DIN14',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VDDIT',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VSSIT',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='DIN15',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='DIN16',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='DIN17',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='DIN18',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='DIN19',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='DCAOFF',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VSSL',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDDL',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='DCBOFF',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='TPWDNB',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DS90C402', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DS90C402'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Dual LVDS Receiver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ds90c402.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nDS90C402\n\nDual LVDS Receiver', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RO1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='RI1+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='RI1-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='RO2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='RI2+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='RI2-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DS90LV011A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DS90LV011A'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'LVDS Driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ds90lv011a.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nDS90LV011A\n\nLVDS Driver', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='OUT-',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='OUT+',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='IN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DS90LV027A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DS90LV027A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Dual LVDS Driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ds90lv027a.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nDS90LV027A\n\nDual LVDS Driver', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='DI1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='DI2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DO-2',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='DO+2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='DO+1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='DO-1',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FD1771', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FD1771'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'Floppy disk controller', 'description':'', 'datasheet':'https://amaus.net/static/S100/western%20digital/datasheet/Western%20Digital%20FD1771%20Specification%20197710.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nFD1771\n\nFloppy disk controller', 'pins':[
            Pin(num='1',name='VBB',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='DI3',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='DI4',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='DI5',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='DI6',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='DI7',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='~{PH1}/STEP',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='~{PH2}/DIRC',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='PH3',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='~{3PM}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='~{TEST}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='HLT',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='~{XTDS}',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='FDCLK',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='FDDATA',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='TG43',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='WG',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='WD',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='READY',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='~{WF}',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='~{TR00}',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='~{IP}',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='~{WPRT}',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='~{DINT}',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='DRQ',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='INTRQ',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{RE}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='DI0',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='DI1',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='DI2',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FIN1019M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FIN1019M'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'lvds driver receiver', 'description':'', 'datasheet':'http://www.onsemi.com/pub/Collateral/FIN1019-D.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nFIN1019M\n\nlvds driver receiver', 'pins':[
            Pin(num='1',name='DE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RI+',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='DO-',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='DO+',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='DI',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='RO',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='~{RE}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='RI-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FIN1019MTC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FIN1019MTC'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'lvds driver receiver', 'description':'', 'datasheet':'http://www.onsemi.com/pub/Collateral/FIN1019-D.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nFIN1019MTC\n\nlvds driver receiver', 'pins':[
            Pin(num='1',name='DE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RI+',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='DO-',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='DO+',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='DI',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='RO',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='~{RE}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='RI-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HT12D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HT12D'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOP-20_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOP-20_7.5x12.8mm_P1.27mm', 'keywords':'Serial Decoder', 'description':'', 'datasheet':'https://www.holtek.com/documents/10179/116711/2_12dv120.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nHT12D\n\nSerial Decoder', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='D8',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='D9',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='D10',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='D11',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='OSC2',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='OSC1',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VT',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A7',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HT12E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HT12E'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOP-20_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOP-20_7.5x12.8mm_P1.27mm', 'keywords':'Serial Encoder', 'description':'', 'datasheet':'https://www.holtek.com/documents/10179/116711/2_12ev120.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nHT12E\n\nSerial Encoder', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='AD8',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='AD9',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='AD10',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='AD11',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~{TE}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='OSC2',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='OSC1',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A7',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC1518', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC1518'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'receiver rs485 rs422 differential', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/15189fa.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nLTC1518\n\nreceiver rs485 rs422 differential', 'pins':[
            Pin(num='1',name='B1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Out3',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='Out4',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='B4',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Out1',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Out2',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='B2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='B3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC1519', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC1519'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'receiver rs485 rs422 differential', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/15189fa.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nLTC1519\n\nreceiver rs485 rs422 differential', 'pins':[
            Pin(num='1',name='B1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Out1',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='EN12',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Out2',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='B2',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A3',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='Out3',func=pin_types.TRISTATE,unit=2),
            Pin(num='12',name='EN34',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='Out4',func=pin_types.TRISTATE,unit=2),
            Pin(num='14',name='A4',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='B4',func=pin_types.INPUT,unit=2),
            Pin(num='9',name='B3',func=pin_types.INPUT,unit=2),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1', '3', '6', '7', '4', '5']},{'label': 'uB', 'num': 2, 'pin_nums': ['14', '10', '9', '13', '11', '15', '12']},{'label': 'uC', 'num': 3, 'pin_nums': ['16', '8']}] }),
        Part(**{ 'name':'LTC1688', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC1688'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'driver rs485 rs422 differential', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/16889fa.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nLTC1688\n\ndriver rs485 rs422 differential', 'pins':[
            Pin(num='1',name='DI1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='DO3A',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='DO3B',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='DO4B',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DO4A',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='DI4',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='DO1A',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='DO1B',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='DO2B',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='DO2A',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='DI2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='DI3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC1689', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC1689'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'driver rs485 rs422 differential', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/16889fa.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nLTC1689\n\ndriver rs485 rs422 differential', 'pins':[
            Pin(num='1',name='DI1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DO1A',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='DO1B',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='EN12',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='DO2B',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='DO2A',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='DI2',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='DO3A',func=pin_types.OUTPUT,unit=2),
            Pin(num='11',name='DO3B',func=pin_types.OUTPUT,unit=2),
            Pin(num='12',name='EN34',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='DO4B',func=pin_types.OUTPUT,unit=2),
            Pin(num='14',name='DO4A',func=pin_types.OUTPUT,unit=2),
            Pin(num='15',name='DI4',func=pin_types.INPUT,unit=2),
            Pin(num='9',name='DI3',func=pin_types.INPUT,unit=2),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '5', '1', '3', '4', '6', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['11', '13', '15', '12', '10', '9', '14']},{'label': 'uC', 'num': 3, 'pin_nums': ['16', '8']}] }),
        Part(**{ 'name':'LTC6957xDD-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC6957xDD-1'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-12-1EP_3x3mm_P0.45mm_EP1.65x2.38mm'], 'footprint':'Package_DFN_QFN:DFN-12-1EP_3x3mm_P0.45mm_EP1.65x2.38mm', 'keywords':'LTC clock converter', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6957fb.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nLTC6957xDD-1\n\nLTC clock converter', 'pins':[
            Pin(num='1',name='FILTA',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OUT1-',func=pin_types.OPENEMIT,unit=1),
            Pin(num='11',name='OUT1+',func=pin_types.OPENEMIT,unit=1),
            Pin(num='12',name='SD1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SD2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='OUT2+',func=pin_types.OPENEMIT,unit=1),
            Pin(num='9',name='OUT2-',func=pin_types.OPENEMIT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC6957xDD-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC6957xDD-2'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-12-1EP_3x3mm_P0.45mm_EP1.65x2.38mm'], 'footprint':'Package_DFN_QFN:DFN-12-1EP_3x3mm_P0.45mm_EP1.65x2.38mm', 'keywords':'LTC clock converter', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6957fb.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nLTC6957xDD-2\n\nLTC clock converter', 'pins':[
            Pin(num='1',name='FILTA',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OUT1-',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='OUT1+',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='SD1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SD2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='OUT2+',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='OUT2-',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC6957xDD-3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC6957xDD-3'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-12-1EP_3x3mm_P0.45mm_EP1.65x2.38mm'], 'footprint':'Package_DFN_QFN:DFN-12-1EP_3x3mm_P0.45mm_EP1.65x2.38mm', 'keywords':'LTC clock converter', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6957fb.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nLTC6957xDD-3\n\nLTC clock converter', 'pins':[
            Pin(num='1',name='FILTA',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='SD1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SD2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GNDOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='OUT2',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC6957xMS-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC6957xMS-1'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-12_3x4mm_P0.65mm'], 'footprint':'Package_SO:MSOP-12_3x4mm_P0.65mm', 'keywords':'LTC clock converter', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6957fb.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nLTC6957xMS-1\n\nLTC clock converter', 'pins':[
            Pin(num='1',name='FILTA',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OUT1-',func=pin_types.OPENEMIT,unit=1),
            Pin(num='11',name='OUT1+',func=pin_types.OPENEMIT,unit=1),
            Pin(num='12',name='SD1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SD2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='OUT2+',func=pin_types.OPENEMIT,unit=1),
            Pin(num='9',name='OUT2-',func=pin_types.OPENEMIT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC6957xMS-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC6957xMS-2'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-12_3x4mm_P0.65mm'], 'footprint':'Package_SO:MSOP-12_3x4mm_P0.65mm', 'keywords':'LTC clock converter', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6957fb.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nLTC6957xMS-2\n\nLTC clock converter', 'pins':[
            Pin(num='1',name='FILTA',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OUT1-',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='OUT1+',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='SD1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SD2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='OUT2+',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='OUT2-',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC6957xMS-3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC6957xMS-3'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-12_3x4mm_P0.65mm'], 'footprint':'Package_SO:MSOP-12_3x4mm_P0.65mm', 'keywords':'LTC clock converter', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6957fb.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nLTC6957xMS-3\n\nLTC clock converter', 'pins':[
            Pin(num='1',name='FILTA',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='SD1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SD2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GNDOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='OUT2',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX6816', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX6816'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-143'], 'footprint':'Package_TO_SOT_SMD:SOT-143', 'keywords':'Switch Debouncer', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/1896.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nMAX6816\n\nSwitch Debouncer', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC100EPT22D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC100EPT22D'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'PECL buffer interface', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MC100EPT22-D.PDF', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nMC100EPT22D\n\nPECL buffer interface', 'pins':[
            Pin(num='1',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{Q0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{Q1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC100EPT22DT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC100EPT22DT'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-8_3x3mm_P0.65mm', 'keywords':'PECL buffer interface', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MC100EPT22-D.PDF', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nMC100EPT22DT\n\nPECL buffer interface', 'pins':[
            Pin(num='1',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{Q0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{Q1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC6840', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC6840'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W15.24mm'], 'footprint':'Package_DIP:DIP-28_W15.24mm', 'keywords':'PTM MC6800', 'description':'', 'datasheet':'http://pdf.datasheetcatalog.com/datasheet/motorola/MC6840.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nMC6840\n\nPTM MC6800', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RS0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='RS1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='RS2',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='R/~{W}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='~{CS0}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='CS1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='E',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='D7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{G2}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='~{G1}',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='O1',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='~{C1}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='O2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{C2}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{G3}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='O3',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{C3}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{IRQ}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC6843', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC6843'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'FDC', 'description':'', 'datasheet':'http://www.datasheetarchive.com/pdf/download.php?id=355f4f5379c550317997643252fd5cac1bb08e&type=M&query=MC6843P', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nMC6843\n\nFDC', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='LCT',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='IDX',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='RDY',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VFOC',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='STP',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='HLD',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='RS2',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='RS1',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='RS0',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='TxAck',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='R/~{W}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='E',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='BD',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='FIR',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='35',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='TxRQ',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='~{IRQ}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='38',name='RDT',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='WDT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='FI',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='TRZ',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='WPT',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='WGT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='HDR',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='DCK',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC6844', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC6844'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'Direct Memory Access Controller', 'description':'', 'datasheet':'http://pdf.datasheetcatalog.com/datasheets/560/501527_DS.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nMC6844\n\nDirect Memory Access Controller', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='A6',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='A7',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='A8',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='A9',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='A10',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='A11',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='A12',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='A13',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='A14',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='A15',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{CS}/Tx_AKB',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='Tx_RQ3',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='R/~{W}',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='Tx_RQ2',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='Tx_RQ1',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='Tx_RQ0',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='~{IRQ}/~{DEND}',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='~{Tx_STB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='Tx_AKA',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='~{DRQ2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='~{DRQ1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='DGRNT',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='E',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='A3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='A4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='A5',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NB3N551MN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NB3N551MN'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.9x1.3mm'], 'footprint':'Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.9x1.3mm', 'keywords':'clock buffer', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/NB3N551-D.PDF', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nNB3N551MN\n\nclock buffer', 'pins':[
            Pin(num='1',name='ICLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Q2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Q3',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='Q4',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='EP',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ONET1191PRGT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ONET1191PRGT'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-16-1EP_3x3mm_P0.5mm_EP1.68x1.68mm'], 'footprint':'Package_DFN_QFN:VQFN-16-1EP_3x3mm_P0.5mm_EP1.68x1.68mm', 'keywords':'limiting amplifier gigabit ethernet sfp sfp+', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/onet1191p.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nONET1191PRGT\n\nlimiting amplifier gigabit ethernet sfp sfp+', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='LOS',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='DISABLE',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VAR',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='DOUT-',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='DOUT+',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='COC-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='COC+',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='DIN+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='DIN-',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='TH',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9306', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9306'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Dual bidirectional I2C Bus and SMBus voltage level translator', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/pca9306.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nPCA9306\n\nDual bidirectional I2C Bus and SMBus voltage level translator', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VREF1',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='SCL1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SDA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SDA2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCL2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VREF2',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='EN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9600D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9600D'}), 'ref_prefix':'U', 'fplist':['Package_SO:SO-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SO-8_3.9x4.9mm_P1.27mm', 'keywords':'I2C buffer', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/PCA9600.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nPCA9600D\n\nI2C buffer', 'pins':[
            Pin(num='1',name='SX',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RX',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='TX',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TY',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='RY',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SY',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9600DP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9600DP'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-8_3x3mm_P0.65mm', 'keywords':'I2C buffer', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/PCA9600.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nPCA9600DP\n\nI2C buffer', 'pins':[
            Pin(num='1',name='SX',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='RX',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='TX',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TY',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='RY',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SY',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9615DP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9615DP'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:TSSOP-10_3x3mm_P0.5mm', 'keywords':'Differential SMBus/I2C buffer', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/PCA9615.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nPCA9615DP\n\nDifferential SMBus/I2C buffer', 'pins':[
            Pin(num='1',name='V_{DD(A)}',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='V_{DD(B)}',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='DSCLM',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='DSCLP',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DSDAP',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='DSDAM',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCI9030-PQFP176', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCI9030-PQFP176'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-176_24x24mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-176_24x24mm_P0.5mm', 'keywords':'PCI', 'description':'', 'datasheet':'http://lhcb-online.web.cern.ch/lhcb-online/ecs/ccpc/docs/plc-9030-databook.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nPCI9030-PQFP176\n\nPCI', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='AD22',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='101',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='102',name='LD1',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='LPMESET',func=pin_types.INPUT,unit=1),
            Pin(num='104',name='LD0',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='LA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='106',name='LA3',func=pin_types.OUTPUT,unit=1),
            Pin(num='107',name='LA4',func=pin_types.OUTPUT,unit=1),
            Pin(num='108',name='LA5',func=pin_types.OUTPUT,unit=1),
            Pin(num='109',name='LA6',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='AD21',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='LA7',func=pin_types.OUTPUT,unit=1),
            Pin(num='111',name='LA8',func=pin_types.OUTPUT,unit=1),
            Pin(num='112',name='BD-SEL#/TST',func=pin_types.INPUT,unit=1),
            Pin(num='113',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='114',name='LA9',func=pin_types.OUTPUT,unit=1),
            Pin(num='115',name='LA10',func=pin_types.INPUT,unit=1),
            Pin(num='116',name='LA11',func=pin_types.OUTPUT,unit=1),
            Pin(num='117',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='118',name='LA12',func=pin_types.OUTPUT,unit=1),
            Pin(num='119',name='LA13',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='AD20',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='LA14',func=pin_types.OUTPUT,unit=1),
            Pin(num='121',name='LA15',func=pin_types.OUTPUT,unit=1),
            Pin(num='122',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='123',name='LA16',func=pin_types.OUTPUT,unit=1),
            Pin(num='124',name='LA17',func=pin_types.OUTPUT,unit=1),
            Pin(num='125',name='LA18',func=pin_types.OUTPUT,unit=1),
            Pin(num='126',name='LPMINT#',func=pin_types.OUTPUT,unit=1),
            Pin(num='127',name='LA19',func=pin_types.OUTPUT,unit=1),
            Pin(num='128',name='LA20',func=pin_types.OUTPUT,unit=1),
            Pin(num='129',name='LA21',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='130',name='LA22',func=pin_types.OUTPUT,unit=1),
            Pin(num='131',name='LA23',func=pin_types.OUTPUT,unit=1),
            Pin(num='132',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='133',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='134',name='GPIO7/LA24',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='GPIO6/LA25',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='GPIO5/LA26',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='GPIO4/LA27',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='ADS#',func=pin_types.OUTPUT,unit=1),
            Pin(num='139',name='BLAST#',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='140',name='WR#',func=pin_types.OUTPUT,unit=1),
            Pin(num='141',name='RD#',func=pin_types.OUTPUT,unit=1),
            Pin(num='142',name='LW/R#',func=pin_types.OUTPUT,unit=1),
            Pin(num='143',name='READY#',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='BTERM#',func=pin_types.INPUT,unit=1),
            Pin(num='145',name='LCLK',func=pin_types.INPUT,unit=1),
            Pin(num='146',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='147',name='CS0#',func=pin_types.OUTPUT,unit=1),
            Pin(num='148',name='CS1#',func=pin_types.OUTPUT,unit=1),
            Pin(num='149',name='LRESETo#',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='AD19',func=pin_types.BIDIR,unit=1),
            Pin(num='150',name='LGNT',func=pin_types.OUTPUT,unit=1),
            Pin(num='151',name='LREQ',func=pin_types.INPUT,unit=1),
            Pin(num='152',name='LINTi1',func=pin_types.INPUT,unit=1),
            Pin(num='153',name='LINTi2',func=pin_types.INPUT,unit=1),
            Pin(num='154',name='GPIO0/WAITo#',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='GPIO1/LLOCKo#',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='GPIO2/CS2#',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='GPIO3/CS3#',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='EECS',func=pin_types.OUTPUT,unit=1),
            Pin(num='159',name='EEDO',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='AD18',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='EESK',func=pin_types.OUTPUT,unit=1),
            Pin(num='161',name='EEDI',func=pin_types.OUTPUT,unit=1),
            Pin(num='162',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='163',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='164',name='TRST#',func=pin_types.INPUT,unit=1),
            Pin(num='165',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='166',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='167',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='168',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='169',name='PME#',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='AD17',func=pin_types.BIDIR,unit=1),
            Pin(num='170',name='INTA#',func=pin_types.OUTPUT,unit=1),
            Pin(num='171',name='RST#',func=pin_types.INPUT,unit=1),
            Pin(num='172',name='PCLK',func=pin_types.INPUT,unit=1),
            Pin(num='173',name='AD31',func=pin_types.BIDIR,unit=1),
            Pin(num='174',name='AD30',func=pin_types.BIDIR,unit=1),
            Pin(num='175',name='AD29',func=pin_types.BIDIR,unit=1),
            Pin(num='176',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='AD16',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='C/BE2#',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='AD28',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='FRAME#',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='IRDY#',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TRDY#',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='DEVSEL#',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='STOP#',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='LOCK#',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PERR#',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='SERR#',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='PAR',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='C/BE1#',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='AD27',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AD15',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='AD14',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='AD13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='AD12',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='AD11',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='AD10',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='AD9',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='AD8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='AD26',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='C/BE0#',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='AD7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='AD6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='AD5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='AD4',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='AD3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='AD2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='AD1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AD25',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='AD0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='ENUM#',func=pin_types.OUTPUT,unit=1),
            Pin(num='52',name='LEDON#',func=pin_types.OUTPUT,unit=1),
            Pin(num='53',name='VI/O',func=pin_types.PWRIN,unit=1),
            Pin(num='54',name='CPCISW',func=pin_types.INPUT,unit=1),
            Pin(num='55',name='LBE3#',func=pin_types.OUTPUT,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='LBE2#',func=pin_types.OUTPUT,unit=1),
            Pin(num='59',name='LBE1#',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='AD24',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='LBE0#',func=pin_types.OUTPUT,unit=1),
            Pin(num='61',name='LD31',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='LD30',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='LD29',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='LD28',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='LD27',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='67',name='LD26',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='LD25',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='LD24',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='C/BE3#',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='71',name='BCLKo',func=pin_types.OUTPUT,unit=1),
            Pin(num='72',name='LD23',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='LD22',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='LD21',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='ALE',func=pin_types.OUTPUT,unit=1),
            Pin(num='76',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='77',name='LD20',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='79',name='LD19',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='IDSEL',func=pin_types.INPUT,unit=1),
            Pin(num='80',name='LD18',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='LD17',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='LD16',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='LD15',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='LD14',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='86',name='LD13',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='LD12',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='89',name='LD11',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='AD23',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='LD10',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='LD9',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='LD8',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='LD7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='GPIO8',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='LD6',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='LD5',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='LD4',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='LD3',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='LD2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'S5933_PQ160', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'S5933_PQ160'}), 'ref_prefix':'U', 'fplist':['Package_QFP:PQFP-160_28x28mm_P0.65mm'], 'footprint':'Package_QFP:PQFP-160_28x28mm_P0.65mm', 'keywords':'PCI 2.1 Compliant Master/Slave Device', 'description':'', 'datasheet':'http://datasheet.datasheetarchive.com/originals/distributors/Datasheets-35/DSA-684194.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nS5933_PQ160\n\nPCI 2.1 Compliant Master/Slave Device', 'pins':[
            Pin(num='10',name='VSS',func=pin_types.PWRIN),
            Pin(num='110',name='VSS',func=pin_types.PWRIN),
            Pin(num='111',name='VCC',func=pin_types.PWRIN),
            Pin(num='130',name='VSS',func=pin_types.PWRIN),
            Pin(num='131',name='VCC',func=pin_types.PWRIN),
            Pin(num='150',name='VSS',func=pin_types.PWRIN),
            Pin(num='151',name='VCC',func=pin_types.PWRIN),
            Pin(num='30',name='VSS',func=pin_types.PWRIN),
            Pin(num='31',name='VCC',func=pin_types.PWRIN),
            Pin(num='50',name='VSS',func=pin_types.PWRIN),
            Pin(num='51',name='VCC',func=pin_types.PWRIN),
            Pin(num='70',name='VSS',func=pin_types.PWRIN),
            Pin(num='71',name='VCC',func=pin_types.PWRIN),
            Pin(num='90',name='VSS',func=pin_types.PWRIN),
            Pin(num='91',name='VCC',func=pin_types.PWRIN),
            Pin(num='11',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='1',name='EQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='EA7',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='WRFIFO#',func=pin_types.INPUT,unit=1),
            Pin(num='103',name='WRFULL',func=pin_types.OUTPUT,unit=1),
            Pin(num='104',name='RDFIFO#',func=pin_types.INPUT,unit=1),
            Pin(num='105',name='DQ21',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='RDEMPTY',func=pin_types.OUTPUT,unit=1),
            Pin(num='107',name='PTADR#',func=pin_types.INPUT,unit=1),
            Pin(num='108',name='PTWR',func=pin_types.OUTPUT,unit=1),
            Pin(num='109',name='EA8',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PTBURST#',func=pin_types.OUTPUT,unit=1),
            Pin(num='113',name='EA9',func=pin_types.OUTPUT,unit=1),
            Pin(num='114',name='PTATN#',func=pin_types.OUTPUT,unit=1),
            Pin(num='115',name='PTRDY#',func=pin_types.INPUT,unit=1),
            Pin(num='116',name='PTBE0#',func=pin_types.OUTPUT,unit=1),
            Pin(num='117',name='DQ20',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PTBE1#',func=pin_types.OUTPUT,unit=1),
            Pin(num='119',name='PTBE2#',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='AD17',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='PTBE3#',func=pin_types.OUTPUT,unit=1),
            Pin(num='121',name='EA10',func=pin_types.OUTPUT,unit=1),
            Pin(num='122',name='PTNUM1',func=pin_types.OUTPUT,unit=1),
            Pin(num='123',name='PTNUM0',func=pin_types.OUTPUT,unit=1),
            Pin(num='124',name='IRQ#',func=pin_types.OUTPUT,unit=1),
            Pin(num='125',name='DQ19',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='SYSRST#',func=pin_types.OUTPUT,unit=1),
            Pin(num='127',name='EWR#/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='ERD#/SCL',func=pin_types.OUTPUT,unit=1),
            Pin(num='129',name='EA11',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='DQ30',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='ADR6',func=pin_types.INPUT,unit=1),
            Pin(num='133',name='DQ18',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='SNV',func=pin_types.INPUT,unit=1),
            Pin(num='137',name='EA12',func=pin_types.OUTPUT,unit=1),
            Pin(num='138',name='FLT#',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='RST#',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='AD16',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='BPCLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='141',name='EA13',func=pin_types.OUTPUT,unit=1),
            Pin(num='142',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='143',name='GNT#',func=pin_types.INPUT,unit=1),
            Pin(num='144',name='REQ#',func=pin_types.OUTPUT,unit=1),
            Pin(num='145',name='DQ17',func=pin_types.BIDIR,unit=1),
            Pin(num='146',name='AD31',func=pin_types.BIDIR,unit=1),
            Pin(num='147',name='AD30',func=pin_types.BIDIR,unit=1),
            Pin(num='148',name='AD29',func=pin_types.BIDIR,unit=1),
            Pin(num='149',name='EA14/FWE',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='C/BE2#',func=pin_types.BIDIR,unit=1),
            Pin(num='152',name='AD28',func=pin_types.BIDIR,unit=1),
            Pin(num='153',name='EA15/FRF',func=pin_types.BIDIR,unit=1),
            Pin(num='154',name='AD27',func=pin_types.BIDIR,unit=1),
            Pin(num='155',name='AD26',func=pin_types.BIDIR,unit=1),
            Pin(num='156',name='AD25',func=pin_types.BIDIR,unit=1),
            Pin(num='157',name='DQ16',func=pin_types.BIDIR,unit=1),
            Pin(num='158',name='AD24',func=pin_types.BIDIR,unit=1),
            Pin(num='159',name='C/BE3#',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='FRAME#',func=pin_types.BIDIR,unit=1),
            Pin(num='160',name='IDSEL',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='EQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='IRDY#',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TRDY#',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='AD23',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DEVSEL#',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='EQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='STOP#',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='LOCK#',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='PERR#',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='DQ29',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='SERR#',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='PAR',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='C/BE1#',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='EQ4/FWC#',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='AD22',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='AD15',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='EQ5/FRC#',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='AD14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='AD13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='AD12',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='DQ28',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='AD11',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='AD10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='AD21',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='AD9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='EQ6/AMREN',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='AD8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='C/BE0#',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='AD7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='DQ27',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='AD6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='AD5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='AD4',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='EQ7/AMWEN',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='DQ31',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='AD3',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='DQ26',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='AD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='AD1',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='AD0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='EA0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='INTA#',func=pin_types.OUTPUT,unit=1),
            Pin(num='59',name='MODE_16/32',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AD20',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BE3#',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='EA1',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='BE2#',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='BE1#',func=pin_types.INPUT,unit=1),
            Pin(num='64',name='ADR5',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='DQ25',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='ADR4',func=pin_types.INPUT,unit=1),
            Pin(num='67',name='ADR3',func=pin_types.INPUT,unit=1),
            Pin(num='68',name='ADR2',func=pin_types.INPUT,unit=1),
            Pin(num='69',name='EA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AD19',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='RD#',func=pin_types.INPUT,unit=1),
            Pin(num='73',name='EA3',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='WR#',func=pin_types.INPUT,unit=1),
            Pin(num='75',name='SELECT#',func=pin_types.INPUT,unit=1),
            Pin(num='76',name='DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='DQ24',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='AD18',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='EA4',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='DQ23',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='BE0#',func=pin_types.INPUT,unit=1),
            Pin(num='88',name='DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='EA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='EQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='DQ22',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='EA6',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='DQ1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SI9986', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SI9986'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'integrated, buffered H-bridge', 'description':'', 'datasheet':'http://www.vishay.com/docs/70007/si9986.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nSI9986\n\nintegrated, buffered H-bridge', 'pins':[
            Pin(num='1',name='SA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PWR',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='SB',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OUTB',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='INB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='INA',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='OUTA',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN65LVDS047D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN65LVDS047D'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'Quad LVDS Driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn65lvds047.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nSN65LVDS047D\n\nQuad LVDS Driver', 'pins':[
            Pin(num='1',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='DOUT4+',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='DOUT3+',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='DOUT3-',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='DOUT2-',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DOUT2+',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='DOUT1+',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='DOUT1-',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='DIN1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='DIN2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='DIN3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='DIN4',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='DOUT4-',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN65LVDS047PW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN65LVDS047PW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'Quad LVDS Driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn65lvds047.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nSN65LVDS047PW\n\nQuad LVDS Driver', 'pins':[
            Pin(num='1',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='DOUT4+',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='DOUT3+',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='DOUT3-',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='DOUT2-',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DOUT2+',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='DOUT1+',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='DOUT1-',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='DIN1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='DIN2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='DIN3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='DIN4',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='DOUT4-',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN65LVDS1D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN65LVDS1D'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'LVDS Driver TI', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn65lvds1.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nSN65LVDS1D\n\nLVDS Driver TI', 'pins':[
            Pin(num='1',name='V_{CC}',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='Z',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN65LVDS1DBV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN65LVDS1DBV'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'LVDS Driver TI', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn65lvds1.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nSN65LVDS1DBV\n\nLVDS Driver TI', 'pins':[
            Pin(num='1',name='V_{CC}',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Z',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='D',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN65LVDS2D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN65LVDS2D'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'LVDS Receiver TI', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn65lvds2.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nSN65LVDS2D\n\nLVDS Receiver TI', 'pins':[
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='V_{CC}',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN65LVDS2DBV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN65LVDS2DBV'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'LVDS Receiver TI', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn65lvds2.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nSN65LVDS2DBV\n\nLVDS Receiver TI', 'pins':[
            Pin(num='1',name='V_{CC}',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='R',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN65LVDT2D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN65LVDT2D'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'LVDS Receiver TI', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn65lvdt2.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nSN65LVDT2D\n\nLVDS Receiver TI', 'pins':[
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='V_{CC}',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN65LVDT2DBV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN65LVDT2DBV'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'LVDS Receiver TI', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn65lvdt2.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nSN65LVDT2DBV\n\nLVDS Receiver TI', 'pins':[
            Pin(num='1',name='V_{CC}',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='R',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74LV8153N', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74LV8153N'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'serial to parallel', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74lv8153.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nSN74LV8153N\n\nserial to parallel', 'pins':[
            Pin(num='1',name='V_{CC1}',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Y7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='Y6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='Y5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='Y4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='Y3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='Y2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='Y1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='19',name='Y0',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='V_{CC2}',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTSEL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='SOUT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN75160BDW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN75160BDW'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'gpib bidirectional bus transceiver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn75160b.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nSN75160BDW\n\ngpib bidirectional bus transceiver', 'pins':[
            Pin(num='1',name='TE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{PE}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='D8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='B1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='B2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='B3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='B4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='B5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='B6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='B7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='B8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN75160BN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN75160BN'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'gpib bidirectional bus transceiver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn75160b.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nSN75160BN\n\ngpib bidirectional bus transceiver', 'pins':[
            Pin(num='1',name='TE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='~{PE}',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='D8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='B1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='B2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='B3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='B4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='B5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='B6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='B7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='B8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TB5D1MD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TB5D1MD'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'differential PECL driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tb5d2h.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nTB5D1MD\n\ndifferential PECL driver', 'pins':[
            Pin(num='1',name='AI',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CO',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~{CO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='E2',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{DO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DO',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='DI',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AO',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{AO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='E1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{BO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='BO',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='BI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='CI',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TB5D1MDW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TB5D1MDW'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'differential PECL driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tb5d2h.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nTB5D1MDW\n\ndifferential PECL driver', 'pins':[
            Pin(num='1',name='AI',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CO',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~{CO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='E2',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{DO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DO',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='DI',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AO',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{AO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='E1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{BO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='BO',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='BI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='CI',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TB5R1D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TB5R1D'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'differential PECL reciver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tb5r1.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nTB5R1D\n\ndifferential PECL reciver', 'pins':[
            Pin(num='1',name='~{AI}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CI',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CO',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='~{E2}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='DO',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DI',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{DI}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AI',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='AO',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='E1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='BO',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='BI',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{BI}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{CI}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TB5R1DW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TB5R1DW'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'differential PECL reciver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tb5r1.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nTB5R1DW\n\ndifferential PECL reciver', 'pins':[
            Pin(num='1',name='~{AI}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CI',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CO',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='~{E2}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='DO',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DI',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{DI}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AI',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='AO',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='E1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='BO',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='BI',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{BI}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{CI}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCA9406DC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCA9406DC'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Bidirectional 1-MHz I2C SMBus Voltage-Level Translator 8kV HBM ESD', 'description':'', 'datasheet':'www.ti.com/lit/ds/symlink/tca9406.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nTCA9406DC\n\nBidirectional 1-MHz I2C SMBus Voltage-Level Translator 8kV HBM ESD', 'pins':[
            Pin(num='1',name='SDA_B',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='SDA_A',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SCL_A',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='OE',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VCCB',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='SCL_B',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCA9800', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCA9800'}), 'ref_prefix':'U', 'fplist':['Package_SO:VSSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:VSSOP-8_3x3mm_P0.65mm', 'keywords':'I2C buffer repeater', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tca9800.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nTCA9800\n\nI2C buffer repeater', 'pins':[
            Pin(num='1',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SCLA',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='SDAA',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SDAB',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SCLB',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCCB',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'U2270B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'U2270B'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'IDIC read/write base stations in contactless identification and immobilizer systems', 'description':'', 'datasheet':'http://www.farnell.com/datasheets/94393.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nU2270B\n\nIDIC read/write base stations in contactless identification and immobilizer systems', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VEXT',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DVS',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VBATT',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='STANDBY',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='RF',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='HIPASS',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='OUTPUT',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='INPUT',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='MS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='CFE',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='COIL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='COIL1',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'WD2791', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'WD2791'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'Floppy disk controller', 'description':'', 'datasheet':'http://pdf.datasheetcatalog.com/datasheets2/12/1229802_1.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nWD2791\n\nFloppy disk controller', 'pins':[
            Pin(num='1',name='ENP',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{DAL3}',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='~{DAL4}',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='~{DAL5}',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='~{DAL6}',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='~{DAL7}',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='STEP',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='DIRC',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='~{5}/8',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='RPW',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='~{TEST}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PUMP',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='~{ENMF}',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='VCO',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='~{RAW_READ}',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='HLD',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='TG43',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='WG',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='WD',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='READY',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='WPW',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='~{TR00}',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='~{IP}',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='~{WPRT}',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='~{DDEN}',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='DRQ',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='INTRQ',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{RE}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='HLT',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{DAL0}',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='~{DAL1}',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='~{DAL2}',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'WD2793', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'WD2793'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'Floppy disk controller', 'description':'', 'datasheet':'http://pdf.datasheetcatalog.com/datasheets2/12/1229802_1.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nWD2793\n\nFloppy disk controller', 'pins':[
            Pin(num='1',name='ENP',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='DAL3',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='DAL4',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='DAL5',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='DAL6',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='DAL7',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='STEP',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='DIRC',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='~{5}/8',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='RPW',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='~{TEST}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PUMP',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='~{ENMF}',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='VCO',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='~{RAW_READ}',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='HLD',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='TG43',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='WG',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='WD',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='READY',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='WPW',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='~{TR00}',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='~{IP}',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='~{WPRT}',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='~{DDEN}',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='DRQ',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='INTRQ',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{RE}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='HLT',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='DAL0',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='DAL1',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='DAL2',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'WD2795', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'WD2795'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'Floppy disk controller', 'description':'', 'datasheet':'http://pdf.datasheetcatalog.com/datasheets2/12/1229802_1.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nWD2795\n\nFloppy disk controller', 'pins':[
            Pin(num='1',name='ENP',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{DAL3}',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='~{DAL4}',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='~{DAL5}',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='~{DAL6}',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='~{DAL7}',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='STEP',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='DIRC',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='~{5}/8',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='RPW',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='~{TEST}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PUMP',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='SSO',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='VCO',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='~{RAW_READ}',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='HLD',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='TG43',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='WG',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='WD',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='READY',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='WPW',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='~{TR00}',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='~{IP}',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='~{WPRT}',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='~{DDEN}',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='DRQ',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='INTRQ',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{RE}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='HLT',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{DAL0}',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='~{DAL1}',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='~{DAL2}',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'WD2797', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'WD2797'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'Floppy disk controller', 'description':'', 'datasheet':'http://pdf.datasheetcatalog.com/datasheets2/12/1229802_1.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nWD2797\n\nFloppy disk controller', 'pins':[
            Pin(num='1',name='ENP',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='DAL3',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='DAL4',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='DAL5',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='DAL6',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='DAL7',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='STEP',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='DIRC',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='~{5}/8',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='RPW',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{MR}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='~{TEST}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PUMP',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='SSO',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='VCO',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='~{RAW_READ}',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='HLD',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='TG43',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='WG',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='WD',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='READY',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='WPW',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='~{TR00}',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='~{IP}',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='~{WPRT}',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='~{DDEN}',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='DRQ',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='INTRQ',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{RE}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='HLT',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='DAL0',func=pin_types.TRISTATE,unit=1),
            Pin(num='8',name='DAL1',func=pin_types.TRISTATE,unit=1),
            Pin(num='9',name='DAL2',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Z8420', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Z8420'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'Z80 PIO parallel', 'description':'', 'datasheet':'https://www.zilog.com/appnotes_download.php?FromPage=DirectLink&dn=PS0180&ft=Product%20Specification%20(Data%20Sheet)%20%20&f=YUhSMGNEb3ZMM2QzZHk1NmFXeHZaeTVqYjIwdlpHOWpjeTk2T0RBdmNITXdNVGd3TG5Ca1pnPT0=', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nZ8420\n\nZ80 PIO parallel', 'pins':[
            Pin(num='1',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{ASTB}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{BSTB}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='ARDY',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='BRDY',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='IEO',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='24',name='IEI',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='~{RD}',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='~{IORQ}',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='~{M1}',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='C/~{D}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='B/~{A}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'6822', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'6822'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'PIA', 'description':'', 'datasheet':'http://pdf1.alldatasheet.com/datasheet-pdf/view/135452/MOTOROLA/MC6822.html', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\n6822\n\nPIA', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='CB1',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='R/~{W}',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='CS0',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{CS2}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='CS1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='ENABLE',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='RS1',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='RS0',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='~{IRQB}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='38',name='~{IRQA}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='39',name='CA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='CA1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'8255A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'8255A'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'8255 PPI', 'description':'', 'datasheet':'http://aturing.umcs.maine.edu/~meadow/courses/cos335/Intel8255A.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\n8255A\n\n8255 PPI', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='~{WR}',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RD}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A0',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'8259A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'8259A'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W15.24mm', 'Package_DIP:DIP-28_W15.24mm'], 'footprint':'Package_DIP:DIP-28_W15.24mm', 'keywords':'PIC', 'description':'', 'datasheet':'http://pdos.csail.mit.edu/6.828/2005/readings/hardware/8259A.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\n8259A\n\nPIC', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='CAS0',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='CAS1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='CAS2',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='~{SP}/~{EN}',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='INT',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='IR0',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='IR1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{WR}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='IR2',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='IR3',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='IR4',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='IR5',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='IR6',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='IR7',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='~{INTA}',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{RD}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='D2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'8259A-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'8259A-2'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W15.24mm', 'Package_DIP:DIP-28_W15.24mm', 'Package_DIP:DIP-28_W15.24mm'], 'footprint':'Package_DIP:DIP-28_W15.24mm', 'keywords':'PIC', 'description':'', 'datasheet':'http://pdos.csail.mit.edu/6.828/2005/readings/hardware/8259A.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\n8259A-2\n\nPIC', 'pins':[
            Pin(num='1',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='CAS0',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='CAS1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='CAS2',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='~{SP}/~{EN}',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='INT',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='IR0',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='IR1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{WR}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='IR2',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='IR3',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='IR4',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='IR5',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='IR6',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='IR7',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='~{INTA}',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{RD}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='D2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'82C55A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'82C55A'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'8255 PPI', 'description':'', 'datasheet':'http://jap.hu/electronic/8255.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\n82C55A\n\n8255 PPI', 'pins':[
            Pin(num='1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='~{WR}',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RD}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A0',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AM26LS31CDB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AM26LS31CDB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'Package_SO:SSOP-16_5.3x6.2mm_P0.65mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'driver rs485 rs422 differential', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/am26ls31.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nAM26LS31CDB\n\ndriver rs485 rs422 differential', 'pins':[
            Pin(num='1',name='1A',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='3Y',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='3Z',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='~{G}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='4Z',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='4Y',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='4A',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='1Y',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='1Z',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='2Z',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='2Y',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='2A',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='3A',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AM26LS31CN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AM26LS31CN'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'Package_SO:SSOP-16_5.3x6.2mm_P0.65mm', 'Package_DIP:DIP-16_W7.62mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'driver rs485 rs422 differential', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/am26ls31.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nAM26LS31CN\n\ndriver rs485 rs422 differential', 'pins':[
            Pin(num='1',name='1A',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='3Y',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='3Z',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='~{G}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='4Z',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='4Y',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='4A',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='1Y',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='1Z',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='2Z',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='2Y',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='2A',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='3A',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AM26LS31MJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AM26LS31MJ'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'Package_SO:SSOP-16_5.3x6.2mm_P0.65mm', 'Package_DIP:DIP-16_W7.62mm', 'Package_DIP:DIP-16_W7.62mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'driver rs485 rs422 differential', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/am26ls31.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nAM26LS31MJ\n\ndriver rs485 rs422 differential', 'pins':[
            Pin(num='1',name='1A',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='3Y',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='3Z',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='~{G}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='4Z',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='4Y',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='4A',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='1Y',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='1Z',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='2Z',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='2Y',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='2A',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='3A',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AM26LS31xNS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AM26LS31xNS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'Package_SO:SSOP-16_5.3x6.2mm_P0.65mm', 'Package_DIP:DIP-16_W7.62mm', 'Package_DIP:DIP-16_W7.62mm', 'Package_SO:SO-16_5.3x10.2mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'driver rs485 rs422 differential', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/am26ls31.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nAM26LS31xNS\n\ndriver rs485 rs422 differential', 'pins':[
            Pin(num='1',name='1A',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='3Y',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='3Z',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='~{G}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='4Z',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='4Y',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='4A',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='1Y',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='1Z',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='2Z',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='2Y',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='2A',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='3A',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC6957xDD-4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC6957xDD-4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-12-1EP_3x3mm_P0.45mm_EP1.65x2.38mm', 'Package_DFN_QFN:DFN-12-1EP_3x3mm_P0.45mm_EP1.65x2.38mm'], 'footprint':'Package_DFN_QFN:DFN-12-1EP_3x3mm_P0.45mm_EP1.65x2.38mm', 'keywords':'LTC clock converter', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6957fb.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nLTC6957xDD-4\n\nLTC clock converter', 'pins':[
            Pin(num='1',name='FILTA',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='SD1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SD2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GNDOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='OUT2',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC6957xMS-4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC6957xMS-4'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-12_3x4mm_P0.65mm', 'Package_SO:MSOP-12_3x4mm_P0.65mm'], 'footprint':'Package_SO:MSOP-12_3x4mm_P0.65mm', 'keywords':'LTC clock converter', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6957fb.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nLTC6957xMS-4\n\nLTC clock converter', 'pins':[
            Pin(num='1',name='FILTA',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='SD1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='FILTB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SD2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GNDOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='OUT2',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC100LVELT22D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC100LVELT22D'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'PECL buffer interface', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MC100LVELT22-D.PDF', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nMC100LVELT22D\n\nPECL buffer interface', 'pins':[
            Pin(num='1',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{Q0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{Q1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC100LVELT22DT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC100LVELT22DT'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-8_3x3mm_P0.65mm', 'Package_SO:TSSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-8_3x3mm_P0.65mm', 'keywords':'PECL buffer interface', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MC100LVELT22-D.PDF', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nMC100LVELT22DT\n\nPECL buffer interface', 'pins':[
            Pin(num='1',name='Q0',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{Q0}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Q1',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{Q1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC68A21', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC68A21'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'PIA', 'description':'', 'datasheet':'http://pdf.datasheetcatalog.com/datasheet/motorola/6821.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nMC68A21\n\nPIA', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='CB1',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='R/~{W}',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='CS0',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{CS2}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='CS1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='ENABLE',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='RS1',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='RS0',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='~{IRQB}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='38',name='~{IRQA}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='39',name='CA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='CA1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC68A40', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC68A40'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W15.24mm', 'Package_DIP:DIP-28_W15.24mm'], 'footprint':'Package_DIP:DIP-28_W15.24mm', 'keywords':'PTM MC6800', 'description':'', 'datasheet':'http://pdf.datasheetcatalog.com/datasheet/motorola/MC6840.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nMC68A40\n\nPTM MC6800', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RS0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='RS1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='RS2',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='R/~{W}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='~{CS0}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='CS1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='E',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='D7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{G2}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='~{G1}',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='O1',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='~{C1}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='O2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{C2}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{G3}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='O3',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{C3}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{IRQ}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC68A44', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC68A44'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'Direct Memory Access Controller', 'description':'', 'datasheet':'http://pdf.datasheetcatalog.com/datasheets/560/501527_DS.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nMC68A44\n\nDirect Memory Access Controller', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='A6',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='A7',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='A8',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='A9',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='A10',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='A11',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='A12',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='A13',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='A14',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='A15',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{CS}/Tx_AKB',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='Tx_RQ3',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='R/~{W}',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='Tx_RQ2',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='Tx_RQ1',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='Tx_RQ0',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='~{IRQ}/~{DEND}',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='~{Tx_STB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='Tx_AKA',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='~{DRQ2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='~{DRQ1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='DGRNT',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='E',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='A3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='A4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='A5',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC68B21', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC68B21'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'PIA', 'description':'', 'datasheet':'http://pdf.datasheetcatalog.com/datasheet/motorola/6821.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nMC68B21\n\nPIA', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='CB1',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='R/~{W}',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='CS0',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='~{CS2}',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='CS1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='ENABLE',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='RS1',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='RS0',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='~{IRQB}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='38',name='~{IRQA}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='39',name='CA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='CA1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC68B40', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC68B40'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W15.24mm', 'Package_DIP:DIP-28_W15.24mm', 'Package_DIP:DIP-28_W15.24mm'], 'footprint':'Package_DIP:DIP-28_W15.24mm', 'keywords':'PTM MC6800', 'description':'', 'datasheet':'http://pdf.datasheetcatalog.com/datasheet/motorola/MC6840.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nMC68B40\n\nPTM MC6800', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RS0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='RS1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='RS2',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='R/~{W}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='~{CS0}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='CS1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='E',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='D7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{G2}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='~{G1}',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='O1',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='~{C1}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='O2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{C2}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{G3}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='O3',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{C3}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~{IRQ}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC68B44', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC68B44'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'Direct Memory Access Controller', 'description':'', 'datasheet':'http://pdf.datasheetcatalog.com/datasheets/560/501527_DS.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nMC68B44\n\nDirect Memory Access Controller', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='A6',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='A7',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='A8',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='A9',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='A10',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='A11',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='A12',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='A13',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='A14',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='A15',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{CS}/Tx_AKB',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='Tx_RQ3',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='R/~{W}',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='Tx_RQ2',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='Tx_RQ1',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='Tx_RQ0',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='~{IRQ}/~{DEND}',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='~{Tx_STB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='Tx_AKA',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='~{DRQ2}',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='~{DRQ1}',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='DGRNT',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='E',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='A2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='A3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='A4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='A5',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9306D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9306D'}), 'ref_prefix':'U', 'fplist':['', 'Package_SO:SO-8_3.9x4.9mm_P1.27mm'], 'footprint':'', 'keywords':'I2C SMBus', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/PCA9306.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nPCA9306D\n\nI2C SMBus', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VREF1',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='SCL1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SDA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SDA2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCL2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VREF2',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='EN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9306DC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9306DC'}), 'ref_prefix':'U', 'fplist':['', 'Package_SO:SO-8_3.9x4.9mm_P1.27mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm'], 'footprint':'', 'keywords':'I2C SMBus', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/PCA9306.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nPCA9306DC\n\nI2C SMBus', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VREF1',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='SCL1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SDA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SDA2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCL2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VREF2',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='EN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9306DC1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9306DC1'}), 'ref_prefix':'U', 'fplist':['', 'Package_SO:SO-8_3.9x4.9mm_P1.27mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm'], 'footprint':'', 'keywords':'I2C SMBus', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/PCA9306.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nPCA9306DC1\n\nI2C SMBus', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VREF1',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='SCL1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SDA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SDA2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCL2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VREF2',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='EN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCA9306DP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCA9306DP'}), 'ref_prefix':'U', 'fplist':['', 'Package_SO:SO-8_3.9x4.9mm_P1.27mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:VSSOP-8_2.3x2mm_P0.5mm', 'Package_SO:TSSOP-8_3x3mm_P0.65mm'], 'footprint':'', 'keywords':'I2C SMBus', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/PCA9306.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nPCA9306DP\n\nI2C SMBus', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VREF1',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='SCL1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='SDA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SDA2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SCL2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VREF2',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='EN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74LV8153PW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74LV8153PW'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'serial to parallel', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74lv8153.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nSN74LV8153PW\n\nserial to parallel', 'pins':[
            Pin(num='1',name='V_{CC1}',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Y7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='Y6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='Y5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='Y4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='Y3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='Y2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='Y1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='19',name='Y0',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='V_{CC2}',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUTSEL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='SOUT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TB5D2H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TB5D2H'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'differential PECL driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tb5d2h.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nTB5D2H\n\ndifferential PECL driver', 'pins':[
            Pin(num='1',name='AI',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CO',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~{CO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='E2',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{DO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DO',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='DI',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AO',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{AO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='E1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{BO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='BO',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='BI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='CI',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TB5D2HDW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TB5D2HDW'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'differential PECL driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tb5d2h.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nTB5D2HDW\n\ndifferential PECL driver', 'pins':[
            Pin(num='1',name='AI',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CO',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~{CO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='E2',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{DO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DO',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='DI',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AO',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{AO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='E1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{BO}',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='BO',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='BI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='CI',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TB5R2D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TB5R2D'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'differential PECL reciver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tb5r1.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nTB5R2D\n\ndifferential PECL reciver', 'pins':[
            Pin(num='1',name='~{AI}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CI',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CO',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='~{E2}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='DO',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DI',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{DI}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AI',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='AO',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='E1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='BO',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='BI',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{BI}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{CI}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TB5R2DW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TB5R2DW'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16W_7.5x10.3mm_P1.27mm', 'keywords':'differential PECL reciver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tb5r1.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nTB5R2DW\n\ndifferential PECL reciver', 'pins':[
            Pin(num='1',name='~{AI}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CI',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CO',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='~{E2}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='DO',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='DI',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{DI}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='AI',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='AO',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='E1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='BO',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='BI',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{BI}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{CI}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCA9801', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCA9801'}), 'ref_prefix':'U', 'fplist':['Package_SO:VSSOP-8_3x3mm_P0.65mm', 'Package_SO:VSSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:VSSOP-8_3x3mm_P0.65mm', 'keywords':'I2C buffer repeater', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tca9801.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nTCA9801\n\nI2C buffer repeater', 'pins':[
            Pin(num='1',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SCLA',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='SDAA',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SDAB',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SCLB',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCCB',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCA9802', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCA9802'}), 'ref_prefix':'U', 'fplist':['Package_SO:VSSOP-8_3x3mm_P0.65mm', 'Package_SO:VSSOP-8_3x3mm_P0.65mm', 'Package_SO:VSSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:VSSOP-8_3x3mm_P0.65mm', 'keywords':'I2C buffer repeater', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tca9802.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nTCA9802\n\nI2C buffer repeater', 'pins':[
            Pin(num='1',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SCLA',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='SDAA',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SDAB',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SCLB',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCCB',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TCA9803', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TCA9803'}), 'ref_prefix':'U', 'fplist':['Package_SO:VSSOP-8_3x3mm_P0.65mm', 'Package_SO:VSSOP-8_3x3mm_P0.65mm', 'Package_SO:VSSOP-8_3x3mm_P0.65mm', 'Package_SO:VSSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:VSSOP-8_3x3mm_P0.65mm', 'keywords':'I2C buffer repeater', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tca9803.pdf', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nTCA9803\n\nI2C buffer repeater', 'pins':[
            Pin(num='1',name='VCCA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SCLA',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='SDAA',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SDAB',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SCLB',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCCB',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Z84C20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Z84C20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-40_W15.24mm', 'Package_DIP:DIP-40_W15.24mm'], 'footprint':'Package_DIP:DIP-40_W15.24mm', 'keywords':'Z80 PIO parallel', 'description':'', 'datasheet':'https://www.zilog.com/appnotes_download.php?FromPage=DirectLink&dn=PS0180&ft=Product%20Specification%20(Data%20Sheet)%20%20&f=YUhSMGNEb3ZMM2QzZHk1NmFXeHZaeTVqYjIwdlpHOWpjeTk2T0RBdmNITXdNVGd3TG5Ca1pnPT0=', 'search_text':'/usr/share/kicad/symbols/Interface.kicad_sym\nZ84C20\n\nZ80 PIO parallel', 'pins':[
            Pin(num='1',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{ASTB}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{BSTB}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='ARDY',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='D0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='BRDY',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='IEO',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='~{INT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='24',name='IEI',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='~{RD}',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='~{IORQ}',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='~{M1}',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='C/~{D}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='B/~{A}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])