from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

CPLD_Altera = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'EP1210', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EP1210'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'EPLD', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/CPLD_Altera.kicad_sym\nEP1210\n\nEPLD', 'pins':[
            Pin(num='1',name='CLK1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='B12',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='B13',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='B20',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='B21',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='B22',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='B23',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='B30',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='B31',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='B32',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='B33',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='I0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='A33',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='A32',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A31',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A30',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A23',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='A22',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='A21',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='A20',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='A13',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='I11',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='I10',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='I9',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='I8',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='B10',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='B11',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EP1810', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EP1810'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'EPLD', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/CPLD_Altera.kicad_sym\nEP1810\n\nEPLD', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='I/O_9A',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='I/O_10A',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='I/O_11A',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='I/O_12A',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='INP1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='INP2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='INP3',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='INP4/CLK1',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='INP5/CLK2',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='I/O_1A',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='INP6',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='INP7',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='INP8',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='I/O_13B',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='I/O_14B',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='I/O_15B',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='I/O_16B',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='I/O_17B',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='I/O_18B',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='I/O_19B',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I/O_2A',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='I/O_20B',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='I/O_21B',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='I/O_22B',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='I/O_23B',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='I/O_24B',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='I/O_25C',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='I/O_26C',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='I/O_27C',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='I/O_28C',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I/O_3A',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='I/O_29C',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='I/O_30C',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='I/O_31C',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='I/O_32C',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='I/O_33C',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='I/O_34C',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='I/O_35C',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='I/O_36C',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='INP9',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='INP10',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I/O_4A',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='INP11',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='CLK3/INP12',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='CLK4/INP13',func=pin_types.INPUT,unit=1),
            Pin(num='54',name='INP14',func=pin_types.INPUT,unit=1),
            Pin(num='55',name='INP15',func=pin_types.INPUT,unit=1),
            Pin(num='56',name='INP16',func=pin_types.INPUT,unit=1),
            Pin(num='57',name='I/O_37D',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='I/O_38D',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='I/O_39D',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I/O_5A',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='I/O_40D',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='I/O_41D',func=pin_types.INPUT,unit=1),
            Pin(num='62',name='I/O_42D',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='I/O_43D',func=pin_types.INPUT,unit=1),
            Pin(num='64',name='I/O_44D',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='I/O_45D',func=pin_types.INPUT,unit=1),
            Pin(num='66',name='I/O_46D',func=pin_types.INPUT,unit=1),
            Pin(num='67',name='I/O_47D',func=pin_types.INPUT,unit=1),
            Pin(num='68',name='I/O_48D',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I/O_6A',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='I/O_7A',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='I/O_8A',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EP300', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EP300'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'EPLD', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/CPLD_Altera.kicad_sym\nEP300\n\nEPLD', 'pins':[
            Pin(num='1',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='IN10',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='IO1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='IO2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='IO3',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='IO4',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='IO5',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='IO6',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='IO7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='IO8',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IN5',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IN6',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IN7',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='IN9',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EP320', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EP320'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'EPLD', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/CPLD_Altera.kicad_sym\nEP320\n\nEPLD', 'pins':[
            Pin(num='1',name='CK/IN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='I/O11',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='I/O12',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='I/O13',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='I/O14',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='I/O15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='I/O16',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='I/O17',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='I/O18',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='I/O19',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='IN5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IN6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IN7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IN8',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='IN9',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EP600', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EP600'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'EPLD', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/CPLD_Altera.kicad_sym\nEP600\n\nEPLD', 'pins':[
            Pin(num='1',name='CLK1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='I/O10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='IN11',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='CLK2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='IN14',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='I/O15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='I/O16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='I/O17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='I/O18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='I/O19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='I/O20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='I/O21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='I/O22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='IN23',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='I/O3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='I/O4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='I/O5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='I/O6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='I/O7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='I/O8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='I/O9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EP910', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EP910'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'EPLD', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/CPLD_Altera.kicad_sym\nEP910\n\nEPLD', 'pins':[
            Pin(num='1',name='CLK1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IO5',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='IO6',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='IO7',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='IO8',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='IO9',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='IO10',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='IO11',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='I0',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='CLK2',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='I11',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='I10',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='I9',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='IO23',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='IO22',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='IO21',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='IO20',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='IO19',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='IO18',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='IO17',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='IO16',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='IO15',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='IO14',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='IO13',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='IO12',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='I8',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='IO0',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IO1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IO2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IO3',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='IO4',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EPM1270F256', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EPM1270F256'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-256_17.0x17.0mm_Layout16x16_P1.0mm_Ball0.5mm_Pad0.4mm_NSMD'], 'footprint':'Package_BGA:BGA-256_17.0x17.0mm_Layout16x16_P1.0mm_Ball0.5mm_Pad0.4mm_NSMD', 'keywords':'MAX2 FBGA', 'description':'', 'datasheet':'https://www.altera.com/content/dam/altera-www/global/en_US/pdfs/literature/hb/max2/max2_mii5v1.pdf', 'search_text':'/usr/share/kicad/symbols/CPLD_Altera.kicad_sym\nEPM1270F256\n\nMAX2 FBGA', 'pins':[
            Pin(num='A1',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='IO2_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO2_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO2_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO2_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='A15',name='IO2_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='IO2_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='IO2_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO2_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO2_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO2_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO2_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO2_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='IO2_B1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO2_B10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO2_B11',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO2_B12',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='IO2_B13',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO2_B14',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='B16',name='IO2_B16',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='IO2_B3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='IO2_B4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='IO2_B5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO2_B6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='IO2_B7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='IO2_B8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO2_B9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='IO2_C10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO2_C11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO2_C12',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO2_C13',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='IO1_C2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='IO1_C3',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='IO2_C4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO2_C5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO2_C6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO2_C7',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO2_C8',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO2_C9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='IO1_D1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO2_D10',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO2_D11',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO2_D12',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='IO1_D2',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='IO1_D3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='IO2_D4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='IO2_D5',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO2_D6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='IO2_D7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO2_D8',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO2_D9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='IO1_E1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='IO2_E10',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='IO2_E11',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='IO1_E2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='IO1_E3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='IO1_E4',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='IO1_E5',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='IO2_E6',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='IO2_E7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='IO2_E8',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='IO2_E9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='IO1_F1',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO2_F10',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='IO1_F2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='IO1_F3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='IO1_F4',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='IO1_F5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='IO1_F6',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='IO2_F7',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='IO1_G1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='IO1_G2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='IO1_G3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='IO1_G4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='IO1_G5',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='IO1_G6',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='IO1_H1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='IO1_H2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='IO1_H3',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='IO1_H4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='IO1_H5/GCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='H8',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='IO1_J1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='IO1_J2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='IO1_J3',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='IO1_J4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='IO1_J5/GCLK1',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='IO1_K1',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='IO1_K2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='IO1_K3',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='IO1_K4',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='IO1_K5',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='IO1_K6',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='IO1_L1',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='IO1_L2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='IO1_L3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='IO1_L4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='IO1_L5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='M1',name='IO1_M1',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='IO1_M2',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='IO1_M3',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='IO1_M4',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='N1',name='IO1_N1',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='IO1_N2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='IO1_N3',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='P1',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='P2',name='IO1_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='C14',name='IO3_C14',func=pin_types.BIDIR,unit=2),
            Pin(num='C15',name='IO3_C15',func=pin_types.BIDIR,unit=2),
            Pin(num='C16',name='VCCIO3',func=pin_types.PWRIN,unit=2),
            Pin(num='D13',name='IO3_D13',func=pin_types.BIDIR,unit=2),
            Pin(num='D14',name='IO3_D14',func=pin_types.BIDIR,unit=2),
            Pin(num='D15',name='IO3_D15',func=pin_types.BIDIR,unit=2),
            Pin(num='D16',name='IO3_D16',func=pin_types.BIDIR,unit=2),
            Pin(num='E12',name='IO3_E12',func=pin_types.BIDIR,unit=2),
            Pin(num='E13',name='IO3_E13',func=pin_types.BIDIR,unit=2),
            Pin(num='E14',name='IO3_E14',func=pin_types.BIDIR,unit=2),
            Pin(num='E15',name='IO3_E15',func=pin_types.BIDIR,unit=2),
            Pin(num='E16',name='IO3_E16',func=pin_types.BIDIR,unit=2),
            Pin(num='F11',name='IO3_F11',func=pin_types.BIDIR,unit=2),
            Pin(num='F12',name='IO3_F12',func=pin_types.BIDIR,unit=2),
            Pin(num='F13',name='IO3_F13',func=pin_types.BIDIR,unit=2),
            Pin(num='F14',name='IO3_F14',func=pin_types.BIDIR,unit=2),
            Pin(num='F15',name='IO3_F15',func=pin_types.BIDIR,unit=2),
            Pin(num='F16',name='IO3_F16',func=pin_types.BIDIR,unit=2),
            Pin(num='G10',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='G11',name='IO3_G11',func=pin_types.BIDIR,unit=2),
            Pin(num='G12',name='IO3_G12',func=pin_types.BIDIR,unit=2),
            Pin(num='G13',name='IO3_G13',func=pin_types.BIDIR,unit=2),
            Pin(num='G14',name='IO3_G14',func=pin_types.BIDIR,unit=2),
            Pin(num='G15',name='IO3_G15',func=pin_types.BIDIR,unit=2),
            Pin(num='G16',name='IO3_G16',func=pin_types.BIDIR,unit=2),
            Pin(num='G9',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='H11',name='VCCIO3',func=pin_types.PWRIN,unit=2),
            Pin(num='H12',name='IO3_H12/GCLK3',func=pin_types.BIDIR,unit=2),
            Pin(num='H13',name='IO3_H13',func=pin_types.BIDIR,unit=2),
            Pin(num='H14',name='IO3_H14',func=pin_types.BIDIR,unit=2),
            Pin(num='H15',name='IO3_H15',func=pin_types.BIDIR,unit=2),
            Pin(num='H16',name='IO3_H16',func=pin_types.BIDIR,unit=2),
            Pin(num='J11',name='VCCIO3',func=pin_types.PWRIN,unit=2),
            Pin(num='J12',name='IO3_J12/GCLK2',func=pin_types.BIDIR,unit=2),
            Pin(num='J13',name='IO3_J13',func=pin_types.BIDIR,unit=2),
            Pin(num='J14',name='IO3_J14',func=pin_types.BIDIR,unit=2),
            Pin(num='J15',name='IO3_J15',func=pin_types.BIDIR,unit=2),
            Pin(num='J16',name='IO3_J16',func=pin_types.BIDIR,unit=2),
            Pin(num='K10',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='K11',name='IO3_K11',func=pin_types.BIDIR,unit=2),
            Pin(num='K12',name='IO3_K12',func=pin_types.BIDIR,unit=2),
            Pin(num='K13',name='IO3_K13',func=pin_types.BIDIR,unit=2),
            Pin(num='K14',name='IO3_K14',func=pin_types.BIDIR,unit=2),
            Pin(num='K15',name='IO3_K15',func=pin_types.BIDIR,unit=2),
            Pin(num='K16',name='IO3_K16',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='K8',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='K9',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='L10',name='IO4_L10',func=pin_types.BIDIR,unit=2),
            Pin(num='L11',name='IO3_L11',func=pin_types.BIDIR,unit=2),
            Pin(num='L12',name='IO3_L12',func=pin_types.BIDIR,unit=2),
            Pin(num='L13',name='IO3_L13',func=pin_types.BIDIR,unit=2),
            Pin(num='L14',name='IO3_L14',func=pin_types.BIDIR,unit=2),
            Pin(num='L15',name='IO3_L15',func=pin_types.BIDIR,unit=2),
            Pin(num='L16',name='IO3_L16',func=pin_types.BIDIR,unit=2),
            Pin(num='L7',name='IO4_L7',func=pin_types.BIDIR,unit=2),
            Pin(num='L8',name='VCCIO4',func=pin_types.PWRIN,unit=2),
            Pin(num='L9',name='VCCIO4',func=pin_types.PWRIN,unit=2),
            Pin(num='M10',name='IO4_M10',func=pin_types.BIDIR,unit=2),
            Pin(num='M11',name='IO4_M11',func=pin_types.BIDIR,unit=2),
            Pin(num='M12',name='IO4_M12',func=pin_types.BIDIR,unit=2),
            Pin(num='M13',name='IO3_M13',func=pin_types.BIDIR,unit=2),
            Pin(num='M14',name='IO3_M14',func=pin_types.BIDIR,unit=2),
            Pin(num='M15',name='IO3_M15',func=pin_types.BIDIR,unit=2),
            Pin(num='M16',name='IO3_M16',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO4_M6',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO4_M7',func=pin_types.BIDIR,unit=2),
            Pin(num='M8',name='IO4_M8/DEV_OE',func=pin_types.BIDIR,unit=2),
            Pin(num='M9',name='IO4_M9/DEV_CLRn',func=pin_types.BIDIR,unit=2),
            Pin(num='N10',name='IO4_N10',func=pin_types.BIDIR,unit=2),
            Pin(num='N11',name='IO4_N11',func=pin_types.BIDIR,unit=2),
            Pin(num='N12',name='IO4_N12',func=pin_types.BIDIR,unit=2),
            Pin(num='N13',name='IO3_N13',func=pin_types.BIDIR,unit=2),
            Pin(num='N14',name='IO3_N14',func=pin_types.BIDIR,unit=2),
            Pin(num='N15',name='IO3_N15',func=pin_types.BIDIR,unit=2),
            Pin(num='N16',name='IO3_N16',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO4_N5',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO4_N6',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO4_N7',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO4_N8',func=pin_types.BIDIR,unit=2),
            Pin(num='N9',name='IO4_N9',func=pin_types.BIDIR,unit=2),
            Pin(num='P10',name='IO4_P10',func=pin_types.BIDIR,unit=2),
            Pin(num='P11',name='IO4_P11',func=pin_types.BIDIR,unit=2),
            Pin(num='P12',name='IO4_P12',func=pin_types.BIDIR,unit=2),
            Pin(num='P13',name='IO4_P13',func=pin_types.BIDIR,unit=2),
            Pin(num='P14',name='IO3_P14',func=pin_types.BIDIR,unit=2),
            Pin(num='P15',name='IO3_P15',func=pin_types.BIDIR,unit=2),
            Pin(num='P16',name='VCCIO3',func=pin_types.PWRIN,unit=2),
            Pin(num='P4',name='IO4_P4',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO4_P5',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO4_P6',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO4_P7',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO4_P8',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='IO4_P9',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO4_R1',func=pin_types.BIDIR,unit=2),
            Pin(num='R10',name='IO4_R10',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO4_R11',func=pin_types.BIDIR,unit=2),
            Pin(num='R12',name='IO4_R12',func=pin_types.BIDIR,unit=2),
            Pin(num='R13',name='IO4_R13',func=pin_types.BIDIR,unit=2),
            Pin(num='R14',name='IO4_R14',func=pin_types.BIDIR,unit=2),
            Pin(num='R15',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='R16',name='IO4_R16',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO4_R3',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO4_R4',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO4_R5',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO4_R6',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO4_R7',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO4_R8',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO4_R9',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='T10',name='IO4_T10',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO4_T11',func=pin_types.BIDIR,unit=2),
            Pin(num='T12',name='IO4_T12',func=pin_types.BIDIR,unit=2),
            Pin(num='T13',name='IO4_T13',func=pin_types.BIDIR,unit=2),
            Pin(num='T14',name='VCCIO4',func=pin_types.PWRIN,unit=2),
            Pin(num='T15',name='IO4_T15',func=pin_types.BIDIR,unit=2),
            Pin(num='T16',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='T2',name='IO4_T2',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='VCCIO4',func=pin_types.PWRIN,unit=2),
            Pin(num='T4',name='IO4_T4',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO4_T5',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO4_T6',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO4_T7',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO4_T8',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='IO4_T9',func=pin_types.BIDIR,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['G6', 'L4', 'G7', 'D5', 'L5', 'B11', 'D6', 'G8', 'C4', 'L6', 'C7', 'D7', 'H1', 'M1', 'D8', 'H10', 'M2', 'D9', 'H2', 'M3', 'B10', 'E1', 'H3', 'B16', 'M4', 'E10', 'H4', 'M5', 'E11', 'H5', 'N1', 'C8', 'E2', 'H6', 'N2', 'B4', 'A12', 'E3', 'H7', 'N3', 'A13', 'B1', 'B5', 'E4', 'H8', 'N4', 'E5', 'H9', 'P1', 'B2', 'E6', 'J1', 'P2', 'E7', 'J10', 'P3', 'A9', 'E8', 'J2', 'A14', 'B6', 'E9', 'J3', 'A15', 'B7', 'F1', 'J4', 'B8', 'F10', 'J5', 'B14', 'C2', 'C3', 'A3', 'B9', 'F2', 'J6', 'A16', 'A8', 'C1', 'F3', 'J7', 'A4', 'B15', 'A2', 'A1', 'A6', 'C10', 'C5', 'F4', 'J8', 'A5', 'A11', 'F5', 'J9', 'C12', 'F6', 'K1', 'C11', 'C6', 'F7', 'K2', 'C13', 'B3', 'C9', 'F8', 'K3', 'D1', 'F9', 'K4', 'D10', 'G1', 'K5', 'D11', 'G2', 'K6', 'A7', 'D12', 'B12', 'G3', 'L1', 'B13', 'D2', 'D4', 'G4', 'L2', 'A10', 'D3', 'G5', 'L3']},{'label': 'uB', 'num': 2, 'pin_nums': ['M12', 'P8', 'F16', 'T8', 'P9', 'M13', 'G10', 'T9', 'G11', 'M14', 'R1', 'G12', 'R10', 'M15', 'M16', 'G13', 'R11', 'G14', 'M6', 'R12', 'J13', 'M7', 'R13', 'J14', 'R14', 'M8', 'J15', 'M9', 'R15', 'J16', 'N10', 'R16', 'F15', 'K10', 'N11', 'R2', 'K11', 'N12', 'R3', 'K12', 'N13', 'R4', 'K13', 'N14', 'R5', 'J12', 'K14', 'N15', 'R6', 'K15', 'R7', 'C14', 'N16', 'K16', 'C15', 'N5', 'R8', 'T7', 'K7', 'C16', 'G16', 'N6', 'R9', 'H13', 'K8', 'D13', 'N7', 'T1', 'G15', 'K9', 'D14', 'N8', 'T10', 'L10', 'D15', 'N9', 'T11', 'L11', 'D16', 'P10', 'T12', 'L12', 'E12', 'G9', 'P11', 'T13', 'L13', 'E13', 'H11', 'P12', 'T14', 'L14', 'E14', 'H12', 'P13', 'T15', 'L15', 'E15', 'P14', 'T16', 'H14', 'L16', 'E16', 'P15', 'T2', 'J11', 'L7', 'F11', 'H15', 'P16', 'T3', 'H16', 'L8', 'F12', 'P4', 'T4', 'L9', 'F13', 'P5', 'T5', 'M10', 'F14', 'P6', 'T6', 'M11', 'P7']}] }),
        Part(**{ 'name':'EPM1270M256', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EPM1270M256'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-256_11.0x11.0mm_Layout20x20_P0.5mm_Ball0.3mm_Pad0.25mm_NSMD'], 'footprint':'Package_BGA:BGA-256_11.0x11.0mm_Layout20x20_P0.5mm_Ball0.3mm_Pad0.25mm_NSMD', 'keywords':'MAX2 MBGA', 'description':'', 'datasheet':'https://www.altera.com/content/dam/altera-www/global/en_US/pdfs/literature/hb/max2/max2_mii5v1.pdf', 'search_text':'/usr/share/kicad/symbols/CPLD_Altera.kicad_sym\nEPM1270M256\n\nMAX2 MBGA', 'pins':[
            Pin(num='A1',name='IO2_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='IO2_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO2_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO2_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO2_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO2_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO2_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO2_A16',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='IO2_A17',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO2_A18',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='IO2_A19',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO2_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='IO2_A20',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO2_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO2_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO2_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO2_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO2_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO2_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO2_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='IO1_B1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO2_B10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO2_B11',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO2_B12',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='IO2_B13',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO2_B14',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO2_B15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='IO2_B16',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='IO2_B17',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO2_B18',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='IO2_B19',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='IO2_B2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO2_B3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='IO2_B4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='IO2_B5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO2_B6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='IO2_B7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='IO2_B8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO2_B9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='IO1_C1',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='C11',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='C14',name='IO2_C14',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO2_C15',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO2_C16',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO2_C17',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='IO1_C2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='IO1_C3',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='IO1_C4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO2_C5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO2_C6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO2_C7',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='IO1_D1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='D13',name='IO2_D13',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO2_D14',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO2_D15',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='IO2_D16',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='IO1_D2',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='IO1_D3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='IO1_D4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='IO2_D5',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO2_D6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='IO2_D7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO2_D8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='IO1_E1',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='IO1_E2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='IO1_E3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='IO1_E4',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='IO1_F1',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='IO1_F2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='IO1_F3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='IO1_F4',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='IO1_G1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='IO1_G2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='IO1_G3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='IO1_G4',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='IO1_H1',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='IO1_H2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='H4',name='IO1_H4',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='IO1_J1',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='IO1_J2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='IO1_K1/GCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='IO1_K2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='K4',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='IO1_L1/GCLK1',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='L2',name='IO1_L2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='L4',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='IO1_M1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='M2',name='IO1_M2',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='M4',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='IO1_N1',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='IO1_N2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='N4',name='IO1_N4',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='IO1_P1',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='IO1_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='IO1_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='IO1_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='IO1_R1',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='IO1_R2',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='IO1_R3',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='IO1_R4',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='IO1_T1',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='IO1_T2',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='T4',name='IO1_T4',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='IO1_U1',func=pin_types.BIDIR,unit=1),
            Pin(num='U11',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='U12',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='U2',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='U3',name='IO1_U3',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='V1',name='IO1_V1',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='V3',name='IO1_V3',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='W1',name='IO1_W1',func=pin_types.BIDIR,unit=1),
            Pin(num='W2',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='B20',name='IO3_B20',func=pin_types.BIDIR,unit=2),
            Pin(num='C12',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='C13',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='C18',name='IO3_C18',func=pin_types.BIDIR,unit=2),
            Pin(num='C19',name='IO3_C19',func=pin_types.BIDIR,unit=2),
            Pin(num='C20',name='IO3_C20',func=pin_types.BIDIR,unit=2),
            Pin(num='C8',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='D17',name='IO3_D17',func=pin_types.BIDIR,unit=2),
            Pin(num='D18',name='IO3_D18',func=pin_types.BIDIR,unit=2),
            Pin(num='D19',name='IO3_D19',func=pin_types.BIDIR,unit=2),
            Pin(num='D20',name='IO3_D20',func=pin_types.BIDIR,unit=2),
            Pin(num='D9',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='E17',name='IO3_E17',func=pin_types.BIDIR,unit=2),
            Pin(num='E18',name='IO3_E18',func=pin_types.BIDIR,unit=2),
            Pin(num='E19',name='IO3_E19',func=pin_types.BIDIR,unit=2),
            Pin(num='E20',name='IO3_E20',func=pin_types.BIDIR,unit=2),
            Pin(num='F17',name='IO3_F17',func=pin_types.BIDIR,unit=2),
            Pin(num='F18',name='IO3_F18',func=pin_types.BIDIR,unit=2),
            Pin(num='F19',name='IO3_F19',func=pin_types.BIDIR,unit=2),
            Pin(num='F20',name='IO3_F20',func=pin_types.BIDIR,unit=2),
            Pin(num='G17',name='IO3_G17',func=pin_types.BIDIR,unit=2),
            Pin(num='G18',name='IO3_G18',func=pin_types.BIDIR,unit=2),
            Pin(num='G19',name='IO3_G19',func=pin_types.BIDIR,unit=2),
            Pin(num='G20',name='IO3_G20',func=pin_types.BIDIR,unit=2),
            Pin(num='H17',name='IO3_H17',func=pin_types.BIDIR,unit=2),
            Pin(num='H18',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='H19',name='IO3_H19',func=pin_types.BIDIR,unit=2),
            Pin(num='H20',name='IO3_H20',func=pin_types.BIDIR,unit=2),
            Pin(num='J17',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='J18',name='VCCIO3',func=pin_types.PWRIN,unit=2),
            Pin(num='J19',name='IO3_J19',func=pin_types.BIDIR,unit=2),
            Pin(num='J20',name='IO3_J20',func=pin_types.BIDIR,unit=2),
            Pin(num='K17',name='VCCIO3',func=pin_types.PWRIN,unit=2),
            Pin(num='K18',name='VCCIO3',func=pin_types.PWRIN,unit=2),
            Pin(num='K19',name='IO3_K19',func=pin_types.BIDIR,unit=2),
            Pin(num='K20',name='IO3_K20',func=pin_types.BIDIR,unit=2),
            Pin(num='L18',name='VCCIO3',func=pin_types.PWRIN,unit=2),
            Pin(num='L19',name='IO3_L19',func=pin_types.BIDIR,unit=2),
            Pin(num='L20',name='IO3_L20/GCLK3',func=pin_types.BIDIR,unit=2),
            Pin(num='M18',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='M19',name='IO3_M19',func=pin_types.BIDIR,unit=2),
            Pin(num='M20',name='IO3_M20/GCLK2',func=pin_types.BIDIR,unit=2),
            Pin(num='N17',name='IO3_N17',func=pin_types.BIDIR,unit=2),
            Pin(num='N18',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='N19',name='IO3_N19',func=pin_types.BIDIR,unit=2),
            Pin(num='N20',name='IO3_N20',func=pin_types.BIDIR,unit=2),
            Pin(num='P17',name='IO3_P17',func=pin_types.BIDIR,unit=2),
            Pin(num='P18',name='IO3_P18',func=pin_types.BIDIR,unit=2),
            Pin(num='P19',name='IO3_P19',func=pin_types.BIDIR,unit=2),
            Pin(num='P20',name='IO3_P20',func=pin_types.BIDIR,unit=2),
            Pin(num='R17',name='IO3_R17',func=pin_types.BIDIR,unit=2),
            Pin(num='R18',name='IO3_R18',func=pin_types.BIDIR,unit=2),
            Pin(num='R19',name='IO3_R19',func=pin_types.BIDIR,unit=2),
            Pin(num='R20',name='IO3_R20',func=pin_types.BIDIR,unit=2),
            Pin(num='T17',name='IO3_T17',func=pin_types.BIDIR,unit=2),
            Pin(num='T18',name='IO3_T18',func=pin_types.BIDIR,unit=2),
            Pin(num='T19',name='IO3_T19',func=pin_types.BIDIR,unit=2),
            Pin(num='T20',name='IO3_T20',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='VCCIO4',func=pin_types.PWRIN,unit=2),
            Pin(num='U13',name='IO4_U13',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='IO4_U14',func=pin_types.BIDIR,unit=2),
            Pin(num='U15',name='IO4_U15',func=pin_types.BIDIR,unit=2),
            Pin(num='U16',name='IO4_U16',func=pin_types.BIDIR,unit=2),
            Pin(num='U17',name='IO3_U17',func=pin_types.BIDIR,unit=2),
            Pin(num='U18',name='IO3_U18',func=pin_types.BIDIR,unit=2),
            Pin(num='U19',name='IO3_U19',func=pin_types.BIDIR,unit=2),
            Pin(num='U20',name='IO3_U20',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO4_U4',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='IO4_U5',func=pin_types.BIDIR,unit=2),
            Pin(num='U6',name='IO4_U6',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO4_U7',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO4_U8',func=pin_types.BIDIR,unit=2),
            Pin(num='V10',name='VCCIO4',func=pin_types.PWRIN,unit=2),
            Pin(num='V11',name='VCCIO4',func=pin_types.PWRIN,unit=2),
            Pin(num='V12',name='VCCIO4',func=pin_types.PWRIN,unit=2),
            Pin(num='V13',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='V14',name='IO4_V14',func=pin_types.BIDIR,unit=2),
            Pin(num='V15',name='IO4_V15',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='IO4_V16',func=pin_types.BIDIR,unit=2),
            Pin(num='V17',name='IO4_V17',func=pin_types.BIDIR,unit=2),
            Pin(num='V18',name='IO4_V18',func=pin_types.BIDIR,unit=2),
            Pin(num='V19',name='IO3_V19',func=pin_types.BIDIR,unit=2),
            Pin(num='V20',name='IO3_V20',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='IO4_V4',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO4_V5',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO4_V6',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO4_V7',func=pin_types.BIDIR,unit=2),
            Pin(num='V9',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='W10',name='IO4_W10',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='IO4_W11',func=pin_types.BIDIR,unit=2),
            Pin(num='W12',name='IO4_W12/DEV_OE',func=pin_types.BIDIR,unit=2),
            Pin(num='W13',name='IO4_W13',func=pin_types.BIDIR,unit=2),
            Pin(num='W14',name='IO4_W14',func=pin_types.BIDIR,unit=2),
            Pin(num='W15',name='IO4_W15',func=pin_types.BIDIR,unit=2),
            Pin(num='W16',name='IO4_W16',func=pin_types.BIDIR,unit=2),
            Pin(num='W17',name='IO4_W17',func=pin_types.BIDIR,unit=2),
            Pin(num='W18',name='IO4_W18',func=pin_types.BIDIR,unit=2),
            Pin(num='W19',name='IO3_W19',func=pin_types.BIDIR,unit=2),
            Pin(num='W20',name='IO3_W20',func=pin_types.BIDIR,unit=2),
            Pin(num='W3',name='IO4_W3',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='IO4_W4',func=pin_types.BIDIR,unit=2),
            Pin(num='W5',name='IO4_W5',func=pin_types.BIDIR,unit=2),
            Pin(num='W6',name='IO4_W6',func=pin_types.BIDIR,unit=2),
            Pin(num='W7',name='IO4_W7',func=pin_types.BIDIR,unit=2),
            Pin(num='W8',name='IO4_W8',func=pin_types.BIDIR,unit=2),
            Pin(num='W9',name='IO4_W9',func=pin_types.BIDIR,unit=2),
            Pin(num='Y1',name='IO4_Y1',func=pin_types.BIDIR,unit=2),
            Pin(num='Y10',name='IO4_Y10',func=pin_types.BIDIR,unit=2),
            Pin(num='Y11',name='IO4_Y11',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='IO4_Y12',func=pin_types.BIDIR,unit=2),
            Pin(num='Y13',name='IO4_Y13/DEV_CLRn',func=pin_types.BIDIR,unit=2),
            Pin(num='Y14',name='IO4_Y14',func=pin_types.BIDIR,unit=2),
            Pin(num='Y15',name='IO4_Y15',func=pin_types.BIDIR,unit=2),
            Pin(num='Y16',name='IO4_Y16',func=pin_types.BIDIR,unit=2),
            Pin(num='Y17',name='IO4_Y17',func=pin_types.BIDIR,unit=2),
            Pin(num='Y18',name='IO4_Y18',func=pin_types.BIDIR,unit=2),
            Pin(num='Y19',name='IO4_Y19',func=pin_types.BIDIR,unit=2),
            Pin(num='Y2',name='IO4_Y2',func=pin_types.BIDIR,unit=2),
            Pin(num='Y20',name='IO3_Y20',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='IO4_Y3',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='IO4_Y4',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='IO4_Y5',func=pin_types.BIDIR,unit=2),
            Pin(num='Y6',name='IO4_Y6',func=pin_types.BIDIR,unit=2),
            Pin(num='Y7',name='IO4_Y7',func=pin_types.BIDIR,unit=2),
            Pin(num='Y8',name='IO4_Y8',func=pin_types.BIDIR,unit=2),
            Pin(num='Y9',name='IO4_Y9',func=pin_types.BIDIR,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['K3', 'B16', 'K4', 'D15', 'U9', 'B17', 'D16', 'L1', 'V1', 'B18', 'D2', 'L17', 'V2', 'B19', 'D3', 'L2', 'V3', 'B2', 'D4', 'L3', 'V8', 'B3', 'D5', 'L4', 'A11', 'W1', 'A1', 'B4', 'D6', 'M1', 'W2', 'B5', 'D7', 'M17', 'A10', 'B6', 'A12', 'D8', 'M2', 'B7', 'E1', 'M3', 'A13', 'B8', 'E2', 'M4', 'A14', 'B9', 'E3', 'N1', 'A15', 'C1', 'E4', 'N2', 'A16', 'C10', 'A17', 'F1', 'N3', 'A18', 'C11', 'F2', 'N4', 'A19', 'C14', 'F3', 'P1', 'A2', 'C15', 'F4', 'P2', 'A20', 'C16', 'G1', 'P3', 'A3', 'C17', 'G2', 'P4', 'A4', 'C2', 'G3', 'R1', 'B15', 'A5', 'C3', 'G4', 'R2', 'A6', 'C4', 'H1', 'R3', 'A7', 'C5', 'H2', 'R4', 'C6', 'A8', 'H3', 'T1', 'A9', 'C7', 'H4', 'T2', 'B1', 'C9', 'J1', 'T3', 'B10', 'D1', 'J2', 'T4', 'B11', 'D10', 'J3', 'U1', 'B12', 'D11', 'J4', 'U11', 'B13', 'D12', 'K1', 'U12', 'U3', 'B14', 'D13', 'K2', 'U2', 'D14']},{'label': 'uB', 'num': 2, 'pin_nums': ['H17', 'W10', 'T19', 'Y4', 'H18', 'W11', 'T20', 'Y5', 'H19', 'U10', 'W12', 'Y6', 'H20', 'W13', 'U13', 'Y7', 'J17', 'U14', 'W14', 'Y8', 'J18', 'U15', 'W15', 'Y9', 'V9', 'J19', 'U16', 'W16', 'J20', 'U17', 'W17', 'B20', 'K17', 'U18', 'W18', 'C12', 'K18', 'U19', 'W19', 'C13', 'K19', 'U20', 'W20', 'C18', 'K20', 'U4', 'W3', 'C19', 'L18', 'U5', 'W4', 'C20', 'L19', 'U6', 'W5', 'C8', 'L20', 'U7', 'W6', 'D17', 'M18', 'U8', 'W7', 'D18', 'M19', 'V10', 'W8', 'D19', 'M20', 'V11', 'W9', 'D20', 'N17', 'V12', 'Y1', 'D9', 'N18', 'V13', 'Y10', 'E17', 'N19', 'V14', 'Y11', 'E18', 'N20', 'V15', 'Y12', 'E19', 'P17', 'V16', 'Y13', 'E20', 'P18', 'V17', 'Y14', 'F17', 'P19', 'V18', 'Y15', 'F18', 'P20', 'V19', 'Y16', 'F19', 'R17', 'V20', 'Y17', 'F20', 'R18', 'V4', 'Y18', 'G17', 'R19', 'V5', 'Y19', 'G20', 'G18', 'R20', 'V6', 'Y2', 'G19', 'T17', 'V7', 'Y20', 'T18', 'Y3']}] }),
        Part(**{ 'name':'EPM1270T144', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EPM1270T144'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'MAX2 TQFP', 'description':'', 'datasheet':'https://www.altera.com/content/dam/altera-www/global/en_US/pdfs/literature/hb/max2/max2_mii5v1.pdf', 'search_text':'/usr/share/kicad/symbols/CPLD_Altera.kicad_sym\nEPM1270T144\n\nMAX2 TQFP', 'pins':[
            Pin(num='1',name='IO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='IO2_109',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='IO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='IO2_110',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='IO2_111',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='IO2_112',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='IO2_113',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='IO2_114',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='117',name='IO2_117',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='IO2_118',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='IO2_119',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='IO1_12',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='IO2_120',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='IO2_121',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='IO2_122',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='IO2_123',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='IO2_124',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='IO2_125',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='127',name='IO2_127',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='129',name='IO2_129',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='IO1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='IO2_130',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='IO2_131',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='IO2_132',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='IO2_133',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='IO2_134',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='IO2_137',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='IO2_138',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='IO2_139',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='IO1_14',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='IO2_140',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='IO2_141',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='IO2_142',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='IO2_143',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='IO2_144',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='IO1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='IO1_16',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='IO1_18/GCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='IO1_20/GCLK1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='IO1_21',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='IO1_22',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='IO1_23',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='IO1_24',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='IO1_27',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='IO1_28',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='IO1_29',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='IO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='IO1_30',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='IO1_31',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='IO1_32',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='IO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='IO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='IO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='IO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='90',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='92',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='99',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VCCIO3',func=pin_types.PWRIN,unit=2),
            Pin(num='101',name='IO3_101',func=pin_types.BIDIR,unit=2),
            Pin(num='102',name='IO3_102',func=pin_types.BIDIR,unit=2),
            Pin(num='103',name='IO3_103',func=pin_types.BIDIR,unit=2),
            Pin(num='104',name='IO3_104',func=pin_types.BIDIR,unit=2),
            Pin(num='105',name='IO3_105',func=pin_types.BIDIR,unit=2),
            Pin(num='106',name='IO3_106',func=pin_types.BIDIR,unit=2),
            Pin(num='107',name='IO3_107',func=pin_types.BIDIR,unit=2),
            Pin(num='108',name='IO3_108',func=pin_types.BIDIR,unit=2),
            Pin(num='115',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='135',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='37',name='IO4_37',func=pin_types.BIDIR,unit=2),
            Pin(num='38',name='IO4_38',func=pin_types.BIDIR,unit=2),
            Pin(num='39',name='IO4_39',func=pin_types.BIDIR,unit=2),
            Pin(num='40',name='IO4_40',func=pin_types.BIDIR,unit=2),
            Pin(num='41',name='IO4_41',func=pin_types.BIDIR,unit=2),
            Pin(num='42',name='IO4_42',func=pin_types.BIDIR,unit=2),
            Pin(num='43',name='IO4_43',func=pin_types.BIDIR,unit=2),
            Pin(num='44',name='IO4_44',func=pin_types.BIDIR,unit=2),
            Pin(num='45',name='IO4_45',func=pin_types.BIDIR,unit=2),
            Pin(num='46',name='VCCIO4',func=pin_types.PWRIN,unit=2),
            Pin(num='48',name='IO4_48',func=pin_types.BIDIR,unit=2),
            Pin(num='49',name='IO4_49',func=pin_types.BIDIR,unit=2),
            Pin(num='50',name='IO4_50',func=pin_types.BIDIR,unit=2),
            Pin(num='51',name='IO4_51',func=pin_types.BIDIR,unit=2),
            Pin(num='52',name='IO4_52',func=pin_types.BIDIR,unit=2),
            Pin(num='53',name='IO4_53',func=pin_types.BIDIR,unit=2),
            Pin(num='55',name='IO4_55',func=pin_types.BIDIR,unit=2),
            Pin(num='57',name='IO4_57',func=pin_types.BIDIR,unit=2),
            Pin(num='58',name='IO4_58',func=pin_types.BIDIR,unit=2),
            Pin(num='59',name='IO4_59',func=pin_types.BIDIR,unit=2),
            Pin(num='60',name='IO4_60/DEV_OE',func=pin_types.BIDIR,unit=2),
            Pin(num='61',name='IO4_61/DEV_CLRn',func=pin_types.BIDIR,unit=2),
            Pin(num='62',name='IO4_62',func=pin_types.BIDIR,unit=2),
            Pin(num='63',name='IO4_63',func=pin_types.BIDIR,unit=2),
            Pin(num='64',name='VCCIO4',func=pin_types.PWRIN,unit=2),
            Pin(num='66',name='IO4_66',func=pin_types.BIDIR,unit=2),
            Pin(num='67',name='IO4_67',func=pin_types.BIDIR,unit=2),
            Pin(num='68',name='IO4_68',func=pin_types.BIDIR,unit=2),
            Pin(num='69',name='IO4_69',func=pin_types.BIDIR,unit=2),
            Pin(num='70',name='IO4_70',func=pin_types.BIDIR,unit=2),
            Pin(num='71',name='IO4_71',func=pin_types.BIDIR,unit=2),
            Pin(num='72',name='IO4_72',func=pin_types.BIDIR,unit=2),
            Pin(num='73',name='IO3_73',func=pin_types.BIDIR,unit=2),
            Pin(num='74',name='IO3_74',func=pin_types.BIDIR,unit=2),
            Pin(num='75',name='IO3_75',func=pin_types.BIDIR,unit=2),
            Pin(num='76',name='IO3_76',func=pin_types.BIDIR,unit=2),
            Pin(num='77',name='IO3_77',func=pin_types.BIDIR,unit=2),
            Pin(num='78',name='IO3_78',func=pin_types.BIDIR,unit=2),
            Pin(num='79',name='IO3_79',func=pin_types.BIDIR,unit=2),
            Pin(num='80',name='IO3_80',func=pin_types.BIDIR,unit=2),
            Pin(num='81',name='IO3_81',func=pin_types.BIDIR,unit=2),
            Pin(num='82',name='VCCIO3',func=pin_types.PWRIN,unit=2),
            Pin(num='84',name='IO3_84',func=pin_types.BIDIR,unit=2),
            Pin(num='85',name='IO3_85',func=pin_types.BIDIR,unit=2),
            Pin(num='86',name='IO3_86',func=pin_types.BIDIR,unit=2),
            Pin(num='87',name='IO3_87',func=pin_types.BIDIR,unit=2),
            Pin(num='88',name='IO3_88',func=pin_types.BIDIR,unit=2),
            Pin(num='89',name='IO3_89/GCLK2',func=pin_types.BIDIR,unit=2),
            Pin(num='91',name='IO3_91/GCLK3',func=pin_types.BIDIR,unit=2),
            Pin(num='93',name='IO3_93',func=pin_types.BIDIR,unit=2),
            Pin(num='94',name='IO3_94',func=pin_types.BIDIR,unit=2),
            Pin(num='95',name='IO3_95',func=pin_types.BIDIR,unit=2),
            Pin(num='96',name='IO3_96',func=pin_types.BIDIR,unit=2),
            Pin(num='97',name='IO3_97',func=pin_types.BIDIR,unit=2),
            Pin(num='98',name='IO3_98',func=pin_types.BIDIR,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['127', '128', '28', '129', '29', '13', '3', '130', '30', '131', '31', '132', '32', '133', '33', '134', '1', '34', '136', '35', '137', '36', '138', '4', '109', '11', '139', '47', '14', '5', '10', '140', '54', '141', '56', '110', '142', '6', '111', '143', '65', '112', '144', '7', '113', '15', '114', '8', '116', '16', '83', '117', '17', '9', '118', '18', '90', '119', '19', '92', '12', '2', '99', '120', '20', '121', '21', '122', '22', '123', '23', '124', '24', '125', '25', '27', '126', '26']},{'label': 'uB', 'num': 2, 'pin_nums': ['41', '60', '107', '50', '69', '77', '86', '96', '108', '42', '51', '100', '87', '78', '61', '70', '97', '43', '101', '115', '52', '62', '71', '79', '88', '98', '135', '44', '102', '53', '63', '72', '80', '85', '89', '95', '37', '103', '45', '55', '64', '73', '81', '91', '104', '38', '46', '57', '66', '74', '82', '93', '68', '39', '105', '48', '58', '67', '75', '84', '94', '40', '106', '49', '59', '76']}] }),
        Part(**{ 'name':'EPM2210F256', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EPM2210F256'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-256_17.0x17.0mm_Layout16x16_P1.0mm_Ball0.5mm_Pad0.4mm_NSMD'], 'footprint':'Package_BGA:BGA-256_17.0x17.0mm_Layout16x16_P1.0mm_Ball0.5mm_Pad0.4mm_NSMD', 'keywords':'MAX2 FBGA', 'description':'', 'datasheet':'https://www.altera.com/content/dam/altera-www/global/en_US/pdfs/literature/hb/max2/max2_mii5v1.pdf', 'search_text':'/usr/share/kicad/symbols/CPLD_Altera.kicad_sym\nEPM2210F256\n\nMAX2 FBGA', 'pins':[
            Pin(num='A1',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='IO2_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO2_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO2_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO2_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='A15',name='IO2_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='IO2_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='IO2_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO2_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO2_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO2_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO2_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO2_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='IO2_B1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO2_B10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO2_B11',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO2_B12',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='IO2_B13',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO2_B14',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='B16',name='IO2_B16',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='IO2_B3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='IO2_B4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='IO2_B5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO2_B6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='IO2_B7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='IO2_B8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO2_B9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='IO2_C10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO2_C11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO2_C12',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO2_C13',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='IO1_C2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='IO1_C3',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='IO2_C4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO2_C5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO2_C6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO2_C7',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO2_C8',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO2_C9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='IO1_D1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO2_D10',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO2_D11',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO2_D12',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='IO1_D2',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='IO1_D3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='IO2_D4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='IO2_D5',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO2_D6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='IO2_D7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO2_D8',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO2_D9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='IO1_E1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='IO2_E10',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='IO2_E11',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='IO1_E2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='IO1_E3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='IO1_E4',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='IO1_E5',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='IO2_E6',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='IO2_E7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='IO2_E8',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='IO2_E9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='IO1_F1',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='IO1_F2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='IO1_F3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='IO1_F4',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='IO1_F5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='IO1_F6',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='IO1_G1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='IO1_G2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='IO1_G3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='IO1_G4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='IO1_G5',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='IO1_H1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='IO1_H2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='IO1_H3',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='IO1_H4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='IO1_H5/GCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='H8',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='IO1_J1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='IO1_J2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='IO1_J3',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='IO1_J4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='IO1_J5/GCLK1',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='IO1_K1',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='K2',name='IO1_K2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='IO1_K3',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='IO1_K4',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='IO1_K5',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='IO1_L1',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='L2',name='IO1_L2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='IO1_L3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='IO1_L4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='IO1_L5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='L7',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='IO1_M1',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='IO1_M2',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='IO1_M3',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='IO1_M4',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='N1',name='IO1_N1',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='IO1_N2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='IO1_N3',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='P1',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='P2',name='IO1_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='C14',name='IO3_C14',func=pin_types.BIDIR,unit=2),
            Pin(num='C15',name='IO3_C15',func=pin_types.BIDIR,unit=2),
            Pin(num='C16',name='VCCIO3',func=pin_types.PWRIN,unit=2),
            Pin(num='D13',name='IO3_D13',func=pin_types.BIDIR,unit=2),
            Pin(num='D14',name='IO3_D14',func=pin_types.BIDIR,unit=2),
            Pin(num='D15',name='IO3_D15',func=pin_types.BIDIR,unit=2),
            Pin(num='D16',name='IO3_D16',func=pin_types.BIDIR,unit=2),
            Pin(num='E12',name='IO3_E12',func=pin_types.BIDIR,unit=2),
            Pin(num='E13',name='IO3_E13',func=pin_types.BIDIR,unit=2),
            Pin(num='E14',name='IO3_E14',func=pin_types.BIDIR,unit=2),
            Pin(num='E15',name='IO3_E15',func=pin_types.BIDIR,unit=2),
            Pin(num='E16',name='IO3_E16',func=pin_types.BIDIR,unit=2),
            Pin(num='F11',name='IO3_F11',func=pin_types.BIDIR,unit=2),
            Pin(num='F12',name='IO3_F12',func=pin_types.BIDIR,unit=2),
            Pin(num='F13',name='IO3_F13',func=pin_types.BIDIR,unit=2),
            Pin(num='F14',name='IO3_F14',func=pin_types.BIDIR,unit=2),
            Pin(num='F15',name='IO3_F15',func=pin_types.BIDIR,unit=2),
            Pin(num='F16',name='IO3_F16',func=pin_types.BIDIR,unit=2),
            Pin(num='G10',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='G12',name='IO3_G12',func=pin_types.BIDIR,unit=2),
            Pin(num='G13',name='IO3_G13',func=pin_types.BIDIR,unit=2),
            Pin(num='G14',name='IO3_G14',func=pin_types.BIDIR,unit=2),
            Pin(num='G15',name='IO3_G15',func=pin_types.BIDIR,unit=2),
            Pin(num='G16',name='IO3_G16',func=pin_types.BIDIR,unit=2),
            Pin(num='G9',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='H11',name='VCCIO3',func=pin_types.PWRIN,unit=2),
            Pin(num='H12',name='IO3_H12/GCLK3',func=pin_types.BIDIR,unit=2),
            Pin(num='H13',name='IO3_H13',func=pin_types.BIDIR,unit=2),
            Pin(num='H14',name='IO3_H14',func=pin_types.BIDIR,unit=2),
            Pin(num='H15',name='IO3_H15',func=pin_types.BIDIR,unit=2),
            Pin(num='H16',name='IO3_H16',func=pin_types.BIDIR,unit=2),
            Pin(num='J11',name='VCCIO3',func=pin_types.PWRIN,unit=2),
            Pin(num='J12',name='IO3_J12/GCLK2',func=pin_types.BIDIR,unit=2),
            Pin(num='J13',name='IO3_J13',func=pin_types.BIDIR,unit=2),
            Pin(num='J14',name='IO3_J14',func=pin_types.BIDIR,unit=2),
            Pin(num='J15',name='IO3_J15',func=pin_types.BIDIR,unit=2),
            Pin(num='J16',name='IO3_J16',func=pin_types.BIDIR,unit=2),
            Pin(num='K10',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='K12',name='IO3_K12',func=pin_types.BIDIR,unit=2),
            Pin(num='K13',name='IO3_K13',func=pin_types.BIDIR,unit=2),
            Pin(num='K14',name='IO3_K14',func=pin_types.BIDIR,unit=2),
            Pin(num='K15',name='IO3_K15',func=pin_types.BIDIR,unit=2),
            Pin(num='K16',name='IO3_K16',func=pin_types.BIDIR,unit=2),
            Pin(num='K7',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='K8',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='K9',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='L11',name='IO3_L11',func=pin_types.BIDIR,unit=2),
            Pin(num='L12',name='IO3_L12',func=pin_types.BIDIR,unit=2),
            Pin(num='L13',name='IO3_L13',func=pin_types.BIDIR,unit=2),
            Pin(num='L14',name='IO3_L14',func=pin_types.BIDIR,unit=2),
            Pin(num='L15',name='IO3_L15',func=pin_types.BIDIR,unit=2),
            Pin(num='L16',name='IO3_L16',func=pin_types.BIDIR,unit=2),
            Pin(num='L8',name='VCCIO4',func=pin_types.PWRIN,unit=2),
            Pin(num='L9',name='VCCIO4',func=pin_types.PWRIN,unit=2),
            Pin(num='M10',name='IO4_M10',func=pin_types.BIDIR,unit=2),
            Pin(num='M11',name='IO4_M11',func=pin_types.BIDIR,unit=2),
            Pin(num='M12',name='IO4_M12',func=pin_types.BIDIR,unit=2),
            Pin(num='M13',name='IO3_M13',func=pin_types.BIDIR,unit=2),
            Pin(num='M14',name='IO3_M14',func=pin_types.BIDIR,unit=2),
            Pin(num='M15',name='IO3_M15',func=pin_types.BIDIR,unit=2),
            Pin(num='M16',name='IO3_M16',func=pin_types.BIDIR,unit=2),
            Pin(num='M6',name='IO4_M6',func=pin_types.BIDIR,unit=2),
            Pin(num='M7',name='IO4_M7',func=pin_types.BIDIR,unit=2),
            Pin(num='M8',name='IO4_M8/DEV_OE',func=pin_types.BIDIR,unit=2),
            Pin(num='M9',name='IO4_M9/DEV_CLRn',func=pin_types.BIDIR,unit=2),
            Pin(num='N10',name='IO4_N10',func=pin_types.BIDIR,unit=2),
            Pin(num='N11',name='IO4_N11',func=pin_types.BIDIR,unit=2),
            Pin(num='N12',name='IO4_N12',func=pin_types.BIDIR,unit=2),
            Pin(num='N13',name='IO3_N13',func=pin_types.BIDIR,unit=2),
            Pin(num='N14',name='IO3_N14',func=pin_types.BIDIR,unit=2),
            Pin(num='N15',name='IO3_N15',func=pin_types.BIDIR,unit=2),
            Pin(num='N16',name='IO3_N16',func=pin_types.BIDIR,unit=2),
            Pin(num='N5',name='IO4_N5',func=pin_types.BIDIR,unit=2),
            Pin(num='N6',name='IO4_N6',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO4_N7',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO4_N8',func=pin_types.BIDIR,unit=2),
            Pin(num='N9',name='IO4_N9',func=pin_types.BIDIR,unit=2),
            Pin(num='P10',name='IO4_P10',func=pin_types.BIDIR,unit=2),
            Pin(num='P11',name='IO4_P11',func=pin_types.BIDIR,unit=2),
            Pin(num='P12',name='IO4_P12',func=pin_types.BIDIR,unit=2),
            Pin(num='P13',name='IO4_P13',func=pin_types.BIDIR,unit=2),
            Pin(num='P14',name='IO3_P14',func=pin_types.BIDIR,unit=2),
            Pin(num='P15',name='IO3_P15',func=pin_types.BIDIR,unit=2),
            Pin(num='P16',name='VCCIO3',func=pin_types.PWRIN,unit=2),
            Pin(num='P4',name='IO4_P4',func=pin_types.BIDIR,unit=2),
            Pin(num='P5',name='IO4_P5',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO4_P6',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO4_P7',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO4_P8',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='IO4_P9',func=pin_types.BIDIR,unit=2),
            Pin(num='R1',name='IO4_R1',func=pin_types.BIDIR,unit=2),
            Pin(num='R10',name='IO4_R10',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO4_R11',func=pin_types.BIDIR,unit=2),
            Pin(num='R12',name='IO4_R12',func=pin_types.BIDIR,unit=2),
            Pin(num='R13',name='IO4_R13',func=pin_types.BIDIR,unit=2),
            Pin(num='R14',name='IO4_R14',func=pin_types.BIDIR,unit=2),
            Pin(num='R15',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='R16',name='IO4_R16',func=pin_types.BIDIR,unit=2),
            Pin(num='R2',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='R3',name='IO4_R3',func=pin_types.BIDIR,unit=2),
            Pin(num='R4',name='IO4_R4',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO4_R5',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO4_R6',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO4_R7',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO4_R8',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO4_R9',func=pin_types.BIDIR,unit=2),
            Pin(num='T1',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='T10',name='IO4_T10',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO4_T11',func=pin_types.BIDIR,unit=2),
            Pin(num='T12',name='IO4_T12',func=pin_types.BIDIR,unit=2),
            Pin(num='T13',name='IO4_T13',func=pin_types.BIDIR,unit=2),
            Pin(num='T14',name='VCCIO4',func=pin_types.PWRIN,unit=2),
            Pin(num='T15',name='IO4_T15',func=pin_types.BIDIR,unit=2),
            Pin(num='T16',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='T2',name='IO4_T2',func=pin_types.BIDIR,unit=2),
            Pin(num='T3',name='VCCIO4',func=pin_types.PWRIN,unit=2),
            Pin(num='T4',name='IO4_T4',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO4_T5',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO4_T6',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO4_T7',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO4_T8',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='IO4_T9',func=pin_types.BIDIR,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['N2', 'E7', 'C10', 'J1', 'N3', 'E8', 'C11', 'J10', 'N4', 'A10', 'C12', 'E9', 'J2', 'P1', 'A11', 'F1', 'C13', 'A1', 'J3', 'P2', 'A13', 'C2', 'F10', 'J4', 'P3', 'A14', 'C3', 'F2', 'J5', 'A15', 'C4', 'F3', 'A16', 'J6', 'F4', 'A2', 'C5', 'A3', 'J7', 'C6', 'F5', 'J8', 'A4', 'C7', 'F6', 'J9', 'A5', 'C8', 'F7', 'K1', 'A6', 'C9', 'F8', 'K11', 'A7', 'D1', 'F9', 'K2', 'A8', 'D10', 'G1', 'K3', 'A9', 'D11', 'G11', 'K4', 'B1', 'D12', 'G2', 'K5', 'B10', 'D2', 'G3', 'K6', 'B11', 'D3', 'G4', 'L1', 'B12', 'D4', 'G5', 'L10', 'B13', 'D5', 'G6', 'L2', 'B14', 'D6', 'G7', 'L3', 'B15', 'D7', 'G8', 'L4', 'B16', 'D8', 'H1', 'L5', 'B2', 'D9', 'H10', 'L6', 'B3', 'E1', 'H2', 'L7', 'B4', 'E10', 'H3', 'M1', 'E6', 'B5', 'E11', 'H4', 'M2', 'B6', 'E2', 'H5', 'M3', 'B7', 'E3', 'H6', 'M4', 'B8', 'A12', 'E4', 'H7', 'M5', 'B9', 'E5', 'H8', 'N1', 'C1', 'H9']},{'label': 'uB', 'num': 2, 'pin_nums': ['H12', 'M14', 'R1', 'M15', 'H13', 'R10', 'H14', 'M16', 'R11', 'M13', 'M6', 'H15', 'R12', 'H16', 'M7', 'R13', 'J11', 'M8', 'R14', 'C14', 'J12', 'M9', 'R15', 'C15', 'J13', 'N10', 'R16', 'C16', 'J14', 'N11', 'R2', 'D13', 'J15', 'N12', 'R3', 'D14', 'J16', 'N13', 'R4', 'D15', 'K10', 'N14', 'R5', 'D16', 'K12', 'N15', 'R6', 'E12', 'K13', 'N16', 'R7', 'E13', 'K14', 'N5', 'R8', 'E14', 'K15', 'N6', 'R9', 'E15', 'K16', 'N7', 'T1', 'E16', 'K7', 'N8', 'T10', 'F11', 'K8', 'N9', 'T11', 'F12', 'K9', 'P10', 'T12', 'F13', 'L11', 'P11', 'T13', 'F14', 'L12', 'P12', 'T14', 'F15', 'L13', 'P13', 'T15', 'F16', 'L14', 'P14', 'T16', 'G10', 'L15', 'P15', 'T2', 'G12', 'L16', 'P16', 'T3', 'G13', 'L8', 'P4', 'T4', 'G14', 'L9', 'P5', 'T5', 'G15', 'M10', 'P6', 'T6', 'G16', 'M11', 'P7', 'T7', 'G9', 'M12', 'P8', 'T8', 'H11', 'P9', 'T9']}] }),
        Part(**{ 'name':'EPM2210F324', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EPM2210F324'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-324_19.0x19.0mm_Layout18x18_P1.0mm_Ball0.5mm_Pad0.4mm_NSMD'], 'footprint':'Package_BGA:BGA-324_19.0x19.0mm_Layout18x18_P1.0mm_Ball0.5mm_Pad0.4mm_NSMD', 'keywords':'MAX2 FBGA', 'description':'', 'datasheet':'https://www.altera.com/content/dam/altera-www/global/en_US/pdfs/literature/hb/max2/max2_mii5v1.pdf', 'search_text':'/usr/share/kicad/symbols/CPLD_Altera.kicad_sym\nEPM2210F324\n\nMAX2 FBGA', 'pins':[
            Pin(num='A1',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='IO2_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO2_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO2_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO2_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO2_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO2_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='A17',name='IO2_A17',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='IO2_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='IO2_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO2_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO2_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO2_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO2_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO2_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='IO2_B1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO2_B10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO2_B11',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO2_B12',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='IO2_B13',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO2_B14',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO2_B15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='IO2_B16',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='B18',name='IO2_B18',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='IO2_B3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='IO2_B4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='IO2_B5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO2_B6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='IO2_B7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='IO2_B8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO2_B9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='IO2_C10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO2_C11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO2_C12',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO2_C13',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO2_C14',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO2_C15',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='IO1_C2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='IO1_C3',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='IO2_C4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO2_C5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO2_C6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO2_C7',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO2_C8',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO2_C9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='IO1_D1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO2_D10',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO2_D11',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO2_D12',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO2_D13',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO2_D14',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='IO1_D2',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='IO1_D3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='IO1_D4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='IO2_D5',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='IO2_D6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='IO2_D7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='IO2_D8',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO2_D9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='IO1_E1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='IO2_E10',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='IO2_E11',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='IO2_E12',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='IO2_E13',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='IO1_E2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='IO1_E3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='IO1_E4',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='IO1_E5',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='IO2_E6',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='IO2_E7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='IO2_E8',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='IO2_E9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='IO1_F1',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO2_F10',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='IO2_F11',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='IO2_F12',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='IO1_F2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='IO1_F3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='IO1_F4',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='IO1_F5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='IO1_F6',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='IO2_F7',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='IO2_F8',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO2_F9',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='IO1_G1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='IO1_G2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='IO1_G3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='IO1_G4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='IO1_G5',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='IO1_G6',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='IO1_G7',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='IO1_H1',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='IO1_H2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='IO1_H3',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='IO1_H4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='IO1_H5',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='IO1_H6',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='H8',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='IO1_J1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='IO1_J2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='IO1_J3',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='IO1_J4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='IO1_J5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='IO1_J6/GCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='IO1_K1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='K11',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='K2',name='IO1_K2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='IO1_K3',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='IO1_K4',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='IO1_K5',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='IO1_K6/GCLK1',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='K8',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='IO1_L1',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='L2',name='IO1_L2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='IO1_L3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='IO1_L4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='IO1_L5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='IO1_L6',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='IO1_M1',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='M2',name='IO1_M2',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='IO1_M3',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='IO1_M4',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='IO1_M5',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='IO1_M6',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='M8',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='IO1_N1',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='IO1_N2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='IO1_N3',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='IO1_N4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='IO1_N5',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='P1',name='IO1_P1',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='IO1_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='IO1_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='P4',name='IO1_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='R1',name='IO1_R1',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='IO1_R2',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='IO1_R3',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='T1',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='T2',name='IO1_T2',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='IO1_T3',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO3_C16',func=pin_types.BIDIR,unit=2),
            Pin(num='C17',name='IO3_C17',func=pin_types.BIDIR,unit=2),
            Pin(num='C18',name='VCCIO3',func=pin_types.PWRIN,unit=2),
            Pin(num='D15',name='IO3_D15',func=pin_types.BIDIR,unit=2),
            Pin(num='D16',name='IO3_D16',func=pin_types.BIDIR,unit=2),
            Pin(num='D17',name='IO3_D17',func=pin_types.BIDIR,unit=2),
            Pin(num='D18',name='IO3_D18',func=pin_types.BIDIR,unit=2),
            Pin(num='E14',name='IO3_E14',func=pin_types.BIDIR,unit=2),
            Pin(num='E15',name='IO3_E15',func=pin_types.BIDIR,unit=2),
            Pin(num='E16',name='IO3_E16',func=pin_types.BIDIR,unit=2),
            Pin(num='E17',name='IO3_E17',func=pin_types.BIDIR,unit=2),
            Pin(num='E18',name='IO3_E18',func=pin_types.BIDIR,unit=2),
            Pin(num='F13',name='IO3_F13',func=pin_types.BIDIR,unit=2),
            Pin(num='F14',name='IO3_F14',func=pin_types.BIDIR,unit=2),
            Pin(num='F15',name='IO3_F15',func=pin_types.BIDIR,unit=2),
            Pin(num='F16',name='IO3_F16',func=pin_types.BIDIR,unit=2),
            Pin(num='F17',name='IO3_F17',func=pin_types.BIDIR,unit=2),
            Pin(num='F18',name='IO3_F18',func=pin_types.BIDIR,unit=2),
            Pin(num='G12',name='IO3_G12',func=pin_types.BIDIR,unit=2),
            Pin(num='G13',name='IO3_G13',func=pin_types.BIDIR,unit=2),
            Pin(num='G14',name='IO3_G14',func=pin_types.BIDIR,unit=2),
            Pin(num='G15',name='IO3_G15',func=pin_types.BIDIR,unit=2),
            Pin(num='G16',name='IO3_G16',func=pin_types.BIDIR,unit=2),
            Pin(num='G17',name='IO3_G17',func=pin_types.BIDIR,unit=2),
            Pin(num='G18',name='IO3_G18',func=pin_types.BIDIR,unit=2),
            Pin(num='H10',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='H11',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='H13',name='IO3_H13',func=pin_types.BIDIR,unit=2),
            Pin(num='H14',name='IO3_H14',func=pin_types.BIDIR,unit=2),
            Pin(num='H15',name='IO3_H15',func=pin_types.BIDIR,unit=2),
            Pin(num='H16',name='IO3_H16',func=pin_types.BIDIR,unit=2),
            Pin(num='H17',name='IO3_H17',func=pin_types.BIDIR,unit=2),
            Pin(num='H18',name='IO3_H18',func=pin_types.BIDIR,unit=2),
            Pin(num='J12',name='VCCIO3',func=pin_types.PWRIN,unit=2),
            Pin(num='J13',name='IO3_J13/GCLK3',func=pin_types.BIDIR,unit=2),
            Pin(num='J14',name='IO3_J14',func=pin_types.BIDIR,unit=2),
            Pin(num='J15',name='IO3_J15',func=pin_types.BIDIR,unit=2),
            Pin(num='J16',name='IO3_J16',func=pin_types.BIDIR,unit=2),
            Pin(num='J17',name='IO3_J17',func=pin_types.BIDIR,unit=2),
            Pin(num='J18',name='IO3_J18',func=pin_types.BIDIR,unit=2),
            Pin(num='K12',name='VCCIO3',func=pin_types.PWRIN,unit=2),
            Pin(num='K13',name='IO3_K13/GCLK2',func=pin_types.BIDIR,unit=2),
            Pin(num='K14',name='IO3_K14',func=pin_types.BIDIR,unit=2),
            Pin(num='K15',name='IO3_K15',func=pin_types.BIDIR,unit=2),
            Pin(num='K16',name='IO3_K16',func=pin_types.BIDIR,unit=2),
            Pin(num='K17',name='IO3_K17',func=pin_types.BIDIR,unit=2),
            Pin(num='K18',name='IO3_K18',func=pin_types.BIDIR,unit=2),
            Pin(num='L10',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='L11',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='L13',name='IO3_L13',func=pin_types.BIDIR,unit=2),
            Pin(num='L14',name='IO3_L14',func=pin_types.BIDIR,unit=2),
            Pin(num='L15',name='IO3_L15',func=pin_types.BIDIR,unit=2),
            Pin(num='L16',name='IO3_L16',func=pin_types.BIDIR,unit=2),
            Pin(num='L17',name='IO3_L17',func=pin_types.BIDIR,unit=2),
            Pin(num='L18',name='IO3_L18',func=pin_types.BIDIR,unit=2),
            Pin(num='L8',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='L9',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='M10',name='VCCIO4',func=pin_types.PWRIN,unit=2),
            Pin(num='M12',name='IO3_M12',func=pin_types.BIDIR,unit=2),
            Pin(num='M13',name='IO3_M13',func=pin_types.BIDIR,unit=2),
            Pin(num='M14',name='IO3_M14',func=pin_types.BIDIR,unit=2),
            Pin(num='M15',name='IO3_M15',func=pin_types.BIDIR,unit=2),
            Pin(num='M16',name='IO3_M16',func=pin_types.BIDIR,unit=2),
            Pin(num='M17',name='IO3_M17',func=pin_types.BIDIR,unit=2),
            Pin(num='M18',name='IO3_M18',func=pin_types.BIDIR,unit=2),
            Pin(num='M9',name='VCCIO4',func=pin_types.PWRIN,unit=2),
            Pin(num='N10',name='IO4_N10/DEV_CLRn',func=pin_types.BIDIR,unit=2),
            Pin(num='N11',name='IO4_N11',func=pin_types.BIDIR,unit=2),
            Pin(num='N12',name='IO4_N12',func=pin_types.BIDIR,unit=2),
            Pin(num='N13',name='IO3_N13',func=pin_types.BIDIR,unit=2),
            Pin(num='N14',name='IO3_N14',func=pin_types.BIDIR,unit=2),
            Pin(num='N15',name='IO3_N15',func=pin_types.BIDIR,unit=2),
            Pin(num='N16',name='IO3_N16',func=pin_types.BIDIR,unit=2),
            Pin(num='N17',name='IO3_N17',func=pin_types.BIDIR,unit=2),
            Pin(num='N18',name='IO3_N18',func=pin_types.BIDIR,unit=2),
            Pin(num='N7',name='IO4_N7',func=pin_types.BIDIR,unit=2),
            Pin(num='N8',name='IO4_N8',func=pin_types.BIDIR,unit=2),
            Pin(num='N9',name='IO4_N9/DEV_OE',func=pin_types.BIDIR,unit=2),
            Pin(num='P10',name='IO4_P10',func=pin_types.BIDIR,unit=2),
            Pin(num='P11',name='IO4_P11',func=pin_types.BIDIR,unit=2),
            Pin(num='P12',name='IO4_P12',func=pin_types.BIDIR,unit=2),
            Pin(num='P13',name='IO4_P13',func=pin_types.BIDIR,unit=2),
            Pin(num='P14',name='IO3_P14',func=pin_types.BIDIR,unit=2),
            Pin(num='P15',name='IO3_P15',func=pin_types.BIDIR,unit=2),
            Pin(num='P16',name='IO3_P16',func=pin_types.BIDIR,unit=2),
            Pin(num='P17',name='IO3_P17',func=pin_types.BIDIR,unit=2),
            Pin(num='P18',name='IO3_P18',func=pin_types.BIDIR,unit=2),
            Pin(num='P6',name='IO4_P6',func=pin_types.BIDIR,unit=2),
            Pin(num='P7',name='IO4_P7',func=pin_types.BIDIR,unit=2),
            Pin(num='P8',name='IO4_P8',func=pin_types.BIDIR,unit=2),
            Pin(num='P9',name='IO4_P9',func=pin_types.BIDIR,unit=2),
            Pin(num='R10',name='IO4_R10',func=pin_types.BIDIR,unit=2),
            Pin(num='R11',name='IO4_R11',func=pin_types.BIDIR,unit=2),
            Pin(num='R12',name='IO4_R12',func=pin_types.BIDIR,unit=2),
            Pin(num='R13',name='IO4_R13',func=pin_types.BIDIR,unit=2),
            Pin(num='R14',name='IO4_R14',func=pin_types.BIDIR,unit=2),
            Pin(num='R15',name='IO3_R15',func=pin_types.BIDIR,unit=2),
            Pin(num='R16',name='IO3_R16',func=pin_types.BIDIR,unit=2),
            Pin(num='R17',name='IO3_R17',func=pin_types.BIDIR,unit=2),
            Pin(num='R18',name='IO3_R18',func=pin_types.BIDIR,unit=2),
            Pin(num='R5',name='IO4_R5',func=pin_types.BIDIR,unit=2),
            Pin(num='R6',name='IO4_R6',func=pin_types.BIDIR,unit=2),
            Pin(num='R7',name='IO4_R7',func=pin_types.BIDIR,unit=2),
            Pin(num='R8',name='IO4_R8',func=pin_types.BIDIR,unit=2),
            Pin(num='R9',name='IO4_R9',func=pin_types.BIDIR,unit=2),
            Pin(num='T10',name='IO4_T10',func=pin_types.BIDIR,unit=2),
            Pin(num='T11',name='IO4_T11',func=pin_types.BIDIR,unit=2),
            Pin(num='T12',name='IO4_T12',func=pin_types.BIDIR,unit=2),
            Pin(num='T13',name='IO4_T13',func=pin_types.BIDIR,unit=2),
            Pin(num='T14',name='IO4_T14',func=pin_types.BIDIR,unit=2),
            Pin(num='T15',name='IO4_T15',func=pin_types.BIDIR,unit=2),
            Pin(num='T16',name='IO3_T16',func=pin_types.BIDIR,unit=2),
            Pin(num='T17',name='IO3_T17',func=pin_types.BIDIR,unit=2),
            Pin(num='T18',name='VCCIO3',func=pin_types.PWRIN,unit=2),
            Pin(num='T4',name='IO4_T4',func=pin_types.BIDIR,unit=2),
            Pin(num='T5',name='IO4_T5',func=pin_types.BIDIR,unit=2),
            Pin(num='T6',name='IO4_T6',func=pin_types.BIDIR,unit=2),
            Pin(num='T7',name='IO4_T7',func=pin_types.BIDIR,unit=2),
            Pin(num='T8',name='IO4_T8',func=pin_types.BIDIR,unit=2),
            Pin(num='T9',name='IO4_T9',func=pin_types.BIDIR,unit=2),
            Pin(num='U1',name='IO4_U1',func=pin_types.BIDIR,unit=2),
            Pin(num='U10',name='IO4_U10',func=pin_types.BIDIR,unit=2),
            Pin(num='U11',name='IO4_U11',func=pin_types.BIDIR,unit=2),
            Pin(num='U12',name='IO4_U12',func=pin_types.BIDIR,unit=2),
            Pin(num='U13',name='IO4_U13',func=pin_types.BIDIR,unit=2),
            Pin(num='U14',name='IO4_U14',func=pin_types.BIDIR,unit=2),
            Pin(num='U15',name='IO4_U15',func=pin_types.BIDIR,unit=2),
            Pin(num='U16',name='IO4_U16',func=pin_types.BIDIR,unit=2),
            Pin(num='U17',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='U18',name='IO4_U18',func=pin_types.BIDIR,unit=2),
            Pin(num='U2',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='U3',name='IO4_U3',func=pin_types.BIDIR,unit=2),
            Pin(num='U4',name='IO4_U4',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='IO4_U5',func=pin_types.BIDIR,unit=2),
            Pin(num='U6',name='IO4_U6',func=pin_types.BIDIR,unit=2),
            Pin(num='U7',name='IO4_U7',func=pin_types.BIDIR,unit=2),
            Pin(num='U8',name='IO4_U8',func=pin_types.BIDIR,unit=2),
            Pin(num='U9',name='IO4_U9',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='V10',name='IO4_V10',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='IO4_V11',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='IO4_V12',func=pin_types.BIDIR,unit=2),
            Pin(num='V13',name='IO4_V13',func=pin_types.BIDIR,unit=2),
            Pin(num='V14',name='IO4_V14',func=pin_types.BIDIR,unit=2),
            Pin(num='V15',name='IO4_V15',func=pin_types.BIDIR,unit=2),
            Pin(num='V16',name='VCCIO4',func=pin_types.PWRIN,unit=2),
            Pin(num='V17',name='IO4_V17',func=pin_types.BIDIR,unit=2),
            Pin(num='V18',name='GNDIO',func=pin_types.PWRIN,unit=2),
            Pin(num='V2',name='IO4_V2',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='VCCIO4',func=pin_types.PWRIN,unit=2),
            Pin(num='V4',name='IO4_V4',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='IO4_V5',func=pin_types.BIDIR,unit=2),
            Pin(num='V6',name='IO4_V6',func=pin_types.BIDIR,unit=2),
            Pin(num='V7',name='IO4_V7',func=pin_types.BIDIR,unit=2),
            Pin(num='V8',name='IO4_V8',func=pin_types.BIDIR,unit=2),
            Pin(num='V9',name='IO4_V9',func=pin_types.BIDIR,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['D4', 'K10', 'N6', 'B2', 'D5', 'G11', 'K11', 'P1', 'A1', 'B3', 'D6', 'G2', 'K2', 'P2', 'B4', 'D7', 'G3', 'K3', 'P3', 'B5', 'D8', 'G4', 'K4', 'P4', 'B6', 'D9', 'G5', 'K5', 'A11', 'P5', 'A12', 'B7', 'E1', 'G6', 'K6', 'R1', 'B8', 'E10', 'G7', 'K7', 'R2', 'A10', 'B9', 'E11', 'G8', 'K8', 'R3', 'C1', 'E12', 'G9', 'K9', 'R4', 'A13', 'C10', 'E13', 'H1', 'L1', 'T1', 'A14', 'C11', 'E2', 'H12', 'L12', 'A15', 'T2', 'C12', 'E3', 'A16', 'H2', 'L2', 'T3', 'A17', 'C13', 'E4', 'A18', 'H3', 'L3', 'C14', 'E5', 'H4', 'L4', 'A2', 'C15', 'E6', 'H5', 'L5', 'A3', 'C2', 'E7', 'H6', 'L6', 'A4', 'C3', 'E8', 'H7', 'L7', 'A5', 'C4', 'E9', 'H8', 'M1', 'A6', 'C5', 'F1', 'H9', 'M11', 'A7', 'C6', 'F10', 'J1', 'M2', 'A8', 'C7', 'F11', 'J10', 'M3', 'A9', 'C8', 'F12', 'J11', 'M4', 'B1', 'C9', 'F2', 'J2', 'M5', 'B10', 'D1', 'F3', 'J3', 'M6', 'B11', 'D10', 'F4', 'J4', 'M7', 'B12', 'D11', 'F5', 'J5', 'M8', 'B13', 'D12', 'F6', 'J6', 'N1', 'B14', 'D13', 'F7', 'J7', 'N2', 'B15', 'D14', 'F8', 'J8', 'N3', 'B16', 'D2', 'F9', 'G10', 'J9', 'N4', 'B17', 'D3', 'G1', 'K1', 'N5', 'B18']},{'label': 'uB', 'num': 2, 'pin_nums': ['P14', 'V17', 'G13', 'L15', 'P15', 'T5', 'V18', 'G14', 'L16', 'P16', 'T6', 'V2', 'G15', 'L17', 'P17', 'T7', 'V3', 'G16', 'L18', 'P18', 'T8', 'V4', 'G17', 'L8', 'P6', 'T9', 'V5', 'G18', 'L9', 'P7', 'U1', 'V6', 'H10', 'M10', 'P8', 'U10', 'V7', 'H11', 'M12', 'P9', 'U11', 'V8', 'H13', 'M13', 'R10', 'U12', 'V9', 'H14', 'M14', 'R11', 'U13', 'H15', 'M15', 'R12', 'U14', 'H16', 'M16', 'R13', 'U15', 'H17', 'M17', 'R14', 'U16', 'C16', 'H18', 'M18', 'R15', 'U17', 'C17', 'J12', 'M9', 'R16', 'U18', 'J13', 'C18', 'N10', 'R17', 'U2', 'D15', 'J14', 'N11', 'R18', 'U3', 'D16', 'J15', 'N12', 'R5', 'U4', 'D17', 'J16', 'N13', 'R6', 'U5', 'D18', 'J17', 'N14', 'R7', 'U6', 'E14', 'J18', 'N15', 'R8', 'U7', 'E15', 'K12', 'N16', 'R9', 'U8', 'E16', 'K13', 'N17', 'T10', 'U9', 'K14', 'E17', 'N18', 'T11', 'V1', 'E18', 'K15', 'N7', 'T12', 'L14', 'V10', 'F13', 'K16', 'N8', 'T13', 'V11', 'F14', 'K17', 'N9', 'T14', 'V12', 'F15', 'K18', 'P10', 'T15', 'V13', 'F16', 'L10', 'P11', 'T16', 'V14', 'F17', 'L11', 'P12', 'T17', 'T4', 'V15', 'F18', 'L13', 'P13', 'T18', 'V16', 'G12']}] }),
        Part(**{ 'name':'EPM240F100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EPM240F100'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-100_11.0x11.0mm_Layout10x10_P1.0mm_Ball0.5mm_Pad0.4mm_NSMD'], 'footprint':'Package_BGA:BGA-100_11.0x11.0mm_Layout10x10_P1.0mm_Ball0.5mm_Pad0.4mm_NSMD', 'keywords':'MAX2 FBGA', 'description':'', 'datasheet':'https://www.altera.com/content/dam/altera-www/global/en_US/pdfs/literature/hb/max2/max2_mii5v1.pdf', 'search_text':'/usr/share/kicad/symbols/CPLD_Altera.kicad_sym\nEPM240F100\n\nMAX2 FBGA', 'pins':[
            Pin(num='A1',name='IO2_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='IO2_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO2_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO2_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO2_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO2_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO2_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO2_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO2_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO2_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='IO1_B1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO2_B10',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='IO2_B2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO2_B3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='IO2_B4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='IO2_B5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO2_B6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='IO2_B7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='IO2_B8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO2_B9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='IO1_C1',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO2_C10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='IO1_C2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='IO2_C3',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='IO2_C4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO2_C5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO2_C6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO2_C7',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO2_C8',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO2_C9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='IO1_D1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO2_D10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='IO1_D2',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='IO1_D3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='IO2_D8',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO2_D9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='IO1_E1/GCLK1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='IO2_E10/GCLK3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='IO1_E2/GCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='IO1_E3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='IO2_E8',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='IO2_E9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='IO1_F1',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO2_F10',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='IO1_F2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='IO1_F3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='IO2_F8/GCLK2',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO2_F9',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='IO1_G1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='IO2_G10',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='IO1_G2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='IO1_G3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='G5',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='IO2_G8',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO2_G9',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='IO1_H1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='IO2_H10',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='H4',name='IO1_H4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='IO1_H5',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='IO1_H6',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='IO1_H7',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='IO1_H8',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='IO2_H9',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='IO2_J10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='J3',name='IO1_J3',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='IO1_J4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='IO1_J5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='IO1_J6',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='IO1_J7/DEV_OE',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='IO1_J8',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='IO1_J9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='IO1_K1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='IO1_K10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='IO1_K2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='IO1_K3',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='IO1_K4',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='IO1_K5',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='IO1_K6',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='IO1_K7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='IO1_K8',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='IO1_K9/DEV_CLRn',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EPM240M100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EPM240M100'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-100_6.0x6.0mm_Layout11x11_P0.5mm_Ball0.3mm_Pad0.25mm_NSMD'], 'footprint':'Package_BGA:BGA-100_6.0x6.0mm_Layout11x11_P0.5mm_Ball0.3mm_Pad0.25mm_NSMD', 'keywords':'MAX2 MBGA', 'description':'', 'datasheet':'https://www.altera.com/content/dam/altera-www/global/en_US/pdfs/literature/hb/max2/max2_mii5v1.pdf', 'search_text':'/usr/share/kicad/symbols/CPLD_Altera.kicad_sym\nEPM240M100\n\nMAX2 MBGA', 'pins':[
            Pin(num='A1',name='IO2_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='IO2_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO2_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO2_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO2_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO2_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO2_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO2_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO2_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO2_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO2_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='IO1_B1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO2_B10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO2_B11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='IO2_B2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO2_B3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='IO2_B4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='IO2_B5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO2_B6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='IO2_B7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='IO2_B8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO2_B9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='IO1_C1',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO2_C10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO2_C11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='IO1_C2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='IO2_C5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO2_C6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO2_C7',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='IO1_D1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO2_D10',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO2_D11',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='IO1_D2',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='IO1_D3',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='D9',name='IO2_D9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='IO1_E1/GCLK1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='IO2_E10',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='IO2_E11',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='IO1_E2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='IO1_F1',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO2_F10/GCLK2',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='IO2_F11',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='IO1_F2/GCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='IO1_F3',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO2_F9',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='IO1_G1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='IO2_G10',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO2_G11/GCLK3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='IO1_G2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='IO1_H1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='IO2_H10',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO2_H11',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='IO1_H2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='IO1_H3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='IO2_H9',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='IO2_J10',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='IO2_J11',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='J4',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='IO1_J5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='IO1_J6',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='IO1_J7',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='IO1_K10',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='IO2_K11',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='K3',name='IO1_K3',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='IO1_K4',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='IO1_K5',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='IO1_K6',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='IO1_K7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='IO1_K8/DEV_CLRn',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='IO1_K9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='IO1_L1',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='IO1_L10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='IO1_L11',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='IO1_L2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='IO1_L3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='IO1_L4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='IO1_L5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='IO1_L6',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='IO1_L7',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='IO1_L8/DEV_OE',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='IO1_L9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EPM240T100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EPM240T100'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'MAX2 TQFP', 'description':'', 'datasheet':'https://www.altera.com/content/dam/altera-www/global/en_US/pdfs/literature/hb/max2/max2_mii5v1.pdf', 'search_text':'/usr/share/kicad/symbols/CPLD_Altera.kicad_sym\nEPM240T100\n\nMAX2 TQFP', 'pins':[
            Pin(num='1',name='IO2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='IO2_100',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='IO1_12/GCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='IO1_14/GCLK1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='IO1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='IO1_16',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='IO1_17',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='IO1_18',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='IO1_19',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='IO1_20',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='IO1_21',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='IO1_26',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='IO1_27',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='IO1_28',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='IO1_29',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='IO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='IO1_30',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='IO1_33',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='IO1_34',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='IO1_35',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='IO1_36',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='IO1_37',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='IO1_38',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='IO1_39',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='IO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='IO1_40',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='IO1_41',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='IO1_42',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='IO1_43/DEV_OE',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='IO1_44/DEV_CLRn',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='IO1_47',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='IO1_48',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='IO1_49',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='IO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='IO1_50',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='IO1_51',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='IO2_52',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='IO2_53',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='IO2_54',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='IO2_55',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='IO2_56',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='IO2_57',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='IO2_58',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='IO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='61',name='IO2_61',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='IO2_62/GCLK2',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='IO2_64/GCLK3',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='66',name='IO2_66',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='IO2_67',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='IO2_68',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='IO2_69',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='IO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='IO2_70',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='IO2_71',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='IO2_72',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='IO2_73',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='IO2_74',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='IO2_75',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='IO2_76',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='IO2_77',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='IO2_78',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='IO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='81',name='IO2_81',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='IO2_82',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='IO2_83',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='IO2_84',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='IO2_85',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='IO2_86',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='IO2_87',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='IO2_88',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='IO2_89',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='90',name='IO2_90',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='IO2_91',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='IO2_92',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='94',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='IO2_95',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='IO2_96',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='IO2_97',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='IO2_98',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='IO2_99',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EPM240ZM100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EPM240ZM100'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-100_6.0x6.0mm_Layout11x11_P0.5mm_Ball0.3mm_Pad0.25mm_NSMD'], 'footprint':'Package_BGA:BGA-100_6.0x6.0mm_Layout11x11_P0.5mm_Ball0.3mm_Pad0.25mm_NSMD', 'keywords':'MAX2 MBGA', 'description':'', 'datasheet':'https://www.altera.com/content/dam/altera-www/global/en_US/pdfs/literature/hb/max2/max2_mii5v1.pdf', 'search_text':'/usr/share/kicad/symbols/CPLD_Altera.kicad_sym\nEPM240ZM100\n\nMAX2 MBGA', 'pins':[
            Pin(num='A1',name='IO2_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='IO2_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO2_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO2_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO2_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO2_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO2_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO2_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO2_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO2_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO2_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='IO1_B1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO2_B10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO2_B11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='IO2_B2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO2_B3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='IO2_B4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='IO2_B5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO2_B6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='IO2_B7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='IO2_B8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO2_B9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='IO1_C1',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO2_C10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO2_C11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='IO1_C2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='IO2_C5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO2_C6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO2_C7',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='IO1_D1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO2_D10',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO2_D11',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='IO1_D2',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='IO1_D3',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='D9',name='IO2_D9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='IO1_E1/GCLK1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='IO2_E10',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='IO2_E11',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='IO1_E2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='IO1_F1',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO2_F10/GCLK2',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='IO2_F11',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='IO1_F2/GCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='IO1_F3',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO2_F9',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='IO1_G1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='IO2_G10',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO2_G11/GCLK3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='IO1_G2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='IO1_H1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='IO2_H10',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO2_H11',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='IO1_H2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='IO1_H3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='IO2_H9',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='IO2_J10',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='IO2_J11',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='J4',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='IO1_J5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='IO1_J6',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='IO1_J7',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='IO1_K10',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='IO2_K11',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='K3',name='IO1_K3',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='IO1_K4',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='IO1_K5',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='IO1_K6',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='IO1_K7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='IO1_K8/DEV_CLRn',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='IO1_K9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='IO1_L1',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='IO1_L10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='IO1_L11',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='IO1_L2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='IO1_L3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='IO1_L4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='IO1_L5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='IO1_L6',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='IO1_L7',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='IO1_L8/DEV_OE',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='IO1_L9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EPM240ZM68', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EPM240ZM68'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-68_5.0x5.0mm_Layout9x9_P0.5mm_Ball0.3mm_Pad0.25mm_NSMD'], 'footprint':'Package_BGA:BGA-68_5.0x5.0mm_Layout9x9_P0.5mm_Ball0.3mm_Pad0.25mm_NSMD', 'keywords':'MAX2 MBGA', 'description':'', 'datasheet':'https://www.altera.com/content/dam/altera-www/global/en_US/pdfs/literature/hb/max2/max2_mii5v1.pdf', 'search_text':'/usr/share/kicad/symbols/CPLD_Altera.kicad_sym\nEPM240ZM68\n\nMAX2 MBGA', 'pins':[
            Pin(num='A1',name='IO1_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO2_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO2_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO2_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO2_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO2_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO2_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO2_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO2_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='IO1_B1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='IO2_B2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO2_B3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='IO2_B4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='IO2_B5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO2_B6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='IO2_B7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='IO2_B8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO2_B9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='IO1_C1',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='IO1_C2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='IO2_C8',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO2_C9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='IO1_D1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='IO1_D2',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='IO2_D8',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO2_D9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='IO1_E1/GCLK1',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='IO1_E2/GCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='IO2_E8/GCLK3',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='IO2_E9/GCLK2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='IO1_F1',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='IO1_F2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='IO1_F3',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='IO2_F8',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO2_F9',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='IO1_G2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='IO1_G6',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='IO2_G8',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO2_G9',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='H2',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='H3',name='IO1_H3',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='IO1_H4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='IO1_H5',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='IO1_H6',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='IO1_H7/DEV_CLRn',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='IO1_H8',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='IO2_H9',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='J2',name='IO1_J2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='IO1_J3',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='IO1_J4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='IO1_J5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='IO1_J6/DEV_OE',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='IO1_J7',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='IO1_J8',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='IO1_J9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EPM570F100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EPM570F100'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-100_11.0x11.0mm_Layout10x10_P1.0mm_Ball0.5mm_Pad0.4mm_NSMD'], 'footprint':'Package_BGA:BGA-100_11.0x11.0mm_Layout10x10_P1.0mm_Ball0.5mm_Pad0.4mm_NSMD', 'keywords':'MAX2 FBGA', 'description':'', 'datasheet':'https://www.altera.com/content/dam/altera-www/global/en_US/pdfs/literature/hb/max2/max2_mii5v1.pdf', 'search_text':'/usr/share/kicad/symbols/CPLD_Altera.kicad_sym\nEPM570F100\n\nMAX2 FBGA', 'pins':[
            Pin(num='A1',name='IO2_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='IO2_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO2_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO2_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO2_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO2_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO2_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO2_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO2_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO2_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='IO1_B1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO2_B10',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='IO2_B2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO2_B3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='IO2_B4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='IO2_B5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO2_B6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='IO2_B7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='IO2_B8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO2_B9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='IO1_C1',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO2_C10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='IO1_C2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='IO2_C3',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='IO2_C4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='IO2_C7',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO2_C8',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO2_C9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='IO1_D1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO2_D10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='IO1_D2',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='IO1_D3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='IO2_D8',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='IO2_D9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='IO1_E1/GCLK1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='IO2_E10/GCLK3',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='IO1_E2/GCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='IO1_E3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='IO2_E8',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='IO2_E9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='IO1_F1',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO2_F10',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='IO1_F2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='IO1_F3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='IO2_F8/GCLK2',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO2_F9',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='IO1_G1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='IO2_G10',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='IO1_G2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='IO1_G3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='G5',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='IO2_G8',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='IO2_G9',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='IO1_H1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='IO2_H10',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='H4',name='IO1_H4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='IO1_H7',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='IO1_H8',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='IO2_H9',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='IO2_J10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='J3',name='IO1_J3',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='IO1_J4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='IO1_J5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='IO1_J6',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='IO1_J7/DEV_OE',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='IO1_J8',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='IO1_J9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='IO1_K1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='IO1_K10',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='IO1_K2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='IO1_K3',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='IO1_K4',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='IO1_K5',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='IO1_K6',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='IO1_K7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='IO1_K8',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='IO1_K9/DEV_CLRn',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EPM570F256', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EPM570F256'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-256_17.0x17.0mm_Layout16x16_P1.0mm_Ball0.5mm_Pad0.4mm_NSMD'], 'footprint':'Package_BGA:BGA-256_17.0x17.0mm_Layout16x16_P1.0mm_Ball0.5mm_Pad0.4mm_NSMD', 'keywords':'MAX2 FBGA', 'description':'', 'datasheet':'https://www.altera.com/content/dam/altera-www/global/en_US/pdfs/literature/hb/max2/max2_mii5v1.pdf', 'search_text':'/usr/share/kicad/symbols/CPLD_Altera.kicad_sym\nEPM570F256\n\nMAX2 FBGA', 'pins':[
            Pin(num='A1',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='IO2_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO2_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO2_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO2_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='A15',name='IO2_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='IO2_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='IO2_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO2_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO2_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO2_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO2_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO2_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='IO2_B1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO2_B10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO2_B11',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO2_B12',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='IO2_B13',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO2_B14',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='B16',name='IO2_B16',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='IO2_B3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='IO2_B4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='IO2_B5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO2_B6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='IO2_B7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='IO2_B8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO2_B9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='C10',name='IO2_C10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO2_C11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO2_C12',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO2_C13',func=pin_types.BIDIR,unit=1),
            Pin(num='C14',name='IO2_C14',func=pin_types.BIDIR,unit=1),
            Pin(num='C15',name='IO2_C15',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='IO1_C2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='IO1_C3',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='IO2_C4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO2_C5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='IO2_C6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='IO2_C7',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='IO2_C8',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='IO2_C9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='IO1_D1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO2_D11',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO2_D12',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO2_D13',func=pin_types.BIDIR,unit=1),
            Pin(num='D14',name='IO2_D14',func=pin_types.BIDIR,unit=1),
            Pin(num='D15',name='IO2_D15',func=pin_types.BIDIR,unit=1),
            Pin(num='D16',name='IO2_D16',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='IO1_D2',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='IO1_D3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='IO2_D4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='IO2_D5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='IO1_E1',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='IO2_E13',func=pin_types.BIDIR,unit=1),
            Pin(num='E14',name='IO2_E14',func=pin_types.BIDIR,unit=1),
            Pin(num='E15',name='IO2_E15',func=pin_types.BIDIR,unit=1),
            Pin(num='E16',name='IO2_E16',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='IO1_E2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='IO1_E3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='IO1_E4',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='IO1_F1',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO2_F13',func=pin_types.BIDIR,unit=1),
            Pin(num='F14',name='IO2_F14',func=pin_types.BIDIR,unit=1),
            Pin(num='F15',name='IO2_F15',func=pin_types.BIDIR,unit=1),
            Pin(num='F16',name='IO2_F16',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='IO1_F2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='IO1_F3',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='IO1_G1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='G14',name='IO2_G14',func=pin_types.BIDIR,unit=1),
            Pin(num='G15',name='IO2_G15',func=pin_types.BIDIR,unit=1),
            Pin(num='G16',name='IO2_G16',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='IO1_G2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='IO1_G3',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='IO1_H1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='H11',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='IO2_H12/GCLK3',func=pin_types.BIDIR,unit=1),
            Pin(num='H14',name='IO2_H14',func=pin_types.BIDIR,unit=1),
            Pin(num='H15',name='IO2_H15',func=pin_types.BIDIR,unit=1),
            Pin(num='H16',name='IO2_H16',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='IO1_H2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='IO1_H3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='IO1_H5/GCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='H8',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='IO1_J1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='J12',name='IO2_J12/GCLK2',func=pin_types.BIDIR,unit=1),
            Pin(num='J14',name='IO2_J14',func=pin_types.BIDIR,unit=1),
            Pin(num='J15',name='IO2_J15',func=pin_types.BIDIR,unit=1),
            Pin(num='J16',name='IO2_J16',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='IO1_J2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='IO1_J3',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='IO1_J5/GCLK1',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='J7',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='J9',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='IO1_K1',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='K14',name='IO2_K14',func=pin_types.BIDIR,unit=1),
            Pin(num='K15',name='IO2_K15',func=pin_types.BIDIR,unit=1),
            Pin(num='K16',name='IO2_K16',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='IO1_K2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='IO1_K3',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='K8',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='IO1_L1',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='IO2_L13',func=pin_types.BIDIR,unit=1),
            Pin(num='L14',name='IO2_L14',func=pin_types.BIDIR,unit=1),
            Pin(num='L15',name='IO2_L15',func=pin_types.BIDIR,unit=1),
            Pin(num='L16',name='IO2_L16',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='IO1_L2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='IO1_L3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='IO1_L4',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='L8',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='IO1_M1',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO2_M13',func=pin_types.BIDIR,unit=1),
            Pin(num='M14',name='IO2_M14',func=pin_types.BIDIR,unit=1),
            Pin(num='M15',name='IO2_M15',func=pin_types.BIDIR,unit=1),
            Pin(num='M16',name='IO2_M16',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='IO1_M2',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='IO1_M3',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='IO1_M4',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='M8',name='IO1_M8/DEV_OE',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='IO1_M9/DEV_CLRn',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='IO1_N1',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='IO1_N12',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='IO2_N13',func=pin_types.BIDIR,unit=1),
            Pin(num='N14',name='IO2_N14',func=pin_types.BIDIR,unit=1),
            Pin(num='N15',name='IO2_N15',func=pin_types.BIDIR,unit=1),
            Pin(num='N16',name='IO2_N16',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='IO1_N2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='IO1_N3',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='N5',name='IO1_N5',func=pin_types.BIDIR,unit=1),
            Pin(num='P1',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='P10',name='IO1_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='P11',name='IO1_P11',func=pin_types.BIDIR,unit=1),
            Pin(num='P12',name='IO1_P12',func=pin_types.BIDIR,unit=1),
            Pin(num='P13',name='IO1_P13',func=pin_types.BIDIR,unit=1),
            Pin(num='P14',name='IO2_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='P15',name='IO2_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='P16',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='P2',name='IO1_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='P3',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='P4',name='IO1_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='P5',name='IO1_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='P6',name='IO1_P6',func=pin_types.BIDIR,unit=1),
            Pin(num='P7',name='IO1_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='P8',name='IO1_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='P9',name='IO1_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='IO1_R1',func=pin_types.BIDIR,unit=1),
            Pin(num='R10',name='IO1_R10',func=pin_types.BIDIR,unit=1),
            Pin(num='R11',name='IO1_R11',func=pin_types.BIDIR,unit=1),
            Pin(num='R12',name='IO1_R12',func=pin_types.BIDIR,unit=1),
            Pin(num='R13',name='IO1_R13',func=pin_types.BIDIR,unit=1),
            Pin(num='R14',name='IO1_R14',func=pin_types.BIDIR,unit=1),
            Pin(num='R15',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='R16',name='IO1_R16',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='R3',name='IO1_R3',func=pin_types.BIDIR,unit=1),
            Pin(num='R4',name='IO1_R4',func=pin_types.BIDIR,unit=1),
            Pin(num='R5',name='IO1_R5',func=pin_types.BIDIR,unit=1),
            Pin(num='R6',name='IO1_R6',func=pin_types.BIDIR,unit=1),
            Pin(num='R7',name='IO1_R7',func=pin_types.BIDIR,unit=1),
            Pin(num='R8',name='IO1_R8',func=pin_types.BIDIR,unit=1),
            Pin(num='R9',name='IO1_R9',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='T10',name='IO1_T10',func=pin_types.BIDIR,unit=1),
            Pin(num='T11',name='IO1_T11',func=pin_types.BIDIR,unit=1),
            Pin(num='T12',name='IO1_T12',func=pin_types.BIDIR,unit=1),
            Pin(num='T13',name='IO1_T13',func=pin_types.BIDIR,unit=1),
            Pin(num='T14',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='T15',name='IO1_T15',func=pin_types.BIDIR,unit=1),
            Pin(num='T16',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='T2',name='IO1_T2',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='T4',name='IO1_T4',func=pin_types.BIDIR,unit=1),
            Pin(num='T5',name='IO1_T5',func=pin_types.BIDIR,unit=1),
            Pin(num='T6',name='IO1_T6',func=pin_types.BIDIR,unit=1),
            Pin(num='T7',name='IO1_T7',func=pin_types.BIDIR,unit=1),
            Pin(num='T8',name='IO1_T8',func=pin_types.BIDIR,unit=1),
            Pin(num='T9',name='IO1_T9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EPM570M100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EPM570M100'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-100_6.0x6.0mm_Layout11x11_P0.5mm_Ball0.3mm_Pad0.25mm_NSMD'], 'footprint':'Package_BGA:BGA-100_6.0x6.0mm_Layout11x11_P0.5mm_Ball0.3mm_Pad0.25mm_NSMD', 'keywords':'MAX2 MBGA', 'description':'', 'datasheet':'https://www.altera.com/content/dam/altera-www/global/en_US/pdfs/literature/hb/max2/max2_mii5v1.pdf', 'search_text':'/usr/share/kicad/symbols/CPLD_Altera.kicad_sym\nEPM570M100\n\nMAX2 MBGA', 'pins':[
            Pin(num='A1',name='IO2_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='IO2_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO2_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO2_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO2_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO2_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO2_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO2_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO2_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO2_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO2_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='IO1_B1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO2_B10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO2_B11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='IO2_B2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO2_B3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='IO2_B4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='IO2_B5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO2_B6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='IO2_B7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='IO2_B8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO2_B9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='IO1_C1',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO2_C10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO2_C11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='IO1_C2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='IO2_C6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='IO1_D1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO2_D10',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO2_D11',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='IO1_D2',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='IO1_D3',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='D9',name='IO2_D9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='IO1_E1/GCLK1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='IO2_E10',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='IO2_E11',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='IO1_E2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='IO1_F1',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO2_F10/GCLK2',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='IO2_F11',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='IO1_F2/GCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='IO1_F3',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO2_F9',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='IO1_G1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='IO2_G10',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO2_G11/GCLK3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='IO1_G2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='IO1_H1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='IO2_H10',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO2_H11',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='IO1_H2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='IO1_H3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='IO2_H9',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='IO2_J10',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='IO2_J11',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='J4',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='IO1_J6',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='IO1_K10',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='IO2_K11',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='K3',name='IO1_K3',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='IO1_K4',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='IO1_K5',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='IO1_K6',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='IO1_K7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='IO1_K8/DEV_CLRn',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='IO1_K9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='IO1_L1',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='IO1_L10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='IO1_L11',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='IO1_L2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='IO1_L3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='IO1_L4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='IO1_L5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='IO1_L6',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='IO1_L7',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='IO1_L8/DEV_OE',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='IO1_L9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EPM570M256', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EPM570M256'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-256_11.0x11.0mm_Layout20x20_P0.5mm_Ball0.3mm_Pad0.25mm_NSMD'], 'footprint':'Package_BGA:BGA-256_11.0x11.0mm_Layout20x20_P0.5mm_Ball0.3mm_Pad0.25mm_NSMD', 'keywords':'MAX2 MBGA', 'description':'', 'datasheet':'https://www.altera.com/content/dam/altera-www/global/en_US/pdfs/literature/hb/max2/max2_mii5v1.pdf', 'search_text':'/usr/share/kicad/symbols/CPLD_Altera.kicad_sym\nEPM570M256\n\nMAX2 MBGA', 'pins':[
            Pin(num='A1',name='IO2_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='IO2_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO2_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO2_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO2_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO2_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO2_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO2_A16',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='IO2_A17',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO2_A18',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='IO2_A19',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO2_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='IO2_A20',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO2_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO2_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO2_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO2_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO2_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO2_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO2_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='IO1_B1',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO2_B12',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='IO2_B13',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO2_B14',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO2_B15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='IO2_B16',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='IO2_B17',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO2_B18',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='IO2_B19',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='IO2_B2',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='IO2_B20',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO2_B3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='IO2_B4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='IO2_B5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO2_B6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='IO2_B7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='IO2_B8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO2_B9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='IO1_C1',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='C11',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='C12',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='C13',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='C15',name='IO2_C15',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO2_C16',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO2_C17',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO2_C18',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='IO2_C19',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='IO1_C2',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='IO2_C20',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='IO1_C3',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO2_C5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='IO1_D1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='D18',name='IO2_D18',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='IO2_D19',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='IO1_D2',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='IO2_D20',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='IO1_D3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='IO1_E1',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='IO2_E17',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='IO2_E18',func=pin_types.BIDIR,unit=1),
            Pin(num='E19',name='IO2_E19',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='IO1_E2',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='IO2_E20',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='IO1_E3',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='IO1_F1',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='IO2_F19',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='IO1_F2',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO2_F20',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='IO1_F3',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='IO1_G1',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO2_G19',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='IO1_G2',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO2_G20',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='IO1_H1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='H19',name='IO2_H19',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='IO1_H2',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='IO2_H20',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='IO1_J1',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='J18',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='J19',name='IO2_J19',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='IO1_J2',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='IO2_J20',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='IO1_K1/GCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='K18',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='K20',name='IO2_K20',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='K4',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='IO1_L1/GCLK1',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='L18',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='L20',name='IO2_L20/GCLK3',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='L4',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='IO1_M1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='M18',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='M19',name='IO2_M19',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='IO1_M2',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='IO2_M20/GCLK2',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='M4',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='IO1_N1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='N19',name='IO2_N19',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='IO1_N2',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='IO2_N20',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='IO1_P1',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='IO2_P19',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='IO1_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO2_P20',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='IO1_R1',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='IO2_R18',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO2_R19',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='IO1_R2',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='IO2_R20',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='IO1_R3',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='IO1_T1',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO2_T18',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO2_T19',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='IO1_T2',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO2_T20',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='T4',name='IO1_T4',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='IO1_U1',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='U11',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='U12',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='U17',name='IO2_U17',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='IO2_U18',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='IO2_U19',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='U20',name='IO2_U20',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='IO1_U3',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='IO1_U4',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='V1',name='IO1_V1',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='V11',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='V12',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='V13',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='V16',name='IO1_V16',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='IO1_V17',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='IO1_V18',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO2_V19',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='V20',name='IO2_V20',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='IO1_V3',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='IO1_V4',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='IO1_V5',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='IO1_V6',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='V9',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='W1',name='IO1_W1',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='IO1_W11',func=pin_types.BIDIR,unit=1),
            Pin(num='W12',name='IO1_W12/DEV_OE',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='IO1_W13',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='IO1_W14',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='IO1_W15',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='IO1_W16',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='IO1_W17',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='IO1_W18',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='IO2_W19',func=pin_types.BIDIR,unit=1),
            Pin(num='W2',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='W20',name='IO2_W20',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='IO1_W3',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='IO1_W4',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='IO1_W5',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='IO1_W6',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='IO1_W7',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='IO1_W8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='IO1_Y1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='IO1_Y10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y11',name='IO1_Y11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='IO1_Y12',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='IO1_Y13/DEV_CLRn',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='IO1_Y14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y15',name='IO1_Y15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='IO1_Y16',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='IO1_Y17',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='IO1_Y18',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='IO1_Y19',func=pin_types.BIDIR,unit=1),
            Pin(num='Y2',name='IO1_Y2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='IO2_Y20',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='IO1_Y3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y4',name='IO1_Y4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='IO1_Y5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='IO1_Y6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='IO1_Y7',func=pin_types.BIDIR,unit=1),
            Pin(num='Y8',name='IO1_Y8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='IO1_Y9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EPM570T100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EPM570T100'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'MAX2 TQFP', 'description':'', 'datasheet':'https://www.altera.com/content/dam/altera-www/global/en_US/pdfs/literature/hb/max2/max2_mii5v1.pdf', 'search_text':'/usr/share/kicad/symbols/CPLD_Altera.kicad_sym\nEPM570T100\n\nMAX2 TQFP', 'pins':[
            Pin(num='1',name='IO2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='IO2_100',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='IO1_12/GCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='IO1_14/GCLK1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='IO1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='IO1_16',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='IO1_17',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='IO1_18',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='IO1_19',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='IO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='IO1_20',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='IO1_21',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='IO1_26',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='IO1_27',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='IO1_28',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='IO1_29',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='IO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='IO1_30',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='IO1_33',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='IO1_34',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='IO1_35',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='IO1_36',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='IO1_38',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='IO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='IO1_40',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='IO1_41',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='IO1_42',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='IO1_43/DEV_OE',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='IO1_44/DEV_CLRn',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='IO1_47',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='IO1_48',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='IO1_49',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='IO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='IO1_50',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='IO1_51',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='IO2_52',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='IO2_53',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='IO2_54',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='IO2_55',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='IO2_56',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='IO2_57',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='IO2_58',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='IO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='61',name='IO2_61',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='IO2_62/GCLK2',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='IO2_64/GCLK3',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='66',name='IO2_66',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='IO2_67',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='IO2_68',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='IO2_69',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='IO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='IO2_70',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='IO2_71',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='IO2_72',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='IO2_73',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='IO2_74',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='IO2_75',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='IO2_76',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='IO2_77',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='IO2_78',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='IO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='81',name='IO2_81',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='IO2_82',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='IO2_83',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='IO2_84',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='IO2_85',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='IO2_86',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='IO2_87',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='89',name='IO2_89',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='90',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='91',name='IO2_91',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='IO2_92',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='94',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='95',name='IO2_95',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='IO2_96',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='IO2_97',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='IO2_98',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='IO2_99',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EPM570T144', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EPM570T144'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'MAX2 TQFP', 'description':'', 'datasheet':'https://www.altera.com/content/dam/altera-www/global/en_US/pdfs/literature/hb/max2/max2_mii5v1.pdf', 'search_text':'/usr/share/kicad/symbols/CPLD_Altera.kicad_sym\nEPM570T144\n\nMAX2 TQFP', 'pins':[
            Pin(num='1',name='IO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='101',name='IO2_101',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='IO2_102',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='IO2_103',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='IO2_104',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='IO2_105',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='IO2_106',func=pin_types.BIDIR,unit=1),
            Pin(num='107',name='IO2_107',func=pin_types.BIDIR,unit=1),
            Pin(num='108',name='IO2_108',func=pin_types.BIDIR,unit=1),
            Pin(num='109',name='IO2_109',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='IO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='IO2_110',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='IO2_111',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='IO2_112',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='IO2_113',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='IO2_114',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='116',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='117',name='IO2_117',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='IO2_118',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='IO2_119',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='IO1_12',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='IO2_120',func=pin_types.BIDIR,unit=1),
            Pin(num='121',name='IO2_121',func=pin_types.BIDIR,unit=1),
            Pin(num='122',name='IO2_122',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='IO2_123',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='IO2_124',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='IO2_125',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='127',name='IO2_127',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='129',name='IO2_129',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='IO1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='IO2_130',func=pin_types.BIDIR,unit=1),
            Pin(num='131',name='IO2_131',func=pin_types.BIDIR,unit=1),
            Pin(num='132',name='IO2_132',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='IO2_133',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='IO2_134',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='136',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='137',name='IO2_137',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='IO2_138',func=pin_types.BIDIR,unit=1),
            Pin(num='139',name='IO2_139',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='IO1_14',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='IO2_140',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='IO2_141',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='IO2_142',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='IO2_143',func=pin_types.BIDIR,unit=1),
            Pin(num='144',name='IO2_144',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='IO1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='IO1_16',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='IO1_18/GCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='IO1_20/GCLK1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='IO1_21',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='IO1_22',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='IO1_23',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='IO1_24',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='IO1_27',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='IO1_28',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='IO1_29',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='IO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='IO1_30',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='IO1_31',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='IO1_32',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='IO1_37',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='IO1_38',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='IO1_39',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='IO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='IO1_40',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='IO1_41',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='IO1_42',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='IO1_43',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='IO1_44',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='IO1_45',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='IO1_48',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='IO1_49',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='IO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='IO1_50',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='IO1_51',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='IO1_52',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='IO1_53',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='IO1_55',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='IO1_57',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='IO1_58',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='IO1_59',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='IO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='IO1_60/DEV_OE',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='IO1_61/DEV_CLRn',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='IO1_62',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='IO1_63',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='66',name='IO1_66',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='IO1_67',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='IO1_68',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='IO1_69',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='IO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='IO1_70',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='IO1_71',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='IO1_72',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='IO2_73',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='IO2_74',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='IO2_75',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='IO2_76',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='IO2_77',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='IO2_78',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='IO2_79',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='IO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='IO2_80',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='IO2_81',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='83',name='GNDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='IO2_84',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='IO2_85',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='IO2_86',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='IO2_87',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='IO2_88',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='IO2_89/GCLK2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='90',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='91',name='IO2_91/GCLK3',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='GNDINT',func=pin_types.PWRIN,unit=1),
            Pin(num='93',name='IO2_93',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='IO2_94',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='IO2_95',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='IO2_96',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='IO2_97',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='IO2_98',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='GNDIO',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EPM570ZM100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EPM570ZM100'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-100_6.0x6.0mm_Layout11x11_P0.5mm_Ball0.3mm_Pad0.25mm_NSMD'], 'footprint':'Package_BGA:BGA-100_6.0x6.0mm_Layout11x11_P0.5mm_Ball0.3mm_Pad0.25mm_NSMD', 'keywords':'MAX2 MBGA', 'description':'', 'datasheet':'https://www.altera.com/content/dam/altera-www/global/en_US/pdfs/literature/hb/max2/max2_mii5v1.pdf', 'search_text':'/usr/share/kicad/symbols/CPLD_Altera.kicad_sym\nEPM570ZM100\n\nMAX2 MBGA', 'pins':[
            Pin(num='A1',name='IO2_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='IO2_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO2_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO2_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO2_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO2_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO2_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO2_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO2_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO2_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO2_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='IO1_B1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO2_B10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO2_B11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='IO2_B2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO2_B3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='IO2_B4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='IO2_B5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO2_B6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='IO2_B7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='IO2_B8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO2_B9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='IO1_C1',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO2_C10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO2_C11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='IO1_C2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='IO2_C6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='IO1_D1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO2_D10',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO2_D11',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='IO1_D2',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='IO1_D3',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='D9',name='IO2_D9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='IO1_E1/GCLK1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='IO2_E10',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='IO2_E11',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='IO1_E2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='IO1_F1',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='IO2_F10/GCLK2',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='IO2_F11',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='IO1_F2/GCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='IO1_F3',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='IO2_F9',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='IO1_G1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='IO2_G10',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='IO2_G11/GCLK3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='IO1_G2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='IO1_H1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='IO2_H10',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='IO2_H11',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='IO1_H2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='IO1_H3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='IO2_H9',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='IO2_J10',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='IO2_J11',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='J4',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='J5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='J6',name='IO1_J6',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='J8',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='IO1_K10',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='IO2_K11',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='K3',name='IO1_K3',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='IO1_K4',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='IO1_K5',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='IO1_K6',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='IO1_K7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='IO1_K8/DEV_CLRn',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='IO1_K9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='IO1_L1',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='IO1_L10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='IO1_L11',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='IO1_L2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='IO1_L3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='IO1_L4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='IO1_L5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='IO1_L6',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='IO1_L7',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='IO1_L8/DEV_OE',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='IO1_L9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EPM570ZM144', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EPM570ZM144'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-144_7.0x7.0mm_Layout13x13_P0.5mm_Ball0.3mm_Pad0.25mm_NSMD'], 'footprint':'Package_BGA:BGA-144_7.0x7.0mm_Layout13x13_P0.5mm_Ball0.3mm_Pad0.25mm_NSMD', 'keywords':'MAX2 MBGA', 'description':'', 'datasheet':'https://www.altera.com/content/dam/altera-www/global/en_US/pdfs/literature/hb/max2/max2_mii5v1.pdf', 'search_text':'/usr/share/kicad/symbols/CPLD_Altera.kicad_sym\nEPM570ZM144\n\nMAX2 MBGA', 'pins':[
            Pin(num='A1',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='A10',name='IO1_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO1_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO1_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO2_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='A3',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='A4',name='IO1_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO1_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO1_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO1_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO1_A8/GCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO1_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='IO1_B1',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='IO1_B10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='IO1_B11',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO2_B12',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='IO2_B13',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='IO1_B2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='B4',name='IO1_B4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='IO1_B5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO1_B6/GCLK1',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='IO1_B7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='IO1_B8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO1_B9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='IO1_C1',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='IO1_C10',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='IO1_C11',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='IO2_C12',func=pin_types.BIDIR,unit=1),
            Pin(num='C13',name='IO2_C13',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='IO1_C2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='IO1_C3',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='IO1_C4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO1_C5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='IO1_C9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='IO1_D1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='IO1_D10',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='IO2_D11',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='IO2_D12',func=pin_types.BIDIR,unit=1),
            Pin(num='D13',name='IO2_D13',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='IO1_D2',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='IO1_D3',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='IO1_D4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='IO1_D5',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='D8',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='D9',name='IO1_D9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='IO1_E1',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='IO2_E10',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='IO2_E11',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='IO2_E12',func=pin_types.BIDIR,unit=1),
            Pin(num='E13',name='IO2_E13',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='IO1_E2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='IO1_E3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='IO1_E4',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='IO1_F1',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F12',name='IO2_F12',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='IO2_F13',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='IO1_F2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='IO1_G1',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='IO2_G12',func=pin_types.BIDIR,unit=1),
            Pin(num='G13',name='IO2_G13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='IO1_G2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='IO1_H1',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='IO2_H10',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H12',name='IO2_H12',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='IO2_H13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='IO1_H2',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H4',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='IO1_J1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='J11',name='IO2_J11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='IO2_J12',func=pin_types.BIDIR,unit=1),
            Pin(num='J13',name='IO2_J13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='IO1_J2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='IO1_J3',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='IO1_J4/DEV_OE',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='IO1_K1/DEV_CLRn',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='IO2_K10',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='IO2_K11',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='IO2_K12',func=pin_types.BIDIR,unit=1),
            Pin(num='K13',name='IO2_K13',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='IO1_K2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='IO1_K3',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='IO1_K4',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='IO2_K5',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='K7',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='K8',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='K9',name='IO2_K9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='IO1_L1',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='IO2_L10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='IO2_L11',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='IO2_L12',func=pin_types.BIDIR,unit=1),
            Pin(num='L13',name='IO2_L13',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='IO1_L2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='IO2_L3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='IO2_L4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='IO2_L5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='L8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='L9',name='IO2_L9',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='IO1_M1',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='IO2_M10',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='IO2_M11',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='IO2_M12',func=pin_types.BIDIR,unit=1),
            Pin(num='M13',name='IO2_M13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='IO2_M2',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='IO2_M3',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='IO2_M4',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='IO2_M5',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='IO2_M6',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='IO2_M7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='IO2_M8',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='IO2_M9',func=pin_types.BIDIR,unit=1),
            Pin(num='N1',name='IO1_N1',func=pin_types.BIDIR,unit=1),
            Pin(num='N10',name='IO2_N10',func=pin_types.BIDIR,unit=1),
            Pin(num='N11',name='IO2_N11',func=pin_types.BIDIR,unit=1),
            Pin(num='N12',name='IO2_N12',func=pin_types.BIDIR,unit=1),
            Pin(num='N13',name='IO2_N13',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='IO2_N2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='IO2_N3',func=pin_types.BIDIR,unit=1),
            Pin(num='N4',name='IO2_N4',func=pin_types.BIDIR,unit=1),
            Pin(num='N5',name='IO2_N5',func=pin_types.BIDIR,unit=1),
            Pin(num='N6',name='IO2_N6',func=pin_types.BIDIR,unit=1),
            Pin(num='N7',name='IO2_N7/GCLK2',func=pin_types.BIDIR,unit=1),
            Pin(num='N8',name='IO2_N8/GCLK3',func=pin_types.BIDIR,unit=1),
            Pin(num='N9',name='IO2_N9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EPM570ZM256', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EPM570ZM256'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-256_11.0x11.0mm_Layout20x20_P0.5mm_Ball0.3mm_Pad0.25mm_NSMD'], 'footprint':'Package_BGA:BGA-256_11.0x11.0mm_Layout20x20_P0.5mm_Ball0.3mm_Pad0.25mm_NSMD', 'keywords':'MAX2 MBGA', 'description':'', 'datasheet':'https://www.altera.com/content/dam/altera-www/global/en_US/pdfs/literature/hb/max2/max2_mii5v1.pdf', 'search_text':'/usr/share/kicad/symbols/CPLD_Altera.kicad_sym\nEPM570ZM256\n\nMAX2 MBGA', 'pins':[
            Pin(num='A1',name='IO2_A1',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='IO2_A10',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='IO2_A11',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='IO2_A12',func=pin_types.BIDIR,unit=1),
            Pin(num='A13',name='IO2_A13',func=pin_types.BIDIR,unit=1),
            Pin(num='A14',name='IO2_A14',func=pin_types.BIDIR,unit=1),
            Pin(num='A15',name='IO2_A15',func=pin_types.BIDIR,unit=1),
            Pin(num='A16',name='IO2_A16',func=pin_types.BIDIR,unit=1),
            Pin(num='A17',name='IO2_A17',func=pin_types.BIDIR,unit=1),
            Pin(num='A18',name='IO2_A18',func=pin_types.BIDIR,unit=1),
            Pin(num='A19',name='IO2_A19',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='IO2_A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A20',name='IO2_A20',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='IO2_A3',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='IO2_A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='IO2_A5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='IO2_A6',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='IO2_A7',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='IO2_A8',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='IO2_A9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='IO1_B1',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='IO2_B12',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='IO2_B13',func=pin_types.BIDIR,unit=1),
            Pin(num='B14',name='IO2_B14',func=pin_types.BIDIR,unit=1),
            Pin(num='B15',name='IO2_B15',func=pin_types.BIDIR,unit=1),
            Pin(num='B16',name='IO2_B16',func=pin_types.BIDIR,unit=1),
            Pin(num='B17',name='IO2_B17',func=pin_types.BIDIR,unit=1),
            Pin(num='B18',name='IO2_B18',func=pin_types.BIDIR,unit=1),
            Pin(num='B19',name='IO2_B19',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='IO2_B2',func=pin_types.BIDIR,unit=1),
            Pin(num='B20',name='IO2_B20',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='IO2_B3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='IO2_B4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='IO2_B5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='IO2_B6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='IO2_B7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='IO2_B8',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='IO2_B9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='IO1_C1',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='C11',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='C12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C15',name='IO2_C15',func=pin_types.BIDIR,unit=1),
            Pin(num='C16',name='IO2_C16',func=pin_types.BIDIR,unit=1),
            Pin(num='C17',name='IO2_C17',func=pin_types.BIDIR,unit=1),
            Pin(num='C18',name='IO2_C18',func=pin_types.BIDIR,unit=1),
            Pin(num='C19',name='IO2_C19',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='IO1_C2',func=pin_types.BIDIR,unit=1),
            Pin(num='C20',name='IO2_C20',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='IO1_C3',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='IO2_C5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C9',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='IO1_D1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='D12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='D18',name='IO2_D18',func=pin_types.BIDIR,unit=1),
            Pin(num='D19',name='IO2_D19',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='IO1_D2',func=pin_types.BIDIR,unit=1),
            Pin(num='D20',name='IO2_D20',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='IO1_D3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='IO1_E1',func=pin_types.BIDIR,unit=1),
            Pin(num='E17',name='IO2_E17',func=pin_types.BIDIR,unit=1),
            Pin(num='E18',name='IO2_E18',func=pin_types.BIDIR,unit=1),
            Pin(num='E19',name='IO2_E19',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='IO1_E2',func=pin_types.BIDIR,unit=1),
            Pin(num='E20',name='IO2_E20',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='IO1_E3',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='IO1_F1',func=pin_types.BIDIR,unit=1),
            Pin(num='F19',name='IO2_F19',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='IO1_F2',func=pin_types.BIDIR,unit=1),
            Pin(num='F20',name='IO2_F20',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='IO1_F3',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='IO1_G1',func=pin_types.BIDIR,unit=1),
            Pin(num='G19',name='IO2_G19',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='IO1_G2',func=pin_types.BIDIR,unit=1),
            Pin(num='G20',name='IO2_G20',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='IO1_H1',func=pin_types.BIDIR,unit=1),
            Pin(num='H18',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H19',name='IO2_H19',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='IO1_H2',func=pin_types.BIDIR,unit=1),
            Pin(num='H20',name='IO2_H20',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='IO1_J1',func=pin_types.BIDIR,unit=1),
            Pin(num='J17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='J18',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='J19',name='IO2_J19',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='IO1_J2',func=pin_types.BIDIR,unit=1),
            Pin(num='J20',name='IO2_J20',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='J4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='K1',name='IO1_K1/GCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='K17',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='K18',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='K20',name='IO2_K20',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='K4',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='L1',name='IO1_L1/GCLK1',func=pin_types.BIDIR,unit=1),
            Pin(num='L17',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='L18',name='VCCIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='L20',name='IO2_L20/GCLK3',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='L4',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='M1',name='IO1_M1',func=pin_types.BIDIR,unit=1),
            Pin(num='M17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='M18',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='M19',name='IO2_M19',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='IO1_M2',func=pin_types.BIDIR,unit=1),
            Pin(num='M20',name='IO2_M20/GCLK2',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='M4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='N1',name='IO1_N1',func=pin_types.BIDIR,unit=1),
            Pin(num='N18',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='N19',name='IO2_N19',func=pin_types.BIDIR,unit=1),
            Pin(num='N2',name='IO1_N2',func=pin_types.BIDIR,unit=1),
            Pin(num='N20',name='IO2_N20',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='P1',name='IO1_P1',func=pin_types.BIDIR,unit=1),
            Pin(num='P19',name='IO2_P19',func=pin_types.BIDIR,unit=1),
            Pin(num='P2',name='IO1_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='P20',name='IO2_P20',func=pin_types.BIDIR,unit=1),
            Pin(num='R1',name='IO1_R1',func=pin_types.BIDIR,unit=1),
            Pin(num='R18',name='IO2_R18',func=pin_types.BIDIR,unit=1),
            Pin(num='R19',name='IO2_R19',func=pin_types.BIDIR,unit=1),
            Pin(num='R2',name='IO1_R2',func=pin_types.BIDIR,unit=1),
            Pin(num='R20',name='IO2_R20',func=pin_types.BIDIR,unit=1),
            Pin(num='R3',name='IO1_R3',func=pin_types.BIDIR,unit=1),
            Pin(num='T1',name='IO1_T1',func=pin_types.BIDIR,unit=1),
            Pin(num='T18',name='IO2_T18',func=pin_types.BIDIR,unit=1),
            Pin(num='T19',name='IO2_T19',func=pin_types.BIDIR,unit=1),
            Pin(num='T2',name='IO1_T2',func=pin_types.BIDIR,unit=1),
            Pin(num='T20',name='IO2_T20',func=pin_types.BIDIR,unit=1),
            Pin(num='T3',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='T4',name='IO1_T4',func=pin_types.BIDIR,unit=1),
            Pin(num='U1',name='IO1_U1',func=pin_types.BIDIR,unit=1),
            Pin(num='U10',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='U11',name='VCCINT',func=pin_types.PWRIN,unit=1),
            Pin(num='U12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='U17',name='IO2_U17',func=pin_types.BIDIR,unit=1),
            Pin(num='U18',name='IO2_U18',func=pin_types.BIDIR,unit=1),
            Pin(num='U19',name='IO2_U19',func=pin_types.BIDIR,unit=1),
            Pin(num='U2',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='U20',name='IO2_U20',func=pin_types.BIDIR,unit=1),
            Pin(num='U3',name='IO1_U3',func=pin_types.BIDIR,unit=1),
            Pin(num='U4',name='IO1_U4',func=pin_types.BIDIR,unit=1),
            Pin(num='U9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='V1',name='IO1_V1',func=pin_types.BIDIR,unit=1),
            Pin(num='V10',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='V11',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='V12',name='VCCIO1',func=pin_types.PWRIN,unit=1),
            Pin(num='V13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='V16',name='IO1_V16',func=pin_types.BIDIR,unit=1),
            Pin(num='V17',name='IO1_V17',func=pin_types.BIDIR,unit=1),
            Pin(num='V18',name='IO1_V18',func=pin_types.BIDIR,unit=1),
            Pin(num='V19',name='IO2_V19',func=pin_types.BIDIR,unit=1),
            Pin(num='V2',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='V20',name='IO2_V20',func=pin_types.BIDIR,unit=1),
            Pin(num='V3',name='IO1_V3',func=pin_types.BIDIR,unit=1),
            Pin(num='V4',name='IO1_V4',func=pin_types.BIDIR,unit=1),
            Pin(num='V5',name='IO1_V5',func=pin_types.BIDIR,unit=1),
            Pin(num='V6',name='IO1_V6',func=pin_types.BIDIR,unit=1),
            Pin(num='V8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='V9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='W1',name='IO1_W1',func=pin_types.BIDIR,unit=1),
            Pin(num='W11',name='IO1_W11',func=pin_types.BIDIR,unit=1),
            Pin(num='W12',name='IO1_W12/DEV_OE',func=pin_types.BIDIR,unit=1),
            Pin(num='W13',name='IO1_W13',func=pin_types.BIDIR,unit=1),
            Pin(num='W14',name='IO1_W14',func=pin_types.BIDIR,unit=1),
            Pin(num='W15',name='IO1_W15',func=pin_types.BIDIR,unit=1),
            Pin(num='W16',name='IO1_W16',func=pin_types.BIDIR,unit=1),
            Pin(num='W17',name='IO1_W17',func=pin_types.BIDIR,unit=1),
            Pin(num='W18',name='IO1_W18',func=pin_types.BIDIR,unit=1),
            Pin(num='W19',name='IO2_W19',func=pin_types.BIDIR,unit=1),
            Pin(num='W2',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='W20',name='IO2_W20',func=pin_types.BIDIR,unit=1),
            Pin(num='W3',name='IO1_W3',func=pin_types.BIDIR,unit=1),
            Pin(num='W4',name='IO1_W4',func=pin_types.BIDIR,unit=1),
            Pin(num='W5',name='IO1_W5',func=pin_types.BIDIR,unit=1),
            Pin(num='W6',name='IO1_W6',func=pin_types.BIDIR,unit=1),
            Pin(num='W7',name='IO1_W7',func=pin_types.BIDIR,unit=1),
            Pin(num='W8',name='IO1_W8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y1',name='IO1_Y1',func=pin_types.BIDIR,unit=1),
            Pin(num='Y10',name='IO1_Y10',func=pin_types.BIDIR,unit=1),
            Pin(num='Y11',name='IO1_Y11',func=pin_types.BIDIR,unit=1),
            Pin(num='Y12',name='IO1_Y12',func=pin_types.BIDIR,unit=1),
            Pin(num='Y13',name='IO1_Y13/DEV_CLRn',func=pin_types.BIDIR,unit=1),
            Pin(num='Y14',name='IO1_Y14',func=pin_types.BIDIR,unit=1),
            Pin(num='Y15',name='IO1_Y15',func=pin_types.BIDIR,unit=1),
            Pin(num='Y16',name='IO1_Y16',func=pin_types.BIDIR,unit=1),
            Pin(num='Y17',name='IO1_Y17',func=pin_types.BIDIR,unit=1),
            Pin(num='Y18',name='IO1_Y18',func=pin_types.BIDIR,unit=1),
            Pin(num='Y19',name='IO1_Y19',func=pin_types.BIDIR,unit=1),
            Pin(num='Y2',name='IO1_Y2',func=pin_types.BIDIR,unit=1),
            Pin(num='Y20',name='IO2_Y20',func=pin_types.BIDIR,unit=1),
            Pin(num='Y3',name='IO1_Y3',func=pin_types.BIDIR,unit=1),
            Pin(num='Y4',name='IO1_Y4',func=pin_types.BIDIR,unit=1),
            Pin(num='Y5',name='IO1_Y5',func=pin_types.BIDIR,unit=1),
            Pin(num='Y6',name='IO1_Y6',func=pin_types.BIDIR,unit=1),
            Pin(num='Y7',name='IO1_Y7',func=pin_types.BIDIR,unit=1),
            Pin(num='Y8',name='IO1_Y8',func=pin_types.BIDIR,unit=1),
            Pin(num='Y9',name='IO1_Y9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EP310', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EP310'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'EPLD', 'description':'', 'datasheet':'https://www.usbid.com/assets/datasheets/A6/ep310%20-%20epld%20-%20altera.pdf', 'search_text':'/usr/share/kicad/symbols/CPLD_Altera.kicad_sym\nEP310\n\nEPLD', 'pins':[
            Pin(num='1',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='IN10',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='IO1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='IO2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='IO3',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='IO4',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='IO5',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='IO6',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='IO7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='IO8',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IN5',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IN6',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IN7',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='IN9',func=pin_types.INPUT,unit=1)], 'unit_defs':[] })])