from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_Microchip_ATtiny = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'ATtiny102-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny102-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-8-1EP_3x2mm_P0.5mm_EP1.3x1.5mm'], 'footprint':'Package_DFN_QFN:DFN-8-1EP_3x2mm_P0.5mm_EP1.3x1.5mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-42505-8-bit-AVR-Microcontrollers-ATtiny102-ATtiny104_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny102-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny102-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny102-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-42505-8-bit-AVR-Microcontrollers-ATtiny102-ATtiny104_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny102-SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny104-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny104-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-42505-8-bit-AVR-Microcontrollers-ATtiny102-ATtiny104_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny104-SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny13V-10M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny13V-10M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2535.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny13V-10M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny13V-10MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny13V-10MM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-10-1EP_3x3mm_P0.5mm_EP1.75x2.7mm'], 'footprint':'Package_DFN_QFN:DFN-10-1EP_3x3mm_P0.5mm_EP1.75x2.7mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2535.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny13V-10MM\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny13V-10P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny13V-10P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2535.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny13V-10P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny13V-10S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny13V-10S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2535.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny13V-10S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny13V-10SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny13V-10SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2535.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny13V-10SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny1634-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny1634-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8303-8-bit-AVR-Microcontroller-tinyAVR-ATtiny1634_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny1634-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL1/PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='XTAL2/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='~{RESET}/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny1634-S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny1634-S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8303-8-bit-AVR-Microcontroller-tinyAVR-ATtiny1634_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny1634-S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='XTAL1/PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='XTAL2/PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='~{RESET}/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='AREF/PA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny20-CC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny20-CC'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-15_3.0x3.0mm_Layout4x4_P0.65mm'], 'footprint':'Package_BGA:UFBGA-15_3.0x3.0mm_Layout4x4_P0.65mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8235-8-bit-avr-microcontroller-attiny20_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny20-CC\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='A2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny20-MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny20-MM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_3x3mm_P0.45mm_EP1.6x1.6mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_3x3mm_P0.45mm_EP1.6x1.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8235-8-bit-avr-microcontroller-attiny20_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny20-MM\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny20-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny20-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8235-8-bit-avr-microcontroller-attiny20_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny20-SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny20-U', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny20-U'}), 'ref_prefix':'U', 'fplist':['Package_CSP:WLCSP-12_1.403x1.555mm_P0.4mm_Stagger'], 'footprint':'Package_CSP:WLCSP-12_1.403x1.555mm_P0.4mm_Stagger', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8235-8-bit-avr-microcontroller-attiny20_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny20-U\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='A1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PB0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny20-X', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny20-X'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8235-8-bit-avr-microcontroller-attiny20_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny20-X\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny202-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny202-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny202-402-AVR-MCU-with-Core-Independent-Peripherals_and-picoPower-40001969A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny202-SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny204-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny204-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/50002687A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny204-SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny2313A-MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny2313A-MM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.45mm_EP1.55x1.55mm'], 'footprint':'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.45mm_EP1.55x1.55mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8246.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny2313A-MM\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PA2/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA1/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA0/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PD6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny2313V-10M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny2313V-10M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:MLF-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:MLF-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2543-AVR-ATtiny2313_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny2313V-10M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PA2/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA1/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA0/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PD6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny2313V-10P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny2313V-10P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2543-AVR-ATtiny2313_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny2313V-10P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA2/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA1/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA0/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny2313V-10S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny2313V-10S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2543-AVR-ATtiny2313_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny2313V-10S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA2/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA1/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA0/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny24A-CC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny24A-CC'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-15_3.0x3.0mm_Layout4x4_P0.65mm'], 'footprint':'Package_BGA:UFBGA-15_3.0x3.0mm_Layout4x4_P0.65mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8183.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny24A-CC\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='A2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny24A-MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny24A-MM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_3x3mm_P0.45mm_EP1.6x1.6mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_3x3mm_P0.45mm_EP1.6x1.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8183.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny24A-MM\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny24V-10M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny24V-10M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8006.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny24V-10M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny24V-10P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny24V-10P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-14_W7.62mm'], 'footprint':'Package_DIP:DIP-14_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8006.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny24V-10P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny24V-10SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny24V-10SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8006.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny24V-10SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny25V-10M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny25V-10M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2586-avr-8-bit-microcontroller-attiny25-attiny45-attiny85_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny25V-10M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='XTAL1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='XTAL2/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny25V-10P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny25V-10P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2586-avr-8-bit-microcontroller-attiny25-attiny45-attiny85_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny25V-10P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny25V-10S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny25V-10S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2586-avr-8-bit-microcontroller-attiny25-attiny45-attiny85_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny25V-10S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny25V-10SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny25V-10SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2586-avr-8-bit-microcontroller-attiny25-attiny45-attiny85_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny25V-10SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny261A-X', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny261A-X'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8197.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny261A-X\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny26L-8M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny26L-8M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc1477.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny26L-8M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='29',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny26L-8P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny26L-8P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc1477.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny26L-8P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny26L-8S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny26L-8S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc1477.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny26L-8S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny28V-1A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny28V-1A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller tinyAVR IR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc1062.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny28V-1A\n\nAVR 8bit Microcontroller tinyAVR IR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny28V-1M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny28V-1M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller tinyAVR IR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc1062.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny28V-1M\n\nAVR 8bit Microcontroller tinyAVR IR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny28V-1P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny28V-1P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR IR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc1062.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny28V-1P\n\nAVR 8bit Microcontroller tinyAVR IR', 'pins':[
            Pin(num='1',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='XTAL1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny4-MA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny4-MA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.9x1.5mm'], 'footprint':'Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.9x1.5mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8127-AVR-8-bit-Microcontroller-ATtiny4-ATtiny5-ATtiny9-ATtiny10_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny4-MA\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny4-TS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny4-TS'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8127-AVR-8-bit-Microcontroller-ATtiny4-ATtiny5-ATtiny9-ATtiny10_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny4-TS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny40-MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny40-MM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_3x3mm_P0.45mm_EP1.6x1.6mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_3x3mm_P0.45mm_EP1.6x1.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8263-8-bit-avr-microcontroller-tinyavr-attiny40_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny40-MM\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='~{RESET}/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny40-S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny40-S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8263-8-bit-avr-microcontroller-tinyavr-attiny40_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny40-S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='~{RESET}/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny40-X', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny40-X'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-8263-8-bit-avr-microcontroller-tinyavr-attiny40_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny40-X\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='~{RESET}/PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny406-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny406-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm'], 'footprint':'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Microchip%208bit%20mcu%20AVR%20ATtiny406%20data%20sheet%2040001976A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny406-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny406-S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny406-S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Microchip%208bit%20mcu%20AVR%20ATtiny406%20data%20sheet%2040001976A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny406-S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny43U-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny43U-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR Battery Boost', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8048.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny43U-M\n\nAVR 8bit Microcontroller tinyAVR Battery Boost', 'pins':[
            Pin(num='1',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='~{RESET}/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='LSW',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny43U-S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny43U-S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR Battery Boost', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8048.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny43U-S\n\nAVR 8bit Microcontroller tinyAVR Battery Boost', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='LSW',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny441-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny441-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8495-8-bit-AVR-Microcontrollers-ATtiny441-ATtiny841_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny441-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny441-MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny441-MM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_3x3mm_P0.45mm_EP1.6x1.6mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_3x3mm_P0.45mm_EP1.6x1.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8495-8-bit-AVR-Microcontrollers-ATtiny441-ATtiny841_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny441-MM\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny441-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny441-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8495-8-bit-AVR-Microcontrollers-ATtiny441-ATtiny841_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny441-SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny45V-10X', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny45V-10X'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-8_4.4x3mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-8_4.4x3mm_P0.65mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2586-avr-8-bit-microcontroller-attiny25-attiny45-attiny85_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny45V-10X\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny461V-10M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny461V-10M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2588-8-bit-avr-microcontrollers-tinyavr-attiny261-attiny461-attiny861_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny461V-10M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='29',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny461V-10P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny461V-10P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2588-8-bit-avr-microcontrollers-tinyavr-attiny261-attiny461-attiny861_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny461V-10P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny461V-10S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny461V-10S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2588-8-bit-avr-microcontrollers-tinyavr-attiny261-attiny461-attiny861_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny461V-10S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny48-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny48-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8008.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny48-A\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny48-CC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny48-CC'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm'], 'footprint':'Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8008.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny48-CC\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='A1',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PB4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny48-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny48-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8008.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny48-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny48-MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny48-MM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8008.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny48-MM\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny48-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny48-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8008.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny48-P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny807-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny807-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny807_1607-Data-Sheet-40002030A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny807-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny828-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny828-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8371.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny828-A\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD2/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny828-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny828-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8371.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny828-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD2/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny87-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny87-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller tinyAVR Automotive', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8265-8-bit-AVR-Microcontroller-tinyAVR-ATtiny87-ATtiny167_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny87-M\n\nAVR 8bit Microcontroller tinyAVR Automotive', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='AREF/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny87-S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny87-S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR Automotive', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8265-8-bit-AVR-Microcontroller-tinyAVR-ATtiny87-ATtiny167_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny87-S\n\nAVR 8bit Microcontroller tinyAVR Automotive', 'pins':[
            Pin(num='1',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AREF/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny87-X', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny87-X'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'AVR 8bit Microcontroller tinyAVR Automotive', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8265-8-bit-AVR-Microcontroller-tinyAVR-ATtiny87-ATtiny167_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny87-X\n\nAVR 8bit Microcontroller tinyAVR Automotive', 'pins':[
            Pin(num='1',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AREF/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny10-MA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny10-MA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.9x1.5mm', 'Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.9x1.5mm'], 'footprint':'Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.9x1.5mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8127-AVR-8-bit-Microcontroller-ATtiny4-ATtiny5-ATtiny9-ATtiny10_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny10-MA\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny10-TS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny10-TS'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8127-AVR-8-bit-Microcontroller-ATtiny4-ATtiny5-ATtiny9-ATtiny10_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny10-TS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny13-20M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny13-20M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2535.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny13-20M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny13-20MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny13-20MM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-10-1EP_3x3mm_P0.5mm_EP1.75x2.7mm', 'Package_DFN_QFN:DFN-10-1EP_3x3mm_P0.5mm_EP1.75x2.7mm'], 'footprint':'Package_DFN_QFN:DFN-10-1EP_3x3mm_P0.5mm_EP1.75x2.7mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2535.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny13-20MM\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny13-20P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny13-20P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2535.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny13-20P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny13-20S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny13-20S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm', 'Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2535.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny13-20S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny13-20SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny13-20SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc2535.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny13-20SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny13A-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny13A-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8126.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny13A-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny13A-MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny13A-MM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-10-1EP_3x3mm_P0.5mm_EP1.75x2.7mm', 'Package_DFN_QFN:DFN-10-1EP_3x3mm_P0.5mm_EP1.75x2.7mm', 'Package_DFN_QFN:DFN-10-1EP_3x3mm_P0.5mm_EP1.75x2.7mm'], 'footprint':'Package_DFN_QFN:DFN-10-1EP_3x3mm_P0.5mm_EP1.75x2.7mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8126.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny13A-MM\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny13A-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny13A-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8126.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny13A-P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny13A-S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny13A-S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm', 'Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm', 'Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8126.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny13A-S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny13A-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny13A-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8126.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny13A-SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny1604-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny1604-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny804_1604-Data-Sheet-40002028A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny1604-SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny1606-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny1606-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm'], 'footprint':'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny806_1606_Data_Sheet_40002029A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny1606-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny1606-S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny1606-S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny806_1606_Data_Sheet_40002029A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny1606-S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny1607-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny1607-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny807_1607-Data-Sheet-40002030A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny1607-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny1614-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny1614-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny1614-data-sheet-40001995A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny1614-SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny1616-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny1616-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm'], 'footprint':'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny3216_ATtiny1616-data-sheet-40001997B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny1616-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny1616-S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny1616-S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny3216_ATtiny1616-data-sheet-40001997B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny1616-S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny1617-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny1617-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny3217_1617-Data-Sheet-40001999B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny1617-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny1624-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny1624-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny1624-26-27-DataSheet-DS40002234A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny1624-SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny1624-X', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny1624-X'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny1624-26-27-DataSheet-DS40002234A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny1624-X\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny1626-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny1626-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm'], 'footprint':'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny1624-26-27-DataSheet-DS40002234A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny1626-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny1626-S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny1626-S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny1624-26-27-DataSheet-DS40002234A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny1626-S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny1626-X', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny1626-X'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny1624-26-27-DataSheet-DS40002234A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny1626-X\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny1627-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny1627-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny1624-26-27-DataSheet-DS40002234A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny1627-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny167-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny167-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller tinyAVR Automotive', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8265-8-bit-AVR-Microcontroller-tinyAVR-ATtiny87-ATtiny167_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny167-M\n\nAVR 8bit Microcontroller tinyAVR Automotive', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='AREF/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny167-S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny167-S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR Automotive', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8265-8-bit-AVR-Microcontroller-tinyAVR-ATtiny87-ATtiny167_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny167-S\n\nAVR 8bit Microcontroller tinyAVR Automotive', 'pins':[
            Pin(num='1',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AREF/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny167-X', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny167-X'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'AVR 8bit Microcontroller tinyAVR Automotive', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8265-8-bit-AVR-Microcontroller-tinyAVR-ATtiny87-ATtiny167_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny167-X\n\nAVR 8bit Microcontroller tinyAVR Automotive', 'pins':[
            Pin(num='1',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AREF/PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny212-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny212-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001911A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny212-SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny214-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny214-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001912A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny214-SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny2313-20M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny2313-20M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:MLF-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:MLF-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:MLF-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2543-AVR-ATtiny2313_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny2313-20M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PA2/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA1/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA0/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PD6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny2313-20P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny2313-20P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2543-AVR-ATtiny2313_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny2313-20P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA2/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA1/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA0/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny2313-20S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny2313-20S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-2543-AVR-ATtiny2313_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny2313-20S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA2/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA1/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA0/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny2313A-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny2313A-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:MLF-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:MLF-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:MLF-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:MLF-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8246.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny2313A-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PA2/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA1/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA0/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PD6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny2313A-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny2313A-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8246.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny2313A-P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA2/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA1/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA0/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny2313A-S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny2313A-S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8246.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny2313A-S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA2/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA1/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA0/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny24-20M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny24-20M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8006.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny24-20M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny24-20P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny24-20P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm'], 'footprint':'Package_DIP:DIP-14_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8006.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny24-20P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny24-20SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny24-20SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8006.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny24-20SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny24A-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny24A-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8183.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny24A-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny24A-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny24A-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm'], 'footprint':'Package_DIP:DIP-14_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8183.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny24A-P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny24A-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny24A-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8183.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny24A-SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny25-20M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny25-20M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2586-avr-8-bit-microcontroller-attiny25-attiny45-attiny85_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny25-20M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='XTAL1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='XTAL2/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny25-20P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny25-20P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2586-avr-8-bit-microcontroller-attiny25-attiny45-attiny85_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny25-20P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny25-20S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny25-20S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm', 'Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2586-avr-8-bit-microcontroller-attiny25-attiny45-attiny85_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny25-20S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny25-20SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny25-20SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2586-avr-8-bit-microcontroller-attiny25-attiny45-attiny85_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny25-20SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny26-16M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny26-16M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc1477.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny26-16M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='29',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny26-16P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny26-16P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc1477.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny26-16P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny26-16S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny26-16S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc1477.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny26-16S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny261A-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny261A-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8197.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny261A-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='29',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny261A-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny261A-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8197.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny261A-P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny261A-S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny261A-S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8197.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny261A-S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny28L-4A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny28L-4A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller tinyAVR IR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc1062.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny28L-4A\n\nAVR 8bit Microcontroller tinyAVR IR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny28L-4M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny28L-4M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller tinyAVR IR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc1062.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny28L-4M\n\nAVR 8bit Microcontroller tinyAVR IR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny28L-4P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny28L-4P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR IR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc1062.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny28L-4P\n\nAVR 8bit Microcontroller tinyAVR IR', 'pins':[
            Pin(num='1',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='XTAL1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny3216-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny3216-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm'], 'footprint':'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny3216_ATtiny1616-data-sheet-40001997B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny3216-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny3216-S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny3216-S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny3216_ATtiny1616-data-sheet-40001997B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny3216-S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny3217-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny3217-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny3217_1617-Data-Sheet-40001999B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny3217-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny3224-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny3224-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny3224-3226-3227-Data-Sheet-DS40002345A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny3224-SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny3224-X', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny3224-X'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny3224-3226-3227-Data-Sheet-DS40002345A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny3224-X\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny3226-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny3226-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm'], 'footprint':'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny3224-3226-3227-Data-Sheet-DS40002345A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny3226-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny3226-S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny3226-S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny3224-3226-3227-Data-Sheet-DS40002345A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny3226-S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny3226-X', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny3226-X'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny3224-3226-3227-Data-Sheet-DS40002345A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny3226-X\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny3227-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny3227-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny3224-3226-3227-Data-Sheet-DS40002345A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny3227-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny402-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny402-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny202-402-AVR-MCU-with-Core-Independent-Peripherals_and-picoPower-40001969A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny402-SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny404-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny404-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/50002687A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny404-SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny412-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny412-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001911A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny412-SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny414-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny414-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001912A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny414-SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny416-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny416-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm'], 'footprint':'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001913A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny416-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny416-S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny416-S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001913A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny416-S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny417-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny417-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001901B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny417-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny424-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny424-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny424-426-427-824-826-827-DataSheet-DS40002311A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny424-SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny424-X', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny424-X'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny424-426-427-824-826-827-DataSheet-DS40002311A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny424-X\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny426-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny426-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm'], 'footprint':'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny424-426-427-824-826-827-DataSheet-DS40002311A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny426-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny426-S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny426-S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny424-426-427-824-826-827-DataSheet-DS40002311A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny426-S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny426-X', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny426-X'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny424-426-427-824-826-827-DataSheet-DS40002311A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny426-X\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny427-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny427-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny424-426-427-824-826-827-DataSheet-DS40002311A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny427-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny4313-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny4313-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:MLF-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:MLF-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:MLF-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:MLF-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:MLF-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8246.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny4313-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PA2/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA1/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA0/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PD6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny4313-MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny4313-MM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.45mm_EP1.55x1.55mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.45mm_EP1.55x1.55mm'], 'footprint':'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.45mm_EP1.55x1.55mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8246.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny4313-MM\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PA2/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA1/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA0/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PD6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny4313-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny4313-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8246.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny4313-P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA2/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA1/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA0/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny4313-S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny4313-S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8246.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny4313-S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA2/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA1/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA0/XTAL1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny44-20M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny44-20M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8006.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny44-20M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny44-20P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny44-20P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm'], 'footprint':'Package_DIP:DIP-14_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8006.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny44-20P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny44-20SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny44-20SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8006.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny44-20SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny44A-CC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny44A-CC'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-15_3.0x3.0mm_Layout4x4_P0.65mm', 'Package_BGA:UFBGA-15_3.0x3.0mm_Layout4x4_P0.65mm'], 'footprint':'Package_BGA:UFBGA-15_3.0x3.0mm_Layout4x4_P0.65mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8183.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny44A-CC\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='A2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny44A-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny44A-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8183.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny44A-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny44A-MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny44A-MM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_3x3mm_P0.45mm_EP1.6x1.6mm', 'Package_DFN_QFN:QFN-20-1EP_3x3mm_P0.45mm_EP1.6x1.6mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_3x3mm_P0.45mm_EP1.6x1.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8183.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny44A-MM\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny44A-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny44A-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm'], 'footprint':'Package_DIP:DIP-14_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8183.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny44A-P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny44A-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny44A-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8183.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny44A-SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny44V-10M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny44V-10M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8006.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny44V-10M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny44V-10P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny44V-10P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm'], 'footprint':'Package_DIP:DIP-14_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8006.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny44V-10P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny44V-10SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny44V-10SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8006.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny44V-10SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny45-20M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny45-20M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2586-avr-8-bit-microcontroller-attiny25-attiny45-attiny85_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny45-20M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='XTAL1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='XTAL2/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny45-20P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny45-20P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2586-avr-8-bit-microcontroller-attiny25-attiny45-attiny85_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny45-20P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny45-20S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny45-20S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm', 'Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm', 'Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2586-avr-8-bit-microcontroller-attiny25-attiny45-attiny85_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny45-20S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny45-20X', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny45-20X'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-8_4.4x3mm_P0.65mm', 'Package_SO:TSSOP-8_4.4x3mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-8_4.4x3mm_P0.65mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2586-avr-8-bit-microcontroller-attiny25-attiny45-attiny85_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny45-20X\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny45V-10M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny45V-10M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2586-avr-8-bit-microcontroller-attiny25-attiny45-attiny85_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny45V-10M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='XTAL1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='XTAL2/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny45V-10P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny45V-10P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2586-avr-8-bit-microcontroller-attiny25-attiny45-attiny85_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny45V-10P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny45V-10S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny45V-10S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm', 'Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm', 'Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm', 'Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2586-avr-8-bit-microcontroller-attiny25-attiny45-attiny85_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny45V-10S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny461-20M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny461-20M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2588-8-bit-avr-microcontrollers-tinyavr-attiny261-attiny461-attiny861_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny461-20M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='29',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny461-20P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny461-20P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2588-8-bit-avr-microcontrollers-tinyavr-attiny261-attiny461-attiny861_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny461-20P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny461-20S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny461-20S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2588-8-bit-avr-microcontrollers-tinyavr-attiny261-attiny461-attiny861_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny461-20S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny461A-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny461A-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8197.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny461A-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='29',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny461A-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny461A-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8197.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny461A-P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny461A-S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny461A-S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8197.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny461A-S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny461A-X', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny461A-X'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8197.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny461A-X\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny5-MA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny5-MA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.9x1.5mm', 'Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.9x1.5mm', 'Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.9x1.5mm'], 'footprint':'Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.9x1.5mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8127-AVR-8-bit-Microcontroller-ATtiny4-ATtiny5-ATtiny9-ATtiny10_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny5-MA\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny5-TS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny5-TS'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8127-AVR-8-bit-Microcontroller-ATtiny4-ATtiny5-ATtiny9-ATtiny10_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny5-TS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny804-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny804-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny804_1604-Data-Sheet-40002028A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny804-SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny806-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny806-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm'], 'footprint':'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny806_1606_Data_Sheet_40002029A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny806-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny806-S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny806-S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny806_1606_Data_Sheet_40002029A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny806-S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny814-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny814-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001912A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny814-SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny816-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny816-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm'], 'footprint':'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001913A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny816-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny816-S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny816-S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001913A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny816-S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny817-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny817-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/40001901B.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny817-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny824-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny824-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny424-426-427-824-826-827-DataSheet-DS40002311A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny824-SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny824-X', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny824-X'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny424-426-427-824-826-827-DataSheet-DS40002311A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny824-X\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny826-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny826-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm'], 'footprint':'Package_DFN_QFN:VQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny424-426-427-824-826-827-DataSheet-DS40002311A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny826-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny826-S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny826-S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny424-426-427-824-826-827-DataSheet-DS40002311A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny826-S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny826-X', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny826-X'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SSOP-20_5.3x7.2mm_P0.65mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny424-426-427-824-826-827-DataSheet-DS40002311A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny826-X\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny827-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny827-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'https://ww1.microchip.com/downloads/en/DeviceDoc/ATtiny424-426-427-824-826-827-DataSheet-DS40002311A.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny827-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='~{RESET}/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny84-20M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny84-20M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8006.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny84-20M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny84-20P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny84-20P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm'], 'footprint':'Package_DIP:DIP-14_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8006.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny84-20P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny84-20SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny84-20SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8006.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny84-20SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny841-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny841-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8495-8-bit-AVR-Microcontrollers-ATtiny441-ATtiny841_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny841-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny841-MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny841-MM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_3x3mm_P0.45mm_EP1.6x1.6mm', 'Package_DFN_QFN:QFN-20-1EP_3x3mm_P0.45mm_EP1.6x1.6mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_3x3mm_P0.45mm_EP1.6x1.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8495-8-bit-AVR-Microcontrollers-ATtiny441-ATtiny841_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny841-MM\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny841-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny841-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8495-8-bit-AVR-Microcontrollers-ATtiny441-ATtiny841_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny841-SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny84A-CC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny84A-CC'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-15_3.0x3.0mm_Layout4x4_P0.65mm', 'Package_BGA:UFBGA-15_3.0x3.0mm_Layout4x4_P0.65mm', 'Package_BGA:UFBGA-15_3.0x3.0mm_Layout4x4_P0.65mm'], 'footprint':'Package_BGA:UFBGA-15_3.0x3.0mm_Layout4x4_P0.65mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8183.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny84A-CC\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='A2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny84A-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny84A-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8183.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny84A-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny84A-MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny84A-MM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_3x3mm_P0.45mm_EP1.6x1.6mm', 'Package_DFN_QFN:QFN-20-1EP_3x3mm_P0.45mm_EP1.6x1.6mm', 'Package_DFN_QFN:QFN-20-1EP_3x3mm_P0.45mm_EP1.6x1.6mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_3x3mm_P0.45mm_EP1.6x1.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8183.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny84A-MM\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny84A-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny84A-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm'], 'footprint':'Package_DIP:DIP-14_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8183.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny84A-P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny84A-SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny84A-SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8183.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny84A-SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny84V-10M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny84V-10M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8006.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny84V-10M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny84V-10P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny84V-10P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm'], 'footprint':'Package_DIP:DIP-14_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8006.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny84V-10P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny84V-10SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny84V-10SS'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8006.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny84V-10SS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AREF/PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='XTAL1/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny85-20M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny85-20M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2586-avr-8-bit-microcontroller-attiny25-attiny45-attiny85_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny85-20M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='XTAL1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='XTAL2/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny85-20P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny85-20P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2586-avr-8-bit-microcontroller-attiny25-attiny45-attiny85_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny85-20P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny85-20S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny85-20S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm', 'Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm', 'Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm', 'Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm', 'Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2586-avr-8-bit-microcontroller-attiny25-attiny45-attiny85_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny85-20S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny85V-10M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny85V-10M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-20-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2586-avr-8-bit-microcontroller-attiny25-attiny45-attiny85_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny85V-10M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='XTAL1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='XTAL2/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny85V-10P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny85V-10P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm', 'Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2586-avr-8-bit-microcontroller-attiny25-attiny45-attiny85_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny85V-10P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny85V-10S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny85V-10S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm', 'Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm', 'Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm', 'Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm', 'Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm', 'Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8W_5.3x5.3mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2586-avr-8-bit-microcontroller-attiny25-attiny45-attiny85_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny85V-10S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTAL1/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XTAL2/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='AREF/PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny861-20M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny861-20M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2588-8-bit-avr-microcontrollers-tinyavr-attiny261-attiny461-attiny861_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny861-20M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='29',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny861-20P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny861-20P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2588-8-bit-avr-microcontrollers-tinyavr-attiny261-attiny461-attiny861_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny861-20P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny861-20S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny861-20S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2588-8-bit-avr-microcontrollers-tinyavr-attiny261-attiny461-attiny861_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny861-20S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny861A-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny861A-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8197.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny861A-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='29',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny861A-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny861A-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8197.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny861A-P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny861A-S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny861A-S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8197.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny861A-S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny861A-X', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny861A-X'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8197.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny861A-X\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny861V-10M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny861V-10M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2588-8-bit-avr-microcontrollers-tinyavr-attiny261-attiny461-attiny861_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny861V-10M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='29',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='30',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny861V-10P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny861V-10P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2588-8-bit-avr-microcontrollers-tinyavr-attiny261-attiny461-attiny861_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny861V-10P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny861V-10S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny861V-10S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/atmel-2588-8-bit-avr-microcontrollers-tinyavr-attiny261-attiny461-attiny861_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny861V-10S\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='~{RESET}/PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AREF/PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='XTAL1/PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='XTAL2/PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny88-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny88-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm', 'Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8008.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny88-A\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny88-CC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny88-CC'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm', 'Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm'], 'footprint':'Package_BGA:UFBGA-32_4.0x4.0mm_Layout6x6_P0.5mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8008.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny88-CC\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='A1',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PB4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny88-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny88-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8008.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny88-M\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny88-MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny88-MM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.45mm_EP2.4x2.4mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8008.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny88-MM\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny88-P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny88-P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc8008.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny88-P\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='~{RESET}/PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny9-MA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny9-MA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.9x1.5mm', 'Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.9x1.5mm', 'Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.9x1.5mm', 'Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.9x1.5mm'], 'footprint':'Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.9x1.5mm', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8127-AVR-8-bit-Microcontroller-ATtiny4-ATtiny5-ATtiny9-ATtiny10_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny9-MA\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PB2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATtiny9-TS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATtiny9-TS'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'AVR 8bit Microcontroller tinyAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/Atmel-8127-AVR-8-bit-Microcontroller-ATtiny4-ATtiny5-ATtiny9-ATtiny10_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_ATtiny.kicad_sym\nATtiny9-TS\n\nAVR 8bit Microcontroller tinyAVR', 'pins':[
            Pin(num='1',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~{RESET}/PB3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])