from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Relay = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'AZ850-x', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AZ850-x'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_FRT5'], 'footprint':'Relay_THT:Relay_DPDT_FRT5', 'keywords':'Miniature Polarised Relay Dual Pole', 'description':'', 'datasheet':'http://www.azettler.com/pdfs/az850.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nAZ850-x\n\nMiniature Polarised Relay Dual Pole', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AZ850P2-x', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AZ850P2-x'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_FRT5'], 'footprint':'Relay_THT:Relay_DPDT_FRT5', 'keywords':'Miniature Polarised Relay Dual Pole Bistable', 'description':'', 'datasheet':'http://www.azettler.com/pdfs/az850.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nAZ850P2-x\n\nMiniature Polarised Relay Dual Pole Bistable', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AZSR131-1AE-12D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AZSR131-1AE-12D'}), 'ref_prefix':'RL2', 'fplist':['Relay_THT:Relay_SPST_Zettler-AZSR131'], 'footprint':'Relay_THT:Relay_SPST_Zettler-AZSR131', 'keywords':'Single Pole Reed Relay SPST', 'description':'', 'datasheet':'https://www.azettler.com/pdfs/azsr131.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nAZSR131-1AE-12D\n\nSingle Pole Reed Relay SPST', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'COTO_3602_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'COTO_3602_Split'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPST_COTO_3602'], 'footprint':'Relay_THT:Relay_DPST_COTO_3602', 'keywords':'reed relay low thermal emf', 'description':'', 'datasheet':'https://cotorelay.com/wp-content/uploads/2014/09/3600_series_reed_relay_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nCOTO_3602_Split\n\nreed relay low thermal emf', 'pins':[
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='23',name='~',func=pin_types.PASSIVE,unit=3),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['A2', 'A1', 'SH']},{'label': 'uB', 'num': 2, 'pin_nums': ['13', '14']},{'label': 'uC', 'num': 3, 'pin_nums': ['23', '24']}] }),
        Part(**{ 'name':'COTO_3650_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'COTO_3650_Split'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_3PST_COTO_3650'], 'footprint':'Relay_THT:Relay_3PST_COTO_3650', 'keywords':'reed relay low thermal emf', 'description':'', 'datasheet':'https://cotorelay.com/wp-content/uploads/2014/09/3600_series_reed_relay_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nCOTO_3650_Split\n\nreed relay low thermal emf', 'pins':[
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SH',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='23',name='~',func=pin_types.PASSIVE,unit=3),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=3),
            Pin(num='33',name='~',func=pin_types.PASSIVE,unit=4),
            Pin(num='34',name='~',func=pin_types.PASSIVE,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['A1', 'A2', 'SH']},{'label': 'uB', 'num': 2, 'pin_nums': ['13', '14']},{'label': 'uC', 'num': 3, 'pin_nums': ['23', '24']},{'label': 'uD', 'num': 4, 'pin_nums': ['34', '33']}] }),
        Part(**{ 'name':'COTO_3660_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'COTO_3660_Split'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_3PST_COTO_3660'], 'footprint':'Relay_THT:Relay_3PST_COTO_3660', 'keywords':'reed relay low thermal emf', 'description':'', 'datasheet':'https://cotorelay.com/wp-content/uploads/2014/09/3600_series_reed_relay_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nCOTO_3660_Split\n\nreed relay low thermal emf', 'pins':[
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='23',name='~',func=pin_types.PASSIVE,unit=3),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=3),
            Pin(num='33',name='~',func=pin_types.PASSIVE,unit=4),
            Pin(num='34',name='~',func=pin_types.PASSIVE,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['A1', 'A2']},{'label': 'uB', 'num': 2, 'pin_nums': ['13', '14']},{'label': 'uC', 'num': 3, 'pin_nums': ['23', '24']},{'label': 'uD', 'num': 4, 'pin_nums': ['33', '34']}] }),
        Part(**{ 'name':'DIPxx-1Axx-11x', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIPxx-1Axx-11x'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_StandexMeder_DIP_LowProfile'], 'footprint':'Relay_THT:Relay_StandexMeder_DIP_LowProfile', 'keywords':'Single Pole Reed Relay SPST', 'description':'', 'datasheet':'https://standexelectronics.com/wp-content/uploads/datasheet_reed_relay_DIP.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nDIPxx-1Axx-11x\n\nSingle Pole Reed Relay SPST', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIPxx-1Axx-12x', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIPxx-1Axx-12x'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_StandexMeder_DIP_LowProfile'], 'footprint':'Relay_THT:Relay_StandexMeder_DIP_LowProfile', 'keywords':'Single Pole Reed Relay SPST', 'description':'', 'datasheet':'https://standexelectronics.com/wp-content/uploads/datasheet_reed_relay_DIP.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nDIPxx-1Axx-12x\n\nSingle Pole Reed Relay SPST', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIPxx-1Axx-12xD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIPxx-1Axx-12xD'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_StandexMeder_DIP_LowProfile'], 'footprint':'Relay_THT:Relay_StandexMeder_DIP_LowProfile', 'keywords':'Single Pole Reed Relay SPST', 'description':'', 'datasheet':'https://standexelectronics.com/wp-content/uploads/datasheet_reed_relay_DIP.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nDIPxx-1Axx-12xD\n\nSingle Pole Reed Relay SPST', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIPxx-1Axx-13x', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIPxx-1Axx-13x'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_StandexMeder_DIP_LowProfile'], 'footprint':'Relay_THT:Relay_StandexMeder_DIP_LowProfile', 'keywords':'Single Pole Reed Relay SPST', 'description':'', 'datasheet':'https://standexelectronics.com/wp-content/uploads/datasheet_reed_relay_DIP.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nDIPxx-1Axx-13x\n\nSingle Pole Reed Relay SPST', 'pins':[
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIPxx-1Cxx-51x', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIPxx-1Cxx-51x'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_StandexMeder_DIP_LowProfile'], 'footprint':'Relay_THT:Relay_StandexMeder_DIP_LowProfile', 'keywords':'Single Pole Reed Relay SPDT', 'description':'', 'datasheet':'https://standexelectronics.com/wp-content/uploads/datasheet_reed_relay_DIP.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nDIPxx-1Cxx-51x\n\nSingle Pole Reed Relay SPDT', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIPxx-2Axx-21x', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIPxx-2Axx-21x'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_StandexMeder_DIP_LowProfile'], 'footprint':'Relay_THT:Relay_StandexMeder_DIP_LowProfile', 'keywords':'Single Pole Reed Relay DPST', 'description':'', 'datasheet':'https://standexelectronics.com/wp-content/uploads/datasheet_reed_relay_DIP.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nDIPxx-2Axx-21x\n\nSingle Pole Reed Relay DPST', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EC2-3NU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EC2-3NU'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Kemet_EC2'], 'footprint':'Relay_THT:Relay_DPDT_Kemet_EC2', 'keywords':'signal relay double pole double throw DPDT DC coil non latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEC2-3NU\n\nsignal relay double pole double throw DPDT DC coil non latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EC2-3SNU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EC2-3SNU'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Kemet_EC2'], 'footprint':'Relay_THT:Relay_DPDT_Kemet_EC2', 'keywords':'signal relay double pole double throw DPDT DC coil single coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEC2-3SNU\n\nsignal relay double pole double throw DPDT DC coil single coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EC2-3TNU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EC2-3TNU'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Kemet_EC2_DoubleCoil'], 'footprint':'Relay_THT:Relay_DPDT_Kemet_EC2_DoubleCoil', 'keywords':'signal relay double pole double throw DPDT DC coil double dual coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEC2-3TNU\n\nsignal relay double pole double throw DPDT DC coil double dual coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-3NKX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-3NKX'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'keywords':'signal relay double pole double throw DPDT DC coil non latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-3NKX\n\nsignal relay double pole double throw DPDT DC coil non latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-3NU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-3NU'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NU'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'keywords':'signal relay double pole double throw DPDT DC coil non latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-3NU\n\nsignal relay double pole double throw DPDT DC coil non latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-3NUH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-3NUH'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUH'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'keywords':'signal relay double pole double throw DPDT DC coil non latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-3NUH\n\nsignal relay double pole double throw DPDT DC coil non latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-3NUX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-3NUX'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'keywords':'signal relay double pole double throw DPDT DC coil non latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-3NUX\n\nsignal relay double pole double throw DPDT DC coil non latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-3SNU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-3SNU'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NU'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'keywords':'signal relay double pole double throw DPDT DC coil single coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-3SNU\n\nsignal relay double pole double throw DPDT DC coil single coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-3SNUH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-3SNUH'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUH'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'keywords':'signal relay double pole double throw DPDT DC coil single coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-3SNUH\n\nsignal relay double pole double throw DPDT DC coil single coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-3SNUX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-3SNUX'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'keywords':'signal relay double pole double throw DPDT DC coil single coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-3SNUX\n\nsignal relay double pole double throw DPDT DC coil single coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-3TNU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-3TNU'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NU_DoubleCoil'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NU_DoubleCoil', 'keywords':'signal relay double pole double throw DPDT DC coil double dual coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-3TNU\n\nsignal relay double pole double throw DPDT DC coil double dual coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-3TNUH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-3TNUH'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUH_DoubleCoil'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH_DoubleCoil', 'keywords':'signal relay double pole double throw DPDT DC coil double dual coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-3TNUH\n\nsignal relay double pole double throw DPDT DC coil double dual coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-3TNUX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-3TNUX'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_DoubleCoil'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_DoubleCoil', 'keywords':'signal relay double pole double throw DPDT DC coil double dual coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-3TNUX\n\nsignal relay double pole double throw DPDT DC coil double dual coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FINDER-30.22', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FINDER-30.22'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Finder_30.22'], 'footprint':'Relay_THT:Relay_DPDT_Finder_30.22', 'keywords':'Dual Pole Relay', 'description':'', 'datasheet':'http://gfinder.findernet.com/assets/Series/354/S30EN.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nFINDER-30.22\n\nDual Pole Relay', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FINDER-32.21-x000', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FINDER-32.21-x000'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPDT_Finder_32.21-x000'], 'footprint':'Relay_THT:Relay_SPDT_Finder_32.21-x000', 'keywords':'Single Pole Relay', 'description':'', 'datasheet':'https://gfinder.findernet.com/assets/Series/355/S32EN.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nFINDER-32.21-x000\n\nSingle Pole Relay', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FINDER-32.21-x300', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FINDER-32.21-x300'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_Finder_32.21-x300'], 'footprint':'Relay_THT:Relay_SPST_Finder_32.21-x300', 'keywords':'Single Pole Relay SPST-NO', 'description':'', 'datasheet':'http://gfinder.findernet.com/assets/Series/355/S32EN.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nFINDER-32.21-x300\n\nSingle Pole Relay SPST-NO', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FINDER-34.51', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FINDER-34.51'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPDT_Finder_34.51_Vertical'], 'footprint':'Relay_THT:Relay_SPDT_Finder_34.51_Vertical', 'keywords':'Single Pole Relay SPDT', 'description':'', 'datasheet':'https://gfinder.findernet.com/public/attachments/34/EN/S34USAEN.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nFINDER-34.51\n\nSingle Pole Relay SPDT', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FINDER-34.51.7xxx.x019', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FINDER-34.51.7xxx.x019'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPDT_Finder_34.51_Horizontal'], 'footprint':'Relay_THT:Relay_SPDT_Finder_34.51_Horizontal', 'keywords':'Single Pole Relay SPDT', 'description':'', 'datasheet':'https://gfinder.findernet.com/public/attachments/34/EN/S34USAEN.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nFINDER-34.51.7xxx.x019\n\nSingle Pole Relay SPDT', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FINDER-36.11', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FINDER-36.11'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPDT_Finder_36.11'], 'footprint':'Relay_THT:Relay_SPDT_Finder_36.11', 'keywords':'spdt relay', 'description':'', 'datasheet':'https://gfinder.findernet.com/public/attachments/36/EN/S36EN.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nFINDER-36.11\n\nspdt relay', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FINDER-40.11', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FINDER-40.11'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPDT_Finder_40.11'], 'footprint':'Relay_THT:Relay_SPDT_Finder_40.11', 'keywords':'Single Pole Relay SPDT Finder', 'description':'', 'datasheet':'https://www.finder-relais.net/de/finder-relais-serie-40.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nFINDER-40.11\n\nSingle Pole Relay SPDT Finder', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FINDER-40.31', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FINDER-40.31'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPDT_Finder_40.31'], 'footprint':'Relay_THT:Relay_SPDT_Finder_40.31', 'keywords':'Single Pole Relay', 'description':'', 'datasheet':'http://gfinder.findernet.com/assets/Series/353/S40EN.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nFINDER-40.31\n\nSingle Pole Relay', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FINDER-40.41', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FINDER-40.41'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPDT_Finder_40.41'], 'footprint':'Relay_THT:Relay_SPDT_Finder_40.41', 'keywords':'Single Pole Relay SPDT Finder', 'description':'', 'datasheet':'https://www.finder-relais.net/de/finder-relais-serie-40.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nFINDER-40.41\n\nSingle Pole Relay SPDT Finder', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FINDER-40.51', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FINDER-40.51'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPDT_Finder_40.51'], 'footprint':'Relay_THT:Relay_SPDT_Finder_40.51', 'keywords':'Single Pole Relay', 'description':'', 'datasheet':'http://gfinder.findernet.com/assets/Series/353/S40EN.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nFINDER-40.51\n\nSingle Pole Relay', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FINDER-40.52', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FINDER-40.52'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Finder_40.52'], 'footprint':'Relay_THT:Relay_DPDT_Finder_40.52', 'keywords':'Dual Pole Relay', 'description':'', 'datasheet':'http://gfinder.findernet.com/assets/Series/353/S40EN.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nFINDER-40.52\n\nDual Pole Relay', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FRT5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FRT5'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_FRT5'], 'footprint':'Relay_THT:Relay_DPDT_FRT5', 'keywords':'relay monostable', 'description':'', 'datasheet':'https://www.elpro.org/de/index.php?controller=attachment&id_attachment=8663', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nFRT5\n\nrelay monostable', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FRT5_separated', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FRT5_separated'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_FRT5'], 'footprint':'Relay_THT:Relay_DPDT_FRT5', 'keywords':'relay monostable', 'description':'', 'datasheet':'https://www.elpro.org/de/index.php?controller=attachment&id_attachment=8663', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nFRT5_separated\n\nrelay monostable', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=3),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=3),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '10']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '2', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['7', '8', '9']}] }),
        Part(**{ 'name':'Fujitsu_FTR-F1A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Fujitsu_FTR-F1A'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPST_Fujitsu_FTR-F1A'], 'footprint':'Relay_THT:Relay_DPST_Fujitsu_FTR-F1A', 'keywords':'double pole single throw relay', 'description':'', 'datasheet':'https://www.fcl.fujitsu.com/downloads/MICRO/fcai/relays/ftr-f1.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nFujitsu_FTR-F1A\n\ndouble pole single throw relay', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Fujitsu_FTR-F1C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Fujitsu_FTR-F1C'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Fujitsu_FTR-F1C'], 'footprint':'Relay_THT:Relay_DPDT_Fujitsu_FTR-F1C', 'keywords':'double pole double throw relay', 'description':'', 'datasheet':'https://www.fcl.fujitsu.com/downloads/MICRO/fcai/relays/ftr-f1.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nFujitsu_FTR-F1C\n\ndouble pole double throw relay', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'G5LE-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'G5LE-1'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPDT_Omron-G5LE-1'], 'footprint':'Relay_THT:Relay_SPDT_Omron-G5LE-1', 'keywords':'Miniature Single Pole Relay', 'description':'', 'datasheet':'http://www.omron.com/ecb/products/pdf/en-g5le.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nG5LE-1\n\nMiniature Single Pole Relay', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'G5Q-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'G5Q-1'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPDT_Omron-G5Q-1'], 'footprint':'Relay_THT:Relay_SPDT_Omron-G5Q-1', 'keywords':'Miniature Single Pole Relay', 'description':'', 'datasheet':'https://www.omron.com/ecb/products/pdf/en-g5q.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nG5Q-1\n\nMiniature Single Pole Relay', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'G5Q-1A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'G5Q-1A'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_Omron-G5Q-1A'], 'footprint':'Relay_THT:Relay_SPST_Omron-G5Q-1A', 'keywords':'Miniature Single Pole Relay', 'description':'', 'datasheet':'https://www.omron.com/ecb/products/pdf/en-g5q.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nG5Q-1A\n\nMiniature Single Pole Relay', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'G5V-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'G5V-1'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPDT_Omron_G5V-1'], 'footprint':'Relay_THT:Relay_SPDT_Omron_G5V-1', 'keywords':'Single Pole Relay SPDT', 'description':'', 'datasheet':'http://omronfs.omron.com/en_US/ecb/products/pdf/en-g5v_1.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nG5V-1\n\nSingle Pole Relay SPDT', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'G5V-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'G5V-2'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Omron_G5V-2'], 'footprint':'Relay_THT:Relay_DPDT_Omron_G5V-2', 'keywords':'Miniature Relay Dual Pole DPDT Omron', 'description':'', 'datasheet':'http://omronfs.omron.com/en_US/ecb/products/pdf/en-g5v_2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nG5V-2\n\nMiniature Relay Dual Pole DPDT Omron', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'G5V-2_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'G5V-2_Split'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Omron_G5V-2'], 'footprint':'Relay_THT:Relay_DPDT_Omron_G5V-2', 'keywords':'Miniature Relay Dual Pole DPDT Omron', 'description':'', 'datasheet':'http://omronfs.omron.com/en_US/ecb/products/pdf/en-g5v_2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nG5V-2_Split\n\nMiniature Relay Dual Pole DPDT Omron', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=3),
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=3),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['16', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '8', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['13', '9', '11']}] }),
        Part(**{ 'name':'G6E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'G6E'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPDT_Omron_G6E'], 'footprint':'Relay_THT:Relay_SPDT_Omron_G6E', 'keywords':'Single Pole Relay SPDT', 'description':'', 'datasheet':'https://www.omron.com/ecb/products/pdf/en-g6e.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nG6E\n\nSingle Pole Relay SPDT', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'G6EU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'G6EU'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPDT_Omron_G6E'], 'footprint':'Relay_THT:Relay_SPDT_Omron_G6E', 'keywords':'Single Pole Relay SPDT', 'description':'', 'datasheet':'https://www.omron.com/ecb/products/pdf/en-g6e.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nG6EU\n\nSingle Pole Relay SPDT', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'G6H-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'G6H-2'}), 'ref_prefix':'K', 'fplist':[''], 'footprint':'', 'keywords':'relay monostable', 'description':'', 'datasheet':'http://cdn-reichelt.de/documents/datenblatt/C300/G6H%23OMR.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nG6H-2\n\nrelay monostable', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'G6HU-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'G6HU-2'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Omron_G6H-2'], 'footprint':'Relay_THT:Relay_DPDT_Omron_G6H-2', 'keywords':'relay monostable', 'description':'', 'datasheet':'http://cdn-reichelt.de/documents/datenblatt/C300/G6H%23OMR.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nG6HU-2\n\nrelay monostable', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'G6K-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'G6K-2'}), 'ref_prefix':'K', 'fplist':[''], 'footprint':'', 'keywords':'Miniature Relay Dual Pole DPDT Omron', 'description':'', 'datasheet':'http://omronfs.omron.com/en_US/ecb/products/pdf/en-g6k.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nG6K-2\n\nMiniature Relay Dual Pole DPDT Omron', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'G6KU-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'G6KU-2'}), 'ref_prefix':'K', 'fplist':[''], 'footprint':'', 'keywords':'Miniature Relay Dual Pole DPDT Omron', 'description':'', 'datasheet':'http://omronfs.omron.com/en_US/ecb/products/pdf/en-g6k.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nG6KU-2\n\nMiniature Relay Dual Pole DPDT Omron', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'G6S-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'G6S-2'}), 'ref_prefix':'K', 'fplist':[''], 'footprint':'', 'keywords':'Miniature Relay Dual Pole DPDT Omron', 'description':'', 'datasheet':'http://omronfs.omron.com/en_US/ecb/products/pdf/en-g6s.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nG6S-2\n\nMiniature Relay Dual Pole DPDT Omron', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'G6SK-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'G6SK-2'}), 'ref_prefix':'K', 'fplist':[''], 'footprint':'', 'keywords':'Miniature Relay Dual Pole DPDT Omron', 'description':'', 'datasheet':'http://omronfs.omron.com/en_US/ecb/products/pdf/en-g6s.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nG6SK-2\n\nMiniature Relay Dual Pole DPDT Omron', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'G6SU-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'G6SU-2'}), 'ref_prefix':'K', 'fplist':[''], 'footprint':'', 'keywords':'Miniature Relay Dual Pole DPDT Omron', 'description':'', 'datasheet':'http://omronfs.omron.com/en_US/ecb/products/pdf/en-g6s.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nG6SU-2\n\nMiniature Relay Dual Pole DPDT Omron', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HF3-01', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HF3-01'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm'], 'footprint':'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm', 'keywords':'Single Pole Relay SPDT', 'description':'', 'datasheet':'https://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=108-98000&DocType=SS&DocLang=EN', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nHF3-01\n\nSingle Pole Relay SPDT', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HF3-51', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HF3-51'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm'], 'footprint':'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm', 'keywords':'Single Pole Relay SPDT', 'description':'', 'datasheet':'https://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=108-98000&DocType=SS&DocLang=EN', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nHF3-51\n\nSingle Pole Relay SPDT', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HONGFA_HFD2-0xx-x-L2-x', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HONGFA_HFD2-0xx-x-L2-x'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Omron_G6AK'], 'footprint':'Relay_THT:Relay_DPDT_Omron_G6AK', 'keywords':'HONGFA set-reset polarized', 'description':'', 'datasheet':'https://source_cn.hongfa.com/Api/DownloadPdf/323', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nHONGFA_HFD2-0xx-x-L2-x\n\nHONGFA set-reset polarized', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM00', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM00'}), 'ref_prefix':'K', 'fplist':[''], 'footprint':'', 'keywords':'relay monostable', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=108-98001&DocType=SS&DocLang=EN', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nIM00\n\nrelay monostable', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM11', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM11'}), 'ref_prefix':'K', 'fplist':[''], 'footprint':'', 'keywords':'relay monastable sensitive', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=108-98001&DocType=SS&DocLang=EN', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nIM11\n\nrelay monastable sensitive', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM21', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM21'}), 'ref_prefix':'K', 'fplist':[''], 'footprint':'', 'keywords':'relay monastable sensitive', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=108-98001&DocType=SS&DocLang=EN', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nIM21\n\nrelay monastable sensitive', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM40', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM40'}), 'ref_prefix':'K', 'fplist':[''], 'footprint':'', 'keywords':'relay bistable', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=108-98001&DocType=SS&DocLang=EN', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nIM40\n\nrelay bistable', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JW2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JW2'}), 'ref_prefix':'RL', 'fplist':['Relay_THT:Relay_DPDT_Panasonic_JW2'], 'footprint':'Relay_THT:Relay_DPDT_Panasonic_JW2', 'keywords':'Panasonic Relay Dual Pole', 'description':'', 'datasheet':'http://www3.panasonic.biz/ac/e_download/control/relay/power/catalog/mech_eng_jw.pdf?via=ok', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nJW2\n\nPanasonic Relay Dual Pole', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSxx-1Axx-75', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSxx-1Axx-75'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_StandexMeder_MS_Form1AB'], 'footprint':'Relay_THT:Relay_SPST_StandexMeder_MS_Form1AB', 'keywords':'Single Pole Reed Relay SPST', 'description':'', 'datasheet':'https://standexelectronics.com/wp-content/uploads/datasheets/42/4205187975e.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nMSxx-1Axx-75\n\nSingle Pole Reed Relay SPST', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSxx-1Bxx-75', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSxx-1Bxx-75'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_StandexMeder_MS_Form1AB'], 'footprint':'Relay_THT:Relay_SPST_StandexMeder_MS_Form1AB', 'keywords':'Single Pole Reed Relay SPST', 'description':'', 'datasheet':'https://standexelectronics.com/de/produkte/ms-reed-relais/', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nMSxx-1Bxx-75\n\nSingle Pole Reed Relay SPST', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RAYEX-L90', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RAYEX-L90'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPDT_RAYEX-L90'], 'footprint':'Relay_THT:Relay_SPDT_RAYEX-L90', 'keywords':'30A Single Pole Relay', 'description':'', 'datasheet':'https://a3.sofastcdn.com/attachment/7jioKBjnRiiSrjrjknRiwS77gwbf3zmp/L90-SERIES.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRAYEX-L90\n\n30A Single Pole Relay', 'pins':[
            Pin(num='11A',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='11B',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RAYEX-L90A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RAYEX-L90A'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_RAYEX-L90A'], 'footprint':'Relay_THT:Relay_SPST_RAYEX-L90A', 'keywords':'30A Single Pole Relay', 'description':'', 'datasheet':'https://a3.sofastcdn.com/attachment/7jioKBjnRiiSrjrjknRiwS77gwbf3zmp/L90-SERIES.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRAYEX-L90A\n\n30A Single Pole Relay', 'pins':[
            Pin(num='13A',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='13B',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RAYEX-L90AS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RAYEX-L90AS'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_RAYEX-L90AS'], 'footprint':'Relay_THT:Relay_SPST_RAYEX-L90AS', 'keywords':'30A Single Pole Relay', 'description':'', 'datasheet':'https://a3.sofastcdn.com/attachment/7jioKBjnRiiSrjrjknRiwS77gwbf3zmp/L90-SERIES.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRAYEX-L90AS\n\n30A Single Pole Relay', 'pins':[
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RAYEX-L90B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RAYEX-L90B'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_RAYEX-L90B'], 'footprint':'Relay_THT:Relay_SPST_RAYEX-L90B', 'keywords':'30A Single Pole Relay', 'description':'', 'datasheet':'https://a3.sofastcdn.com/attachment/7jioKBjnRiiSrjrjknRiwS77gwbf3zmp/L90-SERIES.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRAYEX-L90B\n\n30A Single Pole Relay', 'pins':[
            Pin(num='11A',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='11B',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RAYEX-L90BS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RAYEX-L90BS'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_RAYEX-L90BS'], 'footprint':'Relay_THT:Relay_SPST_RAYEX-L90BS', 'keywords':'30A Single Pole Relay', 'description':'', 'datasheet':'https://a3.sofastcdn.com/attachment/7jioKBjnRiiSrjrjknRiwS77gwbf3zmp/L90-SERIES.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRAYEX-L90BS\n\n30A Single Pole Relay', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RAYEX-L90S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RAYEX-L90S'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPDT_RAYEX-L90S'], 'footprint':'Relay_THT:Relay_SPDT_RAYEX-L90S', 'keywords':'30A Single Pole Relay', 'description':'', 'datasheet':'https://a3.sofastcdn.com/attachment/7jioKBjnRiiSrjrjknRiwS77gwbf3zmp/L90-SERIES.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRAYEX-L90S\n\n30A Single Pole Relay', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RT314A03', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RT314A03'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPDT_Schrack-RT1-16A-FormC_RM5mm'], 'footprint':'Relay_THT:Relay_SPDT_Schrack-RT1-16A-FormC_RM5mm', 'keywords':'TE SPDT 1P2T CO bistable DC', 'description':'', 'datasheet':'https://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=RT1_bistable&DocType=DS&DocLang=English', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRT314A03\n\nTE SPDT 1P2T CO bistable DC', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RT42xAxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RT42xAxx'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Schrack-RT2-FormC_RM5mm'], 'footprint':'Relay_THT:Relay_DPDT_Schrack-RT2-FormC_RM5mm', 'keywords':'TE DPDT CO bistable DC', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=showdoc&DocId=Data+Sheet%7FRT2_bistable%7F1116%7Fpdf%7FEnglish%7FENG_DS_RT2_bistable_1116.pdf%7F1-1415537-8', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRT42xAxx\n\nTE DPDT CO bistable DC', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RT42xFxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RT42xFxx'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Schrack-RT2-FormC-Dual-Coil_RM5mm'], 'footprint':'Relay_THT:Relay_DPDT_Schrack-RT2-FormC-Dual-Coil_RM5mm', 'keywords':'TE DPDT CO bistable DC', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=showdoc&DocId=Data+Sheet%7FRT2_bistable%7F1116%7Fpdf%7FEnglish%7FENG_DS_RT2_bistable_1116.pdf%7F1-1415537-8', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRT42xFxx\n\nTE DPDT CO bistable DC', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RT42xxxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RT42xxxx'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Schrack-RT2-FormC_RM5mm'], 'footprint':'Relay_THT:Relay_DPDT_Schrack-RT2-FormC_RM5mm', 'keywords':'TE DPDT CO monostable', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=showdoc&DocId=Data+Sheet%7FRT2%7F1014%7Fpdf%7FEnglish%7FENG_DS_RT2_1014.pdf%7F6-1393243-3', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRT42xxxx\n\nTE DPDT CO monostable', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RT44xxxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RT44xxxx'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPST_Schrack-RT2-FormA_RM5mm'], 'footprint':'Relay_THT:Relay_DPST_Schrack-RT2-FormA_RM5mm', 'keywords':'TE DPST NO monostable', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=showdoc&DocId=Data+Sheet%7FRT2%7F1014%7Fpdf%7FEnglish%7FENG_DS_RT2_1014.pdf%7F6-1393243-3', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRT44xxxx\n\nTE DPST NO monostable', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Relay_DPDT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Relay_DPDT'}), 'ref_prefix':'K', 'fplist':[''], 'footprint':'', 'keywords':'2P2T 2-Form-C double dual throw pole', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRelay_DPDT\n\n2P2T 2-Form-C double dual throw pole', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Relay_DPDT_Latching_1coil', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Relay_DPDT_Latching_1coil'}), 'ref_prefix':'K', 'fplist':[''], 'footprint':'', 'keywords':'2P2T 2-Form-C double dual pole throw latching', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRelay_DPDT_Latching_1coil\n\n2P2T 2-Form-C double dual pole throw latching', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Relay_DPDT_Latching_2coil', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Relay_DPDT_Latching_2coil'}), 'ref_prefix':'K', 'fplist':[''], 'footprint':'', 'keywords':'2P2T 2-Form-C double dual pole throw latching', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRelay_DPDT_Latching_2coil\n\n2P2T 2-Form-C double dual pole throw latching', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Relay_DPST-NC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Relay_DPST-NC'}), 'ref_prefix':'K', 'fplist':[''], 'footprint':'', 'keywords':'2P2T 2-Form-B double dual pole throw NC', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRelay_DPST-NC\n\n2P2T 2-Form-B double dual pole throw NC', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Relay_DPST-NO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Relay_DPST-NO'}), 'ref_prefix':'K', 'fplist':[''], 'footprint':'', 'keywords':'2P2T 2-Form-A double dual pole throw NO', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRelay_DPST-NO\n\n2P2T 2-Form-A double dual pole throw NO', 'pins':[
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Relay_DPST_Latching_1coil', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Relay_DPST_Latching_1coil'}), 'ref_prefix':'K', 'fplist':[''], 'footprint':'', 'keywords':'2P2Tdouble dual pole throw latching', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRelay_DPST_Latching_1coil\n\n2P2Tdouble dual pole throw latching', 'pins':[
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Relay_DPST_Latching_2coil', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Relay_DPST_Latching_2coil'}), 'ref_prefix':'K', 'fplist':[''], 'footprint':'', 'keywords':'2P2T double dual pole throw latching', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRelay_DPST_Latching_2coil\n\n2P2T double dual pole throw latching', 'pins':[
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Relay_SPDT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Relay_SPDT'}), 'ref_prefix':'K', 'fplist':[''], 'footprint':'', 'keywords':'1P2T 1-Form-C single pole throw', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRelay_SPDT\n\n1P2T 1-Form-C single pole throw', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Relay_SPDT_Latching_1coil', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Relay_SPDT_Latching_1coil'}), 'ref_prefix':'K', 'fplist':[''], 'footprint':'', 'keywords':'1P2T 1-Form-C single pole throw latching', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRelay_SPDT_Latching_1coil\n\n1P2T 1-Form-C single pole throw latching', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Relay_SPDT_Latching_2coil', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Relay_SPDT_Latching_2coil'}), 'ref_prefix':'K', 'fplist':[''], 'footprint':'', 'keywords':'1P2T 1-Form-C single pole throw latching', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRelay_SPDT_Latching_2coil\n\n1P2T 1-Form-C single pole throw latching', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Relay_SPST-NC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Relay_SPST-NC'}), 'ref_prefix':'K', 'fplist':[''], 'footprint':'', 'keywords':'1P1T 1-Form-B single pole throw NC', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRelay_SPST-NC\n\n1P1T 1-Form-B single pole throw NC', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Relay_SPST-NO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Relay_SPST-NO'}), 'ref_prefix':'K', 'fplist':[''], 'footprint':'', 'keywords':'1P1T 1-Form-A single pole throw NO', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRelay_SPST-NO\n\n1P1T 1-Form-A single pole throw NO', 'pins':[
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Relay_SPST_Latching_1coil', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Relay_SPST_Latching_1coil'}), 'ref_prefix':'K', 'fplist':[''], 'footprint':'', 'keywords':'1P1T single pole throw latching', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRelay_SPST_Latching_1coil\n\n1P1T single pole throw latching', 'pins':[
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Relay_SPST_Latching_2coil', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Relay_SPST_Latching_2coil'}), 'ref_prefix':'K', 'fplist':[''], 'footprint':'', 'keywords':'1P1T single pole throw latching', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRelay_SPST_Latching_2coil\n\n1P1T single pole throw latching', 'pins':[
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SANYOU_SRD_Form_A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SANYOU_SRD_Form_A'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_SANYOU_SRD_Series_Form_A'], 'footprint':'Relay_THT:Relay_SPST_SANYOU_SRD_Series_Form_A', 'keywords':'Single Pole Relay SPST', 'description':'', 'datasheet':'http://www.sanyourelay.ca/public/products/pdf/SRD.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nSANYOU_SRD_Form_A\n\nSingle Pole Relay SPST', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SANYOU_SRD_Form_B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SANYOU_SRD_Form_B'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_SANYOU_SRD_Series_Form_B'], 'footprint':'Relay_THT:Relay_SPST_SANYOU_SRD_Series_Form_B', 'keywords':'Single Pole Relay SPST', 'description':'', 'datasheet':'http://www.sanyourelay.ca/public/products/pdf/SRD.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nSANYOU_SRD_Form_B\n\nSingle Pole Relay SPST', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SANYOU_SRD_Form_C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SANYOU_SRD_Form_C'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPDT_SANYOU_SRD_Series_Form_C'], 'footprint':'Relay_THT:Relay_SPDT_SANYOU_SRD_Series_Form_C', 'keywords':'Single Pole Relay SPDT', 'description':'', 'datasheet':'http://www.sanyourelay.ca/public/products/pdf/SRD.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nSANYOU_SRD_Form_C\n\nSingle Pole Relay SPDT', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SILxx-1Axx-71x', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SILxx-1Axx-71x'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_StandexMeder_SIL_Form1A'], 'footprint':'Relay_THT:Relay_SPST_StandexMeder_SIL_Form1A', 'keywords':'Single Pole Reed Relay SPST', 'description':'', 'datasheet':'https://standexelectronics.com/wp-content/uploads/datasheet_reed_relay_SIL.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nSILxx-1Axx-71x\n\nSingle Pole Reed Relay SPST', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SILxx-1Bxx-71x', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SILxx-1Bxx-71x'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_StandexMeder_SIL_Form1B'], 'footprint':'Relay_THT:Relay_SPST_StandexMeder_SIL_Form1B', 'keywords':'Single Pole Reed Relay SPST', 'description':'', 'datasheet':'https://standexelectronics.com/wp-content/uploads/datasheet_reed_relay_SIL.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nSILxx-1Bxx-71x\n\nSingle Pole Reed Relay SPST', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SILxx-1Cxx-51x', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SILxx-1Cxx-51x'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPDT_StandexMeder_SIL_Form1C'], 'footprint':'Relay_THT:Relay_SPDT_StandexMeder_SIL_Form1C', 'keywords':'Single Pole Reed Relay SPDT', 'description':'', 'datasheet':'https://standexelectronics.com/wp-content/uploads/datasheet_reed_relay_SIL.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nSILxx-1Cxx-51x\n\nSingle Pole Reed Relay SPDT', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TE_PCH-1xxx2M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TE_PCH-1xxx2M'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_TE_PCH-1xxx2M'], 'footprint':'Relay_THT:Relay_SPST_TE_PCH-1xxx2M', 'keywords':'Miniature Single Pole Relay', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=showdoc&DocId=Data+Sheet%7FPCH_series_relay_data_sheet_E%7F1215%7Fpdf%7FEnglish%7FENG_DS_PCH_series_relay_data_sheet_E_1215.pdf%7F9-1440003-0', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nTE_PCH-1xxx2M\n\nMiniature Single Pole Relay', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TIANBO-HJR-4102-L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TIANBO-HJR-4102-L'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPDT_HJR-4102'], 'footprint':'Relay_THT:Relay_SPDT_HJR-4102', 'keywords':'Single Pole Relay', 'description':'', 'datasheet':'https://cdn-reichelt.de/documents/datenblatt/C300/DS_HJR4102E.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nTIANBO-HJR-4102-L\n\nSingle Pole Relay', 'pins':[
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'UMS05-1A80-75D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'UMS05-1A80-75D'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_StandexMeder_UMS'], 'footprint':'Relay_THT:Relay_StandexMeder_UMS', 'keywords':'Single Pole Reed Relay SPST', 'description':'', 'datasheet':'https://standexelectronics.com/wp-content/uploads/datasheets/43/4305180175d.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nUMS05-1A80-75D\n\nSingle Pole Reed Relay SPST', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'UMS05-1A80-75L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'UMS05-1A80-75L'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_StandexMeder_UMS'], 'footprint':'Relay_THT:Relay_StandexMeder_UMS', 'keywords':'Single Pole Reed Relay SPST', 'description':'', 'datasheet':'https://standexelectronics.com/wp-content/uploads/datasheets/43/4305180075d.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nUMS05-1A80-75L\n\nSingle Pole Reed Relay SPST', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Y14x-1C-xxDS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Y14x-1C-xxDS'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPDT_HsinDa_Y14'], 'footprint':'Relay_THT:Relay_SPDT_HsinDa_Y14', 'keywords':'Relay SPDT', 'description':'', 'datasheet':'http://www.hsinda.com.tw/upload/file/Y14-20200430135145.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nY14x-1C-xxDS\n\nRelay SPDT', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADW11', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADW11'}), 'ref_prefix':'K', 'fplist':['', 'Relay_THT:Relay_SPST_Panasonic_ADW11'], 'footprint':'', 'keywords':'SPST 1P1T latching bistable', 'description':'', 'datasheet':'https://api.pim.na.industrial.panasonic.com/file_stream/main/fileversion/270', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nADW11\n\nSPST 1P1T latching bistable', 'pins':[
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AZ850P1-x', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AZ850P1-x'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_FRT5', 'Relay_THT:Relay_DPDT_FRT5'], 'footprint':'Relay_THT:Relay_DPDT_FRT5', 'keywords':'Miniature Polarised Relay Dual Pole Bistable', 'description':'', 'datasheet':'http://www.azettler.com/pdfs/az850.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nAZ850P1-x\n\nMiniature Polarised Relay Dual Pole Bistable', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EC2-12NU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EC2-12NU'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Kemet_EC2', 'Relay_THT:Relay_DPDT_Kemet_EC2'], 'footprint':'Relay_THT:Relay_DPDT_Kemet_EC2', 'keywords':'signal relay double pole double throw DPDT DC coil non latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEC2-12NU\n\nsignal relay double pole double throw DPDT DC coil non latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EC2-12SNU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EC2-12SNU'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Kemet_EC2', 'Relay_THT:Relay_DPDT_Kemet_EC2'], 'footprint':'Relay_THT:Relay_DPDT_Kemet_EC2', 'keywords':'signal relay double pole double throw DPDT DC coil single coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEC2-12SNU\n\nsignal relay double pole double throw DPDT DC coil single coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EC2-12TNU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EC2-12TNU'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Kemet_EC2_DoubleCoil', 'Relay_THT:Relay_DPDT_Kemet_EC2_DoubleCoil'], 'footprint':'Relay_THT:Relay_DPDT_Kemet_EC2_DoubleCoil', 'keywords':'signal relay double pole double throw DPDT DC coil double dual coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEC2-12TNU\n\nsignal relay double pole double throw DPDT DC coil double dual coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EC2-24NU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EC2-24NU'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Kemet_EC2', 'Relay_THT:Relay_DPDT_Kemet_EC2', 'Relay_THT:Relay_DPDT_Kemet_EC2'], 'footprint':'Relay_THT:Relay_DPDT_Kemet_EC2', 'keywords':'signal relay double pole double throw DPDT DC coil non latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEC2-24NU\n\nsignal relay double pole double throw DPDT DC coil non latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EC2-24SNU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EC2-24SNU'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Kemet_EC2', 'Relay_THT:Relay_DPDT_Kemet_EC2', 'Relay_THT:Relay_DPDT_Kemet_EC2'], 'footprint':'Relay_THT:Relay_DPDT_Kemet_EC2', 'keywords':'signal relay double pole double throw DPDT DC coil single coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEC2-24SNU\n\nsignal relay double pole double throw DPDT DC coil single coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EC2-24TNU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EC2-24TNU'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Kemet_EC2_DoubleCoil', 'Relay_THT:Relay_DPDT_Kemet_EC2_DoubleCoil', 'Relay_THT:Relay_DPDT_Kemet_EC2_DoubleCoil'], 'footprint':'Relay_THT:Relay_DPDT_Kemet_EC2_DoubleCoil', 'keywords':'signal relay double pole double throw DPDT DC coil double dual coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEC2-24TNU\n\nsignal relay double pole double throw DPDT DC coil double dual coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EC2-4.5NU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EC2-4.5NU'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Kemet_EC2', 'Relay_THT:Relay_DPDT_Kemet_EC2', 'Relay_THT:Relay_DPDT_Kemet_EC2', 'Relay_THT:Relay_DPDT_Kemet_EC2'], 'footprint':'Relay_THT:Relay_DPDT_Kemet_EC2', 'keywords':'signal relay double pole double throw DPDT DC coil non latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEC2-4.5NU\n\nsignal relay double pole double throw DPDT DC coil non latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EC2-4.5SNU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EC2-4.5SNU'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Kemet_EC2', 'Relay_THT:Relay_DPDT_Kemet_EC2', 'Relay_THT:Relay_DPDT_Kemet_EC2', 'Relay_THT:Relay_DPDT_Kemet_EC2'], 'footprint':'Relay_THT:Relay_DPDT_Kemet_EC2', 'keywords':'signal relay double pole double throw DPDT DC coil single coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEC2-4.5SNU\n\nsignal relay double pole double throw DPDT DC coil single coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EC2-4.5TNU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EC2-4.5TNU'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Kemet_EC2_DoubleCoil', 'Relay_THT:Relay_DPDT_Kemet_EC2_DoubleCoil', 'Relay_THT:Relay_DPDT_Kemet_EC2_DoubleCoil', 'Relay_THT:Relay_DPDT_Kemet_EC2_DoubleCoil'], 'footprint':'Relay_THT:Relay_DPDT_Kemet_EC2_DoubleCoil', 'keywords':'signal relay double pole double throw DPDT DC coil double dual coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEC2-4.5TNU\n\nsignal relay double pole double throw DPDT DC coil double dual coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EC2-5NU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EC2-5NU'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Kemet_EC2', 'Relay_THT:Relay_DPDT_Kemet_EC2', 'Relay_THT:Relay_DPDT_Kemet_EC2', 'Relay_THT:Relay_DPDT_Kemet_EC2', 'Relay_THT:Relay_DPDT_Kemet_EC2'], 'footprint':'Relay_THT:Relay_DPDT_Kemet_EC2', 'keywords':'signal relay double pole double throw DPDT DC coil non latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEC2-5NU\n\nsignal relay double pole double throw DPDT DC coil non latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EC2-5SNU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EC2-5SNU'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Kemet_EC2', 'Relay_THT:Relay_DPDT_Kemet_EC2', 'Relay_THT:Relay_DPDT_Kemet_EC2', 'Relay_THT:Relay_DPDT_Kemet_EC2', 'Relay_THT:Relay_DPDT_Kemet_EC2'], 'footprint':'Relay_THT:Relay_DPDT_Kemet_EC2', 'keywords':'signal relay double pole double throw DPDT DC coil single coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEC2-5SNU\n\nsignal relay double pole double throw DPDT DC coil single coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EC2-5TNU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EC2-5TNU'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Kemet_EC2_DoubleCoil', 'Relay_THT:Relay_DPDT_Kemet_EC2_DoubleCoil', 'Relay_THT:Relay_DPDT_Kemet_EC2_DoubleCoil', 'Relay_THT:Relay_DPDT_Kemet_EC2_DoubleCoil', 'Relay_THT:Relay_DPDT_Kemet_EC2_DoubleCoil'], 'footprint':'Relay_THT:Relay_DPDT_Kemet_EC2_DoubleCoil', 'keywords':'signal relay double pole double throw DPDT DC coil double dual coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEC2-5TNU\n\nsignal relay double pole double throw DPDT DC coil double dual coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-12NKX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-12NKX'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'keywords':'signal relay double pole double throw DPDT DC coil non latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-12NKX\n\nsignal relay double pole double throw DPDT DC coil non latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-12NU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-12NU'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'keywords':'signal relay double pole double throw DPDT DC coil non latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-12NU\n\nsignal relay double pole double throw DPDT DC coil non latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-12NUH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-12NUH'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'keywords':'signal relay double pole double throw DPDT DC coil non latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-12NUH\n\nsignal relay double pole double throw DPDT DC coil non latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-12NUX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-12NUX'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'keywords':'signal relay double pole double throw DPDT DC coil non latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-12NUX\n\nsignal relay double pole double throw DPDT DC coil non latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-12SNU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-12SNU'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'keywords':'signal relay double pole double throw DPDT DC coil single coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-12SNU\n\nsignal relay double pole double throw DPDT DC coil single coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-12SNUH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-12SNUH'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'keywords':'signal relay double pole double throw DPDT DC coil single coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-12SNUH\n\nsignal relay double pole double throw DPDT DC coil single coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-12SNUX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-12SNUX'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'keywords':'signal relay double pole double throw DPDT DC coil single coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-12SNUX\n\nsignal relay double pole double throw DPDT DC coil single coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-12TNU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-12TNU'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NU_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU_DoubleCoil'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NU_DoubleCoil', 'keywords':'signal relay double pole double throw DPDT DC coil double dual coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-12TNU\n\nsignal relay double pole double throw DPDT DC coil double dual coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-12TNUH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-12TNUH'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUH_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH_DoubleCoil'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH_DoubleCoil', 'keywords':'signal relay double pole double throw DPDT DC coil double dual coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-12TNUH\n\nsignal relay double pole double throw DPDT DC coil double dual coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-12TNUX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-12TNUX'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_DoubleCoil'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_DoubleCoil', 'keywords':'signal relay double pole double throw DPDT DC coil double dual coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-12TNUX\n\nsignal relay double pole double throw DPDT DC coil double dual coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-24NU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-24NU'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'keywords':'signal relay double pole double throw DPDT DC coil non latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-24NU\n\nsignal relay double pole double throw DPDT DC coil non latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-24NUH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-24NUH'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'keywords':'signal relay double pole double throw DPDT DC coil non latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-24NUH\n\nsignal relay double pole double throw DPDT DC coil non latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-24NUX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-24NUX'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'keywords':'signal relay double pole double throw DPDT DC coil non latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-24NUX\n\nsignal relay double pole double throw DPDT DC coil non latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-24SNU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-24SNU'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'keywords':'signal relay double pole double throw DPDT DC coil single coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-24SNU\n\nsignal relay double pole double throw DPDT DC coil single coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-24SNUH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-24SNUH'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'keywords':'signal relay double pole double throw DPDT DC coil single coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-24SNUH\n\nsignal relay double pole double throw DPDT DC coil single coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-24SNUX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-24SNUX'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'keywords':'signal relay double pole double throw DPDT DC coil single coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-24SNUX\n\nsignal relay double pole double throw DPDT DC coil single coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-24TNU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-24TNU'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NU_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU_DoubleCoil'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NU_DoubleCoil', 'keywords':'signal relay double pole double throw DPDT DC coil double dual coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-24TNU\n\nsignal relay double pole double throw DPDT DC coil double dual coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-24TNUH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-24TNUH'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUH_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH_DoubleCoil'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH_DoubleCoil', 'keywords':'signal relay double pole double throw DPDT DC coil double dual coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-24TNUH\n\nsignal relay double pole double throw DPDT DC coil double dual coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-24TNUX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-24TNUX'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_DoubleCoil'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_DoubleCoil', 'keywords':'signal relay double pole double throw DPDT DC coil double dual coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-24TNUX\n\nsignal relay double pole double throw DPDT DC coil double dual coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-4.5NKX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-4.5NKX'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'keywords':'signal relay double pole double throw DPDT DC coil non latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-4.5NKX\n\nsignal relay double pole double throw DPDT DC coil non latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-4.5NU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-4.5NU'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'keywords':'signal relay double pole double throw DPDT DC coil non latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-4.5NU\n\nsignal relay double pole double throw DPDT DC coil non latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-4.5NUH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-4.5NUH'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'keywords':'signal relay double pole double throw DPDT DC coil non latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-4.5NUH\n\nsignal relay double pole double throw DPDT DC coil non latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-4.5NUX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-4.5NUX'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'keywords':'signal relay double pole double throw DPDT DC coil non latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-4.5NUX\n\nsignal relay double pole double throw DPDT DC coil non latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-4.5SNU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-4.5SNU'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'keywords':'signal relay double pole double throw DPDT DC coil single coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-4.5SNU\n\nsignal relay double pole double throw DPDT DC coil single coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-4.5SNUH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-4.5SNUH'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'keywords':'signal relay double pole double throw DPDT DC coil single coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-4.5SNUH\n\nsignal relay double pole double throw DPDT DC coil single coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-4.5SNUX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-4.5SNUX'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'keywords':'signal relay double pole double throw DPDT DC coil single coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-4.5SNUX\n\nsignal relay double pole double throw DPDT DC coil single coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-4.5TNU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-4.5TNU'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NU_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU_DoubleCoil'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NU_DoubleCoil', 'keywords':'signal relay double pole double throw DPDT DC coil double dual coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-4.5TNU\n\nsignal relay double pole double throw DPDT DC coil double dual coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-4.5TNUH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-4.5TNUH'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUH_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH_DoubleCoil'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH_DoubleCoil', 'keywords':'signal relay double pole double throw DPDT DC coil double dual coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-4.5TNUH\n\nsignal relay double pole double throw DPDT DC coil double dual coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-4.5TNUX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-4.5TNUX'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_DoubleCoil'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_DoubleCoil', 'keywords':'signal relay double pole double throw DPDT DC coil double dual coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-4.5TNUX\n\nsignal relay double pole double throw DPDT DC coil double dual coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-5NU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-5NU'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'keywords':'signal relay double pole double throw DPDT DC coil non latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-5NU\n\nsignal relay double pole double throw DPDT DC coil non latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-5NUH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-5NUH'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'keywords':'signal relay double pole double throw DPDT DC coil non latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-5NUH\n\nsignal relay double pole double throw DPDT DC coil non latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-5NUX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-5NUX'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'keywords':'signal relay double pole double throw DPDT DC coil non latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-5NUX\n\nsignal relay double pole double throw DPDT DC coil non latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-5SNU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-5SNU'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NU', 'keywords':'signal relay double pole double throw DPDT DC coil single coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-5SNU\n\nsignal relay double pole double throw DPDT DC coil single coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-5SNUH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-5SNUH'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH', 'keywords':'signal relay double pole double throw DPDT DC coil single coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-5SNUH\n\nsignal relay double pole double throw DPDT DC coil single coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-5SNUX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-5SNUX'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_NKX', 'keywords':'signal relay double pole double throw DPDT DC coil single coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-5SNUX\n\nsignal relay double pole double throw DPDT DC coil single coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-5TNU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-5TNU'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NU_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NU_DoubleCoil'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NU_DoubleCoil', 'keywords':'signal relay double pole double throw DPDT DC coil double dual coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-5TNU\n\nsignal relay double pole double throw DPDT DC coil double dual coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-5TNUH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-5TNUH'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUH_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH_DoubleCoil'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUH_DoubleCoil', 'keywords':'signal relay double pole double throw DPDT DC coil double dual coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-5TNUH\n\nsignal relay double pole double throw DPDT DC coil double dual coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EE2-5TNUX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EE2-5TNUX'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_DoubleCoil', 'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_DoubleCoil'], 'footprint':'Relay_SMD:Relay_DPDT_Kemet_EE2_NUX_DoubleCoil', 'keywords':'signal relay double pole double throw DPDT DC coil double dual coil latching', 'description':'', 'datasheet':'https://content.kemet.com/datasheets/KEM_R7002_EC2_EE2.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nEE2-5TNUX\n\nsignal relay double pole double throw DPDT DC coil double dual coil latching', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FINDER-40.11-2016', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FINDER-40.11-2016'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPDT_Finder_40.11', 'Relay_THT:Relay_SPDT_Finder_40.11'], 'footprint':'Relay_THT:Relay_SPDT_Finder_40.11', 'keywords':'Single Pole Relay SPDT Finder', 'description':'', 'datasheet':'https://www.finder-relais.net/de/finder-relais-serie-40.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nFINDER-40.11-2016\n\nSingle Pole Relay SPDT Finder', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FINDER-41.52', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FINDER-41.52'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Finder_40.52', 'Relay_THT:Relay_DPDT_Finder_40.52'], 'footprint':'Relay_THT:Relay_DPDT_Finder_40.52', 'keywords':'Dual Pole Relay', 'description':'', 'datasheet':'http://gfinder.findernet.com/assets/Series/357/S41EN.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nFINDER-41.52\n\nDual Pole Relay', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FINDER-44.52', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FINDER-44.52'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Finder_40.52', 'Relay_THT:Relay_DPDT_Finder_40.52', 'Relay_THT:Relay_DPDT_Finder_40.52'], 'footprint':'Relay_THT:Relay_DPDT_Finder_40.52', 'keywords':'Dual Pole Relay', 'description':'', 'datasheet':'http://gfinder.findernet.com/assets/Series/359/S44EN.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nFINDER-44.52\n\nDual Pole Relay', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FINDER-44.62', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FINDER-44.62'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Finder_40.52', 'Relay_THT:Relay_DPDT_Finder_40.52', 'Relay_THT:Relay_DPDT_Finder_40.52', 'Relay_THT:Relay_DPDT_Finder_40.52'], 'footprint':'Relay_THT:Relay_DPDT_Finder_40.52', 'keywords':'Dual Pole Relay', 'description':'', 'datasheet':'http://gfinder.findernet.com/assets/Series/359/S44EN.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nFINDER-44.62\n\nDual Pole Relay', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Fujitsu_FTR-LYAA005x', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Fujitsu_FTR-LYAA005x'}), 'ref_prefix':'K', 'fplist':['', 'Relay_THT:Relay_SPST-NO_Fujitsu_FTR-LYAA005x_FormA_Vertical'], 'footprint':'', 'keywords':'6A SPST-NO Relay', 'description':'', 'datasheet':'https://www.fujitsu.com/sg/imagesgig5/ftr-ly.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nFujitsu_FTR-LYAA005x\n\n6A SPST-NO Relay', 'pins':[
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Fujitsu_FTR-LYCA005x', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Fujitsu_FTR-LYCA005x'}), 'ref_prefix':'K', 'fplist':['', 'Relay_THT:Relay_SPDT_Fujitsu_FTR-LYCA005x_FormC_Vertical'], 'footprint':'', 'keywords':'6A SPDT Relay', 'description':'', 'datasheet':'https://www.fujitsu.com/sg/imagesgig5/ftr-ly.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nFujitsu_FTR-LYCA005x\n\n6A SPDT Relay', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'G2RL-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'G2RL-1'}), 'ref_prefix':'K', 'fplist':['', 'Relay_THT:Relay_SPDT_Fujitsu_FTR-LYCA005x_FormC_Vertical', 'Relay_THT:Relay_SPDT_Omron_G2RL-1'], 'footprint':'', 'keywords':'Single Pole Relay SPDT Omron', 'description':'', 'datasheet':'https://omronfs.omron.com/en_US/ecb/products/pdf/en-g2rl.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nG2RL-1\n\nSingle Pole Relay SPDT Omron', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'G2RL-1-E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'G2RL-1-E'}), 'ref_prefix':'K', 'fplist':['', 'Relay_THT:Relay_SPDT_Fujitsu_FTR-LYCA005x_FormC_Vertical', 'Relay_THT:Relay_SPDT_Omron_G2RL-1', 'Relay_THT:Relay_SPDT_Omron_G2RL-1-E'], 'footprint':'', 'keywords':'Single Pole Relay SPDT Omron High Capacity', 'description':'', 'datasheet':'https://omronfs.omron.com/en_US/ecb/products/pdf/en-g2rl.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nG2RL-1-E\n\nSingle Pole Relay SPDT Omron High Capacity', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'G2RL-1-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'G2RL-1-H'}), 'ref_prefix':'K', 'fplist':['', 'Relay_THT:Relay_SPDT_Fujitsu_FTR-LYCA005x_FormC_Vertical', 'Relay_THT:Relay_SPDT_Omron_G2RL-1', 'Relay_THT:Relay_SPDT_Omron_G2RL-1-E', 'Relay_THT:Relay_SPDT_Omron_G2RL-1'], 'footprint':'', 'keywords':'Single Pole Relay SPDT Omron High Sensitivity', 'description':'', 'datasheet':'https://omronfs.omron.com/en_US/ecb/products/pdf/en-g2rl.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nG2RL-1-H\n\nSingle Pole Relay SPDT Omron High Sensitivity', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'G2RL-1A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'G2RL-1A'}), 'ref_prefix':'K', 'fplist':['', 'Relay_THT:Relay_SPST-NO_Fujitsu_FTR-LYAA005x_FormA_Vertical', 'Relay_THT:Relay_SPST_Omron_G2RL-1A'], 'footprint':'', 'keywords':'Single Pole Relay SPST Omron NO', 'description':'', 'datasheet':'https://omronfs.omron.com/en_US/ecb/products/pdf/en-g2rl.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nG2RL-1A\n\nSingle Pole Relay SPST Omron NO', 'pins':[
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'G2RL-1A-E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'G2RL-1A-E'}), 'ref_prefix':'K', 'fplist':['', 'Relay_THT:Relay_SPST-NO_Fujitsu_FTR-LYAA005x_FormA_Vertical', 'Relay_THT:Relay_SPST_Omron_G2RL-1A', 'Relay_THT:Relay_SPST_Omron_G2RL-1A-E'], 'footprint':'', 'keywords':'Single Pole Relay SPST Omron NO High Capacity', 'description':'', 'datasheet':'https://omronfs.omron.com/en_US/ecb/products/pdf/en-g2rl.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nG2RL-1A-E\n\nSingle Pole Relay SPST Omron NO High Capacity', 'pins':[
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'G2RL-1A-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'G2RL-1A-H'}), 'ref_prefix':'K', 'fplist':['', 'Relay_THT:Relay_SPST-NO_Fujitsu_FTR-LYAA005x_FormA_Vertical', 'Relay_THT:Relay_SPST_Omron_G2RL-1A', 'Relay_THT:Relay_SPST_Omron_G2RL-1A-E', 'Relay_THT:Relay_SPST_Omron_G2RL-1A'], 'footprint':'', 'keywords':'Single Pole Relay SPST Omron NO High Sensitivity', 'description':'', 'datasheet':'https://omronfs.omron.com/en_US/ecb/products/pdf/en-g2rl.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nG2RL-1A-H\n\nSingle Pole Relay SPST Omron NO High Sensitivity', 'pins':[
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'G2RL-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'G2RL-2'}), 'ref_prefix':'K', 'fplist':['', 'Relay_THT:Relay_DPDT_Omron_G2RL-2'], 'footprint':'', 'keywords':'Dual Pole Relay Omron DPDT', 'description':'', 'datasheet':'https://omronfs.omron.com/en_US/ecb/products/pdf/en-g2rl.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nG2RL-2\n\nDual Pole Relay Omron DPDT', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'G2RL-2A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'G2RL-2A'}), 'ref_prefix':'K', 'fplist':['', 'Relay_THT:Relay_DPST_Omron_G2RL-2A'], 'footprint':'', 'keywords':'Dual Pole Relay Omron DPST NO', 'description':'', 'datasheet':'https://omronfs.omron.com/en_US/ecb/products/pdf/en-g2rl.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nG2RL-2A\n\nDual Pole Relay Omron DPST NO', 'pins':[
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'G5NB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'G5NB'}), 'ref_prefix':'K', 'fplist':['', 'Relay_THT:Relay_SPST-NO_Fujitsu_FTR-LYAA005x_FormA_Vertical', 'Relay_THT:Relay_SPST_Omron_G2RL-1A', 'Relay_THT:Relay_SPST_Omron_G2RL-1A-E', 'Relay_THT:Relay_SPST_Omron_G2RL-1A', 'Relay_THT:Relay_SPST_Omron_G5NB'], 'footprint':'', 'keywords':'Omron G5NB Relay SPST-NO', 'description':'', 'datasheet':'https://omronfs.omron.com/en_US/ecb/products/pdf/en-g5nb_el.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nG5NB\n\nOmron G5NB Relay SPST-NO', 'pins':[
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'G6A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'G6A'}), 'ref_prefix':'K', 'fplist':['', 'Relay_THT:Relay_DPDT_Omron_G2RL-2', 'Relay_THT:Relay_DPDT_Omron_G6A'], 'footprint':'', 'keywords':'Relay Dual Pole DPDT 2-Form-C Omron', 'description':'', 'datasheet':'https://omronfs.omron.com/en_US/ecb/products/pdf/en-g6a.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nG6A\n\nRelay Dual Pole DPDT 2-Form-C Omron', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'G6AK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'G6AK'}), 'ref_prefix':'K', 'fplist':['', 'Relay_THT:Relay_DPDT_Omron_G6AK'], 'footprint':'', 'keywords':'2P2T double dual pole throw DPDT 2-Form-C bistable Omron', 'description':'', 'datasheet':'https://omronfs.omron.com/en_US/ecb/products/pdf/en-g6a.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nG6AK\n\n2P2T double dual pole throw DPDT 2-Form-C bistable Omron', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'G6AU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'G6AU'}), 'ref_prefix':'K', 'fplist':['', 'Relay_THT:Relay_DPDT_Omron_G6A'], 'footprint':'', 'keywords':'2P2T double dual pole throw DPDT 2-Form-C bistable Omron', 'description':'', 'datasheet':'https://omronfs.omron.com/en_US/ecb/products/pdf/en-g6a.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nG6AU\n\n2P2T double dual pole throw DPDT 2-Form-C bistable Omron', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HF115F-2Z-x4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HF115F-2Z-x4'}), 'ref_prefix':'K', 'fplist':['', 'Relay_THT:Relay_DPDT_Omron_G2RL-2', 'Relay_THT:Relay_DPDT_Omron_G6A', 'Relay_THT:Relay_DPDT_Hongfa_HF115F-2Z-x4'], 'footprint':'', 'keywords':'2-Form-C', 'description':'', 'datasheet':'https://source.hongfa.com//pdf/web/viewer.html?file=/Uploads/Product/PDF/HF115F_I_en.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nHF115F-2Z-x4\n\n2-Form-C', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HF3-02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HF3-02'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm'], 'footprint':'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm', 'keywords':'Single Pole Relay SPDT', 'description':'', 'datasheet':'http://hiqsdr.com/images/3/3e/Axicom-HF3.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nHF3-02\n\nSingle Pole Relay SPDT', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HF3-03', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HF3-03'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm'], 'footprint':'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm', 'keywords':'Single Pole Relay SPDT', 'description':'', 'datasheet':'http://hiqsdr.com/images/3/3e/Axicom-HF3.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nHF3-03\n\nSingle Pole Relay SPDT', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HF3-04', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HF3-04'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm'], 'footprint':'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm', 'keywords':'Single Pole Relay SPDT', 'description':'', 'datasheet':'http://hiqsdr.com/images/3/3e/Axicom-HF3.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nHF3-04\n\nSingle Pole Relay SPDT', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HF3-05', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HF3-05'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm'], 'footprint':'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm', 'keywords':'Single Pole Relay SPDT', 'description':'', 'datasheet':'http://hiqsdr.com/images/3/3e/Axicom-HF3.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nHF3-05\n\nSingle Pole Relay SPDT', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HF3-06', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HF3-06'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm'], 'footprint':'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm', 'keywords':'Single Pole Relay SPDT', 'description':'', 'datasheet':'http://hiqsdr.com/images/3/3e/Axicom-HF3.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nHF3-06\n\nSingle Pole Relay SPDT', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HF3-07', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HF3-07'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm'], 'footprint':'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_75ohms_Pitch1.27mm', 'keywords':'Single Pole Relay SPDT', 'description':'', 'datasheet':'http://hiqsdr.com/images/3/3e/Axicom-HF3.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nHF3-07\n\nSingle Pole Relay SPDT', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HF3-52', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HF3-52'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm'], 'footprint':'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm', 'keywords':'Single Pole Relay SPDT', 'description':'', 'datasheet':'http://hiqsdr.com/images/3/3e/Axicom-HF3.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nHF3-52\n\nSingle Pole Relay SPDT', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HF3-53', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HF3-53'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm'], 'footprint':'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm', 'keywords':'Single Pole Relay SPDT', 'description':'', 'datasheet':'http://hiqsdr.com/images/3/3e/Axicom-HF3.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nHF3-53\n\nSingle Pole Relay SPDT', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HF3-54', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HF3-54'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm'], 'footprint':'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm', 'keywords':'Single Pole Relay SPDT', 'description':'', 'datasheet':'http://hiqsdr.com/images/3/3e/Axicom-HF3.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nHF3-54\n\nSingle Pole Relay SPDT', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HF3-55', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HF3-55'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm'], 'footprint':'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm', 'keywords':'Single Pole Relay SPDT', 'description':'', 'datasheet':'http://hiqsdr.com/images/3/3e/Axicom-HF3.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nHF3-55\n\nSingle Pole Relay SPDT', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HF3-56', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HF3-56'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm'], 'footprint':'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm', 'keywords':'Single Pole Relay SPDT', 'description':'', 'datasheet':'http://hiqsdr.com/images/3/3e/Axicom-HF3.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nHF3-56\n\nSingle Pole Relay SPDT', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HF3-57', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HF3-57'}), 'ref_prefix':'K', 'fplist':['Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm', 'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm'], 'footprint':'Relay_SMD:Relay_SPDT_AXICOM_HF3Series_50ohms_Pitch1.27mm', 'keywords':'Single Pole Relay SPDT', 'description':'', 'datasheet':'http://hiqsdr.com/images/3/3e/Axicom-HF3.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nHF3-57\n\nSingle Pole Relay SPDT', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HK19F-DCxxV-SHC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HK19F-DCxxV-SHC'}), 'ref_prefix':'K', 'fplist':['', 'Relay_THT:Relay_DPDT_Omron_G2RL-2', 'Relay_THT:Relay_DPDT_Omron_G6A', 'Relay_THT:Relay_DPDT_Hongfa_HF115F-2Z-x4', 'Relay_THT:Relay_DPDT_Finder_30.22'], 'footprint':'', 'keywords':'12V DC Relay DPDT', 'description':'', 'datasheet':'https://www.lcsc.com/datasheet/lcsc_datasheet_1810201512_Ningbo-Keke-New-Era-Appliance-HK19F-DC12V-SHG_C42803.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nHK19F-DCxxV-SHC\n\n12V DC Relay DPDT', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM01', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM01'}), 'ref_prefix':'K', 'fplist':['', ''], 'footprint':'', 'keywords':'relay monostable', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=108-98001&DocType=SS&DocLang=EN', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nIM01\n\nrelay monostable', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM02'}), 'ref_prefix':'K', 'fplist':['', '', ''], 'footprint':'', 'keywords':'relay monostable', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=108-98001&DocType=SS&DocLang=EN', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nIM02\n\nrelay monostable', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM03', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM03'}), 'ref_prefix':'K', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'relay monostable', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=108-98001&DocType=SS&DocLang=EN', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nIM03\n\nrelay monostable', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM04', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM04'}), 'ref_prefix':'K', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'relay monostable', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=108-98001&DocType=SS&DocLang=EN', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nIM04\n\nrelay monostable', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM05', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM05'}), 'ref_prefix':'K', 'fplist':['', '', '', '', '', ''], 'footprint':'', 'keywords':'relay monostable', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=108-98001&DocType=SS&DocLang=EN', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nIM05\n\nrelay monostable', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM06', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM06'}), 'ref_prefix':'K', 'fplist':['', '', '', '', '', '', ''], 'footprint':'', 'keywords':'relay monostable', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=108-98001&DocType=SS&DocLang=EN', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nIM06\n\nrelay monostable', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM07', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM07'}), 'ref_prefix':'K', 'fplist':['', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'relay monostable', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=108-98001&DocType=SS&DocLang=EN', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nIM07\n\nrelay monostable', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM08', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM08'}), 'ref_prefix':'K', 'fplist':['', '', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'relay monostable', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=108-98001&DocType=SS&DocLang=EN', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nIM08\n\nrelay monostable', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM12'}), 'ref_prefix':'K', 'fplist':['', ''], 'footprint':'', 'keywords':'relay monastable sensitive', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=108-98001&DocType=SS&DocLang=EN', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nIM12\n\nrelay monastable sensitive', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM13', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM13'}), 'ref_prefix':'K', 'fplist':['', '', ''], 'footprint':'', 'keywords':'relay monastable sensitive', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=108-98001&DocType=SS&DocLang=EN', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nIM13\n\nrelay monastable sensitive', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM16'}), 'ref_prefix':'K', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'relay monastable sensitive', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=108-98001&DocType=SS&DocLang=EN', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nIM16\n\nrelay monastable sensitive', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM17', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM17'}), 'ref_prefix':'K', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'relay monastable sensitive', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=108-98001&DocType=SS&DocLang=EN', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nIM17\n\nrelay monastable sensitive', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM22', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM22'}), 'ref_prefix':'K', 'fplist':['', ''], 'footprint':'', 'keywords':'relay monastable sensitive', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=108-98001&DocType=SS&DocLang=EN', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nIM22\n\nrelay monastable sensitive', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM23', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM23'}), 'ref_prefix':'K', 'fplist':['', '', ''], 'footprint':'', 'keywords':'relay monastable sensitive', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=108-98001&DocType=SS&DocLang=EN', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nIM23\n\nrelay monastable sensitive', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM26', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM26'}), 'ref_prefix':'K', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'relay monastable sensitive', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=108-98001&DocType=SS&DocLang=EN', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nIM26\n\nrelay monastable sensitive', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM41', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM41'}), 'ref_prefix':'K', 'fplist':['', ''], 'footprint':'', 'keywords':'relay bistable', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=108-98001&DocType=SS&DocLang=EN', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nIM41\n\nrelay bistable', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM42', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM42'}), 'ref_prefix':'K', 'fplist':['', '', ''], 'footprint':'', 'keywords':'relay bistable', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=108-98001&DocType=SS&DocLang=EN', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nIM42\n\nrelay bistable', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM43', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM43'}), 'ref_prefix':'K', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'relay bistable', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=108-98001&DocType=SS&DocLang=EN', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nIM43\n\nrelay bistable', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM44', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM44'}), 'ref_prefix':'K', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'relay bistable', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=108-98001&DocType=SS&DocLang=EN', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nIM44\n\nrelay bistable', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM45', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM45'}), 'ref_prefix':'K', 'fplist':['', '', '', '', '', ''], 'footprint':'', 'keywords':'relay bistable', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=108-98001&DocType=SS&DocLang=EN', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nIM45\n\nrelay bistable', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM46', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM46'}), 'ref_prefix':'K', 'fplist':['', '', '', '', '', '', ''], 'footprint':'', 'keywords':'relay bistable', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=108-98001&DocType=SS&DocLang=EN', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nIM46\n\nrelay bistable', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM47', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM47'}), 'ref_prefix':'K', 'fplist':['', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'relay bistable', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=108-98001&DocType=SS&DocLang=EN', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nIM47\n\nrelay bistable', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IM48', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IM48'}), 'ref_prefix':'K', 'fplist':['', '', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'relay bistable', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=108-98001&DocType=SS&DocLang=EN', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nIM48\n\nrelay bistable', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Panasonic_ALFG1PF09', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Panasonic_ALFG1PF09'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_Finder_32.21-x300', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles'], 'footprint':'Relay_THT:Relay_SPST_Finder_32.21-x300', 'keywords':'single pole spst make contact', 'description':'', 'datasheet':'https://www3.panasonic.biz/ac/e_download/control/relay/power/catalog/mech_eng_lfg.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nPanasonic_ALFG1PF09\n\nsingle pole spst make contact', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Panasonic_ALFG1PF091', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Panasonic_ALFG1PF091'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_Finder_32.21-x300', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles'], 'footprint':'Relay_THT:Relay_SPST_Finder_32.21-x300', 'keywords':'single pole spst make contact', 'description':'', 'datasheet':'https://www3.panasonic.biz/ac/e_download/control/relay/power/catalog/mech_eng_lfg.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nPanasonic_ALFG1PF091\n\nsingle pole spst make contact', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Panasonic_ALFG1PF12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Panasonic_ALFG1PF12'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_Finder_32.21-x300', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles'], 'footprint':'Relay_THT:Relay_SPST_Finder_32.21-x300', 'keywords':'single pole spst make contact', 'description':'', 'datasheet':'https://www3.panasonic.biz/ac/e_download/control/relay/power/catalog/mech_eng_lfg.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nPanasonic_ALFG1PF12\n\nsingle pole spst make contact', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Panasonic_ALFG1PF121', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Panasonic_ALFG1PF121'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_Finder_32.21-x300', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles'], 'footprint':'Relay_THT:Relay_SPST_Finder_32.21-x300', 'keywords':'single pole spst make contact', 'description':'', 'datasheet':'https://www3.panasonic.biz/ac/e_download/control/relay/power/catalog/mech_eng_lfg.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nPanasonic_ALFG1PF121\n\nsingle pole spst make contact', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Panasonic_ALFG1PF18', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Panasonic_ALFG1PF18'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_Finder_32.21-x300', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles'], 'footprint':'Relay_THT:Relay_SPST_Finder_32.21-x300', 'keywords':'single pole spst make contact', 'description':'', 'datasheet':'https://www3.panasonic.biz/ac/e_download/control/relay/power/catalog/mech_eng_lfg.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nPanasonic_ALFG1PF18\n\nsingle pole spst make contact', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Panasonic_ALFG1PF181', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Panasonic_ALFG1PF181'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_Finder_32.21-x300', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles'], 'footprint':'Relay_THT:Relay_SPST_Finder_32.21-x300', 'keywords':'single pole spst make contact', 'description':'', 'datasheet':'https://www3.panasonic.biz/ac/e_download/control/relay/power/catalog/mech_eng_lfg.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nPanasonic_ALFG1PF181\n\nsingle pole spst make contact', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Panasonic_ALFG1PF24', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Panasonic_ALFG1PF24'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_Finder_32.21-x300', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles'], 'footprint':'Relay_THT:Relay_SPST_Finder_32.21-x300', 'keywords':'single pole spst make contact', 'description':'', 'datasheet':'https://www3.panasonic.biz/ac/e_download/control/relay/power/catalog/mech_eng_lfg.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nPanasonic_ALFG1PF24\n\nsingle pole spst make contact', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Panasonic_ALFG1PF241', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Panasonic_ALFG1PF241'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_Finder_32.21-x300', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles'], 'footprint':'Relay_THT:Relay_SPST_Finder_32.21-x300', 'keywords':'single pole spst make contact', 'description':'', 'datasheet':'https://www3.panasonic.biz/ac/e_download/control/relay/power/catalog/mech_eng_lfg.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nPanasonic_ALFG1PF241\n\nsingle pole spst make contact', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Panasonic_ALFG2PF09', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Panasonic_ALFG2PF09'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_Finder_32.21-x300', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles'], 'footprint':'Relay_THT:Relay_SPST_Finder_32.21-x300', 'keywords':'single pole spst make contact', 'description':'', 'datasheet':'https://www3.panasonic.biz/ac/e_download/control/relay/power/catalog/mech_eng_lfg.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nPanasonic_ALFG2PF09\n\nsingle pole spst make contact', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Panasonic_ALFG2PF091', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Panasonic_ALFG2PF091'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_Finder_32.21-x300', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles'], 'footprint':'Relay_THT:Relay_SPST_Finder_32.21-x300', 'keywords':'single pole spst make contact', 'description':'', 'datasheet':'https://www3.panasonic.biz/ac/e_download/control/relay/power/catalog/mech_eng_lfg.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nPanasonic_ALFG2PF091\n\nsingle pole spst make contact', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Panasonic_ALFG2PF12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Panasonic_ALFG2PF12'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_Finder_32.21-x300', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles'], 'footprint':'Relay_THT:Relay_SPST_Finder_32.21-x300', 'keywords':'single pole spst make contact', 'description':'', 'datasheet':'https://www3.panasonic.biz/ac/e_download/control/relay/power/catalog/mech_eng_lfg.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nPanasonic_ALFG2PF12\n\nsingle pole spst make contact', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Panasonic_ALFG2PF121', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Panasonic_ALFG2PF121'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_Finder_32.21-x300', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles'], 'footprint':'Relay_THT:Relay_SPST_Finder_32.21-x300', 'keywords':'single pole spst make contact', 'description':'', 'datasheet':'https://www3.panasonic.biz/ac/e_download/control/relay/power/catalog/mech_eng_lfg.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nPanasonic_ALFG2PF121\n\nsingle pole spst make contact', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Panasonic_ALFG2PF18', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Panasonic_ALFG2PF18'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_Finder_32.21-x300', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles'], 'footprint':'Relay_THT:Relay_SPST_Finder_32.21-x300', 'keywords':'single pole spst make contact', 'description':'', 'datasheet':'https://www3.panasonic.biz/ac/e_download/control/relay/power/catalog/mech_eng_lfg.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nPanasonic_ALFG2PF18\n\nsingle pole spst make contact', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Panasonic_ALFG2PF181', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Panasonic_ALFG2PF181'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_Finder_32.21-x300', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles'], 'footprint':'Relay_THT:Relay_SPST_Finder_32.21-x300', 'keywords':'single pole spst make contact', 'description':'', 'datasheet':'https://www3.panasonic.biz/ac/e_download/control/relay/power/catalog/mech_eng_lfg.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nPanasonic_ALFG2PF181\n\nsingle pole spst make contact', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Panasonic_ALFG2PF24', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Panasonic_ALFG2PF24'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_Finder_32.21-x300', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles'], 'footprint':'Relay_THT:Relay_SPST_Finder_32.21-x300', 'keywords':'single pole spst make contact', 'description':'', 'datasheet':'https://www3.panasonic.biz/ac/e_download/control/relay/power/catalog/mech_eng_lfg.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nPanasonic_ALFG2PF24\n\nsingle pole spst make contact', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Panasonic_ALFG2PF241', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Panasonic_ALFG2PF241'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_Finder_32.21-x300', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles'], 'footprint':'Relay_THT:Relay_SPST_Finder_32.21-x300', 'keywords':'single pole spst make contact', 'description':'', 'datasheet':'https://www3.panasonic.biz/ac/e_download/control/relay/power/catalog/mech_eng_lfg.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nPanasonic_ALFG2PF241\n\nsingle pole spst make contact', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RM50-xx21', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RM50-xx21'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPST_Finder_32.21-x300', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Panasonic_ALFG_FormA_CircularHoles', 'Relay_THT:Relay_SPST_Finder_32.21-x300'], 'footprint':'Relay_THT:Relay_SPST_Finder_32.21-x300', 'keywords':'Single Pole Relay SPST-NO', 'description':'', 'datasheet':'http://www.relpol.pl/en/content/download/13683/165953/file/e_RM50.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRM50-xx21\n\nSingle Pole Relay SPST-NO', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RM84', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RM84'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Finder_40.52', 'Relay_THT:Relay_DPDT_Finder_40.52', 'Relay_THT:Relay_DPDT_Finder_40.52', 'Relay_THT:Relay_DPDT_Finder_40.52', 'Relay_THT:Relay_DPDT_Finder_40.52'], 'footprint':'Relay_THT:Relay_DPDT_Finder_40.52', 'keywords':'Dual Pole Relay', 'description':'', 'datasheet':'http://www.relpol.pl/en/content/download/13766/168095/file/e_RM84.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRM84\n\nDual Pole Relay', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RSM822', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RSM822'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Finder_40.52', 'Relay_THT:Relay_DPDT_Finder_40.52', 'Relay_THT:Relay_DPDT_Finder_40.52', 'Relay_THT:Relay_DPDT_Finder_40.52', 'Relay_THT:Relay_DPDT_Finder_40.52', 'Relay_THT:Relay_DPDT_Finder_40.52'], 'footprint':'Relay_THT:Relay_DPDT_Finder_40.52', 'keywords':'Dual Pole Relay', 'description':'', 'datasheet':'http://www.relpol.pl/en/content/download/14975/202519/file/e_RSM822.pdf', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRSM822\n\nDual Pole Relay', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RT314A05', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RT314A05'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPDT_Schrack-RT1-16A-FormC_RM5mm', 'Relay_THT:Relay_SPDT_Schrack-RT1-16A-FormC_RM5mm'], 'footprint':'Relay_THT:Relay_SPDT_Schrack-RT1-16A-FormC_RM5mm', 'keywords':'TE SPDT 1P2T CO bistable DC', 'description':'', 'datasheet':'https://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=RT1_bistable&DocType=DS&DocLang=English', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRT314A05\n\nTE SPDT 1P2T CO bistable DC', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RT314A06', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RT314A06'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPDT_Schrack-RT1-16A-FormC_RM5mm', 'Relay_THT:Relay_SPDT_Schrack-RT1-16A-FormC_RM5mm', 'Relay_THT:Relay_SPDT_Schrack-RT1-16A-FormC_RM5mm'], 'footprint':'Relay_THT:Relay_SPDT_Schrack-RT1-16A-FormC_RM5mm', 'keywords':'TE SPDT 1P2T CO bistable DC', 'description':'', 'datasheet':'https://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=RT1_bistable&DocType=DS&DocLang=English', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRT314A06\n\nTE SPDT 1P2T CO bistable DC', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RT314A12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RT314A12'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPDT_Schrack-RT1-16A-FormC_RM5mm', 'Relay_THT:Relay_SPDT_Schrack-RT1-16A-FormC_RM5mm', 'Relay_THT:Relay_SPDT_Schrack-RT1-16A-FormC_RM5mm', 'Relay_THT:Relay_SPDT_Schrack-RT1-16A-FormC_RM5mm'], 'footprint':'Relay_THT:Relay_SPDT_Schrack-RT1-16A-FormC_RM5mm', 'keywords':'TE SPDT 1P2T CO bistable DC', 'description':'', 'datasheet':'https://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=RT1_bistable&DocType=DS&DocLang=English', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRT314A12\n\nTE SPDT 1P2T CO bistable DC', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RT314A24', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RT314A24'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_SPDT_Schrack-RT1-16A-FormC_RM5mm', 'Relay_THT:Relay_SPDT_Schrack-RT1-16A-FormC_RM5mm', 'Relay_THT:Relay_SPDT_Schrack-RT1-16A-FormC_RM5mm', 'Relay_THT:Relay_SPDT_Schrack-RT1-16A-FormC_RM5mm', 'Relay_THT:Relay_SPDT_Schrack-RT1-16A-FormC_RM5mm'], 'footprint':'Relay_THT:Relay_SPDT_Schrack-RT1-16A-FormC_RM5mm', 'keywords':'TE SPDT 1P2T CO bistable DC', 'description':'', 'datasheet':'https://www.te.com/commerce/DocumentDelivery/DDEController?Action=srchrtrv&DocNm=RT1_bistable&DocType=DS&DocLang=English', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRT314A24\n\nTE SPDT 1P2T CO bistable DC', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RTE2xAxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RTE2xAxx'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Schrack-RT2-FormC_RM5mm', 'Relay_THT:Relay_DPDT_Schrack-RT2-FormC_RM5mm'], 'footprint':'Relay_THT:Relay_DPDT_Schrack-RT2-FormC_RM5mm', 'keywords':'TE DPDT CO bistable DC', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=showdoc&DocId=Data+Sheet%7FRT2_bistable%7F1116%7Fpdf%7FEnglish%7FENG_DS_RT2_bistable_1116.pdf%7F1-1415537-8', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRTE2xAxx\n\nTE DPDT CO bistable DC', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RTE2xFxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RTE2xFxx'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Schrack-RT2-FormC-Dual-Coil_RM5mm', 'Relay_THT:Relay_DPDT_Schrack-RT2-FormC-Dual-Coil_RM5mm'], 'footprint':'Relay_THT:Relay_DPDT_Schrack-RT2-FormC-Dual-Coil_RM5mm', 'keywords':'TE DPDT CO bistable DC', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=showdoc&DocId=Data+Sheet%7FRT2_bistable%7F1116%7Fpdf%7FEnglish%7FENG_DS_RT2_bistable_1116.pdf%7F1-1415537-8', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRTE2xFxx\n\nTE DPDT CO bistable DC', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RTE2xxxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RTE2xxxx'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPDT_Schrack-RT2-FormC_RM5mm', 'Relay_THT:Relay_DPDT_Schrack-RT2-FormC_RM5mm'], 'footprint':'Relay_THT:Relay_DPDT_Schrack-RT2-FormC_RM5mm', 'keywords':'TE DPDT CO monostable', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=showdoc&DocId=Data+Sheet%7FRT2%7F1014%7Fpdf%7FEnglish%7FENG_DS_RT2_1014.pdf%7F6-1393243-3', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRTE2xxxx\n\nTE DPDT CO monostable', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RTE4xxxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RTE4xxxx'}), 'ref_prefix':'K', 'fplist':['Relay_THT:Relay_DPST_Schrack-RT2-FormA_RM5mm', 'Relay_THT:Relay_DPST_Schrack-RT2-FormA_RM5mm'], 'footprint':'Relay_THT:Relay_DPST_Schrack-RT2-FormA_RM5mm', 'keywords':'TE DPST NO monostable', 'description':'', 'datasheet':'http://www.te.com/commerce/DocumentDelivery/DDEController?Action=showdoc&DocId=Data+Sheet%7FRT2%7F1014%7Fpdf%7FEnglish%7FENG_DS_RT2_1014.pdf%7F6-1393243-3', 'search_text':'/usr/share/kicad/symbols/Relay.kicad_sym\nRTE4xxxx\n\nTE DPST NO monostable', 'pins':[
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] })])