from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Connector_Audio = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'AudioJack2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AudioJack2'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'audio jack receptacle mono phone headphone TS connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nAudioJack2\n\naudio jack receptacle mono phone headphone TS connector', 'pins':[
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AudioJack2_Dual_Ground_Switch', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AudioJack2_Dual_Ground_Switch'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'audio jack dual receptacle mono headphones phone TS connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nAudioJack2_Dual_Ground_Switch\n\naudio jack dual receptacle mono headphones phone TS connector', 'pins':[
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='SN2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='TN2',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['S1', 'SN1', 'G', 'TN1', 'T1']},{'label': 'uB', 'num': 2, 'pin_nums': ['TN2', 'S2', 'SN2', 'T2']}] }),
        Part(**{ 'name':'AudioJack2_Dual_Switch', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AudioJack2_Dual_Switch'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'audio jack dual receptacle mono headphones phone TS connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nAudioJack2_Dual_Switch\n\naudio jack dual receptacle mono headphones phone TS connector', 'pins':[
            Pin(num='S1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='SN2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='TN2',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['S1', 'SN1', 'T1', 'TN1']},{'label': 'uB', 'num': 2, 'pin_nums': ['SN2', 'TN2', 'S2', 'T2']}] }),
        Part(**{ 'name':'AudioJack2_Ground', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AudioJack2_Ground'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'audio jack receptacle mono phone headphone TS connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nAudioJack2_Ground\n\naudio jack receptacle mono phone headphone TS connector', 'pins':[
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AudioJack2_Ground_Switch', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AudioJack2_Ground_Switch'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'audio jack receptacle mono headphones phone TS connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nAudioJack2_Ground_Switch\n\naudio jack receptacle mono headphones phone TS connector', 'pins':[
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AudioJack2_Ground_SwitchT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AudioJack2_Ground_SwitchT'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'audio jack receptacle mono headphones phone TS connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nAudioJack2_Ground_SwitchT\n\naudio jack receptacle mono headphones phone TS connector', 'pins':[
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AudioJack2_Switch', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AudioJack2_Switch'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'audio jack receptacle mono headphones phone TS connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nAudioJack2_Switch\n\naudio jack receptacle mono headphones phone TS connector', 'pins':[
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AudioJack2_SwitchT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AudioJack2_SwitchT'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'audio jack receptacle mono headphones phone TS connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nAudioJack2_SwitchT\n\naudio jack receptacle mono headphones phone TS connector', 'pins':[
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AudioJack3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AudioJack3'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones phones TRS connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nAudioJack3\n\naudio jack receptacle stereo headphones phones TRS connector', 'pins':[
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AudioJack3_Dual_Ground_Switch', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AudioJack3_Dual_Ground_Switch'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'audio jack dual receptacle stereo headphones phones TRS connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nAudioJack3_Dual_Ground_Switch\n\naudio jack dual receptacle stereo headphones phones TRS connector', 'pins':[
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='RN2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='S2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='SN2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='TN2',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['R1', 'RN1', 'T1', 'G', 'TN1', 'S1', 'SN1']},{'label': 'uB', 'num': 2, 'pin_nums': ['RN2', 'SN2', 'S2', 'T2', 'TN2', 'R2']}] }),
        Part(**{ 'name':'AudioJack3_Dual_Switch', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AudioJack3_Dual_Switch'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'audio jack dual receptacle stereo headphones phones TRS connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nAudioJack3_Dual_Switch\n\naudio jack dual receptacle stereo headphones phones TRS connector', 'pins':[
            Pin(num='R1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='RN2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='S2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='SN2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='TN2',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['R1', 'TN1', 'SN1', 'S1', 'RN1', 'T1']},{'label': 'uB', 'num': 2, 'pin_nums': ['T2', 'S2', 'SN2', 'TN2', 'R2', 'RN2']}] }),
        Part(**{ 'name':'AudioJack3_Ground', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AudioJack3_Ground'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones phones TRS connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nAudioJack3_Ground\n\naudio jack receptacle stereo headphones phones TRS connector', 'pins':[
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AudioJack3_Ground_Switch', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AudioJack3_Ground_Switch'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones phones TRS connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nAudioJack3_Ground_Switch\n\naudio jack receptacle stereo headphones phones TRS connector', 'pins':[
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AudioJack3_Ground_SwitchTR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AudioJack3_Ground_SwitchTR'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones phones TRS connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nAudioJack3_Ground_SwitchTR\n\naudio jack receptacle stereo headphones phones TRS connector', 'pins':[
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AudioJack3_Switch', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AudioJack3_Switch'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nAudioJack3_Switch\n\naudio jack receptacle stereo headphones connector', 'pins':[
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AudioJack3_SwitchT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AudioJack3_SwitchT'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones phones TRS connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nAudioJack3_SwitchT\n\naudio jack receptacle stereo headphones phones TRS connector', 'pins':[
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AudioJack3_SwitchTR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AudioJack3_SwitchTR'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones phones TRS connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nAudioJack3_SwitchTR\n\naudio jack receptacle stereo headphones phones TRS connector', 'pins':[
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AudioJack4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AudioJack4'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones TRRS connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nAudioJack4\n\naudio jack receptacle stereo headphones TRRS connector', 'pins':[
            Pin(num='R1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AudioJack4_Ground', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AudioJack4_Ground'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones TRRS connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nAudioJack4_Ground\n\naudio jack receptacle stereo headphones TRRS connector', 'pins':[
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AudioJack4_Ground_SwitchTR1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AudioJack4_Ground_SwitchTR1'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones phones TRS connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nAudioJack4_Ground_SwitchTR1\n\naudio jack receptacle stereo headphones phones TRS connector', 'pins':[
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1N',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AudioJack4_SwitchT1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AudioJack4_SwitchT1'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones phones connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nAudioJack4_SwitchT1\n\naudio jack receptacle stereo headphones phones connector', 'pins':[
            Pin(num='R1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AudioJack4_SwitchTR1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AudioJack4_SwitchTR1'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones phones TRS connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nAudioJack4_SwitchTR1\n\naudio jack receptacle stereo headphones phones TRS connector', 'pins':[
            Pin(num='R1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1N',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AudioJack5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AudioJack5'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones TRRRS connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nAudioJack5\n\naudio jack receptacle stereo headphones TRRRS connector', 'pins':[
            Pin(num='R1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AudioJack5_Ground', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AudioJack5_Ground'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones TRRRS connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nAudioJack5_Ground\n\naudio jack receptacle stereo headphones TRRRS connector', 'pins':[
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AudioPlug2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AudioPlug2'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'audio jack plug stereo headphones TRRS connector 2.5mm 3.5mm 6.35mm', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nAudioPlug2\n\naudio jack plug stereo headphones TRRS connector 2.5mm 3.5mm 6.35mm', 'pins':[
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AudioPlug3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AudioPlug3'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'audio jack plug stereo headphones TRRS connector 2.5mm 3.5mm 6.35mm', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nAudioPlug3\n\naudio jack plug stereo headphones TRRS connector 2.5mm 3.5mm 6.35mm', 'pins':[
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AudioPlug4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AudioPlug4'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'audio jack plug stereo headphones TRRS connector 2.5mm 3.5mm', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nAudioPlug4\n\naudio jack plug stereo headphones TRRS connector 2.5mm 3.5mm', 'pins':[
            Pin(num='R1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SpeakON_NL2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SpeakON_NL2'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'speakon connector', 'description':'', 'datasheet':'http://www.neutrik.com/en/speakon/', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nSpeakON_NL2\n\nspeakon connector', 'pins':[
            Pin(num='1-',name='1-',func=pin_types.PASSIVE),
            Pin(num='1+',name='1+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SpeakON_NL2_AudioJack2_Combo', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SpeakON_NL2_AudioJack2_Combo'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'speakon connector', 'description':'', 'datasheet':'http://www.neutrik.com/en/speakon/', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nSpeakON_NL2_AudioJack2_Combo\n\nspeakon connector', 'pins':[
            Pin(num='1-',name='1-',func=pin_types.PASSIVE),
            Pin(num='1+',name='1+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SpeakON_NL4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SpeakON_NL4'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'speakon connector', 'description':'', 'datasheet':'http://www.neutrik.com/en/speakon/', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nSpeakON_NL4\n\nspeakon connector', 'pins':[
            Pin(num='1-',name='1-',func=pin_types.PASSIVE),
            Pin(num='2+',name='2+',func=pin_types.PASSIVE),
            Pin(num='2-',name='2-',func=pin_types.PASSIVE),
            Pin(num='1+',name='1+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SpeakON_NL4_Switch', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SpeakON_NL4_Switch'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'speakon connector', 'description':'', 'datasheet':'http://www.neutrik.com/en/speakon/', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nSpeakON_NL4_Switch\n\nspeakon connector', 'pins':[
            Pin(num='1-',name='1-',func=pin_types.PASSIVE),
            Pin(num='1-N',name='1-N',func=pin_types.PASSIVE),
            Pin(num='2+',name='2+',func=pin_types.PASSIVE),
            Pin(num='2+N',name='2+N',func=pin_types.PASSIVE),
            Pin(num='2-',name='2-',func=pin_types.PASSIVE),
            Pin(num='1+',name='1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='1+N',name='1+N',func=pin_types.PASSIVE,unit=1),
            Pin(num='2-N',name='2-N',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SpeakON_NL8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SpeakON_NL8'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'speakon connector', 'description':'', 'datasheet':'http://www.neutrik.com/en/speakon/', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nSpeakON_NL8\n\nspeakon connector', 'pins':[
            Pin(num='1-',name='1-',func=pin_types.PASSIVE),
            Pin(num='2+',name='2+',func=pin_types.PASSIVE),
            Pin(num='2-',name='2-',func=pin_types.PASSIVE),
            Pin(num='3+',name='3+',func=pin_types.PASSIVE),
            Pin(num='3-',name='3-',func=pin_types.PASSIVE),
            Pin(num='4+',name='4+',func=pin_types.PASSIVE),
            Pin(num='4-',name='4-',func=pin_types.PASSIVE),
            Pin(num='1+',name='1+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XLR3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XLR3'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'xlr connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nXLR3\n\nxlr connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'XLR3_AudioJack2_Combo', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XLR3_AudioJack2_Combo'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'xlr connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nXLR3_AudioJack2_Combo\n\nxlr connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['S', 'T']}] }),
        Part(**{ 'name':'XLR3_AudioJack2_Combo_Ground', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XLR3_AudioJack2_Combo_Ground'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'xlr connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nXLR3_AudioJack2_Combo_Ground\n\nxlr connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['G', '3', '2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['S', 'T']}] }),
        Part(**{ 'name':'XLR3_AudioJack3_Combo', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XLR3_AudioJack3_Combo'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'xlr connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nXLR3_AudioJack3_Combo\n\nxlr connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['R', 'S', 'T']}] }),
        Part(**{ 'name':'XLR3_AudioJack3_Combo_Ground', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XLR3_AudioJack3_Combo_Ground'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'xlr connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nXLR3_AudioJack3_Combo_Ground\n\nxlr connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['G', '2', '3', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['R', 'S', 'T']}] }),
        Part(**{ 'name':'XLR3_AudioJack3_Combo_GroundSwitch_Switch', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XLR3_AudioJack3_Combo_GroundSwitch_Switch'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'xlr connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nXLR3_AudioJack3_Combo_GroundSwitch_Switch\n\nxlr connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='GN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', 'G', '1', 'GN', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['S', 'TN', 'SN', 'RN', 'T', 'R']}] }),
        Part(**{ 'name':'XLR3_AudioJack3_Combo_Ground_Switch', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XLR3_AudioJack3_Combo_Ground_Switch'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'xlr connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nXLR3_AudioJack3_Combo_Ground_Switch\n\nxlr connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '3', 'G', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['S', 'T', 'TN', 'RN', 'SN', 'R']}] }),
        Part(**{ 'name':'XLR3_AudioJack3_Combo_Switch', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XLR3_AudioJack3_Combo_Switch'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'xlr connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nXLR3_AudioJack3_Combo_Switch\n\nxlr connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '3', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['TN', 'S', 'SN', 'T', 'RN', 'R']}] }),
        Part(**{ 'name':'XLR3_Ground', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XLR3_Ground'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'xlr connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nXLR3_Ground\n\nxlr connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XLR3_Ground_Switched', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XLR3_Ground_Switched'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'xlr connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nXLR3_Ground_Switched\n\nxlr connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='N',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='NC',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='NO',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '3', '1', 'G']},{'label': 'uB', 'num': 2, 'pin_nums': ['NC', 'NO', 'N']}] }),
        Part(**{ 'name':'XLR3_Switched', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XLR3_Switched'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'xlr connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nXLR3_Switched\n\nxlr connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='N',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='NC',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='NO',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['NC', 'N', 'NO']}] }),
        Part(**{ 'name':'XLR4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XLR4'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'xlr connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nXLR4\n\nxlr connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XLR4_Ground', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XLR4_Ground'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'xlr connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nXLR4_Ground\n\nxlr connector', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XLR5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XLR5'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'xlr connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nXLR5\n\nxlr connector', 'pins':[
            Pin(num='1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XLR5_Ground', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XLR5_Ground'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'xlr connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nXLR5_Ground\n\nxlr connector', 'pins':[
            Pin(num='1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'XLR5_Ground_Switched', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XLR5_Ground_Switched'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'xlr connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nXLR5_Ground_Switched\n\nxlr connector', 'pins':[
            Pin(num='1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='N',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='NC',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='NO',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['4', '5', '3', '1', '2', 'G']},{'label': 'uB', 'num': 2, 'pin_nums': ['NO', 'NC', 'N']}] }),
        Part(**{ 'name':'XLR6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'XLR6'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'xlr connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nXLR6\n\nxlr connector', 'pins':[
            Pin(num='1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='P6',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAAH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAAH'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3faah', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAAH\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAAH-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAAH-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3faah-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAAH-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAAH1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAAH1'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3faah1', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAAH1\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAAH1-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAAH1-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3faah1-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAAH1-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAAH1-DA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAAH1-DA'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3faah1-da', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAAH1-DA\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAAH2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAAH2'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3faah2', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAAH2\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAAH2-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAAH2-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3faah2-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAAH2-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAAV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAAV'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3faav', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAAV\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAAV-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAAV-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3faav-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAAV-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAAV1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAAV1'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3faav1', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAAV1\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAAV1-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAAV1-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3faav1-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAAV1-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAAV1-DA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAAV1-DA'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3faav1-da', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAAV1-DA\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAAV2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAAV2'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3faav2', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAAV2\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAAV2-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAAV2-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3faav2-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAAV2-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAH'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fah', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAH\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAH-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAH-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fah-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAH-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAH1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAH1'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fah1', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAH1\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAH1-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAH1-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-0_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fah1-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAH1-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAH1-DA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAH1-DA'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-DA_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fah1-da', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAH1-DA\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAH2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAH2'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fah2', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAH2\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAH2-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAH2-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fah2-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAH2-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAH2-DA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAH2-DA'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fah2-da', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAH2-DA\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAHL-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAHL-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL-0_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fahl-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAHL-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAHL1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAHL1'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fahl1', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAHL1\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAHL1-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAHL1-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1-0_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fahl1-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAHL1-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAHR-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAHR-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR-0_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fahr-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAHR-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAHR1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAHR1'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fahr1', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAHR1\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAHR1-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAHR1-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1-0_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fahr1-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAHR1-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAHR2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAHR2'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fahr2', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAHR2\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAHR2-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAHR2-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fahr2-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAHR2-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAV'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fav', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAV\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAV-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAV-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV-0_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fav-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAV-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAV1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAV1'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fav1', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAV1\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAV1-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAV1-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-0_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fav1-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAV1-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAV1-DA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAV1-DA'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-DA_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fav1-da', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAV1-DA\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAV2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAV2'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fav2', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAV2\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAV2-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAV2-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fav2-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAV2-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FAV2-DA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FAV2-DA'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fav2-da', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FAV2-DA\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FBH1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FBH1'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fbh1', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FBH1\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FBH1-B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FBH1-B'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-B_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fbh1-b', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FBH1-B\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FBH1-DA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FBH1-DA'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-DA_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fbh1-da', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FBH1-DA\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FBH1-E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FBH1-E'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-E_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fbh1-e', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FBH1-E\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FBH2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FBH2'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fbh2', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FBH2\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FBH2-B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FBH2-B'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-B_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fbh2-b', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FBH2-B\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FBH2-DA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FBH2-DA'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-DA_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fbh2-da', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FBH2-DA\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FBH2-E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FBH2-E'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-E_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fbh2-e', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FBH2-E\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FBHL1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FBHL1'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBHL1_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fbhl1', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FBHL1\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FBV1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FBV1'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fbv1', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FBV1\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FBV1-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FBV1-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1-0_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fbv1-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FBV1-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FBV1-B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FBV1-B'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1-B_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fbv1-b', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FBV1-B\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FBV1-DA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FBV1-DA'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1-DA_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fbv1-da', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FBV1-DA\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FBV2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FBV2'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fbv2', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FBV2\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FBV2-B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FBV2-B'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-B_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fbv2-b', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FBV2-B\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FBV2-DA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FBV2-DA'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-DA_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fbv2-da', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FBV2-DA\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3FBV2-SW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3FBV2-SW'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-SW_Vertical'], 'footprint':'', 'keywords':'xlr connector spdt switch neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3fbv2-sw', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3FBV2-SW\n\nxlr connector spdt switch neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='N',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='NC',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='NO',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', 'G', '3', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['NO', 'NC', 'N']}] }),
        Part(**{ 'name':'NC3MAAH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3MAAH'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3maah', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3MAAH\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3MAAH-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3MAAH-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH-0_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3maah-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3MAAH-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3MAAH-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3MAAH-1'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH-1_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3maah-1', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3MAAH-1\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3MAAV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3MAAV'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3maav', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3MAAV\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3MAAV-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3MAAV-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV-0_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3maav-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3MAAV-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3MAAV-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3MAAV-1'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH-1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV-1_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3maav-1', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3MAAV-1\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3MAFH-PH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3MAFH-PH'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH-1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV-1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAFH-PH_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3mafh-ph', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3MAFH-PH\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3MAH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3MAH'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3mah', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3MAH\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3MAH-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3MAH-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH-0_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3mah-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3MAH-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3MAHL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3MAHL'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHL_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3mahl', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3MAHL\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3MAHR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3MAHR'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHL_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHR_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3mahr', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3MAHR\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3MAMH-PH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3MAMH-PH'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH-1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV-1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAFH-PH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAMH-PH_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3mamh-ph', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3MAMH-PH\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3MAV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3MAV'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHL_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHR_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAV_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3mav', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3MAV\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3MAV-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3MAV-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHL_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHR_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAV-0_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3mav-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3MAV-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3MBH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3MBH'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHL_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHR_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3mbh', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3MBH\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3MBH-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3MBH-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHL_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHR_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-0_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3mbh-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3MBH-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3MBH-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3MBH-1'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH-1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV-1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAFH-PH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAMH-PH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-1_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3mbh-1', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3MBH-1\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3MBH-B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3MBH-B'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHL_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHR_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-B_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3mbh-b', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3MBH-B\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3MBH-E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3MBH-E'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHL_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHR_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-E_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3mbh-e', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3MBH-E\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3MBHL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3MBHL'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHL_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHR_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBHL_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3mbhl', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3MBHL\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3MBHL-B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3MBHL-B'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHL_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHR_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBHL_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBHL-B_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3mbhl-b', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3MBHL-B\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3MBHR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3MBHR'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHL_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHR_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBHL_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBHL-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBHR_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3mbhr', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3MBHR\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3MBHR-B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3MBHR-B'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHL_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHR_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBHL_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBHL-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBHR_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBHR-B_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3mbhr-b', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3MBHR-B\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3MBV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3MBV'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHL_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHR_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBHL_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBHL-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBHR_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBHR-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBV_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3mbv', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3MBV\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3MBV-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3MBV-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHL_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHR_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBHL_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBHL-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBHR_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBHR-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBV-0_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3mbv-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3MBV-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3MBV-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3MBV-1'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHL1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR1-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH1-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBHL1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV1-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH-1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV-1_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAFH-PH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAMH-PH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-1_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBV-1_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3mbv-1', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3MBV-1\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3MBV-B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3MBV-B'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHL_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHR_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBHL_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBHL-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBHR_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBHR-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBV-B_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3mbv-b', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3MBV-B\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3MBV-E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3MBV-E'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAHR2-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FAV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBH2-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHL_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAHR_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBH-E_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBHL_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBHL-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBHR_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBHR-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBV-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBV-E_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3mbv-e', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3MBV-E\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='2',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC3MBV-SW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC3MBV-SW'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC3FBV2-SW_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC3MBV-SW_Vertical'], 'footprint':'', 'keywords':'xlr connector spdt switch neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc3mbv-sw', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC3MBV-SW\n\nxlr connector spdt switch neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='N',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='NC',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='NO',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['G', '2', '3', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['N', 'NC', 'NO']}] }),
        Part(**{ 'name':'NC4FAH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC4FAH'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAH_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc4fah', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC4FAH\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC4FAH-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC4FAH-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAH-0_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc4fah-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC4FAH-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC4FAV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC4FAV'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAV_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc4fav', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC4FAV\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC4FAV-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC4FAV-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAV-0_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc4fav-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC4FAV-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC4FBH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC4FBH'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC4FBH_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc4fbh', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC4FBH\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC4FBV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC4FBV'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC4FBH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC4FBV_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc4fbv', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC4FBV\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC4MAH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC4MAH'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC4FBH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC4FBV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC4MAH_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc4mah', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC4MAH\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC4MAV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC4MAV'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC4FBH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC4FBV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC4MAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC4MAV_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc4mav', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC4MAV\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC4MBH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC4MBH'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC4FBH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC4FBV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC4MAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC4MAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC4MBH_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc4mbh', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC4MBH\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC4MBV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC4MBV'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC4FAV-0_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC4FBH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC4FBV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC4MAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC4MAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC4MBH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC4MBV_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc4mbv', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC4MBV\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC5FAH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC5FAH'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc5fah', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC5FAH\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC5FAH-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC5FAH-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH-0_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc5fah-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC5FAH-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC5FAH-DA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC5FAH-DA'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH-DA_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc5fah-da', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC5FAH-DA\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC5FAV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC5FAV'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAV_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc5fav', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC5FAV\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC5FAV-DA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC5FAV-DA'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAV-DA_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc5fav-da', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC5FAV-DA\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC5FAV-SW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC5FAV-SW'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAV-SW_Vertical'], 'footprint':'', 'keywords':'xlr connector spdt switch neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc5fav-sw', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC5FAV-SW\n\nxlr connector spdt switch neutrik', 'pins':[
            Pin(num='1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='N',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='NC',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='NO',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '5', '1', '2', '4', 'G']},{'label': 'uB', 'num': 2, 'pin_nums': ['NC', 'N', 'NO']}] }),
        Part(**{ 'name':'NC5FBH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC5FBH'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAV-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBH_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc5fbh', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC5FBH\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC5FBH-B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC5FBH-B'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAV-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBH-B_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc5fbh-b', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC5FBH-B\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC5FBV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC5FBV'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAV-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBH-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBV_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc5fbv', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC5FBV\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC5FBV-B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC5FBV-B'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAV-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBH-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBV-B_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc5fbv-b', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC5FBV-B\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC5FBV-SW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC5FBV-SW'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAV-SW_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBV-SW_Vertical'], 'footprint':'', 'keywords':'xlr connector spdt switch neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc5fbv-sw', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC5FBV-SW\n\nxlr connector spdt switch neutrik', 'pins':[
            Pin(num='1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='N',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='NC',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='NO',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['5', '3', 'G', '2', '1', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['N', 'NO', 'NC']}] }),
        Part(**{ 'name':'NC5MAH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC5MAH'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAV-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBH-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBV-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5MAH_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc5mah', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC5MAH\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC5MAV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC5MAV'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAV-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBH-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBV-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5MAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5MAV_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc5mav', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC5MAV\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC5MAV-SW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC5MAV-SW'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAV-SW_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBV-SW_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5MAV-SW_Vertical'], 'footprint':'', 'keywords':'xlr connector spdt switch neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc5mav-sw', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC5MAV-SW\n\nxlr connector spdt switch neutrik', 'pins':[
            Pin(num='1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='N',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='NC',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='NO',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '5', 'G', '1', '4', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['NC', 'NO', 'N']}] }),
        Part(**{ 'name':'NC5MBH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC5MBH'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAV-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBH-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBV-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5MAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5MAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5MBH_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc5mbh', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC5MBH\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC5MBH-B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC5MBH-B'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAV-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBH-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBV-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5MAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5MAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5MBH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5MBH-B_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc5mbh-b', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC5MBH-B\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC5MBV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC5MBV'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAV-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBH-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBV-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5MAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5MAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5MBH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5MBH-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5MBV_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc5mbv', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC5MBV\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC5MBV-B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC5MBV-B'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH-0_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAH-DA_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAV-DA_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBH-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBV-B_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5MAH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5MAV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5MBH_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5MBH-B_Horizontal', 'Connector_Audio:Jack_XLR_Neutrik_NC5MBV_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5MBV-B_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc5mbv-b', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC5MBV-B\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC5MBV-SW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC5MBV-SW'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR_Neutrik_NC5FAV-SW_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5FBV-SW_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5MAV-SW_Vertical', 'Connector_Audio:Jack_XLR_Neutrik_NC5MBV-SW_Vertical'], 'footprint':'', 'keywords':'xlr connector spdt switch neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nc5mbv-sw', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNC5MBV-SW\n\nxlr connector spdt switch neutrik', 'pins':[
            Pin(num='1',name='P1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='P5',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='N',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='NC',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='NO',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['4', '1', '2', '5', '3', 'G']},{'label': 'uB', 'num': 2, 'pin_nums': ['N', 'NC', 'NO']}] }),
        Part(**{ 'name':'NCJ10FI-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCJ10FI-H'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ10FI-H_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/ncj10fi-h', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNCJ10FI-H\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='GN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['GN', '3', '2', 'G', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['TN', 'SN', 'RN', 'S', 'R', 'T']}] }),
        Part(**{ 'name':'NCJ10FI-H-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCJ10FI-H-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ10FI-H_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ10FI-H-0_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/ncj10fi-h-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNCJ10FI-H-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='GN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['GN', '3', '1', '2', 'G']},{'label': 'uB', 'num': 2, 'pin_nums': ['TN', 'R', 'SN', 'RN', 'T', 'S']}] }),
        Part(**{ 'name':'NCJ10FI-V', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCJ10FI-V'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ10FI-H_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ10FI-H-0_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ10FI-V_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/ncj10fi-v', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNCJ10FI-V\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='GN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', 'G', 'GN', '2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['RN', 'T', 'S', 'TN', 'SN', 'R']}] }),
        Part(**{ 'name':'NCJ10FI-V-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCJ10FI-V-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ10FI-H_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ10FI-H-0_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ10FI-V_Vertical', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ10FI-V-0_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/ncj10fi-v-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNCJ10FI-V-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='GN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['GN', 'G', '1', '2', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['TN', 'SN', 'T', 'R', 'RN', 'S']}] }),
        Part(**{ 'name':'NCJ5FI-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCJ5FI-H'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ5FI-H_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/ncj5fi-h', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNCJ5FI-H\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['G', '2', '3', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['S', 'T']}] }),
        Part(**{ 'name':'NCJ5FI-H-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCJ5FI-H-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ5FI-H_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ5FI-H-0_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/ncj5fi-h-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNCJ5FI-H-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', 'G', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['S', 'T']}] }),
        Part(**{ 'name':'NCJ5FI-V', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCJ5FI-V'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ5FI-H_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ5FI-H-0_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ5FI-V_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/ncj5fi-v', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNCJ5FI-V\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', 'G', '1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['S', 'T']}] }),
        Part(**{ 'name':'NCJ5FI-V-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCJ5FI-V-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ5FI-H_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ5FI-H-0_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ5FI-V_Vertical', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ5FI-V-0_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/ncj5fi-v-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNCJ5FI-V-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['G', '2', '3', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['S', 'T']}] }),
        Part(**{ 'name':'NCJ6FA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCJ6FA-H'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-H_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/ncj6fa-h', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNCJ6FA-H\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '3', '2', 'G']},{'label': 'uB', 'num': 2, 'pin_nums': ['T', 'R', 'S']}] }),
        Part(**{ 'name':'NCJ6FA-H-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCJ6FA-H-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-H_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-H-0_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/ncj6fa-h-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNCJ6FA-H-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['G', '1', '2', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['S', 'R', 'T']}] }),
        Part(**{ 'name':'NCJ6FA-H-DA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCJ6FA-H-DA'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-H_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-H-0_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-H-DA_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/ncj6fa-h-da', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNCJ6FA-H-DA\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1', 'G', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['S', 'R', 'T']}] }),
        Part(**{ 'name':'NCJ6FA-V', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCJ6FA-V'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-H_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-H-0_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-H-DA_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-V_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/ncj6fa-v', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNCJ6FA-V\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', 'G', '1', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['R', 'T', 'S']}] }),
        Part(**{ 'name':'NCJ6FA-V-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCJ6FA-V-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-H_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-H-0_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-H-DA_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-V_Vertical', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-V-0_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/ncj6fa-v-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNCJ6FA-V-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['G', '1', '3', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['R', 'S', 'T']}] }),
        Part(**{ 'name':'NCJ6FA-V-DA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCJ6FA-V-DA'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-H_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-H-0_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-H-DA_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-V_Vertical', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-V-0_Vertical', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-V-DA_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/ncj6fa-v-da', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNCJ6FA-V-DA\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '1', '2', 'G']},{'label': 'uB', 'num': 2, 'pin_nums': ['S', 'T', 'R']}] }),
        Part(**{ 'name':'NCJ6FI-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCJ6FI-H'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-H_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-H-0_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-H-DA_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-V_Vertical', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-V-0_Vertical', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-V-DA_Vertical', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FI-H_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/ncj6fi-h', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNCJ6FI-H\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', 'G', '2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['S', 'R', 'T']}] }),
        Part(**{ 'name':'NCJ6FI-H-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCJ6FI-H-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-H_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-H-0_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-H-DA_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-V_Vertical', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-V-0_Vertical', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-V-DA_Vertical', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FI-H_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FI-H-0_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/ncj6fi-h-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNCJ6FI-H-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['G', '2', '3', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['R', 'S', 'T']}] }),
        Part(**{ 'name':'NCJ6FI-V', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCJ6FI-V'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-H_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-H-0_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-H-DA_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-V_Vertical', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-V-0_Vertical', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-V-DA_Vertical', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FI-H_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FI-H-0_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FI-V_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/ncj6fi-v', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNCJ6FI-V\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', 'G', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['S', 'R', 'T']}] }),
        Part(**{ 'name':'NCJ6FI-V-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCJ6FI-V-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-H_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-H-0_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-H-DA_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-V_Vertical', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-V-0_Vertical', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FA-V-DA_Vertical', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FI-H_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FI-H-0_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FI-V_Vertical', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ6FI-V-0_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/ncj6fi-v-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNCJ6FI-V-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['G', '1', '2', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['R', 'S', 'T']}] }),
        Part(**{ 'name':'NCJ9FI-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCJ9FI-H'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ9FI-H_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/ncj9fi-h', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNCJ9FI-H\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '1', '2', 'G']},{'label': 'uB', 'num': 2, 'pin_nums': ['R', 'S', 'T', 'SN', 'RN', 'TN']}] }),
        Part(**{ 'name':'NCJ9FI-H-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCJ9FI-H-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ9FI-H_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ9FI-H-0_Horizontal'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/ncj9fi-h-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNCJ9FI-H-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['G', '2', '1', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['SN', 'R', 'T', 'RN', 'TN', 'S']}] }),
        Part(**{ 'name':'NCJ9FI-V', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCJ9FI-V'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ9FI-H_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ9FI-H-0_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ9FI-V_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/ncj9fi-v', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNCJ9FI-V\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '1', '2', 'G']},{'label': 'uB', 'num': 2, 'pin_nums': ['TN', 'RN', 'S', 'SN', 'R', 'T']}] }),
        Part(**{ 'name':'NCJ9FI-V-0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCJ9FI-V-0'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ9FI-H_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ9FI-H-0_Horizontal', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ9FI-V_Vertical', 'Connector_Audio:Jack_XLR-6.35mm_Neutrik_NCJ9FI-V-0_Vertical'], 'footprint':'', 'keywords':'xlr connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/ncj9fi-v-0', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNCJ9FI-V-0\n\nxlr connector neutrik', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '3', 'G']},{'label': 'uB', 'num': 2, 'pin_nums': ['RN', 'TN', 'S', 'T', 'SN', 'R']}] }),
        Part(**{ 'name':'NJ2FD-V', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NJ2FD-V'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ2FD-V_Vertical'], 'footprint':'', 'keywords':'audio jack receptacle mono phone headphone TS connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nj2fd-v', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNJ2FD-V\n\naudio jack receptacle mono phone headphone TS connector neutrik', 'pins':[
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NJ3FD-V', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NJ3FD-V'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ3FD-V_Vertical'], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones phones TRS connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nj3fd-v', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNJ3FD-V\n\naudio jack receptacle stereo headphones phones TRS connector neutrik', 'pins':[
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NJ5FD-V', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NJ5FD-V'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ5FD-V_Vertical'], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones phones TRS connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nj5fd-v', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNJ5FD-V\n\naudio jack receptacle stereo headphones phones TRS connector neutrik', 'pins':[
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NJ6FD-V', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NJ6FD-V'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ6FD-V_Vertical'], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nj6fd-v', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNJ6FD-V\n\naudio jack receptacle stereo headphones connector neutrik', 'pins':[
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NJ6TB-V', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NJ6TB-V'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ6FD-V_Vertical', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ6TB-V_Vertical'], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nj6tb-v', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNJ6TB-V\n\naudio jack receptacle stereo headphones connector neutrik', 'pins':[
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NL2MDXX-H-3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NL2MDXX-H-3'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_speakON_Neutrik_NL2MDXX-H-3_Horizontal'], 'footprint':'', 'keywords':'speakon connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nl2mdxx-h-3', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNL2MDXX-H-3\n\nspeakon connector neutrik', 'pins':[
            Pin(num='1-',name='1-',func=pin_types.PASSIVE),
            Pin(num='1+',name='1+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NL2MDXX-V', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NL2MDXX-V'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_speakON_Neutrik_NL2MDXX-H-3_Horizontal', 'Connector_Audio:Jack_speakON_Neutrik_NL2MDXX-V_Vertical'], 'footprint':'', 'keywords':'speakon connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nl2mdxx-v', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNL2MDXX-V\n\nspeakon connector neutrik', 'pins':[
            Pin(num='1-',name='1-',func=pin_types.PASSIVE),
            Pin(num='1+',name='1+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NL4MDXX-H-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NL4MDXX-H-2'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_speakON_Neutrik_NL4MDXX-H-2_Horizontal'], 'footprint':'', 'keywords':'speakon connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nl4mdxx-h-2', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNL4MDXX-H-2\n\nspeakon connector neutrik', 'pins':[
            Pin(num='1-',name='1-',func=pin_types.PASSIVE),
            Pin(num='2+',name='2+',func=pin_types.PASSIVE),
            Pin(num='2-',name='2-',func=pin_types.PASSIVE),
            Pin(num='1+',name='1+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NL4MDXX-H-3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NL4MDXX-H-3'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_speakON_Neutrik_NL4MDXX-H-2_Horizontal', 'Connector_Audio:Jack_speakON_Neutrik_NL4MDXX-H-3_Horizontal'], 'footprint':'', 'keywords':'speakon connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nl4mdxx-h-3', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNL4MDXX-H-3\n\nspeakon connector neutrik', 'pins':[
            Pin(num='1-',name='1-',func=pin_types.PASSIVE),
            Pin(num='2+',name='2+',func=pin_types.PASSIVE),
            Pin(num='2-',name='2-',func=pin_types.PASSIVE),
            Pin(num='1+',name='1+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NL4MDXX-V', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NL4MDXX-V'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_speakON_Neutrik_NL4MDXX-H-2_Horizontal', 'Connector_Audio:Jack_speakON_Neutrik_NL4MDXX-H-3_Horizontal', 'Connector_Audio:Jack_speakON_Neutrik_NL4MDXX-V_Vertical'], 'footprint':'', 'keywords':'speakon connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nl4mdxx-v', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNL4MDXX-V\n\nspeakon connector neutrik', 'pins':[
            Pin(num='1-',name='1-',func=pin_types.PASSIVE),
            Pin(num='2+',name='2+',func=pin_types.PASSIVE),
            Pin(num='2-',name='2-',func=pin_types.PASSIVE),
            Pin(num='1+',name='1+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NL4MDXX-V-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NL4MDXX-V-2'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_speakON_Neutrik_NL4MDXX-H-2_Horizontal', 'Connector_Audio:Jack_speakON_Neutrik_NL4MDXX-H-3_Horizontal', 'Connector_Audio:Jack_speakON_Neutrik_NL4MDXX-V_Vertical', 'Connector_Audio:Jack_speakON_Neutrik_NL4MDXX-V-2_Vertical'], 'footprint':'', 'keywords':'speakon connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nl4mdxx-v-2', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNL4MDXX-V-2\n\nspeakon connector neutrik', 'pins':[
            Pin(num='1-',name='1-',func=pin_types.PASSIVE),
            Pin(num='2+',name='2+',func=pin_types.PASSIVE),
            Pin(num='2-',name='2-',func=pin_types.PASSIVE),
            Pin(num='1+',name='1+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NL4MDXX-V-3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NL4MDXX-V-3'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_speakON_Neutrik_NL4MDXX-H-2_Horizontal', 'Connector_Audio:Jack_speakON_Neutrik_NL4MDXX-H-3_Horizontal', 'Connector_Audio:Jack_speakON_Neutrik_NL4MDXX-V_Vertical', 'Connector_Audio:Jack_speakON_Neutrik_NL4MDXX-V-2_Vertical', 'Connector_Audio:Jack_speakON_Neutrik_NL4MDXX-V-3_Vertical'], 'footprint':'', 'keywords':'speakon connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nl4mdxx-v-3', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNL4MDXX-V-3\n\nspeakon connector neutrik', 'pins':[
            Pin(num='1-',name='1-',func=pin_types.PASSIVE),
            Pin(num='2+',name='2+',func=pin_types.PASSIVE),
            Pin(num='2-',name='2-',func=pin_types.PASSIVE),
            Pin(num='1+',name='1+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NL8MDXX-V', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NL8MDXX-V'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_speakON_Neutrik_NL8MDXX-V_Vertical'], 'footprint':'', 'keywords':'speakon connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nl8mdxx-v', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNL8MDXX-V\n\nspeakon connector neutrik', 'pins':[
            Pin(num='1-',name='1-',func=pin_types.PASSIVE),
            Pin(num='2+',name='2+',func=pin_types.PASSIVE),
            Pin(num='2-',name='2-',func=pin_types.PASSIVE),
            Pin(num='3+',name='3+',func=pin_types.PASSIVE),
            Pin(num='3-',name='3-',func=pin_types.PASSIVE),
            Pin(num='4+',name='4+',func=pin_types.PASSIVE),
            Pin(num='4-',name='4-',func=pin_types.PASSIVE),
            Pin(num='1+',name='1+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NL8MDXX-V-3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NL8MDXX-V-3'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_speakON_Neutrik_NL8MDXX-V_Vertical', 'Connector_Audio:Jack_speakON_Neutrik_NL8MDXX-V-3_Vertical'], 'footprint':'', 'keywords':'speakon connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nl8mdxx-v-3', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNL8MDXX-V-3\n\nspeakon connector neutrik', 'pins':[
            Pin(num='1-',name='1-',func=pin_types.PASSIVE),
            Pin(num='2+',name='2+',func=pin_types.PASSIVE),
            Pin(num='2-',name='2-',func=pin_types.PASSIVE),
            Pin(num='3+',name='3+',func=pin_types.PASSIVE),
            Pin(num='3-',name='3-',func=pin_types.PASSIVE),
            Pin(num='4+',name='4+',func=pin_types.PASSIVE),
            Pin(num='4-',name='4-',func=pin_types.PASSIVE),
            Pin(num='1+',name='1+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NLJ2MDXX-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NLJ2MDXX-H'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_speakON-6.35mm_Neutrik_NLJ2MDXX-H_Horizontal'], 'footprint':'', 'keywords':'speakon connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nlj2mdxx-h', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNLJ2MDXX-H\n\nspeakon connector neutrik', 'pins':[
            Pin(num='1-',name='1-',func=pin_types.PASSIVE),
            Pin(num='1+',name='1+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NLJ2MDXX-V', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NLJ2MDXX-V'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_speakON-6.35mm_Neutrik_NLJ2MDXX-H_Horizontal', 'Connector_Audio:Jack_speakON-6.35mm_Neutrik_NLJ2MDXX-V_Vertical'], 'footprint':'', 'keywords':'speakon connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nlj2mdxx-v', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNLJ2MDXX-V\n\nspeakon connector neutrik', 'pins':[
            Pin(num='1-',name='1-',func=pin_types.PASSIVE),
            Pin(num='1+',name='1+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NLT4MD-V', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NLT4MD-V'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_speakON_Neutrik_NL4MDXX-H-2_Horizontal', 'Connector_Audio:Jack_speakON_Neutrik_NL4MDXX-H-3_Horizontal', 'Connector_Audio:Jack_speakON_Neutrik_NL4MDXX-V_Vertical', 'Connector_Audio:Jack_speakON_Neutrik_NL4MDXX-V-2_Vertical', 'Connector_Audio:Jack_speakON_Neutrik_NL4MDXX-V-3_Vertical', 'Connector_Audio:Jack_speakON_Neutrik_NLT4MD-V_Vertical'], 'footprint':'', 'keywords':'speakon connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nlt4md-v', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNLT4MD-V\n\nspeakon connector neutrik', 'pins':[
            Pin(num='1-',name='1-',func=pin_types.PASSIVE),
            Pin(num='2+',name='2+',func=pin_types.PASSIVE),
            Pin(num='2-',name='2-',func=pin_types.PASSIVE),
            Pin(num='1+',name='1+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NMJ4HCD2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NMJ4HCD2'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ4HCD2_Horizontal'], 'footprint':'', 'keywords':'audio jack receptacle mono headphones phone TS connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nmj4hcd2', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNMJ4HCD2\n\naudio jack receptacle mono headphones phone TS connector neutrik', 'pins':[
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NMJ4HFD2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NMJ4HFD2'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ4HCD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ4HFD2_Horizontal'], 'footprint':'', 'keywords':'audio jack receptacle mono headphones phone TS connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nmj4hfd2', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNMJ4HFD2\n\naudio jack receptacle mono headphones phone TS connector neutrik', 'pins':[
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NMJ4HFD3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NMJ4HFD3'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ4HCD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ4HFD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ4HFD3_Horizontal'], 'footprint':'', 'keywords':'audio jack receptacle mono headphones phone TS connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nmj4hfd3', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNMJ4HFD3\n\naudio jack receptacle mono headphones phone TS connector neutrik', 'pins':[
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NMJ4HHD2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NMJ4HHD2'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ4HCD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ4HFD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ4HFD3_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ4HHD2_Horizontal'], 'footprint':'', 'keywords':'audio jack receptacle mono headphones phone TS connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nmj4hhd2', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNMJ4HHD2\n\naudio jack receptacle mono headphones phone TS connector neutrik', 'pins':[
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NMJ6HCD2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NMJ6HCD2'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ6FD-V_Vertical', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ6TB-V_Vertical', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HCD2_Horizontal'], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nmj6hcd2', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNMJ6HCD2\n\naudio jack receptacle stereo headphones connector neutrik', 'pins':[
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NMJ6HCD3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NMJ6HCD3'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ6FD-V_Vertical', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ6TB-V_Vertical', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HCD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HCD3_Horizontal'], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nmj6hcd3', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNMJ6HCD3\n\naudio jack receptacle stereo headphones connector neutrik', 'pins':[
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NMJ6HFD2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NMJ6HFD2'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ6FD-V_Vertical', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ6TB-V_Vertical', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HCD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HCD3_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD2_Horizontal'], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nmj6hfd2', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNMJ6HFD2\n\naudio jack receptacle stereo headphones connector neutrik', 'pins':[
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NMJ6HFD2-AU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NMJ6HFD2-AU'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ6FD-V_Vertical', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ6TB-V_Vertical', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HCD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HCD3_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD2-AU_Horizontal'], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nmj6hfd2-au', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNMJ6HFD2-AU\n\naudio jack receptacle stereo headphones connector neutrik', 'pins':[
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NMJ6HFD3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NMJ6HFD3'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ6FD-V_Vertical', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ6TB-V_Vertical', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HCD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HCD3_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD2-AU_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD3_Horizontal'], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nmj6hfd3', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNMJ6HFD3\n\naudio jack receptacle stereo headphones connector neutrik', 'pins':[
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NMJ6HFD4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NMJ6HFD4'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ6FD-V_Vertical', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ6TB-V_Vertical', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HCD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HCD3_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD2-AU_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD3_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD4_Horizontal'], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nmj6hfd4', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNMJ6HFD4\n\naudio jack receptacle stereo headphones connector neutrik', 'pins':[
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NMJ6HHD2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NMJ6HHD2'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ6FD-V_Vertical', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ6TB-V_Vertical', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HCD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HCD3_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD2-AU_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD3_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD4_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HHD2_Horizontal'], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nmj6hhd2', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNMJ6HHD2\n\naudio jack receptacle stereo headphones connector neutrik', 'pins':[
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NRJ3HF-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NRJ3HF-1'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ3HF-1_Horizontal'], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones phones TRS connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nrj3hf-1', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNRJ3HF-1\n\naudio jack receptacle stereo headphones phones TRS connector neutrik', 'pins':[
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NRJ4HF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NRJ4HF'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ4HCD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ4HFD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ4HFD3_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ4HHD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ4HF_Horizontal'], 'footprint':'', 'keywords':'audio jack dual receptacle mono headphones phone TS connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nrj4hf', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNRJ4HF\n\naudio jack dual receptacle mono headphones phone TS connector neutrik', 'pins':[
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NRJ4HF-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NRJ4HF-1'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ4HF-1_Horizontal'], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones phones TRS connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nrj4hf-1', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNRJ4HF-1\n\naudio jack receptacle stereo headphones phones TRS connector neutrik', 'pins':[
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NRJ4HH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NRJ4HH'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ4HCD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ4HFD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ4HFD3_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ4HHD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ4HF_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ4HH_Horizontal'], 'footprint':'', 'keywords':'audio jack receptacle mono headphones phone TS connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nrj4hh', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNRJ4HH\n\naudio jack receptacle mono headphones phone TS connector neutrik', 'pins':[
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NRJ4HH-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NRJ4HH-1'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ4HF-1_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ4HH-1_Horizontal'], 'footprint':'', 'keywords':'audio jack receptacle mono headphones phone TS connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nrj4hh-1', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNRJ4HH-1\n\naudio jack receptacle mono headphones phone TS connector neutrik', 'pins':[
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NRJ6HF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NRJ6HF'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ6FD-V_Vertical', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ6TB-V_Vertical', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HCD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HCD3_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD2-AU_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD3_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD4_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HHD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ6HF_Horizontal'], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nrj6hf', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNRJ6HF\n\naudio jack receptacle stereo headphones connector neutrik', 'pins':[
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NRJ6HF-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NRJ6HF-1'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ6HF-1_Horizontal'], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones phones TRS connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nrj6hf-1', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNRJ6HF-1\n\naudio jack receptacle stereo headphones phones TRS connector neutrik', 'pins':[
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NRJ6HF-1-AU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NRJ6HF-1-AU'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ6HF-1_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ6HF-1-AU_Horizontal'], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones phones TRS connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nrj6hf-1-au', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNRJ6HF-1-AU\n\naudio jack receptacle stereo headphones phones TRS connector neutrik', 'pins':[
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NRJ6HF-AU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NRJ6HF-AU'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ6FD-V_Vertical', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ6TB-V_Vertical', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HCD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HCD3_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD2-AU_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD3_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD4_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HHD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ6HF_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ6HF-AU_Horizontal'], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nrj6hf-au', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNRJ6HF-AU\n\naudio jack receptacle stereo headphones connector neutrik', 'pins':[
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NRJ6HH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NRJ6HH'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ6FD-V_Vertical', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ6TB-V_Vertical', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HCD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HCD3_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD2-AU_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD3_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD4_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HHD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ6HF_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ6HF-AU_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ6HH_Horizontal'], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nrj6hh', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNRJ6HH\n\naudio jack receptacle stereo headphones connector neutrik', 'pins':[
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NRJ6HH-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NRJ6HH-1'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ6HF-1_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ6HF-1-AU_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ6HH-1_Horizontal'], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones phones TRS connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nrj6hh-1', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNRJ6HH-1\n\naudio jack receptacle stereo headphones phones TRS connector neutrik', 'pins':[
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NRJ6HH-AU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NRJ6HH-AU'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ6FD-V_Vertical', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ6TB-V_Vertical', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HCD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HCD3_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD2-AU_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD3_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD4_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HHD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ6HF_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ6HF-AU_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ6HH_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ6HH-AU_Horizontal'], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nrj6hh-au', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNRJ6HH-AU\n\naudio jack receptacle stereo headphones connector neutrik', 'pins':[
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NRJ6HM-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NRJ6HM-1'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ6FD-V_Vertical', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ6TB-V_Vertical', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HCD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HCD3_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD2-AU_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD3_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD4_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HHD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ6HF_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ6HF-AU_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ6HH_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ6HH-AU_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ6HM-1_Horizontal'], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nrj6hm-1', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNRJ6HM-1\n\naudio jack receptacle stereo headphones connector neutrik', 'pins':[
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NRJ6HM-1-AU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NRJ6HM-1-AU'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ6FD-V_Vertical', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ6TB-V_Vertical', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HCD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HCD3_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD2-AU_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD3_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HFD4_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NMJ6HHD2_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ6HF_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ6HF-AU_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ6HH_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ6HH-AU_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ6HM-1_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ6HM-1-AU_Horizontal'], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nrj6hm-1-au', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNRJ6HM-1-AU\n\naudio jack receptacle stereo headphones connector neutrik', 'pins':[
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NRJ6HM-1-PRE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NRJ6HM-1-PRE'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NJ5FD-V_Vertical', 'Connector_Audio:Jack_6.35mm_Neutrik_NRJ6HM-1-PRE_Horizontal'], 'footprint':'', 'keywords':'audio jack receptacle stereo headphones phones TRS connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nrj6hm-1-pre', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNRJ6HM-1-PRE\n\naudio jack receptacle stereo headphones phones TRS connector neutrik', 'pins':[
            Pin(num='R',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NSJ12HC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NSJ12HC'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NSJ12HC_Horizontal'], 'footprint':'', 'keywords':'audio jack dual receptacle stereo headphones phones TRS connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nsj12hc', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNSJ12HC\n\naudio jack dual receptacle stereo headphones phones TRS connector neutrik', 'pins':[
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='RN2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='S2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='SN2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='TN2',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['T1', 'R1', 'RN1', 'SN1', 'G', 'TN1', 'S1']},{'label': 'uB', 'num': 2, 'pin_nums': ['R2', 'S2', 'T2', 'TN2', 'SN2', 'RN2']}] }),
        Part(**{ 'name':'NSJ12HF-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NSJ12HF-1'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NSJ12HC_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NSJ12HF-1_Horizontal'], 'footprint':'', 'keywords':'audio jack dual receptacle stereo headphones phones TRS connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nsj12hf-1', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNSJ12HF-1\n\naudio jack dual receptacle stereo headphones phones TRS connector neutrik', 'pins':[
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='RN2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='S2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='SN2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='TN2',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['G', 'T1', 'TN1', 'RN1', 'S1', 'SN1', 'R1']},{'label': 'uB', 'num': 2, 'pin_nums': ['S2', 'TN2', 'T2', 'R2', 'SN2', 'RN2']}] }),
        Part(**{ 'name':'NSJ12HH-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NSJ12HH-1'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NSJ12HC_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NSJ12HF-1_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NSJ12HH-1_Horizontal'], 'footprint':'', 'keywords':'audio jack dual receptacle stereo headphones phones TRS connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nsj12hh-1', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNSJ12HH-1\n\naudio jack dual receptacle stereo headphones phones TRS connector neutrik', 'pins':[
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='RN2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='S2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='SN2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='TN2',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['RN1', 'SN1', 'T1', 'S1', 'TN1', 'R1', 'G']},{'label': 'uB', 'num': 2, 'pin_nums': ['R2', 'SN2', 'TN2', 'RN2', 'T2', 'S2']}] }),
        Part(**{ 'name':'NSJ12HL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NSJ12HL'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NSJ12HC_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NSJ12HF-1_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NSJ12HH-1_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NSJ12HL_Horizontal'], 'footprint':'', 'keywords':'audio jack dual receptacle stereo headphones phones TRS connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nsj12hl', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNSJ12HL\n\naudio jack dual receptacle stereo headphones phones TRS connector neutrik', 'pins':[
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='RN1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='R2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='RN2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='S2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='SN2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='TN2',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['SN1', 'RN1', 'S1', 'T1', 'TN1', 'G', 'R1']},{'label': 'uB', 'num': 2, 'pin_nums': ['TN2', 'RN2', 'R2', 'SN2', 'S2', 'T2']}] }),
        Part(**{ 'name':'NSJ8HC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NSJ8HC'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NSJ8HC_Horizontal'], 'footprint':'', 'keywords':'audio jack dual receptacle mono headphones phone TS connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nsj8hc', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNSJ8HC\n\naudio jack dual receptacle mono headphones phone TS connector neutrik', 'pins':[
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='SN2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='TN2',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['T1', 'S1', 'G', 'TN1', 'SN1']},{'label': 'uB', 'num': 2, 'pin_nums': ['TN2', 'SN2', 'S2', 'T2']}] }),
        Part(**{ 'name':'NSJ8HL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NSJ8HL'}), 'ref_prefix':'J', 'fplist':['', 'Connector_Audio:Jack_6.35mm_Neutrik_NSJ8HC_Horizontal', 'Connector_Audio:Jack_6.35mm_Neutrik_NSJ8HL_Horizontal'], 'footprint':'', 'keywords':'audio jack dual receptacle mono headphones phone TS connector neutrik', 'description':'', 'datasheet':'https://www.neutrik.com/en/product/nsj8hl', 'search_text':'/usr/share/kicad/symbols/Connector_Audio.kicad_sym\nNSJ8HL\n\naudio jack dual receptacle mono headphones phone TS connector neutrik', 'pins':[
            Pin(num='G',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='SN1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='T1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='TN1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='S2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='SN2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='T2',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='TN2',name='~',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['SN1', 'T1', 'S1', 'G', 'TN1']},{'label': 'uB', 'num': 2, 'pin_nums': ['S2', 'SN2', 'TN2', 'T2']}] })])