from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_ST_STM32F1 = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'STM32F100C_4-6_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100C_4-6_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100c4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100C_4-6_Tx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100C_8-B_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100C_8-B_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100C_8-B_Tx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100R_4-6_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100R_4-6_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100r4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100R_4-6_Hx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='B5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100R_4-6_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100R_4-6_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100r4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100R_4-6_Tx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100R_8-B_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100R_8-B_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100r8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100R_8-B_Hx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='B5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100R_8-B_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100R_8-B_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100r8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100R_8-B_Tx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100R_C-D-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100R_C-D-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100R_C-D-E_Tx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100V_8-B_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100V_8-B_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100v8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100V_8-B_Tx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100V_C-D-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100V_C-D-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100V_C-D-E_Tx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100Z_C-D-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100Z_C-D-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100zc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100Z_C-D-E_Tx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101C_4-6_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101C_4-6_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101c4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101C_4-6_Tx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101C_8-B_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101C_8-B_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101C_8-B_Tx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101C_8-B_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101C_8-B_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101C_8-B_Ux\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101RBHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101RBHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101RBHx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='B5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101R_4-6_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101R_4-6_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101r4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101R_4-6_Tx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101R_8-B_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101R_8-B_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101r8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101R_8-B_Tx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101R_C-D-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101R_C-D-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101R_C-D-E_Tx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101R_F-G_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101R_F-G_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101rf.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101R_F-G_Tx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101T_4-6_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101T_4-6_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm'], 'footprint':'Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101t4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101T_4-6_Ux\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101T_8-B_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101T_8-B_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm'], 'footprint':'Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101t8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101T_8-B_Ux\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101V_8-B_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101V_8-B_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101v8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101V_8-B_Tx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101V_C-D-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101V_C-D-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101V_C-D-E_Tx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101V_F-G_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101V_F-G_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101vf.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101V_F-G_Tx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101Z_C-D-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101Z_C-D-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101zc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101Z_C-D-E_Tx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101Z_F-G_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101Z_F-G_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101zf.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101Z_F-G_Tx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F102C_4-6_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F102C_4-6_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F102', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f102c4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F102C_4-6_Tx\n\nArm Cortex-M3 STM32F1 STM32F102', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F102C_8-B_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F102C_8-B_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F102', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f102c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F102C_8-B_Tx\n\nArm Cortex-M3 STM32F1 STM32F102', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F102R_4-6_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F102R_4-6_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F102', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f102r4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F102R_4-6_Tx\n\nArm Cortex-M3 STM32F1 STM32F102', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F102R_8-B_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F102R_8-B_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F102', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f102r8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F102R_8-B_Tx\n\nArm Cortex-M3 STM32F1 STM32F102', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103C6Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103C6Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103C6Ux\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103CBUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103CBUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103CBUx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103C_4-6_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103C_4-6_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103c4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103C_4-6_Tx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103C_8-B_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103C_8-B_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103C_8-B_Tx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103R_4-6_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103R_4-6_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103r4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103R_4-6_Hx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='B5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103R_4-6_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103R_4-6_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103r4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103R_4-6_Tx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103R_8-B_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103R_8-B_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103r8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103R_8-B_Hx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='B5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103R_8-B_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103R_8-B_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103r8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103R_8-B_Tx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103R_C-D-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103R_C-D-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103R_C-D-E_Tx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103R_C-D-E_Yx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103R_C-D-E_Yx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-64_Die414'], 'footprint':'Package_CSP:ST_WLCSP-64_Die414', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103R_C-D-E_Yx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='C8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103R_F-G_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103R_F-G_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103rf.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103R_F-G_Tx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103T_4-6_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103T_4-6_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm'], 'footprint':'Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103t4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103T_4-6_Ux\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103T_8-B_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103T_8-B_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm'], 'footprint':'Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103t8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103T_8-B_Ux\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103VBIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103VBIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103VBIx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='A1',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C12',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F1',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='F11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='G11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103V_8-B_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103V_8-B_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103v8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103V_8-B_Hx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='H10',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103V_8-B_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103V_8-B_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103v8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103V_8-B_Tx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103V_C-D-E_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103V_C-D-E_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103V_C-D-E_Hx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='H10',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103V_C-D-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103V_C-D-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103V_C-D-E_Tx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103V_F-G_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103V_F-G_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103vf.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103V_F-G_Tx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103Z_C-D-E_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103Z_C-D-E_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-144_10x10mm_Layout12x12_P0.8mm'], 'footprint':'Package_BGA:LFBGA-144_10x10mm_Layout12x12_P0.8mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103zc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103Z_C-D-E_Hx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='A1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='D10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103Z_C-D-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103Z_C-D-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103zc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103Z_C-D-E_Tx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103Z_F-G_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103Z_F-G_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-144_10x10mm_Layout12x12_P0.8mm'], 'footprint':'Package_BGA:LFBGA-144_10x10mm_Layout12x12_P0.8mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103zf.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103Z_F-G_Hx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='A1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='D10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103Z_F-G_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103Z_F-G_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103zf.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103Z_F-G_Tx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F105R_8-B-C_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F105R_8-B-C_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F105/107', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f105r8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F105R_8-B-C_Tx\n\nArm Cortex-M3 STM32F1 STM32F105/107', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F105V_8-B-C_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F105V_8-B-C_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F105/107', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f105v8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F105V_8-B-C_Tx\n\nArm Cortex-M3 STM32F1 STM32F105/107', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F105V_8-B_Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F105V_8-B_Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F105/107', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f105v8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F105V_8-B_Hx\n\nArm Cortex-M3 STM32F1 STM32F105/107', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='H10',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F107R_B-C_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F107R_B-C_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F105/107', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f107rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F107R_B-C_Tx\n\nArm Cortex-M3 STM32F1 STM32F105/107', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F107VCHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F107VCHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F105/107', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f107vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F107VCHx\n\nArm Cortex-M3 STM32F1 STM32F105/107', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='H10',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F107V_B-C_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F107V_B-C_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F105/107', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f107vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F107V_B-C_Tx\n\nArm Cortex-M3 STM32F1 STM32F105/107', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100C4Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100C4Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100c4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100C4Tx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100C6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100C6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100C6Tx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100C8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100C8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100C8Tx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100CBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100CBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100CBTx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100R4Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100R4Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100r4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100R4Hx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='B5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100R4Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100R4Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100r4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100R4Tx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100R6Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100R6Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100r6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100R6Hx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='B5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100R6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100R6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100r6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100R6Tx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100R8Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100R8Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100r8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100R8Hx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='B5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100R8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100R8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100r8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100R8Tx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100RBHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100RBHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100RBHx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='B5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100RBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100RBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100RBTx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100RCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100RCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100RCTx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100RDTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100RDTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100rd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100RDTx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100RETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100RETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100RETx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100V8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100V8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100v8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100V8Tx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100VBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100VBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100VBTx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100VCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100VCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100VCTx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100VDTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100VDTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100vd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100VDTx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100VETx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100ZCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100ZCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100zc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100ZCTx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100ZDTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100ZDTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100zd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100ZDTx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F100ZETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F100ZETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F100 Value Line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f100ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F100ZETx\n\nArm Cortex-M3 STM32F1 STM32F100 Value Line', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101C4Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101C4Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101c4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101C4Tx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101C6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101C6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101C6Tx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101C8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101C8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101C8Tx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101C8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101C8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101C8Ux\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101CBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101CBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101CBTx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101CBUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101CBUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101CBUx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101R4Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101R4Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101r4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101R4Tx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101R6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101R6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101r6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101R6Tx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101R8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101R8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101r8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101R8Tx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101RBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101RBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101RBTx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101RCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101RCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101RCTx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101RDTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101RDTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101rd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101RDTx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101RETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101RETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101RETx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101RFTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101RFTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101rf.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101RFTx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101RGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101RGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101rg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101RGTx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101T4Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101T4Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm', 'Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm'], 'footprint':'Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101t4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101T4Ux\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101T6Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101T6Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm', 'Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm', 'Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm'], 'footprint':'Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101t6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101T6Ux\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101T8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101T8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm', 'Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm'], 'footprint':'Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101t8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101T8Ux\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101TBUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101TBUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm', 'Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm', 'Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm'], 'footprint':'Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101tb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101TBUx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101V8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101V8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101v8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101V8Tx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101VBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101VBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101VBTx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101VCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101VCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101VCTx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101VDTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101VDTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101vd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101VDTx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101VETx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101VFTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101VFTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101vf.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101VFTx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101VGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101VGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101VGTx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101ZCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101ZCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101zc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101ZCTx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101ZDTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101ZDTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101zd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101ZDTx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101ZETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101ZETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101ZETx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101ZFTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101ZFTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101zf.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101ZFTx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F101ZGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F101ZGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f101zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F101ZGTx\n\nArm Cortex-M3 STM32F1 STM32F101', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F102C4Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F102C4Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F102', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f102c4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F102C4Tx\n\nArm Cortex-M3 STM32F1 STM32F102', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F102C6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F102C6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F102', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f102c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F102C6Tx\n\nArm Cortex-M3 STM32F1 STM32F102', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F102C8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F102C8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F102', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f102c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F102C8Tx\n\nArm Cortex-M3 STM32F1 STM32F102', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F102CBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F102CBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F102', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f102cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F102CBTx\n\nArm Cortex-M3 STM32F1 STM32F102', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F102R4Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F102R4Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F102', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f102r4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F102R4Tx\n\nArm Cortex-M3 STM32F1 STM32F102', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F102R6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F102R6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F102', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f102r6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F102R6Tx\n\nArm Cortex-M3 STM32F1 STM32F102', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F102R8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F102R8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F102', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f102r8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F102R8Tx\n\nArm Cortex-M3 STM32F1 STM32F102', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F102RBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F102RBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F102', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f102rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F102RBTx\n\nArm Cortex-M3 STM32F1 STM32F102', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103C4Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103C4Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103c4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103C4Tx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103C6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103C6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103C6Tx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103C8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103C8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103C8Tx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103CBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103CBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103CBTx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103R4Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103R4Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103r4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103R4Hx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='B5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103R4Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103R4Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103r4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103R4Tx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103R6Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103R6Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103r6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103R6Hx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='B5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103R6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103R6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103r6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103R6Tx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103R8Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103R8Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103r8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103R8Hx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='B5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103R8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103R8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103r8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103R8Tx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103RBHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103RBHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:TFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103RBHx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='B5',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB12',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103RBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103RBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103RBTx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103RCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103RCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103RCTx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103RCYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103RCYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-64_Die414', 'Package_CSP:ST_WLCSP-64_Die414'], 'footprint':'Package_CSP:ST_WLCSP-64_Die414', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103RCYx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='C8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103RDTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103RDTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103rd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103RDTx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103RDYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103RDYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-64_Die414', 'Package_CSP:ST_WLCSP-64_Die414', 'Package_CSP:ST_WLCSP-64_Die414'], 'footprint':'Package_CSP:ST_WLCSP-64_Die414', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103rd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103RDYx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='C8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103RETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103RETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103RETx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103REYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103REYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-64_Die414', 'Package_CSP:ST_WLCSP-64_Die414', 'Package_CSP:ST_WLCSP-64_Die414', 'Package_CSP:ST_WLCSP-64_Die414'], 'footprint':'Package_CSP:ST_WLCSP-64_Die414', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103REYx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='A7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='C8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='E8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='F8',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H3',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103RFTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103RFTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103rf.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103RFTx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103RGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103RGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103rg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103RGTx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103T4Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103T4Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm', 'Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm'], 'footprint':'Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103t4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103T4Ux\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103T6Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103T6Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm', 'Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm', 'Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm'], 'footprint':'Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103t6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103T6Ux\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103T8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103T8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm', 'Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm'], 'footprint':'Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103t8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103T8Ux\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103TBUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103TBUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm', 'Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm', 'Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm'], 'footprint':'Package_DFN_QFN:QFN-36-1EP_6x6mm_P0.5mm_EP4.1x4.1mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103tb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103TBUx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103V8Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103V8Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm', 'Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103v8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103V8Hx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='H10',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103V8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103V8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103v8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103V8Tx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103VBHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103VBHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm', 'Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm', 'Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103VBHx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='H10',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103VBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103VBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103VBTx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103VCHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103VCHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm', 'Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103VCHx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='H10',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103VCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103VCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103VCTx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103VDHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103VDHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm', 'Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm', 'Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103vd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103VDHx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='H10',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103VDTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103VDTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103vd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103VDTx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103VEHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103VEHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm', 'Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm', 'Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm', 'Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103VEHx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='H10',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103VETx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103VFTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103VFTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103vf.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103VFTx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103VGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103VGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103vg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103VGTx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103ZCHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103ZCHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-144_10x10mm_Layout12x12_P0.8mm', 'Package_BGA:LFBGA-144_10x10mm_Layout12x12_P0.8mm'], 'footprint':'Package_BGA:LFBGA-144_10x10mm_Layout12x12_P0.8mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103zc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103ZCHx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='A1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='D10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103ZCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103ZCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103zc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103ZCTx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103ZDHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103ZDHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-144_10x10mm_Layout12x12_P0.8mm', 'Package_BGA:LFBGA-144_10x10mm_Layout12x12_P0.8mm', 'Package_BGA:LFBGA-144_10x10mm_Layout12x12_P0.8mm'], 'footprint':'Package_BGA:LFBGA-144_10x10mm_Layout12x12_P0.8mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103zd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103ZDHx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='A1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='D10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103ZDTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103ZDTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103zd.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103ZDTx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103ZEHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103ZEHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-144_10x10mm_Layout12x12_P0.8mm', 'Package_BGA:LFBGA-144_10x10mm_Layout12x12_P0.8mm', 'Package_BGA:LFBGA-144_10x10mm_Layout12x12_P0.8mm', 'Package_BGA:LFBGA-144_10x10mm_Layout12x12_P0.8mm'], 'footprint':'Package_BGA:LFBGA-144_10x10mm_Layout12x12_P0.8mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103ZEHx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='A1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='D10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103ZETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103ZETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103ze.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103ZETx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103ZFHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103ZFHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-144_10x10mm_Layout12x12_P0.8mm', 'Package_BGA:LFBGA-144_10x10mm_Layout12x12_P0.8mm'], 'footprint':'Package_BGA:LFBGA-144_10x10mm_Layout12x12_P0.8mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103zf.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103ZFHx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='A1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='D10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103ZFTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103ZFTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103zf.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103ZFTx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103ZGHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103ZGHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-144_10x10mm_Layout12x12_P0.8mm', 'Package_BGA:LFBGA-144_10x10mm_Layout12x12_P0.8mm', 'Package_BGA:LFBGA-144_10x10mm_Layout12x12_P0.8mm'], 'footprint':'Package_BGA:LFBGA-144_10x10mm_Layout12x12_P0.8mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103ZGHx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='A1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C12',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='D10',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='F10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='J10',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F103ZGTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F103ZGTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F103', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f103zg.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F103ZGTx\n\nArm Cortex-M3 STM32F1 STM32F103', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='101',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='102',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='103',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='104',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='105',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='106',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='107',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='108',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='109',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='110',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='111',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='112',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='113',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='114',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='115',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='116',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='117',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='118',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='119',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='120',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='121',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='122',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='123',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='124',name='PG9',func=pin_types.BIDIR,unit=1),
            Pin(num='125',name='PG10',func=pin_types.BIDIR,unit=1),
            Pin(num='126',name='PG11',func=pin_types.BIDIR,unit=1),
            Pin(num='127',name='PG12',func=pin_types.BIDIR,unit=1),
            Pin(num='128',name='PG13',func=pin_types.BIDIR,unit=1),
            Pin(num='129',name='PG14',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='130',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='131',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='132',name='PG15',func=pin_types.BIDIR,unit=1),
            Pin(num='133',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='134',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='135',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='136',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='137',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='138',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='139',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='140',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='141',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='142',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='143',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='144',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='53',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PF14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='84',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PG5',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PG6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PG7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PG8',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='95',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='96',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PC9',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F105R8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F105R8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F105/107', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f105r8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F105R8Tx\n\nArm Cortex-M3 STM32F1 STM32F105/107', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F105RBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F105RBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F105/107', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f105rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F105RBTx\n\nArm Cortex-M3 STM32F1 STM32F105/107', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F105RCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F105RCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F105/107', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f105rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F105RCTx\n\nArm Cortex-M3 STM32F1 STM32F105/107', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F105V8Hx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F105V8Hx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm', 'Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F105/107', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f105v8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F105V8Hx\n\nArm Cortex-M3 STM32F1 STM32F105/107', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='H10',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F105V8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F105V8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F105/107', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f105v8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F105V8Tx\n\nArm Cortex-M3 STM32F1 STM32F105/107', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F105VBHx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F105VBHx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm', 'Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm', 'Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm'], 'footprint':'Package_BGA:LFBGA-100_10x10mm_Layout10x10_P0.8mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F105/107', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f105vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F105VBHx\n\nArm Cortex-M3 STM32F1 STM32F105/107', 'pins':[
            Pin(num='A1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='C10',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='D10',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='E10',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F9',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='G10',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='H10',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='K10',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F105VBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F105VBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F105/107', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f105vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F105VBTx\n\nArm Cortex-M3 STM32F1 STM32F105/107', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F105VCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F105VCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F105/107', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f105vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F105VCTx\n\nArm Cortex-M3 STM32F1 STM32F105/107', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F107RBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F107RBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F105/107', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f107rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F107RBTx\n\nArm Cortex-M3 STM32F1 STM32F105/107', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F107RCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F107RCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F105/107', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f107rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F107RCTx\n\nArm Cortex-M3 STM32F1 STM32F105/107', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F107VBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F107VBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F105/107', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f107vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F107VBTx\n\nArm Cortex-M3 STM32F1 STM32F105/107', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32F107VCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32F107VCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M3 STM32F1 STM32F105/107', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32f107vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32F1.kicad_sym\nSTM32F107VCTx\n\nArm Cortex-M3 STM32F1 STM32F105/107', 'pins':[
            Pin(num='1',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OSC_IN',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OSC_OUT',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREF-',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='76',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='BOOT0',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] })])