from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_NXP_Kinetis = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'MK20DX128VFM5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MK20DX128VFM5'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL27 ARM Cortex M4', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/K20P32M50SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMK20DX128VFM5\n\nKinetis KL27 ARM Cortex M4', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN),
            Pin(num='10',name='EXTAL32',func=pin_types.INPUT),
            Pin(num='11',name='VBAT',func=pin_types.PWRIN),
            Pin(num='12',name='PTA0',func=pin_types.BIDIR),
            Pin(num='13',name='PTA1',func=pin_types.BIDIR),
            Pin(num='14',name='PTA2',func=pin_types.BIDIR),
            Pin(num='15',name='PTA3',func=pin_types.BIDIR),
            Pin(num='16',name='PTA4/LLWU_P3',func=pin_types.BIDIR),
            Pin(num='17',name='PTA18',func=pin_types.BIDIR),
            Pin(num='18',name='PTA19',func=pin_types.BIDIR),
            Pin(num='19',name='~{RESET}',func=pin_types.INPUT),
            Pin(num='2',name='VSS',func=pin_types.PWRIN),
            Pin(num='20',name='PTB0/LLWU_P5',func=pin_types.BIDIR),
            Pin(num='21',name='PTB1',func=pin_types.BIDIR),
            Pin(num='22',name='PTC1/LLWU_P6',func=pin_types.BIDIR),
            Pin(num='23',name='PTC2',func=pin_types.BIDIR),
            Pin(num='24',name='PTC3/LLWU_P7',func=pin_types.BIDIR),
            Pin(num='25',name='PTC4/LLWU_P8',func=pin_types.BIDIR),
            Pin(num='26',name='PTC5/LLWU_P9',func=pin_types.BIDIR),
            Pin(num='27',name='PTC6/LLWU_P10',func=pin_types.BIDIR),
            Pin(num='28',name='PTC7',func=pin_types.BIDIR),
            Pin(num='29',name='PTD4/LLWU_P14',func=pin_types.BIDIR),
            Pin(num='3',name='USB0_DP',func=pin_types.BIDIR),
            Pin(num='30',name='PTD5',func=pin_types.BIDIR),
            Pin(num='31',name='PTD6/LLWU_P15',func=pin_types.BIDIR),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR),
            Pin(num='5',name='VOUT33',func=pin_types.PWROUT),
            Pin(num='6',name='VREGIN',func=pin_types.PWRIN),
            Pin(num='7',name='VDDA',func=pin_types.PWRIN),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN),
            Pin(num='9',name='XTAL32',func=pin_types.INPUT),
            Pin(num='33',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='USB0_DM',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MK20FX512VMD12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MK20FX512VMD12'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-144_13.0x13.0mm_Layout12x12_P1.0mm'], 'footprint':'Package_BGA:BGA-144_13.0x13.0mm_Layout12x12_P1.0mm', 'keywords':'Kinetis K20 ARM Cortex M4', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/K20P144M120SF3.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMK20FX512VMD12\n\nKinetis K20 ARM Cortex M4', 'pins':[
            Pin(num='A1',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A11',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PTD0/LLWU_P12',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PTC16',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PTC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PTD12',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B11',name='PTC1/LLWU_P6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PTD11',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PTD10',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PTC19',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PTC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PTC11/LLWU_P11',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PTD9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PTD15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C11',name='PTB23',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PTB22',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PTD14',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PTD13',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PTD2/LLWU_P13',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PTC18',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PTC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PTD8',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PTE2/LLWU_P1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PTB20',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PTE1/LLWU_P0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PTC17',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PTC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PTB21',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PTE4/LLWU_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PTE10',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PTE9',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PTE8',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='G10',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='G3',name='PTE12',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PTE11',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PTA29',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PTA28',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H4',name='PTE28',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PGA2_DP/ADC2_DP0/ADC3_DP3/ADC0_DP1',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='PTA27',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PTA26',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PTA25',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PGA2_DM/ADC2_DM0/ADC3_DM3/ADC0_DM1',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='ADC0_SE16/CMP1_IN2/ADC0_SE21',func=pin_types.INPUT,unit=1),
            Pin(num='J4',name='PTE27',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PTA13/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PGA3_DP/ADC3_DP0/ADC2_DP3/ADC1_DP1',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PTA16',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PTA17',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PTA24',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PGA3_DM/ADC3_DM0/ADC2_DM3/ADC1_DM1',func=pin_types.INPUT,unit=1),
            Pin(num='K3',name='ADC1_SE16/CMP2_IN2/ADC0_SE22',func=pin_types.INPUT,unit=1),
            Pin(num='K4',name='PTE26',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PGA0_DP/ADC0_DP0/ADC1_DP3',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PTA14',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PTA15',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PGA0_DM/ADC0_DM0/ADC1_DM3',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='DAC0_OUT/CMP1_IN3/ADC0_SE23',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='DAC1_OUT/CMP0_IN4/CMP2_IN3/ADC1_SE23',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='~{RTC_WAKEUP}',func=pin_types.OUTPUT,unit=1),
            Pin(num='L6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PTA4/LLWU_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PTA11',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PGA1_DP/ADC1_DP0/ADC0_DP3',func=pin_types.INPUT,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PGA1_DM/ADC1_DM0/ADC0_DM3',func=pin_types.INPUT,unit=1),
            Pin(num='M3',name='VREF_OUT/CMP1_IN5/CMP0_IN5/ADC1_SE18',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='M6',name='EXTAL32',func=pin_types.INPUT,unit=1),
            Pin(num='M7',name='XTAL32',func=pin_types.OUTPUT,unit=1),
            Pin(num='M8',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PTA10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MK26FN2M0VMD18', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MK26FN2M0VMD18'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-144_13.0x13.0mm_Layout12x12_P1.0mm'], 'footprint':'Package_BGA:BGA-144_13.0x13.0mm_Layout12x12_P1.0mm', 'keywords':'Kinetis K26 ARM Cortex M4', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/K26P169M180SF5.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMK26FN2M0VMD18\n\nKinetis K26 ARM Cortex M4', 'pins':[
            Pin(num='A1',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A11',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PTD0/LLWU_P12',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PTC16',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PTC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PTD12',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B11',name='PTC1/LLWU_P6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PTD11/LLWU_P25',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PTD10',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PTC19',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PTC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PTC11/LLWU_P11',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PTD9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PTD15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C11',name='PTB23',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PTB22',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PTD14',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PTD13',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PTD2/LLWU_P13',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PTC18',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PTC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PTD8/LLWU_P24',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PTE2/LLWU_P1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PTB20',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PTE1/LLWU_P0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PTC17',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PTC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PTB21',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PTE6/LLWU_P16',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PTE4/LLWU_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PTE10/LLWU_P18',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PTE9/LLWU_P17',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PTE8',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='G10',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='G3',name='PTE12',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PTE11',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PTA29',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PTA28',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H4',name='PTE28',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PGA2_DP/ADC2_DP0/ADC3_DP3/ADC0_DP1',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='PTA27',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PTA26',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PTA25',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PGA2_DM/ADC2_DM0/ADC3_DM3/ADC0_DM1',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='ADC0_SE16/CMP1_IN2/ADC0_SE21',func=pin_types.INPUT,unit=1),
            Pin(num='J4',name='PTE27',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PTA13/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PGA3_DP/ADC3_DP0/ADC2_DP3/ADC1_DP1',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PTA16',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PTA17',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PTA24',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PGA3_DM/ADC3_DM0/ADC2_DM3/ADC1_DM1',func=pin_types.INPUT,unit=1),
            Pin(num='K3',name='ADC1_SE16/CMP2_IN2/ADC0_SE22',func=pin_types.INPUT,unit=1),
            Pin(num='K4',name='PTE26/CLKOUT32K',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PTE25/LLWU_P21',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PGA0_DP/ADC0_DP0/ADC1_DP3',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PTA14',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PTA15',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PGA0_DM/ADC0_DM0/ADC1_DM3',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='DAC0_OUT/CMP1_IN3/ADC0_SE23',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='DAC1_OUT/CMP0_IN4/CMP2_IN3/ADC1_SE23',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='~{RTC_WAKEUP}',func=pin_types.OUTPUT,unit=1),
            Pin(num='L6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PTA4/LLWU_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PTA11/LLWU_P23',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PGA1_DP/ADC1_DP0/ADC0_DP3',func=pin_types.INPUT,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PGA1_DM/ADC1_DM0/ADC0_DM3',func=pin_types.INPUT,unit=1),
            Pin(num='M3',name='VREF_OUT/CMP1_IN5/CMP0_IN5/ADC1_SE18',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='M6',name='EXTAL32',func=pin_types.INPUT,unit=1),
            Pin(num='M7',name='XTAL32',func=pin_types.OUTPUT,unit=1),
            Pin(num='M8',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PTA10/LLWU_P22',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKE02Z64VLC4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKE02Z64VLC4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'NXP Kinetis Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/files-static/microcontrollers/doc/ref_manual/MKE02P64M40SF0RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKE02Z64VLC4\n\nNXP Kinetis Microcontroller', 'pins':[
            Pin(num='1',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS/VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKE02Z64VLD4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKE02Z64VLD4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'keywords':'NXP Kinetis Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/files-static/microcontrollers/doc/ref_manual/MKE02P64M40SF0RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKE02Z64VLD4\n\nNXP Kinetis Microcontroller', 'pins':[
            Pin(num='1',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTH2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS/VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTB7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKE02Z64VLH4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKE02Z64VLH4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'NXP Kinetis Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/files-static/microcontrollers/doc/ref_manual/MKE02P64M40SF0RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKE02Z64VLH4\n\nNXP Kinetis Microcontroller', 'pins':[
            Pin(num='1',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS/VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PTH1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTH0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTH7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTH6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTH2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VREFL',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKE02Z64VQH4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKE02Z64VQH4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'NXP Kinetis Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/files-static/microcontrollers/doc/ref_manual/MKE02P64M40SF0RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKE02Z64VQH4\n\nNXP Kinetis Microcontroller', 'pins':[
            Pin(num='1',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS/VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PTH1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTH0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTH7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTH6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTH2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VREFL',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKE16Z64VLF4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKE16Z64VLF4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Kinetis KE16 ARM Cortex M0+', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/KE1xZP48M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKE16Z64VLF4\n\nKinetis KE16 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE8',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTE11',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTE10',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VREFH',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL02Z32CAF4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL02Z32CAF4'}), 'ref_prefix':'U', 'fplist':['Package_CSP:WLCSP-20_1.994x1.94mm_Layout4x5_P0.4mm'], 'footprint':'Package_CSP:WLCSP-20_1.994x1.94mm_Layout4x5_P0.4mm', 'keywords':'Kinetis KL02 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL02P20M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL02Z32CAF4\n\nKinetis KL02 ARM Cortex M0+', 'pins':[
            Pin(num='A1',name='PTA12/IRQ_13/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PTB13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PTA0/IRQ_0',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PTB3/IRQ_10',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PTB5/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VDD/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PTB4/IRQ_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VSS/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='C4',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PTB2/IRQ_7',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PTB1/IRQ_6',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PTA7/IRQ_4',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PTB0/IRQ_5',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PTA6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL02Z32VFG4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL02Z32VFG4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.9x1.9mm'], 'footprint':'Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.9x1.9mm', 'keywords':'Kinetis KL02 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL02P32M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL02Z32VFG4\n\nKinetis KL02 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='VDD/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PTB2/IRQ_7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB3/IRQ_10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB4/IRQ_11',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB5/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA0/IRQ_0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VSS/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA7/IRQ_4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB0/IRQ_5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB1/IRQ_6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL02Z32VFK4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL02Z32VFK4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'Kinetis KL02 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL02P32M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL02Z32VFK4\n\nKinetis KL02 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTB6/IRQ_2/LPTMR0_ALT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA7/IRQ_4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB0/IRQ_5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB1/IRQ_6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB2/IRQ_7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB3/IRQ_10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB4/IRQ_11',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB5/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB7/IRQ_3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA12/IRQ_13/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB13',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0/IRQ_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL02Z32VFM4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL02Z32VFM4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL02 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL02P32M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL02Z32VFM4\n\nKinetis KL02 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTB6/IRQ_2/LPTMR0_ALT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA7/IRQ_4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0/IRQ_5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB1/IRQ_6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2/IRQ_7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB7/IRQ_3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA10/IRQ_8',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA11/IRQ_9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB3/IRQ_10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB4/IRQ_11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB5/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA12/IRQ_13/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PTA0/IRQ_0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTA5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL03Z32CAF4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL03Z32CAF4'}), 'ref_prefix':'U', 'fplist':['Package_CSP:WLCSP-20_1.994x1.609mm_Layout5x4_P0.4mm'], 'footprint':'Package_CSP:WLCSP-20_1.994x1.609mm_Layout5x4_P0.4mm', 'keywords':'Kinetis KL03 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL03P24M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL03Z32CAF4\n\nKinetis KL03 ARM Cortex M0+', 'pins':[
            Pin(num='A1',name='PTB3/IRQ_10',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PTB5/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PTB13/CLKOUT32K',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PTB2/IRQ_7',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PTB4/IRQ_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PTA12/IRQ_13/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PTB0/IRQ_5/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PTB1/IRQ_6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PTA5/RTC_CLK_IN',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PTA7/IRQ_4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PTA6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL03Z32VFG4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL03Z32VFG4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.9x1.9mm'], 'footprint':'Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.9x1.9mm', 'keywords':'Kinetis KL03 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL03P24M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL03Z32VFG4\n\nKinetis KL03 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PTB2/IRQ_7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB3/IRQ_10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB4/IRQ_11',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB5/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTA5/RTC_CLK_IN',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA7/IRQ_4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB0/IRQ_5/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB1/IRQ_6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL03Z32VFK4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL03Z32VFK4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'Kinetis KL03 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL03P24M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL03Z32VFK4\n\nKinetis KL03 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTB6/IRQ_2/LPTMR0_ALT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA7/IRQ_4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB0/IRQ_5/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB1/IRQ_6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB2/IRQ_7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB3/IRQ_10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB4/IRQ_11',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB5/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB7/IRQ_3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA12/IRQ_13/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB13/CLKOUT32K',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA5/RTC_CLK_IN',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL04Z32VFK4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL04Z32VFK4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'Kinetis KL04 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL04P48M48SF1.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL04Z32VFK4\n\nKinetis KL04 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTB6/IRQ_2/LPTMR0_ALT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA7/IRQ_7/LLWU_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB0/IRQ_8/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB1/IRQ_9',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB2/IRQ_10/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB3/IRQ_14',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB4/IRQ_15/LLWU_P6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB5/IRQ_16',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB7/IRQ_3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA12/IRQ_17/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB13',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA4/LLWU_P0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA5/LLWU_P1/RTC_CLK_IN',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA6/LLWU_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL04Z32VFM4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL04Z32VFM4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL04 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL04P48M48SF1.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL04Z32VFM4\n\nKinetis KL04 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTB6/IRQ_2/LPTMR0_ALT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA6/LLWU_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA7/IRQ_7/LLWU_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0/IRQ_8/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB1/IRQ_9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2/IRQ_10/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB7/IRQ_3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA10/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA11/IRQ_13',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB3/IRQ_14',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB4/IRQ_15/LLWU_P6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB5/IRQ_16',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA12/IRQ_17/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA4/LLWU_P0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTA5/LLWU_P1/RTC_CLK_IN',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL04Z32VLC4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL04Z32VLC4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Kinetis KL04 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL04P48M48SF1.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL04Z32VLC4\n\nKinetis KL04 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTB6/IRQ_2/LPTMR0_ALT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA6/LLWU_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA7/IRQ_7/LLWU_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0/IRQ_8/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB1/IRQ_9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2/IRQ_10/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB7/IRQ_3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA10/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA11/IRQ_13',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB3/IRQ_14',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB4/IRQ_15/LLWU_P6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB5/IRQ_16',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA12/IRQ_17/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA4/LLWU_P0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTA5/LLWU_P1/RTC_CLK_IN',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL04Z32VLF4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL04Z32VLF4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Kinetis KL04 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL04P48M48SF1.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL04Z32VLF4\n\nKinetis KL04 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTB6/IRQ_2/LPTMR0_ALT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA4/LLWU_P0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA5/LLWU_P1/RTC_CLK_IN',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA6/LLWU_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA16/IRQ_4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA17/IRQ_5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB7/IRQ_3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA18/IRQ_6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA7/IRQ_7/LLWU_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB0/IRQ_8/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB1/IRQ_9',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB2/IRQ_10/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB20',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTA14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTB14/IRQ_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA10/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA11/IRQ_13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB3/IRQ_14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB4/IRQ_15/LLWU_P6',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB5/IRQ_16',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTA12/IRQ_17/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTA15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTB12',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB15',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTB13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL05Z32VFK4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL05Z32VFK4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'Kinetis KL05 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL05P48M48SF1.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL05Z32VFK4\n\nKinetis KL05 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTB6/IRQ_2/LPTMR0_ALT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA7/IRQ_7/LLWU_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB0/IRQ_8/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB1/IRQ_9',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB2/IRQ_10/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB3/IRQ_14',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB4/IRQ_15/LLWU_P6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB5/IRQ_16',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB7/IRQ_3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA12/IRQ_17/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB13',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA4/LLWU_P0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA5/LLWU_P1/RTC_CLK_IN',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA6/LLWU_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL05Z32VFM4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL05Z32VFM4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL05 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL05P48M48SF1.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL05Z32VFM4\n\nKinetis KL05 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTB6/IRQ_2/LPTMR0_ALT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA6/LLWU_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA7/IRQ_7/LLWU_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0/IRQ_8/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB1/IRQ_9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2/IRQ_10/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB7/IRQ_3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA10/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA11/IRQ_13',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB3/IRQ_14',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB4/IRQ_15/LLWU_P6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB5/IRQ_16',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA12/IRQ_17/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA4/LLWU_P0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTA5/LLWU_P1/RTC_CLK_IN',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL05Z32VLC4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL05Z32VLC4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Kinetis KL05 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL05P48M48SF1.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL05Z32VLC4\n\nKinetis KL05 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTB6/IRQ_2/LPTMR0_ALT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA6/LLWU_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA7/IRQ_7/LLWU_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0/IRQ_8/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB1/IRQ_9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2/IRQ_10/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB7/IRQ_3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA10/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA11/IRQ_13',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB3/IRQ_14',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB4/IRQ_15/LLWU_P6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB5/IRQ_16',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA12/IRQ_17/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA4/LLWU_P0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTA5/LLWU_P1/RTC_CLK_IN',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL05Z32VLF4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL05Z32VLF4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Kinetis KL05 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL05P48M48SF1.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL05Z32VLF4\n\nKinetis KL05 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTB6/IRQ_2/LPTMR0_ALT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA4/LLWU_P0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA5/LLWU_P1/RTC_CLK_IN',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA6/LLWU_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA16/IRQ_4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA17/IRQ_5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB7/IRQ_3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA18/IRQ_6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA7/IRQ_7/LLWU_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB0/IRQ_8/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB1/IRQ_9',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB2/IRQ_10/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB20',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTA14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTB14/IRQ_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA10/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA11/IRQ_13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB3/IRQ_14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB4/IRQ_15/LLWU_P6',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB5/IRQ_16',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTA12/IRQ_17/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTA15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTB12',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB15',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTB13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL16Z128VFM4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL16Z128VFM4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL16 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL16P64M48SF5.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL16Z128VFM4\n\nKinetis KL16 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE30',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL16Z128VFT4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL16Z128VFT4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'Kinetis KL16 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL16P64M48SF5.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL16Z128VFT4\n\nKinetis KL16 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL16Z128VLH4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL16Z128VLH4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Kinetis KL16 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL16P64M48SF5.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL16Z128VLH4\n\nKinetis KL16 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL16Z256VLH4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL16Z256VLH4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Kinetis KL16 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL16P64M48SF4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL16Z256VLH4\n\nKinetis KL16 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL16Z256VMP4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL16Z256VMP4'}), 'ref_prefix':'U', 'fplist':['Package_BGA:XFBGA-64_5.0x5.0mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:XFBGA-64_5.0x5.0mm_Layout8x8_P0.5mm', 'keywords':'Kinetis KL16 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL16P64M48SF4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL16Z256VMP4\n\nKinetis KL16 ARM Cortex M0+', 'pins':[
            Pin(num='A1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C6',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='G5',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PTA18',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL17Z256CAL4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL17Z256CAL4'}), 'ref_prefix':'U', 'fplist':['Package_CSP:WLCSP-36_2.82x2.67mm_Layout6x6_P0.4mm'], 'footprint':'Package_CSP:WLCSP-36_2.82x2.67mm_Layout6x6_P0.4mm', 'keywords':'Kinetis KL17 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL17P64M48SF6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL17Z256CAL4\n\nKinetis KL17 ARM Cortex M0+', 'pins':[
            Pin(num='A1',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PTA16',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='Reserved',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='Reserved',func=pin_types.PASSIVE,unit=1),
            Pin(num='D1',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PTA17',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PTA15',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='Reserved',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='Reserved',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PTA14',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F3',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL17Z256VFM4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL17Z256VFM4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL17 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL17P64M48SF6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL17Z256VFM4\n\nKinetis KL17 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE30',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL17Z256VFT4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL17Z256VFT4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'Kinetis KL17 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL17P64M48SF6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL17Z256VFT4\n\nKinetis KL17 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL17Z256VLH4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL17Z256VLH4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Kinetis KL17 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL17P64M48SF6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL17Z256VLH4\n\nKinetis KL17 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL17Z256VMP4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL17Z256VMP4'}), 'ref_prefix':'U', 'fplist':['Package_BGA:XFBGA-64_5.0x5.0mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:XFBGA-64_5.0x5.0mm_Layout8x8_P0.5mm', 'keywords':'Kinetis KL17 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL17P64M48SF6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL17Z256VMP4\n\nKinetis KL17 ARM Cortex M0+', 'pins':[
            Pin(num='A1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C6',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='G5',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PTA18',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL17Z64VDA4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL17Z64VDA4'}), 'ref_prefix':'U', 'fplist':['Package_BGA:XFBGA-36_3.5x3.5mm_Layout6x6_P0.5mm'], 'footprint':'Package_BGA:XFBGA-36_3.5x3.5mm_Layout6x6_P0.5mm', 'keywords':'Kinetis KL17 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL17P64M48SF2.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL17Z64VDA4\n\nKinetis KL17 ARM Cortex M0+', 'pins':[
            Pin(num='A1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PTE30/VREF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PTA18',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL17Z64VFM4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL17Z64VFM4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL17 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL17P64M48SF2.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL17Z64VFM4\n\nKinetis KL17 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE30/VREF0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL17Z64VFT4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL17Z64VFT4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'Kinetis KL17 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL17P64M48SF6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL17Z64VFT4\n\nKinetis KL17 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VREFH/VREFO',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL17Z64VLH4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL17Z64VLH4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Kinetis KL17 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL17P64M48SF2.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL17Z64VLH4\n\nKinetis KL17 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VREFH/VREFO',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL17Z64VMP4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL17Z64VMP4'}), 'ref_prefix':'U', 'fplist':['Package_BGA:XFBGA-64_5.0x5.0mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:XFBGA-64_5.0x5.0mm_Layout8x8_P0.5mm', 'keywords':'Kinetis KL17 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL17P64M48SF2.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL17Z64VMP4\n\nKinetis KL17 ARM Cortex M0+', 'pins':[
            Pin(num='A1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C6',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='VREFH/VREFO',func=pin_types.PWRIN,unit=1),
            Pin(num='G5',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PTA18',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL24Z64VFM4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL24Z64VFM4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL24 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL24P80M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL24Z64VFM4\n\nKinetis KL24 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE30',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL24Z64VFT4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL24Z64VFT4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'Kinetis KL24 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL24P80M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL24Z64VFT4\n\nKinetis KL24 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL24Z64VLH4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL24Z64VLH4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Kinetis KL24 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL24P80M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL24Z64VLH4\n\nKinetis KL24 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL24Z64VLK4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL24Z64VLK4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Kinetis KL24 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL24P80M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL24Z64VLK4\n\nKinetis KL24 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='12',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTA16',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA17',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PTC12',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='PTC13',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PTC16',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PTC17',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='USB0_DP',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL25Z128VFM4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL25Z128VFM4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL25 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL25P80M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL25Z128VFM4\n\nKinetis KL25 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE30',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL25Z128VFT4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL25Z128VFT4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'Kinetis KL25 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL25P80M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL25Z128VFT4\n\nKinetis KL25 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL25Z128VLH4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL25Z128VLH4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Kinetis KL25 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL25P80M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL25Z128VLH4\n\nKinetis KL25 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL25Z128VLK4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL25Z128VLK4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Kinetis KL25 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL25P80M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL25Z128VLK4\n\nKinetis KL25 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='12',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTA16',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA17',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PTC12',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='PTC13',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PTC16',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PTC17',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='USB0_DP',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL26Z128CAL4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL26Z128CAL4'}), 'ref_prefix':'U', 'fplist':['Package_CSP:WLCSP-36_2.374x2.459mm_Layout6x6_P0.35mm'], 'footprint':'Package_CSP:WLCSP-36_2.374x2.459mm_Layout6x6_P0.35mm', 'keywords':'Kinetis KL26 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL26P36M48SF5.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL26Z128CAL4\n\nKinetis KL26 ARM Cortex M0+', 'pins':[
            Pin(num='A1',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C4',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='D1',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL26Z128VFM4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL26Z128VFM4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL26 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL26P64M48SF5.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL26Z128VFM4\n\nKinetis KL26 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE30',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL26Z128VFT4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL26Z128VFT4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'Kinetis KL26 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL26P64M48SF5.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL26Z128VFT4\n\nKinetis KL26 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL26Z128VLH4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL26Z128VLH4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Kinetis KL26 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL26P64M48SF5.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL26Z128VLH4\n\nKinetis KL26 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL26Z256VLH4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL26Z256VLH4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Kinetis KL26 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL26P121M48SF4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL26Z256VLH4\n\nKinetis KL26 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL26Z256VLL4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL26Z256VLL4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Kinetis KL26 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL26P121M48SF4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL26Z256VLL4\n\nKinetis KL26 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='13',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTE26',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTA14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTA15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA16',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTA17',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PTB20',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PTB21',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PTB22',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PTB23',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PTC12',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PTC13',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='87',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='88',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='89',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='90',name='PTC16',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PTC17',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PTC18',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL26Z256VMC4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL26Z256VMC4'}), 'ref_prefix':'U', 'fplist':['Package_BGA:XFBGA-121_8x8mm_Layout11x11_P0.65mm'], 'footprint':'Package_BGA:XFBGA-121_8x8mm_Layout11x11_P0.65mm', 'keywords':'Kinetis KL26 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL26P121M48SF4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL26Z256VMC4\n\nKinetis KL26 ARM Cortex M0+', 'pins':[
            Pin(num='A1',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PTC20',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A2',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A6',name='PTC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PTC21',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B10',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PTC22',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PTC18',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B6',name='PTC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C10',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PTC23',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C3',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PTC17',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='D10',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='D3',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PTC16',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E10',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PTB23',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PTB20',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F2',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PTB22',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PTB21',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='G10',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='G3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PTA17',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='H2',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='H4',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PTE26',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PTA16',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='J4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='J5',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K1',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K5',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PTA14',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='L8',name='PTA13/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PTA15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL26Z256VMP4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL26Z256VMP4'}), 'ref_prefix':'U', 'fplist':['Package_BGA:XFBGA-64_5.0x5.0mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:XFBGA-64_5.0x5.0mm_Layout8x8_P0.5mm', 'keywords':'Kinetis KL26 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL26P121M48SF4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL26Z256VMP4\n\nKinetis KL26 ARM Cortex M0+', 'pins':[
            Pin(num='A1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C6',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='G5',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PTA18',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL27Z256VFT4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL27Z256VFT4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'Kinetis KL27 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL27P64M48SF6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL27Z256VFT4\n\nKinetis KL27 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL27Z256VLH4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL27Z256VLH4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Kinetis KL27 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL27P64M48SF6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL27Z256VLH4\n\nKinetis KL27 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL27Z64VFM4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL27Z64VFM4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL27 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL27P64M48SF2.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL27Z64VFM4\n\nKinetis KL27 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='USB_VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE30/VREF0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL27Z64VFT4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL27Z64VFT4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'Kinetis KL27 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL27P64M48SF2.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL27Z64VFT4\n\nKinetis KL27 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VREFH/VREFO',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='USB_VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL27Z64VLH4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL27Z64VLH4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Kinetis KL27 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL27P64M48SF2.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL27Z64VLH4\n\nKinetis KL27 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VREFH/VREFO',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='USB_VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL28Z512VDC7', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL28Z512VDC7'}), 'ref_prefix':'U', 'fplist':['Package_BGA:XFBGA-121_8x8mm_Layout11x11_P0.65mm'], 'footprint':'Package_BGA:XFBGA-121_8x8mm_Layout11x11_P0.65mm', 'keywords':'Kinetis KL28 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/MKL28Z512Vxx7.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL28Z512VDC7\n\nKinetis KL28 ARM Cortex M0+', 'pins':[
            Pin(num='A1',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PTD8/LLWU_P24',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PTC19',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PTC14',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PTC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PTD9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PTD10',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PTC22',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PTC18',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PTC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PTC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PTD12',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PTC23',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PTD11/LLWU_P25',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PTD2/LLWU_P13',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PTC17',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PTC11/LLWU_P11',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PTD14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PTD13',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PTD0/LLWU_P12',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PTC16',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PTD15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PTE2/LLWU_P1',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PTE1/LLWU_P0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PTB23',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PTB20',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PTE6/LLWU_P16',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='PTB22',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PTB21',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='G10',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='G3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VREFH/VREF_OUT',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PTA17',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PTA29',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PTE17/LLWU_P19',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='H4',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PTE26',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PTE4/LLWU_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PTE18/LLWU_P20',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PTA16',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='J4',name='PTA11/LLWU_P23',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PTE25/LLWU_P21',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PTA4/LLWU_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PTA10/LLWU_P22',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K5',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PTA14',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='L8',name='PTA13/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PTA15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL28Z512VLL7', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL28Z512VLL7'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Kinetis KL28 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/MKL28Z512Vxx7.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL28Z512VLL7\n\nKinetis KL28 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='13',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE17/LLWU_P19',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE18/LLWU_P20',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1/LLWU_P0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VREFH/VREF_OUT',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PTE2/LLWU_P1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTE25/LLWU_P21',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTE26',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTA4/LLWU_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTA13/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTA14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTA15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA16',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTA17',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PTE4/LLWU_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PTB20',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PTB21',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PTB22',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PTB23',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE6/LLWU_P16',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PTC1/LLWU_P6',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PTC11/LLWU_P11',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PTC12',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PTC13',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PTC14',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PTC15',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='89',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='90',name='PTC16',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PTC17',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PTC18',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PTD0/LLWU_P12',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PTD2/LLWU_P13',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL43Z256VLH4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL43Z256VLH4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Kinetis KL43 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL43P64M48SF6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL43Z256VLH4\n\nKinetis KL43 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VLL3',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VLL2/PTC20',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VLL1/PTC21',func=pin_types.PWROUT,unit=1),
            Pin(num='51',name='VCAP2/PTC22',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VCAP1/PTC23',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL43Z256VMP4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL43Z256VMP4'}), 'ref_prefix':'U', 'fplist':['Package_BGA:XFBGA-64_5.0x5.0mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:XFBGA-64_5.0x5.0mm_Layout8x8_P0.5mm', 'keywords':'Kinetis KL43 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL43P64M48SF6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL43Z256VMP4\n\nKinetis KL43 ARM Cortex M0+', 'pins':[
            Pin(num='A1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VCAP1/PTC23',func=pin_types.PASSIVE,unit=1),
            Pin(num='A6',name='VLL2/PTC20',func=pin_types.PWROUT,unit=1),
            Pin(num='A7',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VCAP2/PTC22',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='VLL1/PTC21',func=pin_types.PWROUT,unit=1),
            Pin(num='B6',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='VLL3',func=pin_types.PWROUT,unit=1),
            Pin(num='C6',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='G5',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PTA18',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL46Z256VLH4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL46Z256VLH4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Kinetis KL46 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL46P121M48SF4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL46Z256VLH4\n\nKinetis KL46 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VLL3',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VLL2/PTC20',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VLL1/PTC21',func=pin_types.PWROUT,unit=1),
            Pin(num='51',name='VCAP2/PTC22',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VCAP1/PTC23',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL46Z256VLL4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL46Z256VLL4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Kinetis KL46 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL46P121M48SF4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL46Z256VLL4\n\nKinetis KL46 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='13',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTE26',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTA14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTA15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA16',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTA17',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PTB21',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PTB22',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PTB23',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VLL3',func=pin_types.PWROUT,unit=1),
            Pin(num='76',name='VLL2/PTC20',func=pin_types.PWROUT,unit=1),
            Pin(num='77',name='VLL1/PTC21',func=pin_types.PWROUT,unit=1),
            Pin(num='78',name='VCAP2/PTC22',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='VCAP1/PTC23',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PTC12',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PTC13',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='90',name='PTC16',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PTC17',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PTC18',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL46Z256VMC4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL46Z256VMC4'}), 'ref_prefix':'U', 'fplist':['Package_BGA:XFBGA-121_8x8mm_Layout11x11_P0.65mm'], 'footprint':'Package_BGA:XFBGA-121_8x8mm_Layout11x11_P0.65mm', 'keywords':'Kinetis KL46 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL46P121M48SF4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL46Z256VMC4\n\nKinetis KL46 ARM Cortex M0+', 'pins':[
            Pin(num='A1',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VLL2/PTC20',func=pin_types.PWROUT,unit=1),
            Pin(num='A11',name='VLL3',func=pin_types.PWROUT,unit=1),
            Pin(num='A2',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A6',name='PTC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='VLL1/PTC21',func=pin_types.PWROUT,unit=1),
            Pin(num='B1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B10',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VCAP2/PTC22',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PTC18',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B6',name='PTC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C10',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VCAP1/PTC23',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C3',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PTC17',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='D10',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='D3',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PTC16',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E10',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PTB23',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F2',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PTB22',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PTB21',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='G10',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='G3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PTA17',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='H2',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='H4',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PTE26',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PTA16',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='J4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='J5',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K1',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K5',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PTA14',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='L8',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PTA15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL46Z256VMP4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL46Z256VMP4'}), 'ref_prefix':'U', 'fplist':['Package_BGA:XFBGA-64_5.0x5.0mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:XFBGA-64_5.0x5.0mm_Layout8x8_P0.5mm', 'keywords':'Kinetis KL46 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL46P121M48SF4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL46Z256VMP4\n\nKinetis KL46 ARM Cortex M0+', 'pins':[
            Pin(num='A1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VCAP1/PTC23',func=pin_types.PASSIVE,unit=1),
            Pin(num='A6',name='VLL2/PTC20',func=pin_types.PWROUT,unit=1),
            Pin(num='A7',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VCAP2/PTC22',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='VLL1/PTC21',func=pin_types.PWROUT,unit=1),
            Pin(num='B6',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='VLL3',func=pin_types.PWROUT,unit=1),
            Pin(num='C6',name='PTC1/LLWU_P6',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='G5',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PTA18',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKV11Z128VLF7', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKV11Z128VLF7'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Kinetis KV11 ARM Cortex M0+', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/KV11P64M75.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKV11Z128VLF7\n\nKinetis KV11 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKV11Z128VLH7', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKV11Z128VLH7'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Kinetis KV11 ARM Cortex M0+', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/KV11P64M75.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKV11Z128VLH7\n\nKinetis KV11 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTR17',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKW41Z512VHT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKW41Z512VHT'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:NXP_LQFN-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm_16xMask0.45x0.45_ThermalVias'], 'footprint':'Package_DFN_QFN:NXP_LQFN-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm_16xMask0.45x0.45_ThermalVias', 'keywords':'Kinetis KW41Z ARM Cortex M0+', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MKW41Z512.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKW41Z512VHT\n\nKinetis KW41Z ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTA0',func=pin_types.BIDIR),
            Pin(num='10',name='VDCDC_IN',func=pin_types.PWRIN),
            Pin(num='11',name='DCDC_LP',func=pin_types.PASSIVE),
            Pin(num='12',name='DCDC_LN',func=pin_types.PASSIVE),
            Pin(num='13',name='DCDC_GND',func=pin_types.PWRIN),
            Pin(num='14',name='VDD_1P8OUT',func=pin_types.PWROUT),
            Pin(num='15',name='VDD_1P5OUT_PMCIN',func=pin_types.PWROUT),
            Pin(num='16',name='PTB0',func=pin_types.BIDIR),
            Pin(num='17',name='PTB1',func=pin_types.BIDIR),
            Pin(num='18',name='PTB2',func=pin_types.BIDIR),
            Pin(num='19',name='PTB3',func=pin_types.BIDIR),
            Pin(num='2',name='PTA1',func=pin_types.BIDIR),
            Pin(num='20',name='VDD_0',func=pin_types.PWRIN),
            Pin(num='21',name='PTB16',func=pin_types.BIDIR),
            Pin(num='22',name='PTB17',func=pin_types.BIDIR),
            Pin(num='23',name='PTB18',func=pin_types.BIDIR),
            Pin(num='24',name='ADC0_DP0/CMP0_IN0',func=pin_types.INPUT),
            Pin(num='25',name='ADC0_DM0/CMP0_IN1',func=pin_types.INPUT),
            Pin(num='26',name='VSSA',func=pin_types.PWRIN),
            Pin(num='27',name='VREFH/VREF_OUT',func=pin_types.BIDIR),
            Pin(num='28',name='VDDA',func=pin_types.PWRIN),
            Pin(num='29',name='XTAL_OUT',func=pin_types.OUTPUT),
            Pin(num='3',name='PTA2',func=pin_types.BIDIR),
            Pin(num='30',name='EXTAL',func=pin_types.INPUT),
            Pin(num='31',name='XTAL',func=pin_types.INPUT),
            Pin(num='32',name='VDD_RF3',func=pin_types.PWRIN),
            Pin(num='33',name='ANT',func=pin_types.PASSIVE),
            Pin(num='34',name='GANT',func=pin_types.PWRIN),
            Pin(num='35',name='VDD_RF2',func=pin_types.PWRIN),
            Pin(num='36',name='VDD_RF1',func=pin_types.PWRIN),
            Pin(num='37',name='PTC1',func=pin_types.BIDIR),
            Pin(num='38',name='PTC2',func=pin_types.BIDIR),
            Pin(num='39',name='PTC3',func=pin_types.BIDIR),
            Pin(num='4',name='PTA16',func=pin_types.BIDIR),
            Pin(num='40',name='PTC4',func=pin_types.BIDIR),
            Pin(num='41',name='PTC5',func=pin_types.BIDIR),
            Pin(num='42',name='PTC6',func=pin_types.BIDIR),
            Pin(num='43',name='PTC7',func=pin_types.BIDIR),
            Pin(num='44',name='VDD_1',func=pin_types.PWRIN),
            Pin(num='45',name='PTC16',func=pin_types.BIDIR),
            Pin(num='46',name='PTC17',func=pin_types.BIDIR),
            Pin(num='47',name='PTC18',func=pin_types.BIDIR),
            Pin(num='48',name='PTC19',func=pin_types.BIDIR),
            Pin(num='49',name='VSS',func=pin_types.PWRIN),
            Pin(num='5',name='PTA17',func=pin_types.BIDIR),
            Pin(num='6',name='PTA18',func=pin_types.BIDIR),
            Pin(num='7',name='PTA19',func=pin_types.BIDIR),
            Pin(num='8',name='PSWITCH',func=pin_types.INPUT),
            Pin(num='9',name='DCDC_CFG',func=pin_types.INPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MK20DN128VFM5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MK20DN128VFM5'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL27 ARM Cortex M4', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/K20P32M50SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMK20DN128VFM5\n\nKinetis KL27 ARM Cortex M4', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN),
            Pin(num='10',name='EXTAL32',func=pin_types.INPUT),
            Pin(num='11',name='VBAT',func=pin_types.PWRIN),
            Pin(num='12',name='PTA0',func=pin_types.BIDIR),
            Pin(num='13',name='PTA1',func=pin_types.BIDIR),
            Pin(num='14',name='PTA2',func=pin_types.BIDIR),
            Pin(num='15',name='PTA3',func=pin_types.BIDIR),
            Pin(num='16',name='PTA4/LLWU_P3',func=pin_types.BIDIR),
            Pin(num='17',name='PTA18',func=pin_types.BIDIR),
            Pin(num='18',name='PTA19',func=pin_types.BIDIR),
            Pin(num='19',name='~{RESET}',func=pin_types.INPUT),
            Pin(num='2',name='VSS',func=pin_types.PWRIN),
            Pin(num='20',name='PTB0/LLWU_P5',func=pin_types.BIDIR),
            Pin(num='21',name='PTB1',func=pin_types.BIDIR),
            Pin(num='22',name='PTC1/LLWU_P6',func=pin_types.BIDIR),
            Pin(num='23',name='PTC2',func=pin_types.BIDIR),
            Pin(num='24',name='PTC3/LLWU_P7',func=pin_types.BIDIR),
            Pin(num='25',name='PTC4/LLWU_P8',func=pin_types.BIDIR),
            Pin(num='26',name='PTC5/LLWU_P9',func=pin_types.BIDIR),
            Pin(num='27',name='PTC6/LLWU_P10',func=pin_types.BIDIR),
            Pin(num='28',name='PTC7',func=pin_types.BIDIR),
            Pin(num='29',name='PTD4/LLWU_P14',func=pin_types.BIDIR),
            Pin(num='3',name='USB0_DP',func=pin_types.BIDIR),
            Pin(num='30',name='PTD5',func=pin_types.BIDIR),
            Pin(num='31',name='PTD6/LLWU_P15',func=pin_types.BIDIR),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR),
            Pin(num='5',name='VOUT33',func=pin_types.PWROUT),
            Pin(num='6',name='VREGIN',func=pin_types.PWRIN),
            Pin(num='7',name='VDDA',func=pin_types.PWRIN),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN),
            Pin(num='9',name='XTAL32',func=pin_types.INPUT),
            Pin(num='33',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='USB0_DM',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MK20DN32VFM5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MK20DN32VFM5'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL27 ARM Cortex M4', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/K20P32M50SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMK20DN32VFM5\n\nKinetis KL27 ARM Cortex M4', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN),
            Pin(num='10',name='EXTAL32',func=pin_types.INPUT),
            Pin(num='11',name='VBAT',func=pin_types.PWRIN),
            Pin(num='12',name='PTA0',func=pin_types.BIDIR),
            Pin(num='13',name='PTA1',func=pin_types.BIDIR),
            Pin(num='14',name='PTA2',func=pin_types.BIDIR),
            Pin(num='15',name='PTA3',func=pin_types.BIDIR),
            Pin(num='16',name='PTA4/LLWU_P3',func=pin_types.BIDIR),
            Pin(num='17',name='PTA18',func=pin_types.BIDIR),
            Pin(num='18',name='PTA19',func=pin_types.BIDIR),
            Pin(num='19',name='~{RESET}',func=pin_types.INPUT),
            Pin(num='2',name='VSS',func=pin_types.PWRIN),
            Pin(num='20',name='PTB0/LLWU_P5',func=pin_types.BIDIR),
            Pin(num='21',name='PTB1',func=pin_types.BIDIR),
            Pin(num='22',name='PTC1/LLWU_P6',func=pin_types.BIDIR),
            Pin(num='23',name='PTC2',func=pin_types.BIDIR),
            Pin(num='24',name='PTC3/LLWU_P7',func=pin_types.BIDIR),
            Pin(num='25',name='PTC4/LLWU_P8',func=pin_types.BIDIR),
            Pin(num='26',name='PTC5/LLWU_P9',func=pin_types.BIDIR),
            Pin(num='27',name='PTC6/LLWU_P10',func=pin_types.BIDIR),
            Pin(num='28',name='PTC7',func=pin_types.BIDIR),
            Pin(num='29',name='PTD4/LLWU_P14',func=pin_types.BIDIR),
            Pin(num='3',name='USB0_DP',func=pin_types.BIDIR),
            Pin(num='30',name='PTD5',func=pin_types.BIDIR),
            Pin(num='31',name='PTD6/LLWU_P15',func=pin_types.BIDIR),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR),
            Pin(num='5',name='VOUT33',func=pin_types.PWROUT),
            Pin(num='6',name='VREGIN',func=pin_types.PWRIN),
            Pin(num='7',name='VDDA',func=pin_types.PWRIN),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN),
            Pin(num='9',name='XTAL32',func=pin_types.INPUT),
            Pin(num='33',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='USB0_DM',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MK20DN64VFM5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MK20DN64VFM5'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL27 ARM Cortex M4', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/K20P32M50SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMK20DN64VFM5\n\nKinetis KL27 ARM Cortex M4', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN),
            Pin(num='10',name='EXTAL32',func=pin_types.INPUT),
            Pin(num='11',name='VBAT',func=pin_types.PWRIN),
            Pin(num='12',name='PTA0',func=pin_types.BIDIR),
            Pin(num='13',name='PTA1',func=pin_types.BIDIR),
            Pin(num='14',name='PTA2',func=pin_types.BIDIR),
            Pin(num='15',name='PTA3',func=pin_types.BIDIR),
            Pin(num='16',name='PTA4/LLWU_P3',func=pin_types.BIDIR),
            Pin(num='17',name='PTA18',func=pin_types.BIDIR),
            Pin(num='18',name='PTA19',func=pin_types.BIDIR),
            Pin(num='19',name='~{RESET}',func=pin_types.INPUT),
            Pin(num='2',name='VSS',func=pin_types.PWRIN),
            Pin(num='20',name='PTB0/LLWU_P5',func=pin_types.BIDIR),
            Pin(num='21',name='PTB1',func=pin_types.BIDIR),
            Pin(num='22',name='PTC1/LLWU_P6',func=pin_types.BIDIR),
            Pin(num='23',name='PTC2',func=pin_types.BIDIR),
            Pin(num='24',name='PTC3/LLWU_P7',func=pin_types.BIDIR),
            Pin(num='25',name='PTC4/LLWU_P8',func=pin_types.BIDIR),
            Pin(num='26',name='PTC5/LLWU_P9',func=pin_types.BIDIR),
            Pin(num='27',name='PTC6/LLWU_P10',func=pin_types.BIDIR),
            Pin(num='28',name='PTC7',func=pin_types.BIDIR),
            Pin(num='29',name='PTD4/LLWU_P14',func=pin_types.BIDIR),
            Pin(num='3',name='USB0_DP',func=pin_types.BIDIR),
            Pin(num='30',name='PTD5',func=pin_types.BIDIR),
            Pin(num='31',name='PTD6/LLWU_P15',func=pin_types.BIDIR),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR),
            Pin(num='5',name='VOUT33',func=pin_types.PWROUT),
            Pin(num='6',name='VREGIN',func=pin_types.PWRIN),
            Pin(num='7',name='VDDA',func=pin_types.PWRIN),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN),
            Pin(num='9',name='XTAL32',func=pin_types.INPUT),
            Pin(num='33',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='USB0_DM',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MK20DX32VFM5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MK20DX32VFM5'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL27 ARM Cortex M4', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/K20P32M50SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMK20DX32VFM5\n\nKinetis KL27 ARM Cortex M4', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN),
            Pin(num='10',name='EXTAL32',func=pin_types.INPUT),
            Pin(num='11',name='VBAT',func=pin_types.PWRIN),
            Pin(num='12',name='PTA0',func=pin_types.BIDIR),
            Pin(num='13',name='PTA1',func=pin_types.BIDIR),
            Pin(num='14',name='PTA2',func=pin_types.BIDIR),
            Pin(num='15',name='PTA3',func=pin_types.BIDIR),
            Pin(num='16',name='PTA4/LLWU_P3',func=pin_types.BIDIR),
            Pin(num='17',name='PTA18',func=pin_types.BIDIR),
            Pin(num='18',name='PTA19',func=pin_types.BIDIR),
            Pin(num='19',name='~{RESET}',func=pin_types.INPUT),
            Pin(num='2',name='VSS',func=pin_types.PWRIN),
            Pin(num='20',name='PTB0/LLWU_P5',func=pin_types.BIDIR),
            Pin(num='21',name='PTB1',func=pin_types.BIDIR),
            Pin(num='22',name='PTC1/LLWU_P6',func=pin_types.BIDIR),
            Pin(num='23',name='PTC2',func=pin_types.BIDIR),
            Pin(num='24',name='PTC3/LLWU_P7',func=pin_types.BIDIR),
            Pin(num='25',name='PTC4/LLWU_P8',func=pin_types.BIDIR),
            Pin(num='26',name='PTC5/LLWU_P9',func=pin_types.BIDIR),
            Pin(num='27',name='PTC6/LLWU_P10',func=pin_types.BIDIR),
            Pin(num='28',name='PTC7',func=pin_types.BIDIR),
            Pin(num='29',name='PTD4/LLWU_P14',func=pin_types.BIDIR),
            Pin(num='3',name='USB0_DP',func=pin_types.BIDIR),
            Pin(num='30',name='PTD5',func=pin_types.BIDIR),
            Pin(num='31',name='PTD6/LLWU_P15',func=pin_types.BIDIR),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR),
            Pin(num='5',name='VOUT33',func=pin_types.PWROUT),
            Pin(num='6',name='VREGIN',func=pin_types.PWRIN),
            Pin(num='7',name='VDDA',func=pin_types.PWRIN),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN),
            Pin(num='9',name='XTAL32',func=pin_types.INPUT),
            Pin(num='33',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='USB0_DM',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MK20DX64VFM5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MK20DX64VFM5'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL27 ARM Cortex M4', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/K20P32M50SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMK20DX64VFM5\n\nKinetis KL27 ARM Cortex M4', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN),
            Pin(num='10',name='EXTAL32',func=pin_types.INPUT),
            Pin(num='11',name='VBAT',func=pin_types.PWRIN),
            Pin(num='12',name='PTA0',func=pin_types.BIDIR),
            Pin(num='13',name='PTA1',func=pin_types.BIDIR),
            Pin(num='14',name='PTA2',func=pin_types.BIDIR),
            Pin(num='15',name='PTA3',func=pin_types.BIDIR),
            Pin(num='16',name='PTA4/LLWU_P3',func=pin_types.BIDIR),
            Pin(num='17',name='PTA18',func=pin_types.BIDIR),
            Pin(num='18',name='PTA19',func=pin_types.BIDIR),
            Pin(num='19',name='~{RESET}',func=pin_types.INPUT),
            Pin(num='2',name='VSS',func=pin_types.PWRIN),
            Pin(num='20',name='PTB0/LLWU_P5',func=pin_types.BIDIR),
            Pin(num='21',name='PTB1',func=pin_types.BIDIR),
            Pin(num='22',name='PTC1/LLWU_P6',func=pin_types.BIDIR),
            Pin(num='23',name='PTC2',func=pin_types.BIDIR),
            Pin(num='24',name='PTC3/LLWU_P7',func=pin_types.BIDIR),
            Pin(num='25',name='PTC4/LLWU_P8',func=pin_types.BIDIR),
            Pin(num='26',name='PTC5/LLWU_P9',func=pin_types.BIDIR),
            Pin(num='27',name='PTC6/LLWU_P10',func=pin_types.BIDIR),
            Pin(num='28',name='PTC7',func=pin_types.BIDIR),
            Pin(num='29',name='PTD4/LLWU_P14',func=pin_types.BIDIR),
            Pin(num='3',name='USB0_DP',func=pin_types.BIDIR),
            Pin(num='30',name='PTD5',func=pin_types.BIDIR),
            Pin(num='31',name='PTD6/LLWU_P15',func=pin_types.BIDIR),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR),
            Pin(num='5',name='VOUT33',func=pin_types.PWROUT),
            Pin(num='6',name='VREGIN',func=pin_types.PWRIN),
            Pin(num='7',name='VDDA',func=pin_types.PWRIN),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN),
            Pin(num='9',name='XTAL32',func=pin_types.INPUT),
            Pin(num='33',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='USB0_DM',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MK20FN1M0VMD12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MK20FN1M0VMD12'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-144_13.0x13.0mm_Layout12x12_P1.0mm', 'Package_BGA:BGA-144_13.0x13.0mm_Layout12x12_P1.0mm'], 'footprint':'Package_BGA:BGA-144_13.0x13.0mm_Layout12x12_P1.0mm', 'keywords':'Kinetis K20 ARM Cortex M4', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/K20P144M120SF3.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMK20FN1M0VMD12\n\nKinetis K20 ARM Cortex M4', 'pins':[
            Pin(num='A1',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A11',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PTD0/LLWU_P12',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PTC16',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PTC12',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PTD12',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B11',name='PTC1/LLWU_P6',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PTD11',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PTD10',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PTC19',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PTC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PTC11/LLWU_P11',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PTD9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PTD15',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C11',name='PTB23',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PTB22',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PTD14',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PTD13',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PTD2/LLWU_P13',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PTC18',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PTC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PTD8',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PTE2/LLWU_P1',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PTB20',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PTE1/LLWU_P0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PTC17',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PTC13',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PTB21',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PTE4/LLWU_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PTE10',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PTE9',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PTE8',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='G10',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='G3',name='PTE12',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PTE11',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PTA29',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PTA28',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H4',name='PTE28',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PGA2_DP/ADC2_DP0/ADC3_DP3/ADC0_DP1',func=pin_types.INPUT,unit=1),
            Pin(num='J10',name='PTA27',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PTA26',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PTA25',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PGA2_DM/ADC2_DM0/ADC3_DM3/ADC0_DM1',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='ADC0_SE16/CMP1_IN2/ADC0_SE21',func=pin_types.INPUT,unit=1),
            Pin(num='J4',name='PTE27',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='PTA13/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PGA3_DP/ADC3_DP0/ADC2_DP3/ADC1_DP1',func=pin_types.INPUT,unit=1),
            Pin(num='K10',name='PTA16',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PTA17',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PTA24',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PGA3_DM/ADC3_DM0/ADC2_DM3/ADC1_DM1',func=pin_types.INPUT,unit=1),
            Pin(num='K3',name='ADC1_SE16/CMP2_IN2/ADC0_SE22',func=pin_types.INPUT,unit=1),
            Pin(num='K4',name='PTE26',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='K7',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PGA0_DP/ADC0_DP0/ADC1_DP3',func=pin_types.INPUT,unit=1),
            Pin(num='L10',name='PTA14',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PTA15',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PGA0_DM/ADC0_DM0/ADC1_DM3',func=pin_types.INPUT,unit=1),
            Pin(num='L3',name='DAC0_OUT/CMP1_IN3/ADC0_SE23',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='DAC1_OUT/CMP0_IN4/CMP2_IN3/ADC1_SE23',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='~{RTC_WAKEUP}',func=pin_types.OUTPUT,unit=1),
            Pin(num='L6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='L7',name='PTA4/LLWU_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PTA11',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PGA1_DP/ADC1_DP0/ADC0_DP3',func=pin_types.INPUT,unit=1),
            Pin(num='M10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M11',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PGA1_DM/ADC1_DM0/ADC0_DM3',func=pin_types.INPUT,unit=1),
            Pin(num='M3',name='VREF_OUT/CMP1_IN5/CMP0_IN5/ADC1_SE18',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='M6',name='EXTAL32',func=pin_types.INPUT,unit=1),
            Pin(num='M7',name='XTAL32',func=pin_types.OUTPUT,unit=1),
            Pin(num='M8',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PTA10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKE02Z16VLC4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKE02Z16VLC4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'NXP Kinetis Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/files-static/microcontrollers/doc/ref_manual/MKE02P64M40SF0RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKE02Z16VLC4\n\nNXP Kinetis Microcontroller', 'pins':[
            Pin(num='1',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS/VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKE02Z16VLD4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKE02Z16VLD4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'keywords':'NXP Kinetis Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/files-static/microcontrollers/doc/ref_manual/MKE02P64M40SF0RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKE02Z16VLD4\n\nNXP Kinetis Microcontroller', 'pins':[
            Pin(num='1',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTH2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS/VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTB7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKE02Z32VLC4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKE02Z32VLC4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'NXP Kinetis Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/files-static/microcontrollers/doc/ref_manual/MKE02P64M40SF0RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKE02Z32VLC4\n\nNXP Kinetis Microcontroller', 'pins':[
            Pin(num='1',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS/VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKE02Z32VLD4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKE02Z32VLD4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'Package_QFP:LQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-44_10x10mm_P0.8mm', 'keywords':'NXP Kinetis Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/files-static/microcontrollers/doc/ref_manual/MKE02P64M40SF0RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKE02Z32VLD4\n\nNXP Kinetis Microcontroller', 'pins':[
            Pin(num='1',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTH2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS/VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTB7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKE02Z32VLH4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKE02Z32VLH4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'NXP Kinetis Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/files-static/microcontrollers/doc/ref_manual/MKE02P64M40SF0RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKE02Z32VLH4\n\nNXP Kinetis Microcontroller', 'pins':[
            Pin(num='1',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS/VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PTH1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTH0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTH7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTH6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTH2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VREFL',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKE02Z32VQH4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKE02Z32VQH4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'NXP Kinetis Microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/files-static/microcontrollers/doc/ref_manual/MKE02P64M40SF0RM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKE02Z32VQH4\n\nNXP Kinetis Microcontroller', 'pins':[
            Pin(num='1',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VSS/VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PTH1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTH0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTC3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTD6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTC1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTF7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTF6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTF5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTH7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTF4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTB0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTF3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTF2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTH6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='PTF1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTF0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTD4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC6',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTG3',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTG2',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTG1',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTG0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTH2',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTC5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC4',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VREFL',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL02Z16VFG4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL02Z16VFG4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.9x1.9mm', 'Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.9x1.9mm'], 'footprint':'Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.9x1.9mm', 'keywords':'Kinetis KL02 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL02P32M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL02Z16VFG4\n\nKinetis KL02 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='VDD/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PTB2/IRQ_7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB3/IRQ_10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB4/IRQ_11',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB5/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA0/IRQ_0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VSS/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA7/IRQ_4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB0/IRQ_5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB1/IRQ_6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL02Z16VFK4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL02Z16VFK4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'Kinetis KL02 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL02P32M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL02Z16VFK4\n\nKinetis KL02 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTB6/IRQ_2/LPTMR0_ALT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA7/IRQ_4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB0/IRQ_5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB1/IRQ_6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB2/IRQ_7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB3/IRQ_10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB4/IRQ_11',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB5/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB7/IRQ_3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA12/IRQ_13/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB13',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0/IRQ_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL02Z16VFM4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL02Z16VFM4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL02 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL02P32M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL02Z16VFM4\n\nKinetis KL02 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTB6/IRQ_2/LPTMR0_ALT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA7/IRQ_4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0/IRQ_5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB1/IRQ_6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2/IRQ_7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB7/IRQ_3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA10/IRQ_8',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA11/IRQ_9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB3/IRQ_10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB4/IRQ_11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB5/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA12/IRQ_13/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PTA0/IRQ_0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTA5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL02Z8VFG4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL02Z8VFG4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.9x1.9mm', 'Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.9x1.9mm', 'Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.9x1.9mm'], 'footprint':'Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.9x1.9mm', 'keywords':'Kinetis KL02 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL02P32M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL02Z8VFG4\n\nKinetis KL02 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='VDD/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PTB2/IRQ_7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB3/IRQ_10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB4/IRQ_11',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB5/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA0/IRQ_0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VSS/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA7/IRQ_4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB0/IRQ_5',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB1/IRQ_6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL03Z16VFG4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL03Z16VFG4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.9x1.9mm', 'Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.9x1.9mm'], 'footprint':'Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.9x1.9mm', 'keywords':'Kinetis KL03 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL03P24M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL03Z16VFG4\n\nKinetis KL03 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PTB2/IRQ_7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB3/IRQ_10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB4/IRQ_11',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB5/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTA5/RTC_CLK_IN',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA7/IRQ_4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB0/IRQ_5/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB1/IRQ_6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL03Z16VFK4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL03Z16VFK4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'Kinetis KL03 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL03P24M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL03Z16VFK4\n\nKinetis KL03 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTB6/IRQ_2/LPTMR0_ALT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA7/IRQ_4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB0/IRQ_5/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB1/IRQ_6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB2/IRQ_7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB3/IRQ_10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB4/IRQ_11',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB5/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB7/IRQ_3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA12/IRQ_13/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB13/CLKOUT32K',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA5/RTC_CLK_IN',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL03Z32CBF4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL03Z32CBF4'}), 'ref_prefix':'U', 'fplist':['Package_CSP:WLCSP-20_1.994x1.609mm_Layout5x4_P0.4mm', 'Package_CSP:WLCSP-20_1.994x1.609mm_Layout5x4_P0.4mm'], 'footprint':'Package_CSP:WLCSP-20_1.994x1.609mm_Layout5x4_P0.4mm', 'keywords':'Kinetis KL03 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL03P24M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL03Z32CBF4\n\nKinetis KL03 ARM Cortex M0+', 'pins':[
            Pin(num='A1',name='PTB3/IRQ_10',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PTB5/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PTB13/CLKOUT32K',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PTB2/IRQ_7',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PTB4/IRQ_11',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PTA12/IRQ_13/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PTB0/IRQ_5/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PTB1/IRQ_6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PTA5/RTC_CLK_IN',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PTA7/IRQ_4',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PTA6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL03Z8VFG4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL03Z8VFG4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.9x1.9mm', 'Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.9x1.9mm', 'Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.9x1.9mm'], 'footprint':'Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.9x1.9mm', 'keywords':'Kinetis KL03 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL03P24M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL03Z8VFG4\n\nKinetis KL03 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PTB2/IRQ_7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB3/IRQ_10',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB4/IRQ_11',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB5/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTA5/RTC_CLK_IN',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA7/IRQ_4',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTB0/IRQ_5/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB1/IRQ_6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL03Z8VFK4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL03Z8VFK4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'Kinetis KL03 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL03P24M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL03Z8VFK4\n\nKinetis KL03 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTB6/IRQ_2/LPTMR0_ALT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA7/IRQ_4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB0/IRQ_5/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB1/IRQ_6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB2/IRQ_7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB3/IRQ_10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB4/IRQ_11',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB5/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB7/IRQ_3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA12/IRQ_13/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB13/CLKOUT32K',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA5/RTC_CLK_IN',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL04Z16VFK4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL04Z16VFK4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'Kinetis KL04 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL04P48M48SF1.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL04Z16VFK4\n\nKinetis KL04 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTB6/IRQ_2/LPTMR0_ALT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA7/IRQ_7/LLWU_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB0/IRQ_8/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB1/IRQ_9',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB2/IRQ_10/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB3/IRQ_14',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB4/IRQ_15/LLWU_P6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB5/IRQ_16',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB7/IRQ_3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA12/IRQ_17/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB13',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA4/LLWU_P0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA5/LLWU_P1/RTC_CLK_IN',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA6/LLWU_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL04Z16VFM4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL04Z16VFM4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL04 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL04P48M48SF1.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL04Z16VFM4\n\nKinetis KL04 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTB6/IRQ_2/LPTMR0_ALT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA6/LLWU_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA7/IRQ_7/LLWU_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0/IRQ_8/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB1/IRQ_9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2/IRQ_10/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB7/IRQ_3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA10/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA11/IRQ_13',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB3/IRQ_14',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB4/IRQ_15/LLWU_P6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB5/IRQ_16',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA12/IRQ_17/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA4/LLWU_P0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTA5/LLWU_P1/RTC_CLK_IN',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL04Z16VLC4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL04Z16VLC4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Kinetis KL04 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL04P48M48SF1.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL04Z16VLC4\n\nKinetis KL04 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTB6/IRQ_2/LPTMR0_ALT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA6/LLWU_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA7/IRQ_7/LLWU_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0/IRQ_8/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB1/IRQ_9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2/IRQ_10/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB7/IRQ_3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA10/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA11/IRQ_13',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB3/IRQ_14',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB4/IRQ_15/LLWU_P6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB5/IRQ_16',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA12/IRQ_17/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA4/LLWU_P0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTA5/LLWU_P1/RTC_CLK_IN',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL04Z16VLF4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL04Z16VLF4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Kinetis KL04 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL04P48M48SF1.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL04Z16VLF4\n\nKinetis KL04 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTB6/IRQ_2/LPTMR0_ALT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA4/LLWU_P0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA5/LLWU_P1/RTC_CLK_IN',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA6/LLWU_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA16/IRQ_4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA17/IRQ_5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB7/IRQ_3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA18/IRQ_6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA7/IRQ_7/LLWU_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB0/IRQ_8/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB1/IRQ_9',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB2/IRQ_10/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB20',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTA14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTB14/IRQ_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA10/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA11/IRQ_13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB3/IRQ_14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB4/IRQ_15/LLWU_P6',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB5/IRQ_16',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTA12/IRQ_17/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTA15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTB12',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB15',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTB13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL04Z8VFK4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL04Z8VFK4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'Kinetis KL04 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL04P48M48SF1.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL04Z8VFK4\n\nKinetis KL04 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTB6/IRQ_2/LPTMR0_ALT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA7/IRQ_7/LLWU_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB0/IRQ_8/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB1/IRQ_9',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB2/IRQ_10/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB3/IRQ_14',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB4/IRQ_15/LLWU_P6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB5/IRQ_16',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB7/IRQ_3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA12/IRQ_17/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB13',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA4/LLWU_P0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA5/LLWU_P1/RTC_CLK_IN',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA6/LLWU_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL04Z8VFM4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL04Z8VFM4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL04 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL04P48M48SF1.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL04Z8VFM4\n\nKinetis KL04 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTB6/IRQ_2/LPTMR0_ALT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA6/LLWU_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA7/IRQ_7/LLWU_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0/IRQ_8/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB1/IRQ_9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2/IRQ_10/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB7/IRQ_3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA10/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA11/IRQ_13',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB3/IRQ_14',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB4/IRQ_15/LLWU_P6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB5/IRQ_16',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA12/IRQ_17/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA4/LLWU_P0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTA5/LLWU_P1/RTC_CLK_IN',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL04Z8VLC4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL04Z8VLC4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Kinetis KL04 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL04P48M48SF1.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL04Z8VLC4\n\nKinetis KL04 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTB6/IRQ_2/LPTMR0_ALT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA6/LLWU_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA7/IRQ_7/LLWU_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0/IRQ_8/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB1/IRQ_9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2/IRQ_10/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB7/IRQ_3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA10/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA11/IRQ_13',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB3/IRQ_14',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB4/IRQ_15/LLWU_P6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB5/IRQ_16',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA12/IRQ_17/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA4/LLWU_P0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTA5/LLWU_P1/RTC_CLK_IN',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL05Z16VFK4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL05Z16VFK4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'Kinetis KL05 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL05P48M48SF1.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL05Z16VFK4\n\nKinetis KL05 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTB6/IRQ_2/LPTMR0_ALT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA7/IRQ_7/LLWU_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB0/IRQ_8/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB1/IRQ_9',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB2/IRQ_10/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB3/IRQ_14',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB4/IRQ_15/LLWU_P6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB5/IRQ_16',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB7/IRQ_3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA12/IRQ_17/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB13',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA4/LLWU_P0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA5/LLWU_P1/RTC_CLK_IN',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA6/LLWU_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL05Z16VFM4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL05Z16VFM4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL05 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL05P48M48SF1.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL05Z16VFM4\n\nKinetis KL05 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTB6/IRQ_2/LPTMR0_ALT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA6/LLWU_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA7/IRQ_7/LLWU_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0/IRQ_8/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB1/IRQ_9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2/IRQ_10/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB7/IRQ_3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA10/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA11/IRQ_13',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB3/IRQ_14',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB4/IRQ_15/LLWU_P6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB5/IRQ_16',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA12/IRQ_17/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA4/LLWU_P0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTA5/LLWU_P1/RTC_CLK_IN',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL05Z16VLC4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL05Z16VLC4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Kinetis KL05 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL05P48M48SF1.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL05Z16VLC4\n\nKinetis KL05 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTB6/IRQ_2/LPTMR0_ALT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA6/LLWU_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA7/IRQ_7/LLWU_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0/IRQ_8/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB1/IRQ_9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2/IRQ_10/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB7/IRQ_3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA10/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA11/IRQ_13',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB3/IRQ_14',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB4/IRQ_15/LLWU_P6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB5/IRQ_16',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA12/IRQ_17/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA4/LLWU_P0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTA5/LLWU_P1/RTC_CLK_IN',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL05Z16VLF4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL05Z16VLF4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Kinetis KL05 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL05P48M48SF1.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL05Z16VLF4\n\nKinetis KL05 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTB6/IRQ_2/LPTMR0_ALT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA4/LLWU_P0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA5/LLWU_P1/RTC_CLK_IN',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA6/LLWU_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA16/IRQ_4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA17/IRQ_5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB7/IRQ_3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA18/IRQ_6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA7/IRQ_7/LLWU_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB0/IRQ_8/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB1/IRQ_9',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTB2/IRQ_10/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB20',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTA14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTB14/IRQ_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA10/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA11/IRQ_13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB3/IRQ_14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB4/IRQ_15/LLWU_P6',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB5/IRQ_16',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTA12/IRQ_17/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTA15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTB12',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB15',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTB13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL05Z8VFK4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL05Z8VFK4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:QFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'Kinetis KL05 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL05P48M48SF1.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL05Z8VFK4\n\nKinetis KL05 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTB6/IRQ_2/LPTMR0_ALT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA7/IRQ_7/LLWU_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB0/IRQ_8/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB1/IRQ_9',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB2/IRQ_10/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB3/IRQ_14',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB4/IRQ_15/LLWU_P6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTB5/IRQ_16',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB7/IRQ_3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA12/IRQ_17/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB13',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VDD/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTA4/LLWU_P0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTA5/LLWU_P1/RTC_CLK_IN',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA6/LLWU_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTB10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL05Z8VFM4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL05Z8VFM4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL05 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL05P48M48SF1.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL05Z8VFM4\n\nKinetis KL05 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTB6/IRQ_2/LPTMR0_ALT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA6/LLWU_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA7/IRQ_7/LLWU_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0/IRQ_8/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB1/IRQ_9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2/IRQ_10/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB7/IRQ_3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA10/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA11/IRQ_13',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB3/IRQ_14',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB4/IRQ_15/LLWU_P6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB5/IRQ_16',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA12/IRQ_17/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA4/LLWU_P0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTA5/LLWU_P1/RTC_CLK_IN',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL05Z8VLC4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL05Z8VLC4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Kinetis KL05 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL05P48M48SF1.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL05Z8VLC4\n\nKinetis KL05 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTB6/IRQ_2/LPTMR0_ALT3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA6/LLWU_P2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTA7/IRQ_7/LLWU_P3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTB0/IRQ_8/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTB1/IRQ_9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTB2/IRQ_10/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA8',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTB7/IRQ_3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTA9',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA10/IRQ_12',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA11/IRQ_13',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTB3/IRQ_14',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTB4/IRQ_15/LLWU_P6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTB5/IRQ_16',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA12/IRQ_17/LPTMR0_ALT2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PTA0/IRQ_0/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA1/IRQ_1/LPTMR0_ALT1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTA4/LLWU_P0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTA5/LLWU_P1/RTC_CLK_IN',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL16Z32VFM4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL16Z32VFM4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL16 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL16P64M48SF5.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL16Z32VFM4\n\nKinetis KL16 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE30',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL16Z32VFT4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL16Z32VFT4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'Kinetis KL16 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL16P64M48SF5.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL16Z32VFT4\n\nKinetis KL16 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL16Z32VLH4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL16Z32VLH4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Kinetis KL16 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL16P64M48SF5.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL16Z32VLH4\n\nKinetis KL16 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL16Z64VFM4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL16Z64VFM4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL16 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL16P64M48SF5.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL16Z64VFM4\n\nKinetis KL16 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE30',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL16Z64VFT4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL16Z64VFT4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'Kinetis KL16 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL16P64M48SF5.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL16Z64VFT4\n\nKinetis KL16 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL16Z64VLH4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL16Z64VLH4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Kinetis KL16 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL16P64M48SF5.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL16Z64VLH4\n\nKinetis KL16 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL17Z128VFM4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL17Z128VFM4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL17 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL17P64M48SF6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL17Z128VFM4\n\nKinetis KL17 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE30',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL17Z128VFT4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL17Z128VFT4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'Kinetis KL17 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL17P64M48SF6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL17Z128VFT4\n\nKinetis KL17 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL17Z128VLH4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL17Z128VLH4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Kinetis KL17 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL17P64M48SF6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL17Z128VLH4\n\nKinetis KL17 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL17Z128VMP4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL17Z128VMP4'}), 'ref_prefix':'U', 'fplist':['Package_BGA:XFBGA-64_5.0x5.0mm_Layout8x8_P0.5mm', 'Package_BGA:XFBGA-64_5.0x5.0mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:XFBGA-64_5.0x5.0mm_Layout8x8_P0.5mm', 'keywords':'Kinetis KL17 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL17P64M48SF6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL17Z128VMP4\n\nKinetis KL17 ARM Cortex M0+', 'pins':[
            Pin(num='A1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C6',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='G5',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PTA18',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL17Z32VDA4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL17Z32VDA4'}), 'ref_prefix':'U', 'fplist':['Package_BGA:XFBGA-36_3.5x3.5mm_Layout6x6_P0.5mm', 'Package_BGA:XFBGA-36_3.5x3.5mm_Layout6x6_P0.5mm'], 'footprint':'Package_BGA:XFBGA-36_3.5x3.5mm_Layout6x6_P0.5mm', 'keywords':'Kinetis KL17 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL17P64M48SF2.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL17Z32VDA4\n\nKinetis KL17 ARM Cortex M0+', 'pins':[
            Pin(num='A1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='C4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PTE30/VREF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PTA18',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL17Z32VFM4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL17Z32VFM4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL17 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL17P64M48SF2.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL17Z32VFM4\n\nKinetis KL17 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE30/VREF0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL17Z32VFT4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL17Z32VFT4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'Kinetis KL17 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL17P64M48SF6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL17Z32VFT4\n\nKinetis KL17 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VREFH/VREFO',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL17Z32VLH4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL17Z32VLH4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Kinetis KL17 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL17P64M48SF2.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL17Z32VLH4\n\nKinetis KL17 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VREFH/VREFO',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL17Z32VMP4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL17Z32VMP4'}), 'ref_prefix':'U', 'fplist':['Package_BGA:XFBGA-64_5.0x5.0mm_Layout8x8_P0.5mm', 'Package_BGA:XFBGA-64_5.0x5.0mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:XFBGA-64_5.0x5.0mm_Layout8x8_P0.5mm', 'keywords':'Kinetis KL17 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL17P64M48SF2.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL17Z32VMP4\n\nKinetis KL17 ARM Cortex M0+', 'pins':[
            Pin(num='A1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C6',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='VREFH/VREFO',func=pin_types.PWRIN,unit=1),
            Pin(num='G5',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PTA18',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL24Z32VFM4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL24Z32VFM4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL24 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL24P80M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL24Z32VFM4\n\nKinetis KL24 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE30',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL24Z32VFT4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL24Z32VFT4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'Kinetis KL24 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL24P80M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL24Z32VFT4\n\nKinetis KL24 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL24Z32VLH4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL24Z32VLH4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Kinetis KL24 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL24P80M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL24Z32VLH4\n\nKinetis KL24 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL24Z32VLK4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL24Z32VLK4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Kinetis KL24 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL24P80M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL24Z32VLK4\n\nKinetis KL24 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='12',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTA16',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA17',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PTC12',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='PTC13',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PTC16',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PTC17',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='USB0_DP',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL25Z32VFM4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL25Z32VFM4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL25 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL25P80M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL25Z32VFM4\n\nKinetis KL25 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE30',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL25Z32VFT4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL25Z32VFT4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'Kinetis KL25 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL25P80M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL25Z32VFT4\n\nKinetis KL25 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL25Z32VLH4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL25Z32VLH4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Kinetis KL25 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL25P80M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL25Z32VLH4\n\nKinetis KL25 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL25Z32VLK4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL25Z32VLK4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Kinetis KL25 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL25P80M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL25Z32VLK4\n\nKinetis KL25 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='12',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTA16',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA17',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PTC12',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='PTC13',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PTC16',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PTC17',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='USB0_DP',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL25Z64VFM4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL25Z64VFM4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL25 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL25P80M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL25Z64VFM4\n\nKinetis KL25 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE30',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL25Z64VFT4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL25Z64VFT4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'Kinetis KL25 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL25P80M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL25Z64VFT4\n\nKinetis KL25 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL25Z64VLH4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL25Z64VLH4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Kinetis KL25 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL25P80M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL25Z64VLH4\n\nKinetis KL25 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL25Z64VLK4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL25Z64VLK4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Kinetis KL25 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL25P80M48SF0.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL25Z64VLK4\n\nKinetis KL25 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='12',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTA16',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA17',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PTC12',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='70',name='PTC13',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PTC16',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PTC17',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='USB0_DP',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL26Z128VLL4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL26Z128VLL4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Kinetis KL26 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL26P121M48SF4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL26Z128VLL4\n\nKinetis KL26 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='13',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTE26',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTA14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTA15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA16',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTA17',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PTB20',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PTB21',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PTB22',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PTB23',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PTC12',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PTC13',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='87',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='88',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='89',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='90',name='PTC16',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PTC17',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PTC18',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL26Z128VMC4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL26Z128VMC4'}), 'ref_prefix':'U', 'fplist':['Package_BGA:XFBGA-121_8x8mm_Layout11x11_P0.65mm', 'Package_BGA:XFBGA-121_8x8mm_Layout11x11_P0.65mm'], 'footprint':'Package_BGA:XFBGA-121_8x8mm_Layout11x11_P0.65mm', 'keywords':'Kinetis KL26 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL26P121M48SF4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL26Z128VMC4\n\nKinetis KL26 ARM Cortex M0+', 'pins':[
            Pin(num='A1',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PTC20',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A2',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A6',name='PTC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PTC21',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B10',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PTC22',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PTC18',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B6',name='PTC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C10',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PTC23',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C3',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PTC17',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='D10',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='D3',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PTC16',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E10',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PTB23',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PTB20',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F2',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PTB22',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PTB21',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='G10',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='G3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PTA17',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='H2',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='H4',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PTE26',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PTA16',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='J4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='J5',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K1',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K5',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PTA14',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='L8',name='PTA13/LLWU_P4',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PTA15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL26Z32VFM4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL26Z32VFM4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL26 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL26P64M48SF5.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL26Z32VFM4\n\nKinetis KL26 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE30',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL26Z32VFT4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL26Z32VFT4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'Kinetis KL26 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL26P64M48SF5.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL26Z32VFT4\n\nKinetis KL26 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL26Z32VLH4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL26Z32VLH4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Kinetis KL26 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL26P64M48SF5.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL26Z32VLH4\n\nKinetis KL26 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL26Z64VFM4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL26Z64VFM4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL26 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL26P64M48SF5.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL26Z64VFM4\n\nKinetis KL26 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE30',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL26Z64VFT4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL26Z64VFT4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'Kinetis KL26 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL26P64M48SF5.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL26Z64VFT4\n\nKinetis KL26 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL26Z64VLH4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL26Z64VLH4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Kinetis KL26 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL26P64M48SF5.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL26Z64VLH4\n\nKinetis KL26 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL27Z128VFT4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL27Z128VFT4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'Kinetis KL27 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL27P64M48SF6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL27Z128VFT4\n\nKinetis KL27 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL27Z128VLH4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL27Z128VLH4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Kinetis KL27 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL27P64M48SF6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL27Z128VLH4\n\nKinetis KL27 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL27Z32VFM4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL27Z32VFM4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Kinetis KL27 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL27P64M48SF2.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL27Z32VFM4\n\nKinetis KL27 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='USB_VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDDA/VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VSSA/VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE30/VREF0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL27Z32VFT4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL27Z32VFT4'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'Kinetis KL27 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL27P64M48SF2.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL27Z32VFT4\n\nKinetis KL27 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VREFH/VREFO',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='USB_VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL27Z32VLH4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL27Z32VLH4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Kinetis KL27 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL27P64M48SF2.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL27Z32VLH4\n\nKinetis KL27 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VREFH/VREFO',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='USB_VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PTE20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL43Z128VLH4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL43Z128VLH4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Kinetis KL43 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL43P64M48SF6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL43Z128VLH4\n\nKinetis KL43 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VLL3',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VLL2/PTC20',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VLL1/PTC21',func=pin_types.PWROUT,unit=1),
            Pin(num='51',name='VCAP2/PTC22',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VCAP1/PTC23',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL43Z128VMP4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL43Z128VMP4'}), 'ref_prefix':'U', 'fplist':['Package_BGA:XFBGA-64_5.0x5.0mm_Layout8x8_P0.5mm', 'Package_BGA:XFBGA-64_5.0x5.0mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:XFBGA-64_5.0x5.0mm_Layout8x8_P0.5mm', 'keywords':'Kinetis KL43 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL43P64M48SF6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL43Z128VMP4\n\nKinetis KL43 ARM Cortex M0+', 'pins':[
            Pin(num='A1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='VCAP1/PTC23',func=pin_types.PASSIVE,unit=1),
            Pin(num='A6',name='VLL2/PTC20',func=pin_types.PWROUT,unit=1),
            Pin(num='A7',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='VCAP2/PTC22',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='VLL1/PTC21',func=pin_types.PWROUT,unit=1),
            Pin(num='B6',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='VLL3',func=pin_types.PWROUT,unit=1),
            Pin(num='C6',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='E3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='G5',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='PTA18',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL46Z128VLH4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL46Z128VLH4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Kinetis KL46 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL46P121M48SF4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL46Z128VLH4\n\nKinetis KL46 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VLL3',func=pin_types.PWROUT,unit=1),
            Pin(num='49',name='VLL2/PTC20',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VLL1/PTC21',func=pin_types.PWROUT,unit=1),
            Pin(num='51',name='VCAP2/PTC22',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='VCAP1/PTC23',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PTE20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL46Z128VLL4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL46Z128VLL4'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Kinetis KL46 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL46P121M48SF4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL46Z128VLL4\n\nKinetis KL46 ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='13',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PTE26',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PTA14',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PTA15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PTA16',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PTA17',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PTB21',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PTB22',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PTB23',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='VLL3',func=pin_types.PWROUT,unit=1),
            Pin(num='76',name='VLL2/PTC20',func=pin_types.PWROUT,unit=1),
            Pin(num='77',name='VLL1/PTC21',func=pin_types.PWROUT,unit=1),
            Pin(num='78',name='VCAP2/PTC22',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='VCAP1/PTC23',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PTC12',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PTC13',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='90',name='PTC16',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PTC17',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PTC18',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKL46Z128VMC4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKL46Z128VMC4'}), 'ref_prefix':'U', 'fplist':['Package_BGA:XFBGA-121_8x8mm_Layout11x11_P0.65mm', 'Package_BGA:XFBGA-121_8x8mm_Layout11x11_P0.65mm'], 'footprint':'Package_BGA:XFBGA-121_8x8mm_Layout11x11_P0.65mm', 'keywords':'Kinetis KL46 ARM Cortex M0+', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/KL46P121M48SF4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKL46Z128VMC4\n\nKinetis KL46 ARM Cortex M0+', 'pins':[
            Pin(num='A1',name='PTD7',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VLL2/PTC20',func=pin_types.PWROUT,unit=1),
            Pin(num='A11',name='VLL3',func=pin_types.PWROUT,unit=1),
            Pin(num='A2',name='PTD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PTD4/LLWU_P14',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A6',name='PTC13',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PTC8',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PTC4/LLWU_P8',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='VLL1/PTC21',func=pin_types.PWROUT,unit=1),
            Pin(num='B1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B10',name='PTB16',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VCAP2/PTC22',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='PTD6/LLWU_P15',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PTD3',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PTC18',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B6',name='PTC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PTC7',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PTC3/LLWU_P7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PTC0',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C10',name='PTB11',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='VCAP1/PTC23',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='C3',name='PTD2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PTC17',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PTC11',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PTC10',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PTC6/LLWU_P10',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PTC2',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PTB19',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='D10',name='PTB10',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PTB8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='D3',name='PTD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PTD0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PTC16',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PTC9',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PTC5/LLWU_P9',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PTC1/LLWU_P6/RTC_CLKIN',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PTB18',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E10',name='PTB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PTB7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PTE2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PTE1',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PTE0',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='PTB23',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='PTB17',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='USB0_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='F10',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F2',name='USB0_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PTE6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PTE3',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='PTB22',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PTB21',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VOUT33',func=pin_types.PWROUT,unit=1),
            Pin(num='G10',name='PTB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='PTB0/LLWU_P5',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='VREGIN',func=pin_types.PWRIN,unit=1),
            Pin(num='G3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='PTE5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='VREFH',func=pin_types.PWRIN,unit=1),
            Pin(num='G6',name='VREFL',func=pin_types.PWRIN,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='PTB3',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='PTB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PTE16',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PTA17',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='H2',name='PTE17',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='H4',name='PTA7',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PTE24',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PTE26',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PTE4',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PTA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PTA3',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PTE18',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PTA16',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PTA20',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PTE19',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='J4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='J5',name='PTE25',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='PTA0',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='PTA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='PTA4',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K1',name='PTE20',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='PTA19',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PTE21',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PTA6',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K5',name='PTE30',func=pin_types.BIDIR,unit=1),
            Pin(num='K6',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='PTA5',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PTA12',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PTA14',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PTE22',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='L11',name='PTA18',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PTE23',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PTE29',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PTE31',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='L8',name='PTA13',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PTA15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MKW21Z256VHT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKW21Z256VHT'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:NXP_LQFN-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm_16xMask0.45x0.45_ThermalVias', 'Package_DFN_QFN:NXP_LQFN-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm_16xMask0.45x0.45_ThermalVias'], 'footprint':'Package_DFN_QFN:NXP_LQFN-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm_16xMask0.45x0.45_ThermalVias', 'keywords':'Kinetis KW21Z ARM Cortex M0+', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MKW41Z512.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKW21Z256VHT\n\nKinetis KW21Z ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTA0',func=pin_types.BIDIR),
            Pin(num='10',name='VDCDC_IN',func=pin_types.PWRIN),
            Pin(num='11',name='DCDC_LP',func=pin_types.PASSIVE),
            Pin(num='12',name='DCDC_LN',func=pin_types.PASSIVE),
            Pin(num='13',name='DCDC_GND',func=pin_types.PWRIN),
            Pin(num='14',name='VDD_1P8OUT',func=pin_types.PWROUT),
            Pin(num='15',name='VDD_1P5OUT_PMCIN',func=pin_types.PWROUT),
            Pin(num='16',name='PTB0',func=pin_types.BIDIR),
            Pin(num='17',name='PTB1',func=pin_types.BIDIR),
            Pin(num='18',name='PTB2',func=pin_types.BIDIR),
            Pin(num='19',name='PTB3',func=pin_types.BIDIR),
            Pin(num='2',name='PTA1',func=pin_types.BIDIR),
            Pin(num='20',name='VDD_0',func=pin_types.PWRIN),
            Pin(num='21',name='PTB16',func=pin_types.BIDIR),
            Pin(num='22',name='PTB17',func=pin_types.BIDIR),
            Pin(num='23',name='PTB18',func=pin_types.BIDIR),
            Pin(num='24',name='ADC0_DP0/CMP0_IN0',func=pin_types.INPUT),
            Pin(num='25',name='ADC0_DM0/CMP0_IN1',func=pin_types.INPUT),
            Pin(num='26',name='VSSA',func=pin_types.PWRIN),
            Pin(num='27',name='VREFH/VREF_OUT',func=pin_types.BIDIR),
            Pin(num='28',name='VDDA',func=pin_types.PWRIN),
            Pin(num='29',name='XTAL_OUT',func=pin_types.OUTPUT),
            Pin(num='3',name='PTA2',func=pin_types.BIDIR),
            Pin(num='30',name='EXTAL',func=pin_types.INPUT),
            Pin(num='31',name='XTAL',func=pin_types.INPUT),
            Pin(num='32',name='VDD_RF3',func=pin_types.PWRIN),
            Pin(num='33',name='ANT',func=pin_types.PASSIVE),
            Pin(num='34',name='GANT',func=pin_types.PWRIN),
            Pin(num='35',name='VDD_RF2',func=pin_types.PWRIN),
            Pin(num='36',name='VDD_RF1',func=pin_types.PWRIN),
            Pin(num='37',name='PTC1',func=pin_types.BIDIR),
            Pin(num='38',name='PTC2',func=pin_types.BIDIR),
            Pin(num='39',name='PTC3',func=pin_types.BIDIR),
            Pin(num='4',name='PTA16',func=pin_types.BIDIR),
            Pin(num='40',name='PTC4',func=pin_types.BIDIR),
            Pin(num='41',name='PTC5',func=pin_types.BIDIR),
            Pin(num='42',name='PTC6',func=pin_types.BIDIR),
            Pin(num='43',name='PTC7',func=pin_types.BIDIR),
            Pin(num='44',name='VDD_1',func=pin_types.PWRIN),
            Pin(num='45',name='PTC16',func=pin_types.BIDIR),
            Pin(num='46',name='PTC17',func=pin_types.BIDIR),
            Pin(num='47',name='PTC18',func=pin_types.BIDIR),
            Pin(num='48',name='PTC19',func=pin_types.BIDIR),
            Pin(num='49',name='VSS',func=pin_types.PWRIN),
            Pin(num='5',name='PTA17',func=pin_types.BIDIR),
            Pin(num='6',name='PTA18',func=pin_types.BIDIR),
            Pin(num='7',name='PTA19',func=pin_types.BIDIR),
            Pin(num='8',name='PSWITCH',func=pin_types.INPUT),
            Pin(num='9',name='DCDC_CFG',func=pin_types.INPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MKW21Z512VHT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKW21Z512VHT'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:NXP_LQFN-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm_16xMask0.45x0.45_ThermalVias', 'Package_DFN_QFN:NXP_LQFN-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm_16xMask0.45x0.45_ThermalVias', 'Package_DFN_QFN:NXP_LQFN-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm_16xMask0.45x0.45_ThermalVias'], 'footprint':'Package_DFN_QFN:NXP_LQFN-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm_16xMask0.45x0.45_ThermalVias', 'keywords':'Kinetis KW21Z ARM Cortex M0+', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MKW41Z512.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKW21Z512VHT\n\nKinetis KW21Z ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTA0',func=pin_types.BIDIR),
            Pin(num='10',name='VDCDC_IN',func=pin_types.PWRIN),
            Pin(num='11',name='DCDC_LP',func=pin_types.PASSIVE),
            Pin(num='12',name='DCDC_LN',func=pin_types.PASSIVE),
            Pin(num='13',name='DCDC_GND',func=pin_types.PWRIN),
            Pin(num='14',name='VDD_1P8OUT',func=pin_types.PWROUT),
            Pin(num='15',name='VDD_1P5OUT_PMCIN',func=pin_types.PWROUT),
            Pin(num='16',name='PTB0',func=pin_types.BIDIR),
            Pin(num='17',name='PTB1',func=pin_types.BIDIR),
            Pin(num='18',name='PTB2',func=pin_types.BIDIR),
            Pin(num='19',name='PTB3',func=pin_types.BIDIR),
            Pin(num='2',name='PTA1',func=pin_types.BIDIR),
            Pin(num='20',name='VDD_0',func=pin_types.PWRIN),
            Pin(num='21',name='PTB16',func=pin_types.BIDIR),
            Pin(num='22',name='PTB17',func=pin_types.BIDIR),
            Pin(num='23',name='PTB18',func=pin_types.BIDIR),
            Pin(num='24',name='ADC0_DP0/CMP0_IN0',func=pin_types.INPUT),
            Pin(num='25',name='ADC0_DM0/CMP0_IN1',func=pin_types.INPUT),
            Pin(num='26',name='VSSA',func=pin_types.PWRIN),
            Pin(num='27',name='VREFH/VREF_OUT',func=pin_types.BIDIR),
            Pin(num='28',name='VDDA',func=pin_types.PWRIN),
            Pin(num='29',name='XTAL_OUT',func=pin_types.OUTPUT),
            Pin(num='3',name='PTA2',func=pin_types.BIDIR),
            Pin(num='30',name='EXTAL',func=pin_types.INPUT),
            Pin(num='31',name='XTAL',func=pin_types.INPUT),
            Pin(num='32',name='VDD_RF3',func=pin_types.PWRIN),
            Pin(num='33',name='ANT',func=pin_types.PASSIVE),
            Pin(num='34',name='GANT',func=pin_types.PWRIN),
            Pin(num='35',name='VDD_RF2',func=pin_types.PWRIN),
            Pin(num='36',name='VDD_RF1',func=pin_types.PWRIN),
            Pin(num='37',name='PTC1',func=pin_types.BIDIR),
            Pin(num='38',name='PTC2',func=pin_types.BIDIR),
            Pin(num='39',name='PTC3',func=pin_types.BIDIR),
            Pin(num='4',name='PTA16',func=pin_types.BIDIR),
            Pin(num='40',name='PTC4',func=pin_types.BIDIR),
            Pin(num='41',name='PTC5',func=pin_types.BIDIR),
            Pin(num='42',name='PTC6',func=pin_types.BIDIR),
            Pin(num='43',name='PTC7',func=pin_types.BIDIR),
            Pin(num='44',name='VDD_1',func=pin_types.PWRIN),
            Pin(num='45',name='PTC16',func=pin_types.BIDIR),
            Pin(num='46',name='PTC17',func=pin_types.BIDIR),
            Pin(num='47',name='PTC18',func=pin_types.BIDIR),
            Pin(num='48',name='PTC19',func=pin_types.BIDIR),
            Pin(num='49',name='VSS',func=pin_types.PWRIN),
            Pin(num='5',name='PTA17',func=pin_types.BIDIR),
            Pin(num='6',name='PTA18',func=pin_types.BIDIR),
            Pin(num='7',name='PTA19',func=pin_types.BIDIR),
            Pin(num='8',name='PSWITCH',func=pin_types.INPUT),
            Pin(num='9',name='DCDC_CFG',func=pin_types.INPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MKW31Z256VHT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKW31Z256VHT'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:NXP_LQFN-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm_16xMask0.45x0.45_ThermalVias', 'Package_DFN_QFN:NXP_LQFN-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm_16xMask0.45x0.45_ThermalVias', 'Package_DFN_QFN:NXP_LQFN-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm_16xMask0.45x0.45_ThermalVias', 'Package_DFN_QFN:NXP_LQFN-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm_16xMask0.45x0.45_ThermalVias'], 'footprint':'Package_DFN_QFN:NXP_LQFN-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm_16xMask0.45x0.45_ThermalVias', 'keywords':'Kinetis KW31Z ARM Cortex M0+', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MKW41Z512.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKW31Z256VHT\n\nKinetis KW31Z ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTA0',func=pin_types.BIDIR),
            Pin(num='10',name='VDCDC_IN',func=pin_types.PWRIN),
            Pin(num='11',name='DCDC_LP',func=pin_types.PASSIVE),
            Pin(num='12',name='DCDC_LN',func=pin_types.PASSIVE),
            Pin(num='13',name='DCDC_GND',func=pin_types.PWRIN),
            Pin(num='14',name='VDD_1P8OUT',func=pin_types.PWROUT),
            Pin(num='15',name='VDD_1P5OUT_PMCIN',func=pin_types.PWROUT),
            Pin(num='16',name='PTB0',func=pin_types.BIDIR),
            Pin(num='17',name='PTB1',func=pin_types.BIDIR),
            Pin(num='18',name='PTB2',func=pin_types.BIDIR),
            Pin(num='19',name='PTB3',func=pin_types.BIDIR),
            Pin(num='2',name='PTA1',func=pin_types.BIDIR),
            Pin(num='20',name='VDD_0',func=pin_types.PWRIN),
            Pin(num='21',name='PTB16',func=pin_types.BIDIR),
            Pin(num='22',name='PTB17',func=pin_types.BIDIR),
            Pin(num='23',name='PTB18',func=pin_types.BIDIR),
            Pin(num='24',name='ADC0_DP0/CMP0_IN0',func=pin_types.INPUT),
            Pin(num='25',name='ADC0_DM0/CMP0_IN1',func=pin_types.INPUT),
            Pin(num='26',name='VSSA',func=pin_types.PWRIN),
            Pin(num='27',name='VREFH/VREF_OUT',func=pin_types.BIDIR),
            Pin(num='28',name='VDDA',func=pin_types.PWRIN),
            Pin(num='29',name='XTAL_OUT',func=pin_types.OUTPUT),
            Pin(num='3',name='PTA2',func=pin_types.BIDIR),
            Pin(num='30',name='EXTAL',func=pin_types.INPUT),
            Pin(num='31',name='XTAL',func=pin_types.INPUT),
            Pin(num='32',name='VDD_RF3',func=pin_types.PWRIN),
            Pin(num='33',name='ANT',func=pin_types.PASSIVE),
            Pin(num='34',name='GANT',func=pin_types.PWRIN),
            Pin(num='35',name='VDD_RF2',func=pin_types.PWRIN),
            Pin(num='36',name='VDD_RF1',func=pin_types.PWRIN),
            Pin(num='37',name='PTC1',func=pin_types.BIDIR),
            Pin(num='38',name='PTC2',func=pin_types.BIDIR),
            Pin(num='39',name='PTC3',func=pin_types.BIDIR),
            Pin(num='4',name='PTA16',func=pin_types.BIDIR),
            Pin(num='40',name='PTC4',func=pin_types.BIDIR),
            Pin(num='41',name='PTC5',func=pin_types.BIDIR),
            Pin(num='42',name='PTC6',func=pin_types.BIDIR),
            Pin(num='43',name='PTC7',func=pin_types.BIDIR),
            Pin(num='44',name='VDD_1',func=pin_types.PWRIN),
            Pin(num='45',name='PTC16',func=pin_types.BIDIR),
            Pin(num='46',name='PTC17',func=pin_types.BIDIR),
            Pin(num='47',name='PTC18',func=pin_types.BIDIR),
            Pin(num='48',name='PTC19',func=pin_types.BIDIR),
            Pin(num='49',name='VSS',func=pin_types.PWRIN),
            Pin(num='5',name='PTA17',func=pin_types.BIDIR),
            Pin(num='6',name='PTA18',func=pin_types.BIDIR),
            Pin(num='7',name='PTA19',func=pin_types.BIDIR),
            Pin(num='8',name='PSWITCH',func=pin_types.INPUT),
            Pin(num='9',name='DCDC_CFG',func=pin_types.INPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MKW31Z512VHT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKW31Z512VHT'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:NXP_LQFN-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm_16xMask0.45x0.45_ThermalVias', 'Package_DFN_QFN:NXP_LQFN-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm_16xMask0.45x0.45_ThermalVias', 'Package_DFN_QFN:NXP_LQFN-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm_16xMask0.45x0.45_ThermalVias', 'Package_DFN_QFN:NXP_LQFN-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm_16xMask0.45x0.45_ThermalVias', 'Package_DFN_QFN:NXP_LQFN-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm_16xMask0.45x0.45_ThermalVias'], 'footprint':'Package_DFN_QFN:NXP_LQFN-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm_16xMask0.45x0.45_ThermalVias', 'keywords':'Kinetis KW31Z ARM Cortex M0+', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MKW41Z512.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKW31Z512VHT\n\nKinetis KW31Z ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTA0',func=pin_types.BIDIR),
            Pin(num='10',name='VDCDC_IN',func=pin_types.PWRIN),
            Pin(num='11',name='DCDC_LP',func=pin_types.PASSIVE),
            Pin(num='12',name='DCDC_LN',func=pin_types.PASSIVE),
            Pin(num='13',name='DCDC_GND',func=pin_types.PWRIN),
            Pin(num='14',name='VDD_1P8OUT',func=pin_types.PWROUT),
            Pin(num='15',name='VDD_1P5OUT_PMCIN',func=pin_types.PWROUT),
            Pin(num='16',name='PTB0',func=pin_types.BIDIR),
            Pin(num='17',name='PTB1',func=pin_types.BIDIR),
            Pin(num='18',name='PTB2',func=pin_types.BIDIR),
            Pin(num='19',name='PTB3',func=pin_types.BIDIR),
            Pin(num='2',name='PTA1',func=pin_types.BIDIR),
            Pin(num='20',name='VDD_0',func=pin_types.PWRIN),
            Pin(num='21',name='PTB16',func=pin_types.BIDIR),
            Pin(num='22',name='PTB17',func=pin_types.BIDIR),
            Pin(num='23',name='PTB18',func=pin_types.BIDIR),
            Pin(num='24',name='ADC0_DP0/CMP0_IN0',func=pin_types.INPUT),
            Pin(num='25',name='ADC0_DM0/CMP0_IN1',func=pin_types.INPUT),
            Pin(num='26',name='VSSA',func=pin_types.PWRIN),
            Pin(num='27',name='VREFH/VREF_OUT',func=pin_types.BIDIR),
            Pin(num='28',name='VDDA',func=pin_types.PWRIN),
            Pin(num='29',name='XTAL_OUT',func=pin_types.OUTPUT),
            Pin(num='3',name='PTA2',func=pin_types.BIDIR),
            Pin(num='30',name='EXTAL',func=pin_types.INPUT),
            Pin(num='31',name='XTAL',func=pin_types.INPUT),
            Pin(num='32',name='VDD_RF3',func=pin_types.PWRIN),
            Pin(num='33',name='ANT',func=pin_types.PASSIVE),
            Pin(num='34',name='GANT',func=pin_types.PWRIN),
            Pin(num='35',name='VDD_RF2',func=pin_types.PWRIN),
            Pin(num='36',name='VDD_RF1',func=pin_types.PWRIN),
            Pin(num='37',name='PTC1',func=pin_types.BIDIR),
            Pin(num='38',name='PTC2',func=pin_types.BIDIR),
            Pin(num='39',name='PTC3',func=pin_types.BIDIR),
            Pin(num='4',name='PTA16',func=pin_types.BIDIR),
            Pin(num='40',name='PTC4',func=pin_types.BIDIR),
            Pin(num='41',name='PTC5',func=pin_types.BIDIR),
            Pin(num='42',name='PTC6',func=pin_types.BIDIR),
            Pin(num='43',name='PTC7',func=pin_types.BIDIR),
            Pin(num='44',name='VDD_1',func=pin_types.PWRIN),
            Pin(num='45',name='PTC16',func=pin_types.BIDIR),
            Pin(num='46',name='PTC17',func=pin_types.BIDIR),
            Pin(num='47',name='PTC18',func=pin_types.BIDIR),
            Pin(num='48',name='PTC19',func=pin_types.BIDIR),
            Pin(num='49',name='VSS',func=pin_types.PWRIN),
            Pin(num='5',name='PTA17',func=pin_types.BIDIR),
            Pin(num='6',name='PTA18',func=pin_types.BIDIR),
            Pin(num='7',name='PTA19',func=pin_types.BIDIR),
            Pin(num='8',name='PSWITCH',func=pin_types.INPUT),
            Pin(num='9',name='DCDC_CFG',func=pin_types.INPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MKW41Z256VHT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MKW41Z256VHT'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:NXP_LQFN-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm_16xMask0.45x0.45_ThermalVias', 'Package_DFN_QFN:NXP_LQFN-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm_16xMask0.45x0.45_ThermalVias', 'Package_DFN_QFN:NXP_LQFN-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm_16xMask0.45x0.45_ThermalVias', 'Package_DFN_QFN:NXP_LQFN-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm_16xMask0.45x0.45_ThermalVias', 'Package_DFN_QFN:NXP_LQFN-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm_16xMask0.45x0.45_ThermalVias', 'Package_DFN_QFN:NXP_LQFN-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm_16xMask0.45x0.45_ThermalVias'], 'footprint':'Package_DFN_QFN:NXP_LQFN-48-1EP_7x7mm_P0.5mm_EP3.5x3.5mm_16xMask0.45x0.45_ThermalVias', 'keywords':'Kinetis KW41Z ARM Cortex M0+', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/MKW41Z512.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_Kinetis.kicad_sym\nMKW41Z256VHT\n\nKinetis KW41Z ARM Cortex M0+', 'pins':[
            Pin(num='1',name='PTA0',func=pin_types.BIDIR),
            Pin(num='10',name='VDCDC_IN',func=pin_types.PWRIN),
            Pin(num='11',name='DCDC_LP',func=pin_types.PASSIVE),
            Pin(num='12',name='DCDC_LN',func=pin_types.PASSIVE),
            Pin(num='13',name='DCDC_GND',func=pin_types.PWRIN),
            Pin(num='14',name='VDD_1P8OUT',func=pin_types.PWROUT),
            Pin(num='15',name='VDD_1P5OUT_PMCIN',func=pin_types.PWROUT),
            Pin(num='16',name='PTB0',func=pin_types.BIDIR),
            Pin(num='17',name='PTB1',func=pin_types.BIDIR),
            Pin(num='18',name='PTB2',func=pin_types.BIDIR),
            Pin(num='19',name='PTB3',func=pin_types.BIDIR),
            Pin(num='2',name='PTA1',func=pin_types.BIDIR),
            Pin(num='20',name='VDD_0',func=pin_types.PWRIN),
            Pin(num='21',name='PTB16',func=pin_types.BIDIR),
            Pin(num='22',name='PTB17',func=pin_types.BIDIR),
            Pin(num='23',name='PTB18',func=pin_types.BIDIR),
            Pin(num='24',name='ADC0_DP0/CMP0_IN0',func=pin_types.INPUT),
            Pin(num='25',name='ADC0_DM0/CMP0_IN1',func=pin_types.INPUT),
            Pin(num='26',name='VSSA',func=pin_types.PWRIN),
            Pin(num='27',name='VREFH/VREF_OUT',func=pin_types.BIDIR),
            Pin(num='28',name='VDDA',func=pin_types.PWRIN),
            Pin(num='29',name='XTAL_OUT',func=pin_types.OUTPUT),
            Pin(num='3',name='PTA2',func=pin_types.BIDIR),
            Pin(num='30',name='EXTAL',func=pin_types.INPUT),
            Pin(num='31',name='XTAL',func=pin_types.INPUT),
            Pin(num='32',name='VDD_RF3',func=pin_types.PWRIN),
            Pin(num='33',name='ANT',func=pin_types.PASSIVE),
            Pin(num='34',name='GANT',func=pin_types.PWRIN),
            Pin(num='35',name='VDD_RF2',func=pin_types.PWRIN),
            Pin(num='36',name='VDD_RF1',func=pin_types.PWRIN),
            Pin(num='37',name='PTC1',func=pin_types.BIDIR),
            Pin(num='38',name='PTC2',func=pin_types.BIDIR),
            Pin(num='39',name='PTC3',func=pin_types.BIDIR),
            Pin(num='4',name='PTA16',func=pin_types.BIDIR),
            Pin(num='40',name='PTC4',func=pin_types.BIDIR),
            Pin(num='41',name='PTC5',func=pin_types.BIDIR),
            Pin(num='42',name='PTC6',func=pin_types.BIDIR),
            Pin(num='43',name='PTC7',func=pin_types.BIDIR),
            Pin(num='44',name='VDD_1',func=pin_types.PWRIN),
            Pin(num='45',name='PTC16',func=pin_types.BIDIR),
            Pin(num='46',name='PTC17',func=pin_types.BIDIR),
            Pin(num='47',name='PTC18',func=pin_types.BIDIR),
            Pin(num='48',name='PTC19',func=pin_types.BIDIR),
            Pin(num='49',name='VSS',func=pin_types.PWRIN),
            Pin(num='5',name='PTA17',func=pin_types.BIDIR),
            Pin(num='6',name='PTA18',func=pin_types.BIDIR),
            Pin(num='7',name='PTA19',func=pin_types.BIDIR),
            Pin(num='8',name='PSWITCH',func=pin_types.INPUT),
            Pin(num='9',name='DCDC_CFG',func=pin_types.INPUT)], 'unit_defs':[] })])